@@ -21,9 +21,12 @@ import java.io.IOException;
 import java.net.InetAddress;
 import java.rmi.dgc.VMID;
 import java.security.Principal;
+import java.security.PrivilegedAction;
+import java.security.PrivilegedExceptionAction;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Calendar;
+import java.util.Collections;
 import java.util.Date;
 import java.util.GregorianCalendar;
 import java.util.HashMap;
@@ -41,7 +44,9 @@ import javax.security.auth.Subject;
 import javax.security.auth.login.AppConfigurationEntry;
 import javax.security.auth.login.Configuration;
 import javax.security.auth.login.LoginContext;
+import javax.security.auth.login.LoginException;
 
+import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -77,7 +82,7 @@ public class MiscUtil {
 	private static String sApplicationType = null;
 	private static UserGroupInformation ugiLoginUser = null;
 	private static Subject subjectLoginUser = null;
-	private static String local_hostname = null ;
+	private static String local_hostname = null;
 
 	private static Map<String, LogHistory> logHistoryList = new Hashtable<String, LogHistory>();
 	private static int logInterval = 30000; // 30 seconds
@@ -88,7 +93,7 @@ public class MiscUtil {
 					"yyyy-MM-dd HH:mm:ss.SSS").create();
 		} catch (Throwable excp) {
 			LogLog.warn(
-					"failed to create GsonBuilder object. stringigy() will return obj.toString(), instead of Json",
+					"failed to create GsonBuilder object. stringify() will return obj.toString(), instead of Json",
 					excp);
 		}
 
@@ -482,7 +487,9 @@ public class MiscUtil {
 	}
 
 	public static UserGroupInformation getUGILoginUser() {
-		if (ugiLoginUser == null) {
+		UserGroupInformation ret = ugiLoginUser;
+
+		if (ret == null) {
 			try {
 				// Do not cache ugiLoginUser if it is not explicitly set with
 				// setUGILoginUser.
@@ -491,12 +498,45 @@ public class MiscUtil {
 				// in when the token is scheduled to expire. So it is better
 				// to get the user object every time from UserGroupInformation class and
 				// not cache it
-				return getLoginUser();
+				ret = getLoginUser();
 			} catch (IOException e) {
 				logger.error("Error getting UGI.", e);
 			}
 		}
-		return ugiLoginUser;
+
+		if(ret != null) {
+			try {
+			ret.checkTGTAndReloginFromKeytab();
+			} catch(IOException ioe) {
+				logger.error("Error renewing TGT and relogin. Ignoring Exception, and continuing with the old TGT", ioe);
+			}
+		}
+
+		return ret;
+	}
+
+	/**
+	 * Execute the {@link PrivilegedExceptionAction} on the {@link UserGroupInformation} if it's set, otherwise call it directly
+	 */
+	public static <X> X executePrivilegedAction(final PrivilegedExceptionAction<X> action) throws Exception {
+		final UserGroupInformation ugi = getUGILoginUser();
+		if (ugi != null) {
+			return ugi.doAs(action);
+		} else {
+			return action.run();
+		}
+	}
+
+	/**
+	 * Execute the {@link PrivilegedAction} on the {@link UserGroupInformation} if it's set, otherwise call it directly.
+	 */
+	public static <X> X executePrivilegedAction(final PrivilegedAction<X> action) {
+		final UserGroupInformation ugi = getUGILoginUser();
+		if (ugi != null) {
+			return ugi.doAs(action);
+		} else {
+			return action.run();
+		}
 	}
 
 	public static Subject getSubjectLoginUser() {
@@ -507,7 +547,7 @@ public class MiscUtil {
 		return KerberosName.getRules();
 	}
 	/**
-	 * 
+	 *
 	 * @param principal
 	 *            This could be in the format abc/host@domain.com
 	 * @return
@@ -535,25 +575,24 @@ public class MiscUtil {
 	 * @return
 	 */
 	static public Set<String> getGroupsForRequestUser(String userName) {
-		if (userName == null) {
-			return null;
-		}
-		try {
-			UserGroupInformation ugi = UserGroupInformation
-					.createRemoteUser(userName);
-			String groups[] = ugi.getGroupNames();
-			if (groups != null && groups.length > 0) {
-				Set<String> groupsSet = new java.util.HashSet<String>();
-				for (int i = 0; i < groups.length; i++) {
-					groupsSet.add(groups[i]);
+		if (userName != null) {
+			try {
+				UserGroupInformation ugi = UserGroupInformation
+						.createRemoteUser(userName);
+				String[] groups = ugi.getGroupNames();
+				if (groups != null && groups.length > 0) {
+					Set<String> groupsSet = new java.util.HashSet<String>();
+					for (String group : groups) {
+						groupsSet.add(group);
+					}
+					return groupsSet;
 				}
-				return groupsSet;
+			} catch (Throwable e) {
+				logErrorMessageByInterval(logger,
+						"Error getting groups for users. userName=" + userName, e);
 			}
-		} catch (Throwable e) {
-			logErrorMessageByInterval(logger,
-					"Error getting groups for users. userName=" + userName, e);
 		}
-		return null;
+		return Collections.emptySet();
 	}
 
 	static public boolean logErrorMessageByInterval(Log useLogger,
@@ -597,7 +636,50 @@ public class MiscUtil {
 
 	}
 
-	public static void authWithConfig(String appName, Configuration config) {
+	public static void setUGIFromJAASConfig(String jaasConfigAppName) throws Exception {
+		String keytabFile 			= null;
+		String principal  			= null;
+		UserGroupInformation ugi 	= null;
+		if (logger.isDebugEnabled()){
+			logger.debug("===> MiscUtil.setUGIFromJAASConfig() jaasConfigAppName: " + jaasConfigAppName);
+		}
+		try {
+			AppConfigurationEntry entries[] = Configuration.getConfiguration().getAppConfigurationEntry(jaasConfigAppName);
+			if(!ArrayUtils.isEmpty(entries)) {
+				for (AppConfigurationEntry entry : entries) {
+					if (entry.getOptions().get("keyTab") != null) {
+						keytabFile = (String) entry.getOptions().get("keyTab");
+					}
+					if (entry.getOptions().get("principal") != null) {
+						principal = (String) entry.getOptions().get("principal");
+					}
+					if (!StringUtils.isEmpty(principal) && !StringUtils.isEmpty(keytabFile)) {
+						break;
+					}
+				}
+				if (!StringUtils.isEmpty(principal) && !StringUtils.isEmpty(keytabFile)) {
+					// This will login and set the UGI
+					UserGroupInformation.loginUserFromKeytab(principal, keytabFile);
+					ugi = UserGroupInformation.getLoginUser();
+				} else {
+					String error_mesage = "Unable to get the principal/keytab from jaasConfigAppName: " + jaasConfigAppName;
+					logger.error(error_mesage);
+					throw new Exception(error_mesage);
+				}
+				logger.info("MiscUtil.setUGIFromJAASConfig() UGI: " + ugi + " principal: " + principal + " keytab: " + keytabFile);
+			} else {
+				logger.warn("JAASConfig file not found! Ranger Plugin will not working in a Secure Cluster...");
+			}
+		} catch ( Exception e) {
+			logger.error("Unable to set UGI for Principal: " + principal + " keytab: " + keytabFile );
+			throw e;
+		}
+		if (logger.isDebugEnabled()) {
+			logger.debug("<=== MiscUtil.setUGIFromJAASConfig() jaasConfigAppName: " + jaasConfigAppName + " UGI: " + ugi + " principal: " + principal + " keytab: " + keytabFile);
+		}
+	}
+        public static void authWithConfig(String appName, Configuration config) throws LoginException {
+                LoginContext loginContext = null;
 		try {
 			if (config != null) {
 				logger.info("Getting AppConfigrationEntry[] for appName="
@@ -618,7 +700,7 @@ public class MiscUtil {
 					}
 				}
 
-				LoginContext loginContext = new LoginContext(appName,
+                                loginContext = new LoginContext(appName,
 						new Subject(), null, config);
 				logger.info("Login in for appName=" + appName);
 				loginContext.login();
@@ -643,6 +725,10 @@ public class MiscUtil {
 		} catch (Throwable t) {
 			logger.fatal("Error logging as appName=" + appName + ", config="
 					+ config.toString() + ", error=" + t.getMessage());
+                } finally {
+                        if (loginContext != null) {
+                                loginContext.logout();
+                        }
 		}
 	}
 
@@ -655,6 +741,7 @@ public class MiscUtil {
 		Subject serverSubject = new Subject();
 		int successLoginCount = 0;
 		String[] spnegoPrincipals = null;
+
 		try {
 			if (principal.equals("*")) {
 				spnegoPrincipals = KerberosUtil.getPrincipalNames(keytab,
@@ -673,6 +760,7 @@ public class MiscUtil {
 			boolean useKeytab = true;
 			if (!useKeytab) {
 				logger.info("Creating UGI with subject");
+                                LoginContext loginContext = null;
 				List<LoginContext> loginContexts = new ArrayList<LoginContext>();
 				for (String spnegoPrincipal : spnegoPrincipals) {
 					try {
@@ -680,7 +768,7 @@ public class MiscUtil {
 								+ ", for principal " + spnegoPrincipal);
 						final KerberosConfiguration kerberosConfiguration = new KerberosConfiguration(
 								keytab, spnegoPrincipal);
-						final LoginContext loginContext = new LoginContext("",
+                                                loginContext = new LoginContext("",
 								serverSubject, null, kerberosConfiguration);
 						loginContext.login();
 						successLoginCount++;
@@ -705,6 +793,10 @@ public class MiscUtil {
 						} catch (Throwable e) {
 							logger.error("Error creating UGI from subject. subject="
 									+ serverSubject);
+                                                } finally {
+                                                        if (loginContext != null) {
+                                                                loginContext.logout();
+                                                        }
 						}
 					} else {
 						logger.error("Total logins were successfull from keytab="
@@ -786,14 +878,12 @@ public class MiscUtil {
 	}
 
 	public static UserGroupInformation getLoginUser() throws IOException {
-		UserGroupInformation ugi = UserGroupInformation.getLoginUser();
-		ugi.checkTGTAndReloginFromKeytab();
-		return ugi;
+		return UserGroupInformation.getLoginUser();
 	}
 
-	private static  void initLocalHost() {
+	private static void initLocalHost() {
 		if ( logger.isDebugEnabled() ) {
-			logger.debug("==> MiscUti.initLocalHost()");
+			logger.debug("==> MiscUtil.initLocalHost()");
 		}
 
 		try {
@@ -802,7 +892,7 @@ public class MiscUtil {
 			LogLog.warn("getHostname()", excp);
 		}
 		if ( logger.isDebugEnabled() ) {
-			logger.debug("<== MiscUti.initLocalHost()");
+			logger.debug("<== MiscUtil.initLocalHost()");
 		}
 	}
 	public static Date getUTCDateForLocalDate(Date date) {
