@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -28,7 +28,6 @@ import java.io.FileReader;
 import java.io.FileWriter;
 import java.io.IOException;
 import java.io.PrintWriter;
-import java.security.PrivilegedAction;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
@@ -41,6 +40,7 @@ import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.log4j.MDC;
 import org.apache.ranger.audit.model.AuditEventBase;
 import org.apache.ranger.audit.provider.AuditHandler;
 import org.apache.ranger.audit.provider.MiscUtil;
@@ -375,7 +375,7 @@ public class AuditFileSpool implements Runnable {
 	/**
 	 * If any files are still not processed. Also, if the destination is not
 	 * reachable
-	 * 
+	 *
 	 * @return
 	 */
 	public boolean isPending() {
@@ -390,7 +390,7 @@ public class AuditFileSpool implements Runnable {
 
 	/**
 	 * Milliseconds from last attempt time
-	 * 
+	 *
 	 * @return
 	 */
 	public long getLastAttemptTimeDelta() {
@@ -458,7 +458,7 @@ public class AuditFileSpool implements Runnable {
 	/**
 	 * This return the current file. If there are not current open output file,
 	 * then it will return null
-	 * 
+	 *
 	 * @return
 	 * @throws Exception
 	 */
@@ -567,7 +567,7 @@ public class AuditFileSpool implements Runnable {
 
 	/**
 	 * Load the index file
-	 * 
+	 *
 	 * @throws IOException
 	 */
 	void loadIndexFile() throws IOException {
@@ -747,32 +747,22 @@ public class AuditFileSpool implements Runnable {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see java.lang.Runnable#run()
 	 */
 	@Override
 	public void run() {
 		try {
-			if (MiscUtil.getUGILoginUser() != null) {
-				PrivilegedAction<Void> action = new PrivilegedAction<Void>() {
-					public Void run() {
-						runDoAs();
-						return null;
-					};
-				};
-				logger.info("Running fileSpool " + consumerProvider.getName()
-						+ " as user " + MiscUtil.getUGILoginUser());
-				MiscUtil.getUGILoginUser().doAs(action);
-			} else {
-				runDoAs();
-			}
+			//This is done to clear the MDC context to avoid issue with Ranger Auditing for Knox
+			MDC.clear();
+			runLogAudit();
 		} catch (Throwable t) {
 			logger.fatal("Exited thread without abnormaly. queue="
 					+ consumerProvider.getName(), t);
 		}
 	}
 
-	public void runDoAs() {
+	public void runLogAudit() {
 		// boolean isResumed = false;
 		while (true) {
 			try {
