@@ -154,7 +154,14 @@ fi
 
 if [ "${HCOMPONENT_INSTALL_DIR_NAME}" = "" ]
 then
-	HCOMPONENT_INSTALL_DIR_NAME=${HCOMPONENT_NAME}
+    if [ "${HCOMPONENT_NAME}" = "knox" ];
+    then
+        HCOMPONENT_INSTALL_DIR_NAME=$(getInstallProperty 'KNOX_HOME')
+    fi
+    if [ "${HCOMPONENT_INSTALL_DIR_NAME}" = "" ]
+    then
+	    HCOMPONENT_INSTALL_DIR_NAME=${HCOMPONENT_NAME}
+    fi
 fi
 
 firstletter=${HCOMPONENT_INSTALL_DIR_NAME:0:1}
@@ -694,13 +701,13 @@ then
             }
             {
                 if ($1 == "nimbus.authorizer") {
-                    if ($2 ~ /^[ \t]*"backtype.storm.security.auth.authorizer.SimpleACLAuthorizer"[ \t]*$/) {
+                    if ($2 ~ /^[ \t]*"org.apache.storm.security.auth.authorizer.SimpleACLAuthorizer"[ \t]*$/) {
                         configured = 1 ;
                         printf("%s\n",$0) ;
                     }
                     else {
                         printf("#%s\n",$0);
-                        printf("nimbus.authorizer: \"backtype.storm.security.auth.authorizer.SimpleACLAuthorizer\"\n") ;
+                        printf("nimbus.authorizer: \"org.apache.storm.security.auth.authorizer.SimpleACLAuthorizer\"\n") ;
                         configured = 1 ;
                     }
                 }
@@ -710,7 +717,7 @@ then
             }
             END {
                 if (configured == 0) {
-                    printf("nimbus.authorizer: \"backtype.storm.security.auth.authorizer.SimpleACLAuthorizer\"\n") ;
+                    printf("nimbus.authorizer: \"org.apache.storm.security.auth.authorizer.SimpleACLAuthorizer\"\n") ;
                 }
             }' ${CFG_FILE} > ${CFG_FILE}.new &&  cat ${CFG_FILE}.new > ${CFG_FILE} && rm -f ${CFG_FILE}.new	
 		fi
