@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -27,12 +27,15 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.plugin.errors.ValidationErrorCode;
 import org.apache.ranger.plugin.model.RangerPolicy;
+import org.apache.ranger.plugin.model.RangerPolicy.RangerDataMaskPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemAccess;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
+import org.apache.ranger.plugin.model.RangerPolicy.RangerRowFilterPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicyResourceSignature;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.model.RangerServiceDef;
+import org.apache.ranger.plugin.model.RangerServiceDef.RangerAccessTypeDef;
 import org.apache.ranger.plugin.model.RangerServiceDef.RangerResourceDef;
 import org.apache.ranger.plugin.store.ServiceStore;
 
@@ -302,6 +305,7 @@ public class RangerPolicyValidator extends RangerValidator {
 
 			if (serviceNameValid) { // resource checks can't be done meaningfully otherwise
 				valid = isValidResources(policy, failures, action, isAdmin, serviceDef) && valid;
+				valid = isValidAccessTypeDef(policy, failures, action, isAdmin, serviceDef) && valid;
 			}
 		}
 		
@@ -311,7 +315,80 @@ public class RangerPolicyValidator extends RangerValidator {
 		return valid;
 	}
 	
-	boolean isValidResources(RangerPolicy policy, final List<ValidationFailureDetails> failures, Action action, 
+	boolean isValidAccessTypeDef(RangerPolicy policy, final List<ValidationFailureDetails> failures, Action action,boolean isAdmin, final RangerServiceDef serviceDef) {
+		boolean valid = true;
+		if(LOG.isDebugEnabled()) {
+			LOG.debug(String.format("==> RangerPolicyValidator.isValidAccessTypeDef(%s, %s, %s,%s,%s)", policy, failures, action,isAdmin,serviceDef));
+		}
+		int policyType=policy.getPolicyType() == null ? RangerPolicy.POLICY_TYPE_ACCESS : policy.getPolicyType();
+		//row filter policy
+		if (policyType==RangerPolicy.POLICY_TYPE_ROWFILTER){
+			List<String> rowFilterAccessTypeDefNames=new ArrayList<String>();
+			if(serviceDef!=null && serviceDef.getRowFilterDef()!=null){
+				if(!CollectionUtils.isEmpty(serviceDef.getRowFilterDef().getAccessTypes())){
+					for(RangerAccessTypeDef rangerAccessTypeDef:serviceDef.getRowFilterDef().getAccessTypes()){
+						rowFilterAccessTypeDefNames.add(rangerAccessTypeDef.getName().toLowerCase());
+					}
+				}
+			}
+
+			if(!CollectionUtils.isEmpty(policy.getRowFilterPolicyItems())){
+				for(RangerRowFilterPolicyItem rangerRowFilterPolicyItem:policy.getRowFilterPolicyItems()){
+					if(!CollectionUtils.isEmpty(rangerRowFilterPolicyItem.getAccesses())){
+						for(RangerPolicyItemAccess rangerPolicyItemAccess : rangerRowFilterPolicyItem.getAccesses()){
+							if(!rowFilterAccessTypeDefNames.contains(rangerPolicyItemAccess.getType().toLowerCase())){
+								ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_POLICY_ITEM_ACCESS_TYPE_INVALID;
+								failures.add(new ValidationFailureDetailsBuilder()
+									.field("row filter policy item access type")
+									.isSemanticallyIncorrect()
+									.becauseOf(error.getMessage(rangerPolicyItemAccess.getType(), rowFilterAccessTypeDefNames))
+									.errorCode(error.getErrorCode())
+									.build());
+								valid = false;
+							}
+						}
+					}
+				}
+			}
+		}
+		//data mask policy
+		if (policyType==RangerPolicy.POLICY_TYPE_DATAMASK){
+			List<String> dataMaskAccessTypeDefNames=new ArrayList<String>();
+			if(serviceDef!=null && serviceDef.getDataMaskDef()!=null){
+				if(!CollectionUtils.isEmpty(serviceDef.getDataMaskDef().getAccessTypes())){
+					for(RangerAccessTypeDef rangerAccessTypeDef:serviceDef.getDataMaskDef().getAccessTypes()){
+						dataMaskAccessTypeDefNames.add(rangerAccessTypeDef.getName().toLowerCase());
+					}
+				}
+			}
+
+			if(!CollectionUtils.isEmpty(policy.getDataMaskPolicyItems())){
+				for(RangerDataMaskPolicyItem rangerDataMaskPolicyItem:policy.getDataMaskPolicyItems()){
+					if(!CollectionUtils.isEmpty(rangerDataMaskPolicyItem.getAccesses())){
+						for(RangerPolicyItemAccess rangerPolicyItemAccess : rangerDataMaskPolicyItem.getAccesses()){
+							if(!dataMaskAccessTypeDefNames.contains(rangerPolicyItemAccess.getType().toLowerCase())){
+								ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_POLICY_ITEM_ACCESS_TYPE_INVALID;
+								failures.add(new ValidationFailureDetailsBuilder()
+									.field("data masking policy item access type")
+									.isSemanticallyIncorrect()
+									.becauseOf(error.getMessage(rangerPolicyItemAccess.getType(), dataMaskAccessTypeDefNames))
+									.errorCode(error.getErrorCode())
+									.build());
+								valid = false;
+							}
+						}
+					}
+				}
+			}
+		}
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug(String.format("<== RangerPolicyValidator.isValidAccessTypeDef(%s, %s, %s,%s,%s)", policy, failures, action,isAdmin,serviceDef));
+		}
+		return valid;
+	}
+
+	boolean isValidResources(RangerPolicy policy, final List<ValidationFailureDetails> failures, Action action,
 			boolean isAdmin, final RangerServiceDef serviceDef) {
 		
 		if(LOG.isDebugEnabled()) {
@@ -385,10 +462,10 @@ public class RangerPolicyValidator extends RangerValidator {
 			LOG.warn("RangerPolicyValidator.isValidResourceNames: serviceDef does not have any resource hierarchies, possibly due to a old/migrated service def!  Skipping this check!");
 		} else {
 			/*
-			 * A policy is for a single hierarchy however, it doesn't specify which one.  So we have to guess which hierarchy(s) it possibly be for.  First, see if the policy could be for 
+			 * A policy is for a single hierarchy however, it doesn't specify which one.  So we have to guess which hierarchy(s) it possibly be for.  First, see if the policy could be for
 			 * any of the known hierarchies?  A candidate hierarchy is one whose resource levels are a superset of those in the policy.
 			 * Why?  What we want to catch at this stage is policies that straddles multiple hierarchies, e.g. db, udf and column for a hive policy.
-			 * This has the side effect of catch spurious levels specified on the policy, e.g. having a level "blah" on a hive policy.  
+			 * This has the side effect of catch spurious levels specified on the policy, e.g. having a level "blah" on a hive policy.
 			 */
 			Set<List<RangerResourceDef>> candidateHierarchies = filterHierarchies_hierarchyHasAllPolicyResources(policyResources, hierarchies, defHelper);
 			if (candidateHierarchies.isEmpty()) {
@@ -450,7 +527,7 @@ public class RangerPolicyValidator extends RangerValidator {
 	}
 	
 	/**
-	 * String representation of mandatory resources of all the hierarchies suitable of showing to user.  Mandatory resources within a hierarchy are not ordered per the hierarchy. 
+	 * String representation of mandatory resources of all the hierarchies suitable of showing to user.  Mandatory resources within a hierarchy are not ordered per the hierarchy.
 	 * @param hierarchies
 	 * @param defHelper
 	 * @return
@@ -483,7 +560,7 @@ public class RangerPolicyValidator extends RangerValidator {
 		return builder.toString();
 	}
 	/**
-	 * Returns the subset of all hierarchies that are a superset of the policy's resources. 
+	 * Returns the subset of all hierarchies that are a superset of the policy's resources.
 	 * @param policyResources
 	 * @param hierarchies
 	 * @return
@@ -502,7 +579,7 @@ public class RangerPolicyValidator extends RangerValidator {
 	}
 	
 	/**
-	 * Returns the subset of hierarchies all of whose mandatory resources were found in policy's resource set.  candidate hierarchies are expected to have passed 
+	 * Returns the subset of hierarchies all of whose mandatory resources were found in policy's resource set.  candidate hierarchies are expected to have passed
 	 * <code>filterHierarchies_hierarchyHasAllPolicyResources</code> check first.
 	 * @param policyResources
 	 * @param hierarchies
