@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -26,6 +26,7 @@ import java.util.Set;
 import java.util.List;
 
 import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -35,6 +36,7 @@ import org.apache.ranger.plugin.model.RangerServiceDef.RangerResourceDef;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.validation.RangerServiceDefHelper;
 import org.apache.ranger.plugin.policyengine.RangerAccessResource;
+import org.apache.ranger.plugin.policyengine.RangerAccessResourceImpl;
 import org.apache.ranger.plugin.resourcematcher.RangerDefaultResourceMatcher;
 import org.apache.ranger.plugin.resourcematcher.RangerResourceMatcher;
 
@@ -50,6 +52,16 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
 	private Map<String, RangerResourceMatcher> matchers = null;
 	private boolean                            needsDynamicEval = false;
 	private List<RangerResourceDef> firstValidResourceDefHierarchy;
+	/*
+	 * For hive resource policy:
+	 * 	lastNonAnyMatcherIndex will be set to
+	 * 		0 : if all matchers in policy are '*'; such as database=*, table=*, column=*
+	 * 		1 : database=hr, table=*, column=*
+	 * 		2 : database=<any>, table=employee, column=*
+	 * 		3 : database=<any>, table=<any>, column=ssn
+	 */
+	private int lastNonAnyMatcherIndex = 0;
+
 
 	@Override
 	public void setServiceDef(RangerServiceDef serviceDef) {
@@ -143,6 +155,9 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
 									needsDynamicEval = true;
 								}
 								matchers.put(resourceName, matcher);
+								if (!matcher.isMatchAny()) {
+									lastNonAnyMatcherIndex = matchers.size();
+								}
 							} else {
 								LOG.error("failed to find matcher for resource " + resourceName);
 							}
@@ -198,51 +213,6 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
 		return matchers != null ? matchers.get(resourceName) : null;
 	}
 
-	public boolean isMatch(RangerAccessResource resource, Map<String, Object> evalContext) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyResourceMatcher.isMatch(" + resource + ", " + evalContext + ")");
-		}
-
-		boolean ret = false;
-
-		if(serviceDef != null && serviceDef.getResources() != null) {
-			Collection<String> resourceKeys = resource == null ? null : resource.getKeys();
-			Collection<String> policyKeys   = matchers == null ? null : matchers.keySet();
-
-			boolean keysMatch = CollectionUtils.isEmpty(resourceKeys) || (policyKeys != null && policyKeys.containsAll(resourceKeys));
-
-			if(keysMatch) {
-				for(RangerResourceDef resourceDef : serviceDef.getResources()) {
-					String                resourceName  = resourceDef.getName();
-					String                resourceValue = resource == null ? null : resource.getValue(resourceName);
-					RangerResourceMatcher matcher       = matchers == null ? null : matchers.get(resourceName);
-
-					// when no value exists for a resourceName, consider it a match only if: policy doesn't have a matcher OR matcher allows no-value resource
-					if(StringUtils.isEmpty(resourceValue)) {
-						ret = matcher == null || matcher.isMatch(resourceValue, evalContext);
-					} else {
-						ret = matcher != null && matcher.isMatch(resourceValue, evalContext);
-					}
-
-					if(! ret) {
-						break;
-					}
-				}
-			} else {
-				if(LOG.isDebugEnabled()) {
-					LOG.debug("isMatch(): keysMatch=false. isMatch=" + resourceKeys + "; policyKeys=" + policyKeys);
-				}
-			}
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyResourceMatcher.isMatch(" + resource  + ", " + evalContext + "): " + ret);
-		}
-
-		return ret;
-	}
-
-
 	@Override
 	public boolean isMatch(Map<String, RangerPolicyResource> resources, Map<String, Object> evalContext) {
 		if(LOG.isDebugEnabled()) {
@@ -343,119 +313,318 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
 	}
 
 	@Override
-	public boolean isHeadMatch(RangerAccessResource resource, Map<String, Object> evalContext) {
-
+	public boolean isCompleteMatch(Map<String, RangerPolicyResource> resources, Map<String, Object> evalContext) {
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyResourceMatcher.isHeadMatch(" + resource + ", " + evalContext + ")");
+			LOG.debug("==> RangerDefaultPolicyResourceMatcher.isCompleteMatch(" + resources + ", " + evalContext + ")");
 		}
 
 		boolean ret = false;
 
-		if (matchers == null) {
+		if(serviceDef != null && serviceDef.getResources() != null) {
+			Collection<String> resourceKeys = resources == null ? null : resources.keySet();
+			Collection<String> policyKeys   = matchers == null ? null : matchers.keySet();
 
-			LOG.debug("RangerDefaultPolicyResourceMatcher.isHeadMatch(): PolicyResourceMatcher not initialized correctly!!!");
-			ret = false;
+			boolean keysMatch = false;
 
-		} else if (resource == null || CollectionUtils.isEmpty(resource.getKeys())) { // sanity-check, firewalling
+			if (resourceKeys != null && policyKeys != null) {
+				keysMatch = CollectionUtils.isEqualCollection(resourceKeys, policyKeys);
+			}
 
-			LOG.debug("RangerDefaultPolicyResourceMatcher.isHeadMatch: resource was null/empty!");
-			ret = true; // null resource matches anything
+			if(keysMatch) {
+				for(RangerResourceDef resourceDef : serviceDef.getResources()) {
+					String                resourceName   = resourceDef.getName();
+					RangerPolicyResource  resourceValues = resources == null ? null : resources.get(resourceName);
+					RangerPolicyResource  policyValues   = policyResources == null ? null : policyResources.get(resourceName);
 
-		} else {
-
-			ret = newIsHeadMatch(resource, evalContext);
+					if(resourceValues == null || CollectionUtils.isEmpty(resourceValues.getValues())) {
+						ret = (policyValues == null || CollectionUtils.isEmpty(policyValues.getValues()));
+					} else if(policyValues != null && CollectionUtils.isNotEmpty(policyValues.getValues())) {
+						ret = CollectionUtils.isEqualCollection(resourceValues.getValues(), policyValues.getValues());
+					}
 
+					if(! ret) {
+						break;
+					}
+				}
+			} else {
+				if(LOG.isDebugEnabled()) {
+					LOG.debug("isCompleteMatch(): keysMatch=false. resourceKeys=" + resourceKeys + "; policyKeys=" + policyKeys);
+				}
+			}
 		}
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyResourceMatcher.matchResourceHead(" + resource + ", " + evalContext  + "): " + ret);
+			LOG.debug("<== RangerDefaultPolicyResourceMatcher.isCompleteMatch(" + resources + ", " + evalContext + "): " + ret);
 		}
 
 		return ret;
 	}
 
 	@Override
-	public boolean isExactHeadMatch(RangerAccessResource resource, Map<String, Object> evalContext) {
+	public boolean isMatch(RangerAccessResource resource, Map<String, Object> evalContext) {
+		return isMatch(resource, MatchScope.SELF_OR_ANCESTOR, evalContext);
+	}
 
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyResourceMatcher.isExactHeadMatch(" + resource + ", " + evalContext + ")");
-		}
+	@Override
+	public boolean isMatch(RangerPolicy policy, MatchScope scope, Map<String, Object> evalContext) {
 
 		boolean ret = false;
+		MatchType matchType = MatchType.NONE;
 
-		if (matchers == null) {
+		Map<String, RangerPolicyResource> resources = policy.getResources();
 
-			LOG.debug("RangerDefaultPolicyResourceMatcher.isExactHeadMatch(): PolicyResourceMatcher not initialized correctly!!!");
-			ret = false;
+		if (MapUtils.isNotEmpty(resources)) {
 
-		} else if (resource == null || CollectionUtils.isEmpty(resource.getKeys())) { // sanity-check, firewalling
+			RangerAccessResourceImpl accessResource = new RangerAccessResourceImpl();
+			accessResource.setServiceDef(serviceDef);
 
-			LOG.debug("RangerDefaultPolicyResourceMatcher.isExactHeadMatch: resource was null/empty!");
-			ret = false;
+			// Build up accessResource resourceDef by resourceDef.
+			// For each resourceDef,
+			// 		examine policy-values one by one.
+			// 		The first value that is acceptable, that is,
+			// 			value matches in any way, is used for that resourceDef, and
+			//			next resourceDef is processed.
+			// 		If none of the values matches, the policy as a whole definitely will not match,
+			//		therefore, the match is failed
+			// After all resourceDefs are processed, and some match is achieved at every
+			// level, the final matchType (which is for the entire policy) is checked against
+			// requested scope to determine the match-result.
 
-		} else if (matchers.size() > resource.getKeys().size()) {
+			// Unit tests in TestDefaultPolicyResourceForPolicy.java, test_defaultpolicyresourcematcher_for_policy.json,
+			// and test_defaultpolicyresourcematcher_for_hdfs_policy.json
 
-			LOG.debug("RangerDefaultPolicyResourceMatcher.isExactHeadMatch: more levels specified in PolicyResourceMatcher than in resource being matched!!");
-			ret = false;
+			for (RangerResourceDef resourceDef : firstValidResourceDefHierarchy) {
 
+				ret = false;
+				matchType = MatchType.NONE;
+
+				String name = resourceDef.getName();
+				RangerPolicyResource policyResource = resources.get(name);
+
+				if (policyResource != null) {
+					for (String value : policyResource.getValues()) {
+
+						accessResource.setValue(name, value);
+
+						matchType = getMatchType(accessResource, evalContext);
+
+						if (matchType != MatchType.NONE) { // One value for this resourceDef matched
+							ret = true;
+							break;
+						}
+					}
+				}
+
+				if (!ret) { // None of the values specified for this resourceDef matched, no point in continuing with next resourceDef
+					break;
+				}
+			}
+			ret = ret && isMatch(scope, matchType);
+		}
+		return ret;
+	}
+
+	@Override
+	public boolean isMatch(RangerAccessResource resource, MatchScope scope, Map<String, Object> evalContext) {
+
+		final boolean ret;
+
+		MatchType matchType = getMatchType(resource, evalContext);
+		ret = isMatch(scope, matchType);
+
+		return ret;
+	}
+
+	@Override
+	public MatchType getMatchType(RangerAccessResource resource, Map<String, Object> evalContext) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerDefaultPolicyResourceMatcher.getMatchType(" + resource + evalContext + ")");
+		}
+
+		int matchersSize = matchers == null ? 0 : matchers.size();
+		int resourceKeysSize = resource == null || resource.getKeys() == null ? 0 : resource.getKeys().size();
+
+		MatchType ret = MatchType.NONE;
+
+		if (!isValid(resource)) {
+			ret = MatchType.NONE;
+		} else if (matchersSize == 0 || lastNonAnyMatcherIndex == 0) {
+			ret = resourceKeysSize == 0 ? MatchType.SELF : MatchType.ANCESTOR;
+		} else if (resourceKeysSize == 0) {
+			ret = MatchType.DESCENDANT;
 		} else {
+			int index = 0;
+			for (RangerResourceDef resourceDef : firstValidResourceDefHierarchy) {
 
-			ret = newIsHeadMatch(resource, evalContext);
+				String resourceName = resourceDef.getName();
+				RangerResourceMatcher matcher = matchers.get(resourceName);
+				String resourceValue = resource.getValue(resourceName);
+
+				if (resourceValue != null) {
+					if (matcher != null) {
+						index++;
+						if (matcher.isMatch(resourceValue, evalContext)) {
+							ret = index == resourceKeysSize && matcher.isMatchAny() ? MatchType.ANCESTOR : MatchType.SELF;
+						} else {
+							ret = MatchType.NONE;
+							break;
+						}
+					} else {
+						// More resource-levels than matchers
+						ret = MatchType.ANCESTOR;
+						break;
+					}
+				} else {
+					if (matcher != null) {
+						// More matchers than resource-levels
+						if (index >= lastNonAnyMatcherIndex) {
+							// All AnyMatch matchers after this
+							ret = MatchType.ANCESTOR;
+						} else {
+							ret = MatchType.DESCENDANT;
+						}
+					} else {
+						// Common part of several possible hierarchies matched
+						if (resourceKeysSize > index) {
+							ret = MatchType.ANCESTOR;
+						}
+					}
+					break;
+				}
+			}
 
 		}
 
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyResourceMatcher.isExactHeadMatch(" + resource + ", " + evalContext + ")" + ret);
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerDefaultPolicyResourceMatcher.getMatchType(" + resource + evalContext + "): " + ret);
 		}
 
 		return ret;
 	}
 
-	private boolean newIsHeadMatch(RangerAccessResource resource, Map<String, Object> evalContext) {
-
-		if (LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyResourceMatcher.newIsHeadMatch(" + resource + ", " + evalContext + ")");
-		}
-
-		boolean skipped = false;
-		boolean matched = true;
-
-		for (RangerResourceDef resourceDef : firstValidResourceDefHierarchy) {
-
-			String resourceName = resourceDef.getName();
-			String resourceValue = resource.getValue(resourceName);
-			RangerResourceMatcher matcher = matchers.get(resourceName);
-
-			if (matcher != null) {
-
-				if (StringUtils.isNotBlank(resourceValue)) {
-
-					if (!skipped) {
-
-						matched = matcher.isMatch(resourceValue, evalContext);
-
-					} else {
-
-						matched = false;
-
-					}
-				} else {
-
-					skipped = true;
+	private boolean isValidResourceDefHierachyForResource(List<RangerResourceDef> resourceHierarchy, RangerAccessResource resource) {
+		boolean foundAllResourceKeys = true;
 
+		for (String resourceKey : resource.getKeys()) {
+			boolean found = false;
+			for (RangerResourceDef resourceDef : resourceHierarchy) {
+				if (resourceDef.getName().equals(resourceKey)) {
+					found = true;
+					break;
 				}
 			}
-
-			if (!matched) {
+			if (!found) {
+				foundAllResourceKeys = false;
 				break;
 			}
 		}
 
+		return foundAllResourceKeys;
+	}
+
+	private boolean isValid(RangerAccessResource resource) {
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyResourceMatcher.newIsHeadMatch(" + resource + ", " + evalContext + "): " + matched);
+			LOG.debug("==> RangerDefaultPolicyResourceMatcher.isValid(" + resource + ")");
 		}
 
-		return matched;
+		boolean ret = true;
+
+		if (matchers != null && resource != null && resource.getKeys() != null) {
+			if (matchers.keySet().containsAll(resource.getKeys()) || resource.getKeys().containsAll(matchers.keySet())) {
+
+				List<RangerResourceDef> aValidHierarchy = null;
+
+				if (resource.getKeys().containsAll(matchers.keySet()) && resource.getKeys().size() > matchers.keySet().size()) {
+					if (isValidResourceDefHierachyForResource(firstValidResourceDefHierarchy, resource)) {
+						aValidHierarchy = firstValidResourceDefHierarchy;
+					} else {
+						RangerServiceDefHelper serviceDefHelper = new RangerServiceDefHelper(serviceDef, false);
+						int policyType = policy != null && policy.getPolicyType() != null ? policy.getPolicyType() : RangerPolicy.POLICY_TYPE_ACCESS;
+						Set<List<RangerResourceDef>> validResourceHierarchies = serviceDefHelper.getResourceHierarchies(policyType);
+
+						for (List<RangerResourceDef> resourceHierarchy : validResourceHierarchies) {
+							if (resourceHierarchy == firstValidResourceDefHierarchy) { // Pointer comparison
+								// firstValidResourceDefHierarchy is already checked before and it does not match
+								continue;
+							}
+
+							if (isValidResourceDefHierachyForResource(resourceHierarchy, resource)) {
+								aValidHierarchy = resourceHierarchy;
+								break;
+							}
+						}
+					}
+				} else {
+					aValidHierarchy = firstValidResourceDefHierarchy;
+				}
+
+				if (aValidHierarchy != null) {
+					boolean skipped = false;
+
+					for (RangerResourceDef resourceDef : aValidHierarchy) {
+
+						String resourceName = resourceDef.getName();
+						String resourceValue = resource.getValue(resourceName);
+
+						if (resourceValue == null) {
+							if (!skipped) {
+								skipped = true;
+							}
+						} else {
+							if (skipped) {
+								ret = false;
+								break;
+							}
+						}
+
+					}
+				} else {
+					ret = false;
+				}
+			} else {
+				ret = false;
+			}
+		}
+
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerDefaultPolicyResourceMatcher.isValid(" + resource + "): " + ret);
+		}
+
+		return ret;
+	}
+
+	private boolean isMatch(final MatchScope scope, final MatchType matchType) {
+		final boolean ret;
+		switch (scope) {
+			case SELF_OR_ANCESTOR_OR_DESCENDANT: {
+				ret = matchType != MatchType.NONE;
+				break;
+			}
+			case SELF: {
+				ret = matchType == MatchType.SELF;
+				break;
+			}
+			case SELF_OR_DESCENDANT: {
+				ret = matchType == MatchType.SELF || matchType == MatchType.DESCENDANT;
+				break;
+			}
+			case SELF_OR_ANCESTOR: {
+				ret = matchType == MatchType.SELF || matchType == MatchType.ANCESTOR;
+				break;
+			}
+			case DESCENDANT: {
+				ret = matchType == MatchType.DESCENDANT;
+				break;
+			}
+			case ANCESTOR: {
+				ret = matchType == MatchType.ANCESTOR;
+				break;
+			}
+			default:
+				ret = matchType != MatchType.NONE;
+				break;
+		}
+		return ret;
 	}
 
 	@Override
@@ -527,51 +696,4 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
 		return ret;
 	}
 
-	@Override
-	public boolean isCompleteMatch(Map<String, RangerPolicyResource> resources, Map<String, Object> evalContext) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyResourceMatcher.isCompleteMatch(" + resources + ", " + evalContext + ")");
-		}
-
-		boolean ret = false;
-
-		if(serviceDef != null && serviceDef.getResources() != null) {
-			Collection<String> resourceKeys = resources == null ? null : resources.keySet();
-			Collection<String> policyKeys   = matchers == null ? null : matchers.keySet();
-
-			boolean keysMatch = false;
-
-			if (resourceKeys != null && policyKeys != null) {
-				keysMatch = CollectionUtils.isEqualCollection(resourceKeys, policyKeys);
-			}
-
-			if(keysMatch) {
-				for(RangerResourceDef resourceDef : serviceDef.getResources()) {
-					String                resourceName   = resourceDef.getName();
-					RangerPolicyResource  resourceValues = resources == null ? null : resources.get(resourceName);
-					RangerPolicyResource  policyValues   = policyResources == null ? null : policyResources.get(resourceName);
-
-					if(resourceValues == null || CollectionUtils.isEmpty(resourceValues.getValues())) {
-						ret = (policyValues == null || CollectionUtils.isEmpty(policyValues.getValues()));
-					} else if(policyValues != null && CollectionUtils.isNotEmpty(policyValues.getValues())) {
-						ret = CollectionUtils.isEqualCollection(resourceValues.getValues(), policyValues.getValues());
-					}
-
-					if(! ret) {
-						break;
-					}
-				}
-			} else {
-				if(LOG.isDebugEnabled()) {
-					LOG.debug("isCompleteMatch(): keysMatch=false. resourceKeys=" + resourceKeys + "; policyKeys=" + policyKeys);
-				}
-			}
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyResourceMatcher.isCompleteMatch(" + resources + ", " + evalContext + "): " + ret);
-		}
-
-		return ret;
-	}
 }
