@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -28,6 +28,9 @@ import org.apache.ranger.plugin.policyengine.RangerAccessResource;
 import org.apache.ranger.plugin.resourcematcher.RangerResourceMatcher;
 
 public interface RangerPolicyResourceMatcher {
+	enum MatchScope { SELF_OR_ANCESTOR_OR_DESCENDANT, SELF, SELF_OR_DESCENDANT, SELF_OR_ANCESTOR, DESCENDANT, ANCESTOR };
+	enum MatchType { NONE, SELF, DESCENDANT, ANCESTOR };
+
 	void setServiceDef(RangerServiceDef serviceDef);
 
 	void setPolicy(RangerPolicy policy);
@@ -44,12 +47,14 @@ public interface RangerPolicyResourceMatcher {
 
 	boolean isMatch(Map<String, RangerPolicyResource> resources, Map<String, Object> evalContext);
 
+	boolean isMatch(RangerAccessResource resource, MatchScope scope, Map<String, Object> evalContext);
+
+	boolean isMatch(RangerPolicy policy, MatchScope scope, Map<String, Object> evalContext);
+
+	MatchType getMatchType(RangerAccessResource resource, Map<String, Object> evalContext);
+
 	boolean isCompleteMatch(RangerAccessResource resource, Map<String, Object> evalContext);
 
-	boolean isHeadMatch(RangerAccessResource resource, Map<String, Object> evalContext);
-
-	boolean isExactHeadMatch(RangerAccessResource resource, Map<String, Object> evalContext);
-
 	boolean isCompleteMatch(Map<String, RangerPolicyResource> resources, Map<String, Object> evalContext);
 
 	boolean getNeedsDynamicEval();
