@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -19,6 +19,7 @@
 
 package org.apache.ranger.plugin.service;
 
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Hashtable;
 import java.util.Map;
@@ -31,6 +32,7 @@ import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.admin.client.RangerAdminClient;
 import org.apache.ranger.admin.client.RangerAdminRESTClient;
 import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
+import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequestImpl;
@@ -44,6 +46,7 @@ import org.apache.ranger.plugin.policyengine.RangerPolicyEngineOptions;
 import org.apache.ranger.plugin.policyengine.RangerResourceAccessInfo;
 import org.apache.ranger.plugin.policyengine.RangerRowFilterResult;
 import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator;
+import org.apache.ranger.plugin.store.EmbeddedServiceDefsUtil;
 import org.apache.ranger.plugin.util.GrantRevokeRequest;
 import org.apache.ranger.plugin.util.PolicyRefresher;
 import org.apache.ranger.plugin.util.ServicePolicies;
@@ -63,6 +66,7 @@ public class RangerBasePlugin {
 	private RangerAccessResultProcessor resultProcessor = null;
 	private boolean                   useForwardedIPAddress = false;
 	private String[]                  trustedProxyAddresses = null;
+	private String                    clusterName = null;
 	private Timer                     policyEngineRefreshTimer;
 
 	Map<String, LogHistory> logHistoryList = new Hashtable<String, RangerBasePlugin.LogHistory>();
@@ -77,6 +81,14 @@ public class RangerBasePlugin {
 	public String getServiceType() {
 		return serviceType;
 	}
+	
+	public String getClusterName() {
+		return clusterName;
+	}
+
+	public void setClusterName(String clusterName) {
+		this.clusterName = clusterName;
+	}
 
 	public RangerServiceDef getServiceDef() {
 		RangerPolicyEngine policyEngine = this.policyEngine;
@@ -108,6 +120,7 @@ public class RangerBasePlugin {
 		long   pollingIntervalMs = RangerConfiguration.getInstance().getLong(propertyPrefix + ".policy.pollIntervalMs", 30 * 1000);
 		String cacheDir          = RangerConfiguration.getInstance().get(propertyPrefix + ".policy.cache.dir");
 		serviceName = RangerConfiguration.getInstance().get(propertyPrefix + ".service.name");
+		clusterName = RangerConfiguration.getInstance().get(propertyPrefix + ".ambari.cluster.name", "");
 
 		useForwardedIPAddress = RangerConfiguration.getInstance().getBoolean(propertyPrefix + ".use.x-forwarded-for.ipaddress", false);
 		String trustedProxyAddressString = RangerConfiguration.getInstance().get(propertyPrefix + ".trusted.proxy.ipaddresses");
@@ -174,17 +187,24 @@ public class RangerBasePlugin {
 		try {
 			RangerPolicyEngine oldPolicyEngine = this.policyEngine;
 
-			RangerPolicyEngine policyEngine = new RangerPolicyEngineImpl(appId, policies, policyEngineOptions);
-			policyEngine.setUseForwardedIPAddress(useForwardedIPAddress);
-			policyEngine.setTrustedProxyAddresses(trustedProxyAddresses);
+			if (policies == null) {
+				policies = getDefaultSvcPolicies();
+			}
+			if (policies == null) {
+				this.policyEngine = null;
+			} else {
+				RangerPolicyEngine policyEngine = new RangerPolicyEngineImpl(appId, policies, policyEngineOptions);
+				policyEngine.setUseForwardedIPAddress(useForwardedIPAddress);
+				policyEngine.setTrustedProxyAddresses(trustedProxyAddresses);
 
-			this.policyEngine = policyEngine;
+				this.policyEngine = policyEngine;
+			}
 
 			if (oldPolicyEngine != null && !oldPolicyEngine.preCleanup()) {
 				LOG.error("preCleanup() failed on the previous policy engine instance !!");
 			}
 		} catch (Exception e) {
-			LOG.error("setPolicies: policy engine initialization failed!  Leaving current policy engine as-is.");
+			LOG.error("setPolicies: policy engine initialization failed!  Leaving current policy engine as-is. Exception : ", e);
 		}
 	}
 
@@ -395,6 +415,7 @@ public class RangerBasePlugin {
 			accessRequest.setClientType(request.getClientType());
 			accessRequest.setRequestData(request.getRequestData());
 			accessRequest.setSessionId(request.getSessionId());
+			accessRequest.setClusterName(request.getClusterName());
 
 			// call isAccessAllowed() to determine if audit is enabled or not
 			RangerAccessResult accessResult = isAccessAllowed(accessRequest, null);
@@ -411,7 +432,36 @@ public class RangerBasePlugin {
 			}
 		}
 	}
-	
+
+	public RangerServiceDef getDefaultServiceDef() {
+		RangerServiceDef ret = null;
+
+		if (StringUtils.isNotBlank(serviceType)) {
+			try {
+				ret = EmbeddedServiceDefsUtil.instance().getEmbeddedServiceDef(serviceType);
+			} catch (Exception exp) {
+				LOG.error("Could not get embedded service-def for " + serviceType);
+			}
+		}
+		return ret;
+	}
+
+	private ServicePolicies getDefaultSvcPolicies() {
+		ServicePolicies ret = null;
+
+		RangerServiceDef serviceDef = getServiceDef();
+		if (serviceDef == null) {
+			serviceDef = getDefaultServiceDef();
+		}
+		if (serviceDef != null) {
+			ret = new ServicePolicies();
+			ret.setServiceDef(serviceDef);
+			ret.setServiceName(serviceName);
+			ret.setPolicies(new ArrayList<RangerPolicy>());
+		}
+		return ret;
+	}
+
 	public boolean logErrorMessage(String message) {
 		LogHistory log = logHistoryList.get(message);
 		if (log == null) {
