@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -38,7 +38,7 @@ import com.google.gson.GsonBuilder;
  * library (hdfs/hbase/hive/knox/storm/..). If any of these service-defs
  * don't exist in the given service store, they will be created in the store
  * using the embedded definitions.
- * 
+ *
  * init() method should be called from ServiceStore implementations to
  * initialize embedded service-defs.
  */
@@ -47,7 +47,7 @@ public class EmbeddedServiceDefsUtil {
 
 
 	// following servicedef list should be reviewed/updated whenever a new embedded service-def is added
-	private static final String DEFAULT_BOOTSTRAP_SERVICEDEF_LIST = "tag,hdfs,hbase,hive,kms,knox,storm,yarn,kafka,solr,atlas";
+	private static final String DEFAULT_BOOTSTRAP_SERVICEDEF_LIST = "tag,hdfs,hbase,hive,kms,knox,storm,yarn,kafka,solr,atlas,nifi";
 	private static final String PROPERTY_SUPPORTED_SERVICE_DEFS = "ranger.supportedcomponents";
 	private Set<String> supportedServiceDefs;
 	public static final String EMBEDDED_SERVICEDEF_TAG_NAME  = "tag";
@@ -62,6 +62,7 @@ public class EmbeddedServiceDefsUtil {
 	public static final String EMBEDDED_SERVICEDEF_SOLR_NAME  = "solr";
 	public static final String EMBEDDED_SERVICEDEF_NIFI_NAME  = "nifi";
 	public static final String EMBEDDED_SERVICEDEF_ATLAS_NAME  = "atlas";
+	public static final String EMBEDDED_SERVICEDEF_WASB_NAME  = "wasb";
 
 	public static final String PROPERTY_CREATE_EMBEDDED_SERVICE_DEFS = "ranger.service.store.create.embedded.service-defs";
 
@@ -91,6 +92,7 @@ public class EmbeddedServiceDefsUtil {
 	private RangerServiceDef solrServiceDef  = null;
 	private RangerServiceDef nifiServiceDef  = null;
 	private RangerServiceDef atlasServiceDef  = null;
+	private RangerServiceDef wasbServiceDef	 = null;
 
 	private RangerServiceDef tagServiceDef = null;
 
@@ -99,6 +101,7 @@ public class EmbeddedServiceDefsUtil {
 
 	/* private constructor to restrict instantiation of this singleton utility class */
 	private EmbeddedServiceDefsUtil() {
+		gsonBuilder = new GsonBuilder().setDateFormat("yyyyMMdd-HH:mm:ss.SSS-Z").setPrettyPrinting().create();
 	}
 
 	public static EmbeddedServiceDefsUtil instance() {
@@ -111,11 +114,9 @@ public class EmbeddedServiceDefsUtil {
 		try {
 			createEmbeddedServiceDefs = RangerConfiguration.getInstance().getBoolean(PROPERTY_CREATE_EMBEDDED_SERVICE_DEFS, true);
 
-			gsonBuilder = new GsonBuilder().setDateFormat("yyyyMMdd-HH:mm:ss.SSS-Z").setPrettyPrinting().create();
-
 			supportedServiceDefs =getSupportedServiceDef();
 			/*
-			 * Maintaining the following service-def create-order is critical for the 
+			 * Maintaining the following service-def create-order is critical for the
 			 * the legacy service-defs (HDFS/HBase/Hive/Knox/Storm) to be assigned IDs
 			 * that were used in earlier version (0.4) */
 			hdfsServiceDef  = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_HDFS_NAME);
@@ -128,9 +129,11 @@ public class EmbeddedServiceDefsUtil {
 			kafkaServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_KAFKA_NAME);
 			solrServiceDef  = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_SOLR_NAME);
 			nifiServiceDef  = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_NIFI_NAME);
-			atlasServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_ATLAS_NAME); 
+			atlasServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_ATLAS_NAME);
 
 			tagServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_TAG_NAME);
+			wasbServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_WASB_NAME);
+
 
 			// Ensure that tag service def is updated with access types of all service defs
 			store.updateTagServiceDefForAccessTypes();
@@ -182,11 +185,21 @@ public class EmbeddedServiceDefsUtil {
 	}
 
     public long getAtlasServiceDefId() {
-        return getId(atlasServiceDef); 
-    } 
+        return getId(atlasServiceDef);
+    }
 
 	public long getTagServiceDefId() { return getId(tagServiceDef); }
 
+	public long getWasbServiceDefId() { return getId(wasbServiceDef); }
+
+	public RangerServiceDef getEmbeddedServiceDef(String defType) throws Exception {
+		RangerServiceDef serviceDef=null;
+		if(StringUtils.isNotEmpty(defType)){
+			serviceDef=loadEmbeddedServiceDef(defType);
+		}
+		return serviceDef;
+	}
+
 	private long getId(RangerServiceDef serviceDef) {
 		return serviceDef == null || serviceDef.getId() == null ? -1 : serviceDef.getId().longValue();
 	}
@@ -206,8 +219,11 @@ public class EmbeddedServiceDefsUtil {
 				LOG.info("creating embedded service-def " + serviceDefName);
 				if (ret.getId() != null) {
 					store.setPopulateExistingBaseFields(true);
-					ret = store.createServiceDef(ret);
-					store.setPopulateExistingBaseFields(false);
+					try {
+						ret = store.createServiceDef(ret);
+					} finally {
+						store.setPopulateExistingBaseFields(false);
+					}
 				} else {
 					ret = store.createServiceDef(ret);
 				}
