@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -41,6 +41,7 @@ public class SearchFilter {
 	public static final String USER            = "user";          // search
 	public static final String GROUP           = "group";         // search
 	public static final String RESOURCE_PREFIX = "resource:";     // search
+	public static final String RESOURCE_MATCH_SCOPE = "resourceMatchScope"; // search - valid values: "self", "ancestor", "self_or_ancestor"
 	public static final String POL_RESOURCE    = "polResource";   // search
 	public static final String POLICY_NAME_PARTIAL = "policyNamePartial";    // search, sort
 	public static final String CREATE_TIME     = "createTime";    // sort
@@ -49,7 +50,7 @@ public class SearchFilter {
 	public static final String PAGE_SIZE       = "pageSize";
 	public static final String SORT_BY         = "sortBy";
 	public static final String RESOURCE_SIGNATURE = "resourceSignature:";     // search
-	public static final String POLICY_TYPE = "policyType"; // search
+	public static final String POLICY_TYPE     = "policyType";    // search
     public static final String GUID		   = "guid"; //search
 
 	public static final String TAG_DEF_ID                = "tagDefId";            // search
@@ -65,6 +66,12 @@ public class SearchFilter {
 	public static final String TAG_MAP_GUID              = "tagResourceMapGuid";  // search
 
 	public static final String SERVICE_NAME_PARTIAL      = "serviceNamePartial";
+
+	public static final String PLUGIN_HOST_NAME          = "pluginHostName";
+	public static final String PLUGIN_APP_TYPE           = "pluginAppType";
+	public static final String PLUGIN_ENTITY_TYPE        = "pluginEntityType";
+	public static final String PLUGIN_IP_ADDRESS         = "pluginIpAddress";
+
 	private Map<String, String> params     = null;
 	private int                 startIndex = 0;
 	private int                 maxRows    = Integer.MAX_VALUE;
