@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -32,8 +32,8 @@ import org.apache.ranger.audit.provider.AuditHandler;
 import org.apache.ranger.audit.provider.AuditProviderFactory;
 import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
 import org.apache.ranger.plugin.audit.RangerDefaultAuditHandler;
+import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.model.RangerPolicy;
-import org.apache.ranger.plugin.model.RangerTag;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.policyengine.TestPolicyEngine.PolicyEngineTestCase.TestData;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
@@ -53,6 +53,7 @@ import java.lang.reflect.Type;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Set;
 
 import static org.junit.Assert.*;
 
@@ -105,7 +106,7 @@ public class TestPolicyEngine {
 
 		System.out.println("provider=" + provider.toString());
 
-		File file = File.createTempFile("ranger-admin-test-site", ".xml") ;
+		File file = File.createTempFile("ranger-admin-test-site", ".xml");
 		file.deleteOnExit();
 
 		FileOutputStream outStream = new FileOutputStream(file);
@@ -147,6 +148,10 @@ public class TestPolicyEngine {
 				"                <name>ranger.plugin.hive.trusted.proxy.ipaddresses</name>\n" +
 				"                <value>255.255.255.255; 128.101.101.101;128.101.101.99</value>\n" +
 				"        </property>\n" +
+				"        <property>\n" +
+				"                <name>ranger.plugin.tag.attr.additional.date.formats</name>\n" +
+				"                <value>abcd||xyz||yyyy/MM/dd'T'HH:mm:ss.SSS'Z'</value>\n" +
+				"        </property>\n" +
 				"</configuration>\n");
 		writer.close();
 
@@ -221,6 +226,13 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(hbaseTestResourceFiles);
 	}
 
+	@Test
+	public void testPolicyEngine_hbase_namespace() {
+		String[] hbaseTestResourceFiles = { "/policyengine/test_policyengine_hbase_namespace.json" };
+
+		runTestsFromResourceFiles(hbaseTestResourceFiles);
+	}
+
 	@Test
 	public void testPolicyEngine_conditions() {
 		String[] conditionsTestResourceFiles = { "/policyengine/test_policyengine_conditions.json" };
@@ -256,6 +268,20 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(conditionsTestResourceFiles);
 	}
 
+    @Test
+    public void testPolicyEngine_hiveForShowDatabases() {
+        String[] conditionsTestResourceFiles = { "/policyengine/test_policyengine_tag_hive_for_show_databases.json" };
+
+        runTestsFromResourceFiles(conditionsTestResourceFiles);
+    }
+
+	@Test
+	public void testPolicyEngine_descendant_tags() {
+		String[] resourceFiles = {"/policyengine/test_policyengine_descendant_tags.json"};
+
+		runTestsFromResourceFiles(resourceFiles);
+	}
+
 	@Test
 	public void testPolicyEngine_hiveMasking() {
 		String[] resourceFiles = {"/policyengine/test_policyengine_hive_mask_filter.json"};
@@ -263,6 +289,13 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(resourceFiles);
 	}
 
+	@Test
+	public void testPolicyEngine_owner() {
+		String[] resourceFiles = {"/policyengine/test_policyengine_owner.json"};
+
+		runTestsFromResourceFiles(resourceFiles);
+	}
+
 	private void runTestsFromResourceFiles(String[] resourceNames) {
 		for(String resourceName : resourceNames) {
 			InputStream inStream = this.getClass().getResourceAsStream(resourceName);
@@ -343,11 +376,11 @@ public class TestPolicyEngine {
 
 				if(!StringUtils.isEmpty(tagsJsonString)) {
 					try {
-						Type listType = new TypeToken<List<RangerTag>>() {
+						Type setType = new TypeToken<Set<RangerTagForEval>>() {
 						}.getType();
-						List<RangerTag> tagList = gsonBuilder.fromJson(tagsJsonString, listType);
+						Set<RangerTagForEval> tags = gsonBuilder.fromJson(tagsJsonString, setType);
 
-						context.put(RangerAccessRequestUtil.KEY_CONTEXT_TAGS, tagList);
+						context.put(RangerAccessRequestUtil.KEY_CONTEXT_TAGS, tags);
 					} catch (Exception e) {
 						System.err.println("TestPolicyEngine.runTests(): error parsing TAGS JSON string in file " + testName + ", tagsJsonString=" +
 								tagsJsonString + ", exception=" + e);
