@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -19,6 +19,7 @@
 
  package org.apache.ranger.credentialapi;
 import java.io.BufferedReader;
+import java.io.File;
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.lang.reflect.Field;
@@ -82,9 +83,10 @@ public class buildks {
 	    		providerPath=args[5];
 				if(!isValidCreateCommand(command,alias,valueOption,credential,providerOption,providerPath)){
 	    			return returnCode;
-	    		}	    		
+				}
+				deleteInvalidKeystore(providerPath);
 	    		tempCredential=CredentialReader.getDecryptedString(providerPath, alias);
-	    	}else{  
+	    	}else{
 	    		return returnCode;
 	    	}
 	    	
@@ -134,7 +136,7 @@ public class buildks {
 	    			return returnCode;
 	    		}	    		
 		    	displayCommand(args);
-	    	}else{  
+	    	}else{
 	    		return returnCode;
 	    	}	    	
 	    	
@@ -147,10 +149,10 @@ public class buildks {
 	    	//get valid and remaining argument
 	    	String[] toolArgs = parser.getRemainingArgs();	    	
 	    	//execute command in CredentialShell
-			// int i = 0 ;
+			// int i = 0;
 			//  for(String s : toolArgs) {
-			//		System.out.println("TooArgs [" + i + "] = [" + s + "]") ;
-		    //		i++ ;
+			//		System.out.println("TooArgs [" + i + "] = [" + s + "]");
+		    //		i++;
 			// }
 	    	returnCode= cs.run(toolArgs);
 	    	//if response code is zero then success else failure	    	
@@ -159,7 +161,7 @@ public class buildks {
     		ex.printStackTrace();
     	} catch(Exception ex){
     		ex.printStackTrace();
-    	}  
+    	}
 		return returnCode;
 	}
 	public int createCredentialFromUserInput(){
@@ -183,9 +185,9 @@ public class buildks {
 			if(providerPath!=null && !providerPath.trim().isEmpty() && !providerPath.startsWith("localjceks://file")&&!providerPath.startsWith("jceks://file"))
 			{
     			if(providerPath.startsWith("/")){
-					providerPath="localjceks://file"+providerPath;
+					providerPath="jceks://file"+providerPath;
 				}else{
-					providerPath="localjceks://file/"+providerPath;
+					providerPath="jceks://file/"+providerPath;
 				}
         	}	        	
     		command="create";
@@ -217,7 +219,7 @@ public class buildks {
     		ex.printStackTrace();
     	} catch(Exception ex){
     		ex.printStackTrace();
-    	}  
+    	}
 		return returnCode;
 	}	
 	
@@ -237,7 +239,7 @@ public class buildks {
 				}
 	    		//display command which need to be executed or entered
 	    		displayCommand(args);
-	    	}else{  
+	    	}else{
 	    		return returnCode;
 	    	}	    	
 	    	CredentialShell cs = new CredentialShell();
@@ -256,7 +258,7 @@ public class buildks {
     		ex.printStackTrace();
     	} catch(Exception ex){
     		ex.printStackTrace();
-    	}  
+    	}
 		return returnCode;
 	}	
 	
@@ -279,7 +281,7 @@ public class buildks {
 
 	    		//display command which need to be executed or entered
 	    		displayCommand(args);
-	    	}else{  
+	    	}else{
 	    		return returnCode;
 	    	}	    	
 	    	CredentialShell cs = new CredentialShell();
@@ -298,7 +300,7 @@ public class buildks {
     		ex.printStackTrace();
     	} catch(Exception ex){
     		ex.printStackTrace();
-    	}  
+    	}
 		return returnCode;
 	}	
 	
@@ -401,7 +403,7 @@ public class buildks {
 	
 	public static void displayCommand(String args[])
     {
-		String debugOption = System.getProperty("debug") ;
+		String debugOption = System.getProperty("debug");
 		if (debugOption != null && "TRUE".equalsIgnoreCase(debugOption)) {
 			StringBuilder tempBuffer=new StringBuilder("");
 			if(args!=null && args.length>0){
@@ -415,16 +417,16 @@ public class buildks {
 	
 	public static void displaySyntax(String command){
 		if(command!=null && command.trim().equalsIgnoreCase("create")){
-			System.out.println("Correct syntax is:create <aliasname> -value <password> -provider <localjceks://file/filepath>");
-			System.out.println("sample command is:create myalias -value password123 -provider localjceks://file/tmp/ks/myks.jceks");
+			System.out.println("Correct syntax is:create <aliasname> -value <password> -provider <jceks://file/filepath>");
+			System.out.println("sample command is:create myalias -value password123 -provider jceks://file/tmp/ks/myks.jceks");
 		}
 		if(command!=null && command.trim().equalsIgnoreCase("list")){
-			System.out.println("Correct syntax is:list -provider <localjceks://file/filepath>");
-			System.out.println("sample command is:list -provider localjceks://file/tmp/ks/myks.jceks");
+			System.out.println("Correct syntax is:list -provider <jceks://file/filepath>");
+			System.out.println("sample command is:list -provider jceks://file/tmp/ks/myks.jceks");
 		}
 		if(command!=null && command.trim().equalsIgnoreCase("get")){
-			System.out.println("Correct syntax is:get <aliasname> -provider <localjceks://file/filepath>");
-			System.out.println("sample command is:get myalias -provider localjceks://file/tmp/ks/myks.jceks");
+			System.out.println("Correct syntax is:get <aliasname> -provider <jceks://file/filepath>");
+			System.out.println("sample command is:get myalias -provider jceks://file/tmp/ks/myks.jceks");
 		}
 	}
 	public String getCredential(String args[]){
@@ -495,29 +497,50 @@ public class buildks {
 		}
 		return isValid;
 	}
-  
+
 	private static boolean isCredentialShellInteractiveEnabled() {
-		boolean ret = false ;
+		boolean ret = false;
 		
-		String fieldName = "interactive" ;
+		String fieldName = "interactive";
 		
-		CredentialShell cs = new CredentialShell() ;
+		CredentialShell cs = new CredentialShell();
 		
 		try {
-			Field interactiveField = cs.getClass().getDeclaredField(fieldName) ;
+			Field interactiveField = cs.getClass().getDeclaredField(fieldName);
 			
 			if (interactiveField != null) {
 				interactiveField.setAccessible(true);
-				ret = interactiveField.getBoolean(cs) ;
-				System.out.println("FOUND value of [" + fieldName + "] field in the Class [" + cs.getClass().getName() + "] = [" + ret + "]") ;
+				ret = interactiveField.getBoolean(cs);
+				System.out.println("FOUND value of [" + fieldName + "] field in the Class [" + cs.getClass().getName() + "] = [" + ret + "]");
 			}
 		} catch (Throwable e) {
-			System.out.println("Unable to find the value of [" + fieldName + "] field in the Class [" + cs.getClass().getName() + "]. Skiping -f option") ;
+			System.out.println("Unable to find the value of [" + fieldName + "] field in the Class [" + cs.getClass().getName() + "]. Skiping -f option");
 			e.printStackTrace();
 			ret = false;
 		}
 		
-		return ret ;
+		return ret;
 		
 	}
+
+	public void deleteInvalidKeystore(String providerPath){
+		if(providerPath!=null){
+			String keystore=null;
+			if(providerPath.startsWith("jceks://file")){
+				keystore=providerPath.replace("jceks://file","");
+			}else if(providerPath.startsWith("localjceks://file")){
+				keystore=providerPath.replace("jceks://file","");
+			}else{
+				keystore=providerPath;
+			}
+			if(keystore!=null && !keystore.isEmpty()){
+				File file =new File(keystore);
+				if(file!=null && file.length()==0){
+					System.out.println("Provider file '"+keystore+"' is in invalid state or corrupt!! will try to delete first.");
+					file.delete();
+					file=null;
+				}
+			}
+		}
+	}
 }
