@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -27,7 +27,7 @@ import java.util.Date;
 import java.util.Iterator;
 import java.util.Properties;
 import java.util.logging.Logger;
-
+import java.util.List;
 import javax.servlet.ServletException;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
@@ -38,7 +38,10 @@ import org.apache.catalina.connector.Connector;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.valves.AccessLogValve;
 import org.apache.hadoop.security.SecureClientLogin;
-
+import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.security.alias.CredentialProvider;
+import org.apache.hadoop.security.alias.CredentialProviderFactory;
+import org.apache.hadoop.security.alias.JavaKeyStoreProvider;
 import javax.security.auth.Subject;
 
 import org.w3c.dom.Document;
@@ -50,13 +53,14 @@ public class EmbeddedServer {
 	
 	private static final Logger LOG = Logger.getLogger(EmbeddedServer.class
 			.getName());
+	private static final String DEFAULT_NAME_RULE = "DEFAULT";
 	
-	private static final String DEFAULT_CONFIG_FILENAME = "ranger-admin-site.xml";
+	private static final String DEFAULT_CONFIG_FILENAME = "ranger-admin-default-site.xml";
 	private static final String CORE_SITE_CONFIG_FILENAME = "core-site.xml";
 	
 	private static final String DEFAULT_WEBAPPS_ROOT_FOLDER = "webapps";
 	
-	private static String configFile = DEFAULT_CONFIG_FILENAME;
+	private static String configFile = "ranger-admin-site.xml";
 	
 	private static final String AUTH_TYPE_KERBEROS = "kerberos";
     private static final String AUTHENTICATION_TYPE = "hadoop.security.authentication";
@@ -64,6 +68,7 @@ public class EmbeddedServer {
     private static final String ADMIN_USER_KEYTAB = "ranger.admin.kerberos.keytab";
 
 	private static final String ADMIN_NAME_RULES = "hadoop.security.auth_to_local";
+	private static final String ADMIN_SERVER_NAME = "rangeradmin";
 	
 	private Properties serverConfigProperties = new Properties();
 
@@ -76,6 +81,7 @@ public class EmbeddedServer {
 			configFile = args[0];
 		}
 		loadConfig(CORE_SITE_CONFIG_FILENAME);
+		loadConfig(DEFAULT_CONFIG_FILENAME);
 		loadConfig(configFile);		
 	}
 	
@@ -87,10 +93,10 @@ public class EmbeddedServer {
 
 		String logDir =  null;
 		logDir = getConfig("logdir");
-		if(logDir == null)
-		{
+		if (logDir == null) {
 			logDir = getConfig("kms.log.dir");
-		}		
+		}
+		String servername = getConfig("servername");
 		String hostName = getConfig("ranger.service.host");
 		int serverPort = getIntConfig("ranger.service.http.port", 6181);
 		int sslPort = getIntConfig("ranger.service.https.port", -1);
@@ -124,15 +130,32 @@ public class EmbeddedServer {
 			ssl.setScheme("https");
 			ssl.setAttribute("SSLEnabled", "true");
 			ssl.setAttribute("sslProtocol", getConfig("ranger.service.https.attrib.ssl.protocol", "TLS"));
-			ssl.setAttribute("clientAuth", getConfig("ranger.service.https.attrib.clientAuth", "false"));
-			ssl.setAttribute("keyAlias", getConfig("ranger.service.https.attrib.keystore.keyalias"));
-			ssl.setAttribute("keystorePass", getConfig("ranger.service.https.attrib.keystore.pass"));
+			String clientAuth=getConfig("ranger.service.https.attrib.clientAuth", "false");
+			if("false".equalsIgnoreCase(clientAuth)){
+				clientAuth=getConfig("ranger.service.https.attrib.client.auth", "want");
+			}
+			ssl.setAttribute("clientAuth",clientAuth);
+			String providerPath=getConfig("ranger.credential.provider.path");
+			String keyAlias= getConfig("ranger.service.https.attrib.keystore.credential.alias","keyStoreCredentialAlias");
+			String keystorePass=null;
+			if(providerPath!=null && keyAlias!=null){
+				keystorePass=getDecryptedString(providerPath.trim(), keyAlias.trim());
+				if(keystorePass==null || keystorePass.trim().isEmpty() || "none".equalsIgnoreCase(keystorePass.trim())){
+					keystorePass=getConfig("ranger.service.https.attrib.keystore.pass");
+				}
+			}
+			ssl.setAttribute("keyAlias", getConfig("ranger.service.https.attrib.keystore.keyalias","rangeradmin"));
+			ssl.setAttribute("keystorePass", keystorePass);
 			ssl.setAttribute("keystoreFile", getKeystoreFile());
 			
-			String enabledProtocols = "SSLv2Hello, TLSv1, TLSv1.1, TLSv1.2";
+                        String defaultEnabledProtocols = "SSLv2Hello, TLSv1, TLSv1.1, TLSv1.2";
+                        String enabledProtocols = getConfig("ranger.service.https.attrib.ssl.enabled.protocols", defaultEnabledProtocols);
 			ssl.setAttribute("sslEnabledProtocols", enabledProtocols);
-			
-			server.getService().addConnector(ssl); 
+			String ciphers = getConfig("ranger.tomcat.ciphers");
+			if (ciphers != null && ciphers.trim() != null && ciphers.trim().length() > 0) {
+				ssl.setAttribute("ciphers", ciphers);
+			}
+			server.getService().addConnector(ssl);
 
 			//
 			// Making this as a default connector
@@ -154,7 +177,6 @@ public class EmbeddedServer {
 		valve.setEnabled(true);
 		valve.setFileDateFormat(getConfig("ranger.accesslog.dateformat", "yyyy-MM-dd.HH"));
 		valve.setDirectory(logDirectory.getAbsolutePath());
-		valve.setRotatable(true);
 		valve.setSuffix(".log");
 		
 		String logPattern = getConfig("ranger.accesslog.pattern", "%h %l %u %t \"%r\" %s %b");
@@ -214,67 +236,57 @@ public class EmbeddedServer {
 			lce.printStackTrace();
 		}
 		
-		if(getConfig("logdir") != null){
+		if (servername.equalsIgnoreCase(ADMIN_SERVER_NAME)) {
 			String keytab = getConfig(ADMIN_USER_KEYTAB);
-	//		String principal = getConfig(ADMIN_USER_PRINCIPAL);
 			String principal = null;
 			try {
 				principal = SecureClientLogin.getPrincipal(getConfig(ADMIN_USER_PRINCIPAL), hostName);
 			} catch (IOException ignored) {
-				 // do nothing
+				LOG.warning("Failed to get ranger.admin.kerberos.principal. Reason: " + ignored.toString());
 			}
 			String nameRules = getConfig(ADMIN_NAME_RULES);
-			if(getConfig(AUTHENTICATION_TYPE) != null && getConfig(AUTHENTICATION_TYPE).trim().equalsIgnoreCase(AUTH_TYPE_KERBEROS) && SecureClientLogin.isKerberosCredentialExists(principal, keytab)){			
+			if (nameRules == null || nameRules.length() == 0) {
+				LOG.info("Name is empty. Setting Name Rule as 'DEFAULT'");
+				nameRules = DEFAULT_NAME_RULE;
+			}
+			if (getConfig(AUTHENTICATION_TYPE) != null
+					&& getConfig(AUTHENTICATION_TYPE).trim().equalsIgnoreCase(AUTH_TYPE_KERBEROS)
+					&& SecureClientLogin.isKerberosCredentialExists(principal,keytab)) {
 				try{
-					LOG.info("Provided Kerberos Credential : Principal = "+principal+" and Keytab = "+keytab);
-					Subject sub = SecureClientLogin.loginUserFromKeytab(principal, keytab, nameRules) ;
+					LOG.info("Provided Kerberos Credential : Principal = "
+							+ principal + " and Keytab = " + keytab);
+					Subject sub = SecureClientLogin.loginUserFromKeytab(principal, keytab, nameRules);
 					Subject.doAs(sub, new PrivilegedAction<Void>() {
 						@Override
 						public Void run() {
-							try{
-								LOG.info("Starting Server using kerberos crendential");
-								server.start();
-								server.getServer().await();
-								shutdownServer();
-							}catch (LifecycleException e) {
-								LOG.severe("Tomcat Server failed to start:" + e.toString());
-								e.printStackTrace();
-							}catch (Exception e) {
-								LOG.severe("Tomcat Server failed to start:" + e.toString());
-								e.printStackTrace();
-							}
+							LOG.info("Starting Server using kerberos credential");
+							startServer(server);
 							return null;
 						}
 					});
-				}catch(Exception e){
+				} catch (Exception e) {
 					LOG.severe("Tomcat Server failed to start:" + e.toString());
 					e.printStackTrace();
 				}
-			}else{
-				try{                 
-					server.start(); 
-					server.getServer().await();
-					shutdownServer();
-				} catch (LifecycleException e) {
-					LOG.severe("Tomcat Server failed to start:" + e.toString());
-					e.printStackTrace(); 
-				} catch (Exception e) {
-					LOG.severe("Tomcat Server failed to start:" + e.toString());
-					e.printStackTrace(); 
-				}
-			}
-		}else{
-			try{                 
-				server.start(); 
-				server.getServer().await();
-				shutdownServer();
-			} catch (LifecycleException e) {
-				LOG.severe("Tomcat Server failed to start:" + e.toString());
-				e.printStackTrace(); 
-			} catch (Exception e) {
-				LOG.severe("Tomcat Server failed to start:" + e.toString());
-				e.printStackTrace(); 
+			} else {
+				startServer(server);
 			}
+		} else {
+			startServer(server);
+		}
+	}
+
+	private void startServer(final Tomcat server) {
+		try {
+			server.start();
+			server.getServer().await();
+			shutdownServer();
+		} catch (LifecycleException e) {
+			LOG.severe("Tomcat Server failed to start:" + e.toString());
+			e.printStackTrace();
+		} catch (Exception e) {
+			LOG.severe("Tomcat Server failed to start:" + e.toString());
+			e.printStackTrace();
 		}
 	}
 
@@ -282,7 +294,7 @@ public class EmbeddedServer {
 		String keystoreFile=getConfig("ranger.service.https.attrib.keystore.file");
 		if (keystoreFile == null || keystoreFile.trim().isEmpty()) {
 			// new property not configured, lets use the old property
-			keystoreFile = getConfig("ranger.https.attrib.keystore.file") ;
+			keystoreFile = getConfig("ranger.https.attrib.keystore.file");
 		}
 		return keystoreFile;
 	}
@@ -306,12 +318,14 @@ public class EmbeddedServer {
 	}
 	
 	protected int getIntConfig(String key, int defaultValue) {
-		int ret = 0;
+		int ret = defaultValue;
 		String retStr = getConfig(key);
-		if (retStr == null) {
-			ret = defaultValue;
-		} else {
-			ret = Integer.parseInt(retStr);
+		try {
+			if (retStr != null) {
+				ret = Integer.parseInt(retStr);
+			}
+		} catch (Exception err) {
+			LOG.warning(retStr + " can't be parsed to int. Reason: " + err.toString());
 		}
 		return ret;
 	}
@@ -417,17 +431,19 @@ public class EmbeddedServer {
 			}
 
 		} catch (Exception e) {
-			e.printStackTrace();
+			LOG.severe("Load configuration fail. Reason: " + e.toString());
 		}
 
 	}
 	protected long getLongConfig(String key, long defaultValue) {
-		long ret = 0;
+		long ret = defaultValue;
 		String retStr = getConfig(key);
-		if (retStr == null) {
-		        ret = defaultValue;
-		} else {
+		try{
+			if (retStr != null) {
 		        ret = Long.parseLong(retStr);
+			}
+		}catch(Exception err){
+			LOG.warning(retStr + " can't be parsed to long. Reason: " + err.toString());
 		}
 		return ret;
 	}
@@ -440,16 +456,62 @@ public class EmbeddedServer {
 		server.getConnector().setMaxPostSize(getIntConfig("ranger.service.http.connector.attrib.maxPostSize", 2097152));
 		server.getConnector().setMaxSavePostSize(getIntConfig("ranger.service.http.connector.attrib.maxSavePostSize", 4096));
 		server.getConnector().setParseBodyMethods(getConfig("ranger.service.http.connector.attrib.methods", "POST"));
-		Iterator<Object> iterator=serverConfigProperties.keySet().iterator();
-		String key=null;
-		String property=null;
+		server.getConnector().setURIEncoding(getConfig("ranger.service.http.connector.attrib.URIEncoding", "UTF-8"));
+		Iterator<Object> iterator = serverConfigProperties.keySet().iterator();
+		String key = null;
+		String property = null;
 		while (iterator.hasNext()){
-		        key=iterator.next().toString();
-		        if(key!=null && key.startsWith("ranger.service.http.connector.property.")){
-		                property=key.replace("ranger.service.http.connector.property.","");
-		                server.getConnector().setProperty(property,getConfig(key));
-		                LOG.info(property+":"+server.getConnector().getProperty(property));
-		        }
+			key = iterator.next().toString();
+			if(key != null && key.startsWith("ranger.service.http.connector.property.")){
+				property = key.replace("ranger.service.http.connector.property.","");
+				server.getConnector().setProperty(property,getConfig(key));
+				LOG.info(property + ":" + server.getConnector().getProperty(property));
+			}
 		}
 	}
+
+	public String getDecryptedString(String CrendentialProviderPath,String alias) {
+		String credential=null;
+		try{
+			if(CrendentialProviderPath==null || alias==null||CrendentialProviderPath.trim().isEmpty()||alias.trim().isEmpty()){
+				return null;
+			}
+			char[] pass = null;
+			Configuration conf = new Configuration();
+			String crendentialProviderPrefixJceks=JavaKeyStoreProvider.SCHEME_NAME + "://file";
+			String crendentialProviderPrefixLocalJceks="localjceks://file";
+			crendentialProviderPrefixJceks=crendentialProviderPrefixJceks.toLowerCase();
+			CrendentialProviderPath=CrendentialProviderPath.trim();
+			alias=alias.trim();
+			if(CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixJceks) ||  CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixLocalJceks)){
+				conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH,CrendentialProviderPath);
+			}else{
+				if(CrendentialProviderPath.startsWith("/")){
+					conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH,JavaKeyStoreProvider.SCHEME_NAME + "://file" + CrendentialProviderPath);
+				}else{
+					conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH,JavaKeyStoreProvider.SCHEME_NAME + "://file/" + CrendentialProviderPath);
+				}
+			}
+			List<CredentialProvider> providers = CredentialProviderFactory.getProviders(conf);
+			List<String> aliasesList;
+			CredentialProvider.CredentialEntry credEntry=null;
+			for(CredentialProvider provider: providers) {
+				//System.out.println("Credential Provider :" + provider);
+				aliasesList=provider.getAliases();
+				if(aliasesList!=null && aliasesList.contains(alias.toLowerCase())){
+					credEntry=null;
+					credEntry= provider.getCredentialEntry(alias);
+					pass = credEntry.getCredential();
+					if(pass!=null && pass.length>0){
+						credential=String.valueOf(pass);
+						break;
+					}
+				}
+			}
+		}catch(Exception ex){
+			LOG.severe("CredentialReader failed while decrypting provided string. Reason: " + ex.toString());
+			credential=null;
+		}
+		return credential;
+	}
 }
