@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -133,14 +133,14 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 	final HbaseAuthUtils _authUtils = _factory.getAuthUtils();
 	private static volatile RangerHBasePlugin hbasePlugin = null;
 	
-	// Utilities Methods 
+	// Utilities Methods
 	protected byte[] getTableName(RegionCoprocessorEnvironment e) {
 		Region region = e.getRegion();
 		byte[] tableName = null;
 		if (region != null) {
 			HRegionInfo regionInfo = region.getRegionInfo();
 			if (regionInfo != null) {
-				tableName = regionInfo.getTable().getName() ;
+				tableName = regionInfo.getTable().getName();
 			}
 		}
 		return tableName;
@@ -163,7 +163,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 		return isSpecialTable(Bytes.toString(tableName));
 	}
 	protected boolean isSpecialTable(String input) {
-		final String[] specialTables = new String[] { "hbase:meta", "-ROOT-", ".META."}; 
+		final String[] specialTables = new String[] { "hbase:meta", "-ROOT-", ".META."};
 		for (String specialTable : specialTables ) {
 			if (specialTable.equals(input)) {
 				return true;
@@ -208,7 +208,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 		return strAddr;
 	}
 
-	// Methods that are used within the CoProcessor 
+	// Methods that are used within the CoProcessor
 	private void requireScannerOwner(InternalScanner s) throws AccessDeniedException {
      if (!RpcServer.isInRpcCallContext()) {
        return;
@@ -243,9 +243,15 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 				} else {
 					Iterator<String> columnIterator = new ColumnIterator(columnCollection);
 					Set<String> columns = new HashSet<String>();
-					while (columnIterator.hasNext()) {
-						String column = columnIterator.next();
-						columns.add(column);
+					try {
+						while (columnIterator.hasNext()) {
+							String column = columnIterator.next();
+							columns.add(column);
+						}
+					} catch (Throwable t) {
+						LOG.error("Exception encountered when converting family-map to set of columns. Ignoring and returning empty set of columns for family[" + family + "]", t);
+						LOG.error("Ignoring exception and returning empty set of columns for family[" + family +"]");
+						columns.clear();
 					}
 					result.put(family, columns);
 				}
@@ -262,10 +268,11 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 		final AuthzAuditEvent _accessDeniedEvent;
 		final String _denialReason;
 		final RangerAuthorizationFilter _filter;
+		final String _clusterName;
 
 		ColumnFamilyAccessResult(boolean everythingIsAccessible, boolean somethingIsAccessible,
 								 List<AuthzAuditEvent> accessAllowedEvents, List<AuthzAuditEvent> familyLevelAccessEvents, AuthzAuditEvent accessDeniedEvent, String denialReason,
-								 RangerAuthorizationFilter filter) {
+								 RangerAuthorizationFilter filter, String clusterName) {
 			_everythingIsAccessible = everythingIsAccessible;
 			_somethingIsAccessible = somethingIsAccessible;
 			// WARNING: we are just holding on to reference of the collection.  Potentially risky optimization
@@ -275,6 +282,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 			_denialReason = denialReason;
 			// cached values of access results
 			_filter = filter;
+			_clusterName = clusterName;
 		}
 		
 		@Override
@@ -287,14 +295,15 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 					.add("accessDeniedEvent", _accessDeniedEvent)
 					.add("denialReason", _denialReason)
 					.add("filter", _filter)
+					.add("clusterName", _clusterName)
 					.toString();
 			
 		}
 	}
 	
-	ColumnFamilyAccessResult evaluateAccess(String operation, Action action, final RegionCoprocessorEnvironment env, 
-			final Map<byte[], ? extends Collection<?>> familyMap) throws AccessDeniedException {
-		
+	ColumnFamilyAccessResult evaluateAccess(String operation, Action action, final RegionCoprocessorEnvironment env,
+											final Map<byte[], ? extends Collection<?>> familyMap) throws AccessDeniedException {
+
 		String access = _authUtils.getAccess(action);
 		User user = getActiveUser();
 		String userName = _userUtils.getUserAsString(user);
@@ -311,12 +320,13 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 			throw new AccessDeniedException("Insufficient permissions for operation '" + operation + "',action: " + action);
 		}
 		String table = Bytes.toString(tableBytes);
+		String clusterName = hbasePlugin.getClusterName();
 
 		final String messageTemplate = "evaluateAccess: exiting: user[%s], Operation[%s], access[%s], families[%s], verdict[%s]";
 		ColumnFamilyAccessResult result;
 		if (canSkipAccessCheck(operation, access, table) || canSkipAccessCheck(operation, access, env)) {
 			LOG.debug("evaluateAccess: exiting: isKnownAccessPattern returned true: access allowed, not audited");
-			result = new ColumnFamilyAccessResult(true, true, null, null, null, null, null);
+			result = new ColumnFamilyAccessResult(true, true, null, null, null, null, null, null);
 			if (LOG.isDebugEnabled()) {
 				Map<String, Set<String>> families = getColumnFamilies(familyMap);
 				String message = String.format(messageTemplate, userName, operation, access, families.toString(), result.toString());
@@ -326,14 +336,15 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 		}
 		
 		// let's create a session that would be reused.  Set things on it that won't change.
-		HbaseAuditHandler auditHandler = _factory.getAuditHandler(); 
+		HbaseAuditHandler auditHandler = _factory.getAuditHandler();
 		AuthorizationSession session = new AuthorizationSession(hbasePlugin)
 				.operation(operation)
 				.remoteAddress(getRemoteAddress())
 				.auditHandler(auditHandler)
 				.user(user)
 				.access(access)
-				.table(table);
+				.table(table)
+				.clusterName(clusterName);
 		Map<String, Set<String>> families = getColumnFamilies(familyMap);
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("evaluateAccess: families to process: " + families.toString());
@@ -352,11 +363,10 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 				reason = String.format("Insufficient permissions for user ‘%s',action: %s, tableName:%s, no column families found.", user.getName(), operation, table);
 			}
 			AuthzAuditEvent event = auditHandler.getAndDiscardMostRecentEvent(); // this could be null, of course, depending on audit settings of table.
-
 			// if authorized then pass captured events as access allowed set else as access denied set.
-			result = new ColumnFamilyAccessResult(authorized, authorized, 
+			result = new ColumnFamilyAccessResult(authorized, authorized,
 						authorized ? Collections.singletonList(event) : null,
-						null, authorized ? null : event, reason, null);
+						null, authorized ? null : event, reason, null, clusterName);
 			if (LOG.isDebugEnabled()) {
 				String message = String.format(messageTemplate, userName, operation, access, families.toString(), result.toString());
 				LOG.debug(message);
@@ -408,6 +418,10 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 					}
 				} else {
 					everythingIsAccessible = false;
+					if (auditEvent != null && deniedEvent == null) { // we need to capture just one denial event
+						LOG.debug("evaluateAccess: Setting denied access audit event with last auth failure audit event.");
+						deniedEvent = auditEvent;
+					}
 					if (LOG.isDebugEnabled()) {
 						LOG.debug("evaluateAccess: no family level access [" + family + "].  Checking if has partial access (of any type)...");
 					}
@@ -478,7 +492,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 		}
 		// Cache of auth results are encapsulated the in the filter. Not every caller of the function uses it - only preGet and preOpt will.
 		RangerAuthorizationFilter filter = new RangerAuthorizationFilter(session, familesAccessAllowed, familesAccessDenied, familesAccessIndeterminate, columnsAccessAllowed);
-		result = new ColumnFamilyAccessResult(everythingIsAccessible, somethingIsAccessible, authorizedEvents, familyLevelAccessEvents, deniedEvent, denialReason, filter);
+		result = new ColumnFamilyAccessResult(everythingIsAccessible, somethingIsAccessible, authorizedEvents, familyLevelAccessEvents, deniedEvent, denialReason, filter, clusterName);
 		if (LOG.isDebugEnabled()) {
 			String message = String.format(messageTemplate, userName, operation, access, families.toString(), result.toString());
 			LOG.debug(message);
@@ -525,7 +539,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 		return combinedFilter;
 	}
 
-	void requirePermission(final String operation, final Action action, final RegionCoprocessorEnvironment regionServerEnv, final Map<byte[], ? extends Collection<?>> familyMap) 
+	void requirePermission(final String operation, final Action action, final RegionCoprocessorEnvironment regionServerEnv, final Map<byte[], ? extends Collection<?>> familyMap)
 			throws AccessDeniedException {
 
 		ColumnFamilyAccessResult accessResult = evaluateAccess(operation, action, regionServerEnv, familyMap);
@@ -550,7 +564,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 	 * @param columnFamily
 	 * @param column
 	 * @return
-	 * @throws AccessDeniedException 
+	 * @throws AccessDeniedException
 	 */
 	void authorizeAccess(String operation, String otherInformation, Action action, String table, String columnFamily, String column) throws AccessDeniedException {
 		
@@ -570,8 +584,9 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 			return;
 		}
 		User user = getActiveUser();
+		String clusterName = hbasePlugin.getClusterName();
 		
-		HbaseAuditHandler auditHandler = _factory.getAuditHandler(); 
+		HbaseAuditHandler auditHandler = _factory.getAuditHandler();
 		AuthorizationSession session = new AuthorizationSession(hbasePlugin)
 			.operation(operation)
 			.otherInformation(otherInformation)
@@ -582,6 +597,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 			.table(table)
 			.columnFamily(columnFamily)
 			.column(column)
+			.clusterName(clusterName)
 			.buildRequest()
 			.authorize();
 		
@@ -595,13 +611,13 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 		session.publishResults();
 	}
 	
-	boolean canSkipAccessCheck(final String operation, String access, final String table) 
+	boolean canSkipAccessCheck(final String operation, String access, final String table)
 			throws AccessDeniedException {
 		
 		User user = getActiveUser();
 		boolean result = false;
 		if (user == null) {
-			String message = "Unexpeceted: User is null: access denied, not audited!"; 
+			String message = "Unexpeceted: User is null: access denied, not audited!";
 			LOG.warn("canSkipAccessCheck: exiting" + message);
 			throw new AccessDeniedException("No user associated with request (" + operation + ") for action: " + access + "on table:" + table);
 		} else if (isAccessForMetadataRead(access, table)) {
@@ -616,6 +632,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 	
 	boolean canSkipAccessCheck(final String operation, String access, final RegionCoprocessorEnvironment regionServerEnv) throws AccessDeniedException {
 
+		String clusterName = hbasePlugin.getClusterName();
 		User user = getActiveUser();
 		// read access to metadata tables is always allowed and isn't audited.
 		if (isAccessForMetaTables(regionServerEnv) && _authUtils.isReadAccess(access)) {
@@ -630,6 +647,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 				.remoteAddress(getRemoteAddress())
 				.user(user)
 				.access(createAccess)
+				.clusterName(clusterName)
 				.buildRequest()
 				.authorize();
 			if (session.isAuthorized()) {
@@ -748,7 +766,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 	}
 	@Override
 	public void preCloneSnapshot(ObserverContext<MasterCoprocessorEnvironment> ctx, SnapshotDescription snapshot, HTableDescriptor hTableDescriptor) throws IOException {
-		requirePermission("cloneSnapshot", Permission.Action.ADMIN);
+		requirePermission("cloneSnapshot", hTableDescriptor.getTableName().getName(), Permission.Action.ADMIN);
 	}
 	@Override
 	public void preClose(ObserverContext<RegionCoprocessorEnvironment> e, boolean abortRequested) throws IOException {
@@ -766,7 +784,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 
 	@Override
 	public void preCreateTable(ObserverContext<MasterCoprocessorEnvironment> c, HTableDescriptor desc, HRegionInfo[] regions) throws IOException {
-		requirePermission("createTable", desc.getName(), Permission.Action.CREATE);
+		requirePermission("createTable", desc.getTableName().getName(), Permission.Action.CREATE);
 	}
 	@Override
 	public void preDelete(ObserverContext<RegionCoprocessorEnvironment> c, Delete delete, WALEdit edit, Durability durability) throws IOException {
@@ -875,7 +893,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 	}
 	@Override
 	public void preRestoreSnapshot(ObserverContext<MasterCoprocessorEnvironment> ctx, SnapshotDescription snapshot, HTableDescriptor hTableDescriptor) throws IOException {
-		requirePermission("restoreSnapshot", hTableDescriptor.getName(), Permission.Action.ADMIN);
+		requirePermission("restoreSnapshot", hTableDescriptor.getTableName().getName(), Permission.Action.ADMIN);
 	}
 
 	@Override
@@ -924,7 +942,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 	}
 	@Override
 	public void preSnapshot(ObserverContext<MasterCoprocessorEnvironment> ctx, SnapshotDescription snapshot, HTableDescriptor hTableDescriptor) throws IOException {
-		requirePermission("snapshot", hTableDescriptor.getName(), Permission.Action.ADMIN);
+		requirePermission("snapshot", hTableDescriptor.getTableName().getName(), Permission.Action.ADMIN);
 	}
 	@Override
 	public void preSplit(ObserverContext<RegionCoprocessorEnvironment> e) throws IOException {
@@ -1077,6 +1095,7 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 			LOG.debug(String.format("==> postGetTableDescriptors(count(tableNamesList)=%s, count(descriptors)=%s, regex=%s)", tableNamesList == null ? 0 : tableNamesList.size(),
 					descriptors == null ? 0 : descriptors.size(), regex));
 		}
+		String clusterName = hbasePlugin.getClusterName();
 
 		if (CollectionUtils.isNotEmpty(descriptors)) {
 			// Retains only those which passes authorization checks
@@ -1089,7 +1108,8 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 				.remoteAddress(getRemoteAddress())
 				.auditHandler(auditHandler)
 				.user(user)
-				.access(access);
+				.access(access)
+				.clusterName(clusterName);
 	
 			Iterator<HTableDescriptor> itr = descriptors.iterator();
 			while (itr.hasNext()) {
@@ -1156,6 +1176,10 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 				RangerHBasePlugin plugin = hbasePlugin;
 
 				if(plugin != null) {
+
+					String clusterName = plugin.getClusterName();
+					grData.setClusterName(clusterName);
+					
 					RangerAccessResultProcessor auditHandler = new RangerDefaultAuditHandler();
 
 					plugin.grantAccess(grData, auditHandler);
@@ -1195,6 +1219,9 @@ public class RangerAuthorizationCoprocessor extends RangerAuthorizationCoprocess
 				RangerHBasePlugin plugin = hbasePlugin;
 
 				if(plugin != null) {
+					String clusterName = plugin.getClusterName();
+					grData.setClusterName(clusterName);
+					
 					RangerAccessResultProcessor auditHandler = new RangerDefaultAuditHandler();
 
 					plugin.revokeAccess(grData, auditHandler);
