@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -58,7 +58,17 @@ import org.apache.ranger.plugin.service.RangerBasePlugin;
 
 import com.google.common.collect.Sets;
 
+import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
+
 public class RangerHdfsAuthorizer extends INodeAttributeProvider {
+	public static final String KEY_FILENAME = "FILENAME";
+	public static final String KEY_BASE_FILENAME = "BASE_FILENAME";
+	public static final String DEFAULT_FILENAME_EXTENSION_SEPARATOR = ".";
+
+    public static final String KEY_RESOURCE_PATH = "path";
+
+    public static final String RANGER_FILENAME_EXTENSION_SEPARATOR_PROP = "ranger.plugin.hdfs.filename.extension.separator";
+
 	private static final Log LOG = LogFactory.getLog(RangerHdfsAuthorizer.class);
 
 	private RangerHdfsPlugin           rangerPlugin            = null;
@@ -251,6 +261,12 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 						INodeAttributes ancestorAttribs = inodeAttrs.length > ancestorIndex ? inodeAttrs[ancestorIndex] : null;
 
 						authzStatus = isAccessAllowed(ancestor, ancestorAttribs, ancestorAccess, user, groups, plugin, auditHandler);
+						if (authzStatus == AuthzStatus.NOT_DETERMINED) {
+							authzStatus = checkDefaultEnforcer(fsOwner, superGroup, ugi, inodeAttrs, inodes,
+											pathByNameArr, snapshotId, path, ancestorIndex, doCheckOwner,
+											ancestorAccess, FsAction.NONE, FsAction.NONE, FsAction.NONE, ignoreEmptyDir,
+											isTraverseOnlyCheck, ancestor, parent, inode, auditHandler);
+						}
 					}
 
 					// checkParentAccess
@@ -258,6 +274,12 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 						INodeAttributes parentAttribs = inodeAttrs.length > 1 ? inodeAttrs[inodeAttrs.length - 2] : null;
 
 						authzStatus = isAccessAllowed(parent, parentAttribs, parentAccess, user, groups, plugin, auditHandler);
+						if (authzStatus == AuthzStatus.NOT_DETERMINED) {
+							authzStatus = checkDefaultEnforcer(fsOwner, superGroup, ugi, inodeAttrs, inodes,
+											pathByNameArr, snapshotId, path, ancestorIndex, doCheckOwner,
+											FsAction.NONE, parentAccess, FsAction.NONE, FsAction.NONE, ignoreEmptyDir,
+											isTraverseOnlyCheck, ancestor, parent, inode, auditHandler);
+						}
 					}
 
 					// checkINodeAccess
@@ -265,6 +287,12 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 						INodeAttributes inodeAttribs = inodeAttrs.length > 0 ? inodeAttrs[inodeAttrs.length - 1] : null;
 
 						authzStatus = isAccessAllowed(inode, inodeAttribs, access, user, groups, plugin, auditHandler);
+						if (authzStatus == AuthzStatus.NOT_DETERMINED) {
+							authzStatus = checkDefaultEnforcer(fsOwner, superGroup, ugi, inodeAttrs, inodes,
+											pathByNameArr, snapshotId, path, ancestorIndex, doCheckOwner,
+											FsAction.NONE, FsAction.NONE, access, FsAction.NONE, ignoreEmptyDir,
+											isTraverseOnlyCheck, ancestor, parent, inode, auditHandler);
+						}
 					}
 
 					// checkSubAccess
@@ -291,6 +319,12 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 								}
 							}
 						}
+						if (authzStatus == AuthzStatus.NOT_DETERMINED) {
+							authzStatus = checkDefaultEnforcer(fsOwner, superGroup, ugi, inodeAttrs, inodes,
+											pathByNameArr, snapshotId, path, ancestorIndex, doCheckOwner,
+											FsAction.NONE, FsAction.NONE, FsAction.NONE, subAccess, ignoreEmptyDir,
+											isTraverseOnlyCheck, ancestor, parent, inode, auditHandler);
+						}
 					}
 
 					// checkOwnerAccess
@@ -302,45 +336,11 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 					}
 				}
 
-				if(authzStatus == AuthzStatus.NOT_DETERMINED && RangerHdfsPlugin.isHadoopAuthEnabled() && defaultEnforcer != null) {
-					try {
-						defaultEnforcer.checkPermission(fsOwner, superGroup, ugi, inodeAttrs, inodes,
-														pathByNameArr, snapshotId, path, ancestorIndex, doCheckOwner,
-														ancestorAccess, parentAccess, access, subAccess, ignoreEmptyDir);
-
-						authzStatus = AuthzStatus.ALLOW;
-					} finally {
-						if(auditHandler != null) {
-							INode    nodeChecked = inode;
-							FsAction action      = access;
-
-							if(isTraverseOnlyCheck) {
-								if(nodeChecked == null || nodeChecked.isFile()) {
-									if(parent != null) {
-										nodeChecked = parent;
-									} else if(ancestor != null) {
-										nodeChecked = ancestor;
-									}
-								}
-
-								action = FsAction.EXECUTE;
-							} else if(action == null) {
-								if(parentAccess != null) {
-									nodeChecked = parent;
-									action      = parentAccess;
-								} else if(ancestorAccess != null) {
-									nodeChecked = ancestor;
-									action      = ancestorAccess;
-								} else if(subAccess != null) {
-									action = subAccess;
-								}
-							}
-
-							String pathChecked = nodeChecked != null ? nodeChecked.getFullPathName() : path;
-
-							auditHandler.logHadoopEvent(pathChecked, action, authzStatus == AuthzStatus.ALLOW);
-						}
-					}
+				if (authzStatus == AuthzStatus.NOT_DETERMINED) {
+					authzStatus = checkDefaultEnforcer(fsOwner, superGroup, ugi, inodeAttrs, inodes,
+									pathByNameArr, snapshotId, path, ancestorIndex, doCheckOwner,
+									ancestorAccess, parentAccess, access, subAccess, ignoreEmptyDir,
+									isTraverseOnlyCheck, ancestor, parent, inode, auditHandler);
 				}
 
 				if(authzStatus != AuthzStatus.ALLOW) {
@@ -356,7 +356,7 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 						}
 					}
 
-					throw new RangerAccessControlException("Permission denied: user=" + user + ", access=" + action + ", inode=\"" + path + "\"") ;
+					throw new RangerAccessControlException("Permission denied: user=" + user + ", access=" + action + ", inode=\"" + path + "\"");
 				}
 			} finally {
 				if(auditHandler != null) {
@@ -369,10 +369,63 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 			}
 		}
 
+		private AuthzStatus checkDefaultEnforcer(String fsOwner, String superGroup, UserGroupInformation ugi,
+									INodeAttributes[] inodeAttrs, INode[] inodes, byte[][] pathByNameArr,
+									int snapshotId, String path, int ancestorIndex, boolean doCheckOwner,
+									FsAction ancestorAccess, FsAction parentAccess, FsAction access,
+									FsAction subAccess, boolean ignoreEmptyDir,
+                                    boolean isTraverseOnlyCheck, INode ancestor,
+												 INode parent, INode inode, RangerHdfsAuditHandler auditHandler
+												 ) throws AccessControlException {
+			    AuthzStatus authzStatus = AuthzStatus.NOT_DETERMINED;
+				if(RangerHdfsPlugin.isHadoopAuthEnabled() && defaultEnforcer != null) {
+					try {
+						defaultEnforcer.checkPermission(fsOwner, superGroup, ugi, inodeAttrs, inodes,
+														pathByNameArr, snapshotId, path, ancestorIndex, doCheckOwner,
+														ancestorAccess, parentAccess, access, subAccess, ignoreEmptyDir);
+
+						authzStatus = AuthzStatus.ALLOW;
+					} finally {
+						if(auditHandler != null) {
+							INode    nodeChecked = inode;
+							FsAction action      = access;
+							if(isTraverseOnlyCheck) {
+								if(nodeChecked == null || nodeChecked.isFile()) {
+									if(parent != null) {
+										nodeChecked = parent;
+									} else if(ancestor != null) {
+										nodeChecked = ancestor;
+									}
+								}
+
+								action = FsAction.EXECUTE;
+							} else if(action == null || action == FsAction.NONE)  {
+								if(parentAccess != null && parentAccess != FsAction.NONE ) {
+									nodeChecked = parent;
+									action      = parentAccess;
+								} else if(ancestorAccess != null  && ancestorAccess != FsAction.NONE ) {
+									nodeChecked = ancestor;
+									action      = ancestorAccess;
+								} else if(subAccess != null && subAccess != FsAction.NONE ) {
+									action = subAccess;
+								}
+							}
+
+							String pathChecked = nodeChecked != null ? nodeChecked.getFullPathName() : path;
+
+							auditHandler.logHadoopEvent(pathChecked, action, authzStatus == AuthzStatus.ALLOW);
+						}
+					}
+                                        return authzStatus;
+				}
+                                return authzStatus;
+                }
+
 		private AuthzStatus isAccessAllowed(INode inode, INodeAttributes inodeAttribs, FsAction access, String user, Set<String> groups, RangerHdfsPlugin plugin, RangerHdfsAuditHandler auditHandler) {
 			AuthzStatus ret       = null;
 			String      path      = inode != null ? inode.getFullPathName() : null;
 			String      pathOwner = inodeAttribs != null ? inodeAttribs.getUserName() : null;
+			String 		clusterName = plugin.getClusterName();
 
 			if(pathOwner == null && inode != null) {
 				pathOwner = inode.getUserName();
@@ -395,7 +448,7 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 			}
 
 			for(String accessType : accessTypes) {
-				RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(path, pathOwner, access, accessType, user, groups);
+				RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(inode, path, pathOwner, access, accessType, user, groups, clusterName);
 
 				RangerAccessResult result = plugin.isAccessAllowed(request, auditHandler);
 
@@ -428,6 +481,8 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 
 class RangerHdfsPlugin extends RangerBasePlugin {
 	private static boolean hadoopAuthEnabled = RangerHadoopConstants.RANGER_ADD_HDFS_PERMISSION_DEFAULT;
+	private static String fileNameExtensionSeparator;
+
 
 	public RangerHdfsPlugin() {
 		super("hdfs", "hdfs");
@@ -437,25 +492,28 @@ class RangerHdfsPlugin extends RangerBasePlugin {
 		super.init();
 		
 		RangerHdfsPlugin.hadoopAuthEnabled = RangerConfiguration.getInstance().getBoolean(RangerHadoopConstants.RANGER_ADD_HDFS_PERMISSION_PROP, RangerHadoopConstants.RANGER_ADD_HDFS_PERMISSION_DEFAULT);
+		RangerHdfsPlugin.fileNameExtensionSeparator = RangerConfiguration.getInstance().get(RangerHdfsAuthorizer.RANGER_FILENAME_EXTENSION_SEPARATOR_PROP, RangerHdfsAuthorizer.DEFAULT_FILENAME_EXTENSION_SEPARATOR);
 	}
 
 	public static boolean isHadoopAuthEnabled() {
 		return RangerHdfsPlugin.hadoopAuthEnabled;
 	}
+	public static String getFileNameExtensionSeparator() {
+		return RangerHdfsPlugin.fileNameExtensionSeparator;
+	}
 }
 
 class RangerHdfsResource extends RangerAccessResourceImpl {
-	private static final String KEY_PATH = "path";
-
 
 	public RangerHdfsResource(String path, String owner) {
-		super.setValue(KEY_PATH, path);
+		super.setValue(RangerHdfsAuthorizer.KEY_RESOURCE_PATH, path);
 		super.setOwnerUser(owner);
 	}
 }
 
 class RangerHdfsAccessRequest extends RangerAccessRequestImpl {
-	public RangerHdfsAccessRequest(String path, String pathOwner, FsAction access, String accessType, String user, Set<String> groups) {
+
+	public RangerHdfsAccessRequest(INode inode, String path, String pathOwner, FsAction access, String accessType, String user, Set<String> groups, String clusterName) {
 		super.setResource(new RangerHdfsResource(path, pathOwner));
 		super.setAccessType(accessType);
 		super.setUser(user);
@@ -463,15 +521,31 @@ class RangerHdfsAccessRequest extends RangerAccessRequestImpl {
 		super.setAccessTime(new Date());
 		super.setClientIPAddress(getRemoteIp());
 		super.setAction(access.toString());
+		super.setClusterName(clusterName);
+
+		if (inode != null) {
+			buildRequestContext(inode);
+		}
 	}
 	
 	private static String getRemoteIp() {
-		String ret = null ;
-		InetAddress ip = Server.getRemoteIp() ;
+		String ret = null;
+		InetAddress ip = Server.getRemoteIp();
 		if (ip != null) {
 			ret = ip.getHostAddress();
 		}
-		return ret ;
+		return ret;
+	}
+	private void buildRequestContext(final INode inode) {
+		if (inode.isFile()) {
+			String fileName = inode.getLocalName();
+			RangerAccessRequestUtil.setTokenInContext(getContext(), RangerHdfsAuthorizer.KEY_FILENAME, fileName);
+			int lastExtensionSeparatorIndex = fileName.lastIndexOf(RangerHdfsPlugin.getFileNameExtensionSeparator());
+			if (lastExtensionSeparatorIndex != -1) {
+				String baseFileName = fileName.substring(0, lastExtensionSeparatorIndex);
+				RangerAccessRequestUtil.setTokenInContext(getContext(), RangerHdfsAuthorizer.KEY_BASE_FILENAME, baseFileName);
+			}
+		}
 	}
 }
 
@@ -483,19 +557,19 @@ class RangerHdfsAuditHandler extends RangerDefaultAuditHandler {
 	private final String pathToBeValidated;
 	private final boolean auditOnlyIfDenied;
 
-	private static final String    HadoopModuleName = RangerConfiguration.getInstance().get(RangerHadoopConstants.AUDITLOG_HADOOP_MODULE_ACL_NAME_PROP , RangerHadoopConstants.DEFAULT_HADOOP_MODULE_ACL_NAME) ;
-	private static final String    excludeUserList  = RangerConfiguration.getInstance().get(RangerHadoopConstants.AUDITLOG_HDFS_EXCLUDE_LIST_PROP, RangerHadoopConstants.AUDITLOG_EMPTY_STRING) ;
-	private static HashSet<String> excludeUsers     = null ;
+	private static final String    HadoopModuleName = RangerConfiguration.getInstance().get(RangerHadoopConstants.AUDITLOG_HADOOP_MODULE_ACL_NAME_PROP , RangerHadoopConstants.DEFAULT_HADOOP_MODULE_ACL_NAME);
+	private static final String    excludeUserList  = RangerConfiguration.getInstance().get(RangerHadoopConstants.AUDITLOG_HDFS_EXCLUDE_LIST_PROP, RangerHadoopConstants.AUDITLOG_EMPTY_STRING);
+	private static HashSet<String> excludeUsers     = null;
 
 	static {
 		if (excludeUserList != null && excludeUserList.trim().length() > 0) {
-			excludeUsers = new HashSet<String>() ;
+			excludeUsers = new HashSet<String>();
 			for(String excludeUser : excludeUserList.trim().split(",")) {
-				excludeUser = excludeUser.trim() ;
+				excludeUser = excludeUser.trim();
 				if (LOG.isDebugEnabled()) {
 					LOG.debug("Adding exclude user [" + excludeUser + "]");
 				}
-				excludeUsers.add(excludeUser) ;
+				excludeUsers.add(excludeUser);
 				}
 		}
 	}
