@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -69,11 +69,13 @@ import com.google.common.collect.Sets;
 import org.apache.ranger.plugin.util.RangerRequestedResources;
 
 public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
-	private static final Log LOG = LogFactory.getLog(RangerHiveAuthorizer.class) ;
+	private static final Log LOG = LogFactory.getLog(RangerHiveAuthorizer.class);
 
 	private static final char COLUMN_SEP = ',';
 
-	private static volatile RangerHivePlugin hivePlugin = null ;
+	private static final String HIVE_CONF_VAR_QUERY_STRING = "hive.query.string";
+
+	private static volatile RangerHivePlugin hivePlugin = null;
 
 	public RangerHiveAuthorizer(HiveMetastoreClientFactory metastoreClientFactory,
 								  HiveConf                   hiveConf,
@@ -140,6 +142,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		try {
 			RangerHiveResource resource = getHiveResource(HiveOperationType.GRANT_PRIVILEGE, hivePrivObject);
 			GrantRevokeRequest request  = createGrantRevokeData(resource, hivePrincipals, hivePrivileges, grantorPrincipal, grantOption);
+			request.setClusterName(hivePlugin.getClusterName());
 
 			LOG.info("grantPrivileges(): " + request);
 			if(LOG.isDebugEnabled()) {
@@ -180,6 +183,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		try {
 			RangerHiveResource resource = getHiveResource(HiveOperationType.REVOKE_PRIVILEGE, hivePrivObject);
 			GrantRevokeRequest request  = createGrantRevokeData(resource, hivePrincipals, hivePrivileges, grantorPrincipal, grantOption);
+			request.setClusterName(hivePlugin.getClusterName());
 
 			LOG.info("revokePrivileges(): " + request);
 			if(LOG.isDebugEnabled()) {
@@ -221,6 +225,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			HiveAuthzSessionContext sessionContext = getHiveAuthzSessionContext();
 			String                  user           = ugi.getShortUserName();
 			Set<String>             groups         = Sets.newHashSet(ugi.getGroupNames());
+			String clusterName = hivePlugin.getClusterName();
 
 			if(LOG.isDebugEnabled()) {
 				LOG.debug(toString(hiveOpType, inputHObjs, outputHObjs, context, sessionContext));
@@ -242,9 +247,11 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 						continue;
 					}
 
-					if(resource.getObjectType() == HiveObjectType.URI) {
-						String   path       = hiveObj.getObjectName();
-						FsAction permission = FsAction.READ;
+					String 	path         		= hiveObj.getObjectName();
+					HiveObjectType hiveObjType  = resource.getObjectType();
+
+					if(hiveObjType == HiveObjectType.URI && isPathInFSScheme(path)) {
+						FsAction permission = getURIAccessType(hiveOpType);
 
 						if(!isURIAccessAllowed(user, permission, path, getHiveConf())) {
 							throw new HiveAccessControlException(String.format("Permission denied: user [%s] does not have [%s] privilege on [%s]", user, permission.name(), path));
@@ -253,14 +260,14 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 						continue;
 					}
 
-					HiveAccessType accessType = getAccessType(hiveObj, hiveOpType, true);
+					HiveAccessType accessType = getAccessType(hiveObj, hiveOpType, hiveObjType, true);
 
 					if(accessType == HiveAccessType.NONE) {
 						continue;
 					}
 
 					if(!existsByResourceAndAccessType(requests, resource, accessType)) {
-						RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, hiveOpType, accessType, context, sessionContext);
+						RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, hiveOpType, accessType, context, sessionContext, clusterName);
 
 						requests.add(request);
 					}
@@ -269,7 +276,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				// this should happen only for SHOWDATABASES
 				if (hiveOpType == HiveOperationType.SHOWDATABASES) {
 					RangerHiveResource resource = new RangerHiveResource(HiveObjectType.DATABASE, null);
-					RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, hiveOpType.name(), HiveAccessType.USE, context, sessionContext);
+					RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, hiveOpType.name(), HiveAccessType.USE, context, sessionContext, clusterName);
 					requests.add(request);
 				} else {
 					if (LOG.isDebugEnabled()) {
@@ -286,9 +293,11 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 						continue;
 					}
 
-					if(resource.getObjectType() == HiveObjectType.URI) {
-						String   path       = hiveObj.getObjectName();
-						FsAction permission = FsAction.WRITE;
+					String   path       = hiveObj.getObjectName();
+					HiveObjectType hiveObjType  = resource.getObjectType();
+
+					if(hiveObjType == HiveObjectType.URI  && isPathInFSScheme(path)) {
+						FsAction permission = getURIAccessType(hiveOpType);
 
 		                if(!isURIAccessAllowed(user, permission, path, getHiveConf())) {
 		    				throw new HiveAccessControlException(String.format("Permission denied: user [%s] does not have [%s] privilege on [%s]", user, permission.name(), path));
@@ -297,14 +306,14 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 						continue;
 					}
 
-					HiveAccessType accessType = getAccessType(hiveObj, hiveOpType, false);
+					HiveAccessType accessType = getAccessType(hiveObj, hiveOpType, hiveObjType, false);
 
 					if(accessType == HiveAccessType.NONE) {
 						continue;
 					}
 
 					if(!existsByResourceAndAccessType(requests, resource, accessType)) {
-						RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, hiveOpType, accessType, context, sessionContext);
+						RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, hiveOpType, accessType, context, sessionContext, clusterName);
 
 						requests.add(request);
 					}
@@ -350,54 +359,61 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 						for(RangerAccessResult colResult : colResults) {
 							result = colResult;
 
-							if(!result.getIsAllowed()) {
+							if(result != null && !result.getIsAllowed()) {
 								break;
 							}
 						}
 					}
 				} else {
 					result = hivePlugin.isAccessAllowed(request, auditHandler);
+				}
 
-					if(result != null && result.getIsAllowed() && blockAccessIfRowfilterColumnMaskSpecified(hiveOpType, request.getHiveAccessType())) {
-						// check if row-filtering or column-masking is applicable for the table/view being accessed
-						RangerHiveResource res = (RangerHiveResource)request.getResource();
+				if((result == null || result.getIsAllowed()) && isBlockAccessIfRowfilterColumnMaskSpecified(hiveOpType, request)) {
+					// check if row-filtering is applicable for the table/view being accessed
+					HiveAccessType     savedAccessType = request.getHiveAccessType();
+					RangerHiveResource tblResource     = new RangerHiveResource(HiveObjectType.TABLE, resource.getDatabase(), resource.getTable());
 
-						if(res.getObjectType() == HiveObjectType.TABLE || res.getObjectType() == HiveObjectType.VIEW) {
-							HiveAccessType savedAccessType = request.getHiveAccessType();
+					request.setHiveAccessType(HiveAccessType.SELECT); // filtering/masking policies are defined only for SELECT
+					request.setResource(tblResource);
 
-							request.setHiveAccessType(HiveAccessType.SELECT); // filtering/masking policies are defined only for SELECT
+					RangerRowFilterResult rowFilterResult = getRowFilterResult(request);
 
-							RangerRowFilterResult rowFilterResult = getRowFilterResult(request);
-
-							if (isRowFilterEnabled(rowFilterResult)) {
-								result.setIsAllowed(false);
-								result.setPolicyId(rowFilterResult.getPolicyId());
-								result.setReason("User does not have acces to all rows of the table");
-							} else {
-								// check if masking is enabled for any column in the table/view
-								request.setResourceMatchingScope(RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS);
-
-								RangerDataMaskResult dataMaskResult = getDataMaskResult(request);
-
-								if (isDataMaskEnabled(dataMaskResult)) {
-									result.setIsAllowed(false);
-									result.setPolicyId(dataMaskResult.getPolicyId());
-									result.setReason("User does not have acces to unmasked column values");
-								}
-							}
-
-							request.setHiveAccessType(savedAccessType);
-
-							if(! result.getIsAllowed()) {
-								auditHandler.processResult(result);
-							}
+					if (isRowFilterEnabled(rowFilterResult)) {
+						if(result == null) {
+							result = new RangerAccessResult(rowFilterResult.getServiceName(), rowFilterResult.getServiceDef(), request);
 						}
+
+						result.setIsAllowed(false);
+						result.setPolicyId(rowFilterResult.getPolicyId());
+						result.setReason("User does not have acces to all rows of the table");
+					} else {
+						// check if masking is enabled for any column in the table/view
+						request.setResourceMatchingScope(RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS);
+
+						RangerDataMaskResult dataMaskResult = getDataMaskResult(request);
+
+						if (isDataMaskEnabled(dataMaskResult)) {
+							if(result == null) {
+								result = new RangerAccessResult(dataMaskResult.getServiceName(), dataMaskResult.getServiceDef(), request);
+							}
+
+							result.setIsAllowed(false);
+							result.setPolicyId(dataMaskResult.getPolicyId());
+							result.setReason("User does not have acces to unmasked column values");
+						}
+					}
+
+					request.setHiveAccessType(savedAccessType);
+					request.setResource(resource);
+
+					if(result != null && !result.getIsAllowed()) {
+						auditHandler.processResult(result);
 					}
 				}
 
-				if(result != null && !result.getIsAllowed()) {
+				if(result == null || !result.getIsAllowed()) {
 					String path = resource.getAsString();
-
+					path = (path == null) ? "Unknown resource!!" : buildPathForException(path, hiveOpType);
 					throw new HiveAccessControlException(String.format("Permission denied: user [%s] does not have [%s] privilege on [%s]",
 														 user, request.getHiveAccessType().name(), path));
 				}
@@ -427,14 +443,14 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		List<HivePrivilegeObject> ret = null;
 
 		// bail out early if nothing is there to validate!
-		if (objs == null) { 
+		if (objs == null) {
 			LOG.debug("filterListCmdObjects: meta objects list was null!");
 		} else if (objs.isEmpty()) {
 			LOG.debug("filterListCmdObjects: meta objects list was empty!");
 			ret = objs;
 		} else if (getCurrentUserGroupInfo() == null) {
 			/*
-			 * This is null for metastore and there doesn't seem to be a way to tell if one is running as metastore or hiveserver2! 
+			 * This is null for metastore and there doesn't seem to be a way to tell if one is running as metastore or hiveserver2!
 			 */
 			LOG.warn("filterListCmdObjects: user information not available");
 			ret = objs;
@@ -473,7 +489,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				if (resource == null) {
 					LOG.error("filterListCmdObjects: RangerHiveResource returned by createHiveResource is null");
 				} else {
-					RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, context, sessionContext);
+					RangerHiveAccessRequest request = new RangerHiveAccessRequest(resource, user, groups, context, sessionContext, hivePlugin.getClusterName());
 					RangerAccessResult result = hivePlugin.isAccessAllowed(request);
 					if (result == null) {
 						LOG.error("filterListCmdObjects: Internal error: null RangerAccessResult object received back from isAccessAllowed()!");
@@ -520,6 +536,8 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 					LOG.debug("applyRowFilterAndColumnMasking(hiveObjType=" + hiveObjType + ")");
 				}
 
+				boolean needToTransform = false;
+
 				if (hiveObjType == HivePrivilegeObjectType.TABLE_OR_VIEW) {
 					String database = hiveObj.getDbname();
 					String table    = hiveObj.getObjectName();
@@ -532,26 +550,29 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 						}
 
 						hiveObj.setRowFilterExpression(rowFilterExpr);
+						needToTransform = true;
 					}
 
 					if (CollectionUtils.isNotEmpty(hiveObj.getColumns())) {
 						List<String> columnTransformers = new ArrayList<String>();
 
 						for (String column : hiveObj.getColumns()) {
-							String columnTransformer = getCellValueTransformer(queryContext, database, table, column);
+							boolean isColumnTransformed = addCellValueTransformerAndCheckIfTransformed(queryContext, database, table, column, columnTransformers);
 
 							if(LOG.isDebugEnabled()) {
-								LOG.debug("columnTransformer(database=" + database + ", table=" + table + ", column=" + column + "): " + columnTransformer);
+								LOG.debug("addCellValueTransformerAndCheckIfTransformed(database=" + database + ", table=" + table + ", column=" + column + "): " + isColumnTransformed);
 							}
 
-							columnTransformers.add(columnTransformer);
+							needToTransform = needToTransform || isColumnTransformed;
 						}
 
 						hiveObj.setCellValueTransformers(columnTransformers);
 					}
 				}
 
-				ret.add(hiveObj);
+				if (needToTransform) {
+					ret.add(hiveObj);
+				}
 			}
 		}
 
@@ -623,8 +644,9 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			String                  user           = ugi.getShortUserName();
 			Set<String>             groups         = Sets.newHashSet(ugi.getGroupNames());
 			HiveObjectType          objectType     = HiveObjectType.TABLE;
+			String 					clusterName    = hivePlugin.getClusterName();
 			RangerHiveResource      resource       = new RangerHiveResource(objectType, databaseName, tableOrViewName);
-			RangerHiveAccessRequest request        = new RangerHiveAccessRequest(resource, user, groups, objectType.name(), HiveAccessType.SELECT, context, sessionContext);
+			RangerHiveAccessRequest request        = new RangerHiveAccessRequest(resource, user, groups, objectType.name(), HiveAccessType.SELECT, context, sessionContext, clusterName);
 
 			RangerRowFilterResult result = hivePlugin.evalRowFilterPolicies(request, auditHandler);
 
@@ -642,18 +664,20 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		return ret;
 	}
 
-	private String getCellValueTransformer(HiveAuthzContext context, String databaseName, String tableOrViewName, String columnName) throws SemanticException {
+	private boolean addCellValueTransformerAndCheckIfTransformed(HiveAuthzContext context, String databaseName, String tableOrViewName, String columnName, List<String> columnTransformers) throws SemanticException {
 		UserGroupInformation ugi = getCurrentUserGroupInfo();
 
+		String clusterName = hivePlugin.getClusterName();
 		if(ugi == null) {
 			throw new SemanticException("user information not available");
 		}
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> getCellValueTransformer(" + databaseName + ", " + tableOrViewName + ", " + columnName + ")");
+			LOG.debug("==> addCellValueTransformerAndCheckIfTransformed(" + databaseName + ", " + tableOrViewName + ", " + columnName + ")");
 		}
 
-		String ret = columnName;
+		boolean ret = false;
+		String columnTransformer = columnName;
 
 		RangerHiveAuditHandler auditHandler = new RangerHiveAuditHandler();
 
@@ -663,11 +687,13 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			Set<String>             groups         = Sets.newHashSet(ugi.getGroupNames());
 			HiveObjectType          objectType     = HiveObjectType.COLUMN;
 			RangerHiveResource      resource       = new RangerHiveResource(objectType, databaseName, tableOrViewName, columnName);
-			RangerHiveAccessRequest request        = new RangerHiveAccessRequest(resource, user, groups, objectType.name(), HiveAccessType.SELECT, context, sessionContext);
+			RangerHiveAccessRequest request        = new RangerHiveAccessRequest(resource, user, groups, objectType.name(), HiveAccessType.SELECT, context, sessionContext, clusterName);
 
 			RangerDataMaskResult result = hivePlugin.evalDataMaskPolicies(request, auditHandler);
 
-			if(isDataMaskEnabled(result)) {
+			ret = isDataMaskEnabled(result);
+
+			if(ret) {
 				String                maskType    = result.getMaskType();
 				RangerDataMaskTypeDef maskTypeDef = result.getMaskTypeDef();
 				String transformer	= null;
@@ -676,18 +702,18 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				}
 
 				if(StringUtils.equalsIgnoreCase(maskType, RangerPolicy.MASK_TYPE_NULL)) {
-					ret = "NULL";
+					columnTransformer = "NULL";
 				} else if(StringUtils.equalsIgnoreCase(maskType, RangerPolicy.MASK_TYPE_CUSTOM)) {
 					String maskedValue = result.getMaskedValue();
 
 					if(maskedValue == null) {
-						ret = "NULL";
+						columnTransformer = "NULL";
 					} else {
-						ret = maskedValue.replace("{col}", columnName);
+						columnTransformer = maskedValue.replace("{col}", columnName);
 					}
 
 				} else if(StringUtils.isNotEmpty(transformer)) {
-					ret = transformer.replace("{col}", columnName);
+					columnTransformer = transformer.replace("{col}", columnName);
 				}
 
 				/*
@@ -702,8 +728,10 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			auditHandler.flushAudit();
 		}
 
+		columnTransformers.add(columnTransformer);
+
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== getCellValueTransformer(" + databaseName + ", " + tableOrViewName + ", " + columnName + "): " + ret);
+			LOG.debug("<== addCellValueTransformerAndCheckIfTransformed(" + databaseName + ", " + tableOrViewName + ", " + columnName + "): " + ret);
 		}
 
 		return ret;
@@ -818,11 +846,22 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 
 		return objType;
 	}
-	
-	private HiveAccessType getAccessType(HivePrivilegeObject hiveObj, HiveOperationType hiveOpType, boolean isInput) {
+
+	private HiveAccessType getAccessType(HivePrivilegeObject hiveObj, HiveOperationType hiveOpType, HiveObjectType hiveObjectType, boolean isInput) {
 		HiveAccessType           accessType       = HiveAccessType.NONE;
 		HivePrivObjectActionType objectActionType = hiveObj.getActionType();
-		
+
+		// This is for S3 read operation
+		if (hiveObjectType == HiveObjectType.URI && isInput ) {
+			accessType = HiveAccessType.READ;
+			return accessType;
+		}
+		// This is for S3 write
+		if (hiveObjectType == HiveObjectType.URI && !isInput ) {
+			accessType = HiveAccessType.WRITE;
+			return accessType;
+		}
+
 		switch(objectActionType) {
 			case INSERT:
 			case INSERT_OVERWRITE:
@@ -870,6 +909,8 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				case ALTERTABLE_CLUSTER_SORT:
 				case ALTERTABLE_COMPACT:
 				case ALTERTABLE_DROPPARTS:
+				case ALTERTABLE_DROPCONSTRAINT:
+				case ALTERTABLE_ADDCONSTRAINT:
 				case ALTERTABLE_FILEFORMAT:
 				case ALTERTABLE_LOCATION:
 				case ALTERTABLE_MERGEFILES:
@@ -892,6 +933,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				case ALTERVIEW_PROPERTIES:
 				case ALTERVIEW_RENAME:
 				case DROPVIEW_PROPERTIES:
+				case MSCK:
 					accessType = HiveAccessType.ALTER;
 				break;
 
@@ -939,15 +981,30 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				case QUERY:
 				case SHOW_TABLESTATUS:
 				case SHOW_CREATETABLE:
-				case SHOWCOLUMNS:
 				case SHOWINDEXES:
 				case SHOWPARTITIONS:
 				case SHOW_TBLPROPERTIES:
-				case DESCTABLE:
 				case ANALYZE_TABLE:
 					accessType = HiveAccessType.SELECT;
 				break;
 
+				case SHOWCOLUMNS:
+				case DESCTABLE:
+					switch (StringUtil.toLower(hivePlugin.DescribeShowTableAuth)){
+						case "show-allowed":
+							// This is not implemented so defaulting to current behaviour of blocking describe/show columns not to show any columns.
+							// This has to be implemented when hive provides the necessary filterListCmdObjects for
+							// SELECT/SHOWCOLUMS/DESCTABLE to filter the columns based on access provided in ranger.
+						case "none":
+						case "":
+							accessType = HiveAccessType.SELECT;
+							break;
+						case "show-all":
+							accessType = HiveAccessType.USE;
+							break;
+					}
+				break;
+
 				// any access done for metadata access of actions that have support from hive for filtering
 				case SHOWDATABASES:
 				case SWITCHDATABASE:
@@ -976,7 +1033,6 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				case DROPROLE:
 				case EXPLAIN:
 				case GRANT_ROLE:
-				case MSCK:
 				case REVOKE_ROLE:
 				case RESET:
 				case SET:
@@ -997,6 +1053,163 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		return accessType;
 	}
 
+	private FsAction getURIAccessType(HiveOperationType hiveOpType) {
+		FsAction ret = FsAction.NONE;
+
+		switch(hiveOpType) {
+			case LOAD:
+			case IMPORT:
+				ret = FsAction.READ;
+			break;
+
+			case EXPORT:
+				ret = FsAction.WRITE;
+			break;
+
+			case CREATEDATABASE:
+			case CREATETABLE:
+			case CREATETABLE_AS_SELECT:
+			case ALTERDATABASE:
+			case ALTERDATABASE_OWNER:
+			case ALTERTABLE_ADDCOLS:
+			case ALTERTABLE_REPLACECOLS:
+			case ALTERTABLE_RENAMECOL:
+			case ALTERTABLE_RENAMEPART:
+			case ALTERTABLE_RENAME:
+			case ALTERTABLE_DROPPARTS:
+			case ALTERTABLE_ADDPARTS:
+			case ALTERTABLE_TOUCH:
+			case ALTERTABLE_ARCHIVE:
+			case ALTERTABLE_UNARCHIVE:
+			case ALTERTABLE_PROPERTIES:
+			case ALTERTABLE_SERIALIZER:
+			case ALTERTABLE_PARTCOLTYPE:
+			case ALTERTABLE_DROPCONSTRAINT:
+			case ALTERTABLE_ADDCONSTRAINT:
+			case ALTERTABLE_SERDEPROPERTIES:
+			case ALTERTABLE_CLUSTER_SORT:
+			case ALTERTABLE_BUCKETNUM:
+			case ALTERTABLE_UPDATETABLESTATS:
+			case ALTERTABLE_UPDATEPARTSTATS:
+			case ALTERTABLE_PROTECTMODE:
+			case ALTERTABLE_FILEFORMAT:
+			case ALTERTABLE_LOCATION:
+			case ALTERINDEX_PROPS:
+			case ALTERTABLE_MERGEFILES:
+			case ALTERTABLE_SKEWED:
+			case ALTERTABLE_COMPACT:
+			case ALTERTABLE_EXCHANGEPARTITION:
+			case ALTERPARTITION_SERIALIZER:
+			case ALTERPARTITION_SERDEPROPERTIES:
+			case ALTERPARTITION_BUCKETNUM:
+			case ALTERPARTITION_PROTECTMODE:
+			case ALTERPARTITION_FILEFORMAT:
+			case ALTERPARTITION_LOCATION:
+			case ALTERPARTITION_MERGEFILES:
+			case ALTERTBLPART_SKEWED_LOCATION:
+				ret = FsAction.ALL;
+				break;
+
+			case EXPLAIN:
+			case DROPDATABASE:
+			case SWITCHDATABASE:
+			case LOCKDB:
+			case UNLOCKDB:
+			case DROPTABLE:
+			case DESCTABLE:
+			case DESCFUNCTION:
+			case MSCK:
+			case ANALYZE_TABLE:
+			case CACHE_METADATA:
+			case SHOWDATABASES:
+			case SHOWTABLES:
+			case SHOWCOLUMNS:
+			case SHOW_TABLESTATUS:
+			case SHOW_TBLPROPERTIES:
+			case SHOW_CREATEDATABASE:
+			case SHOW_CREATETABLE:
+			case SHOWFUNCTIONS:
+			case SHOWINDEXES:
+			case SHOWPARTITIONS:
+			case SHOWLOCKS:
+			case SHOWCONF:
+			case CREATEFUNCTION:
+			case DROPFUNCTION:
+			case RELOADFUNCTION:
+			case CREATEMACRO:
+			case DROPMACRO:
+			case CREATEVIEW:
+			case DROPVIEW:
+			case CREATEINDEX:
+			case DROPINDEX:
+			case ALTERINDEX_REBUILD:
+			case ALTERVIEW_PROPERTIES:
+			case DROPVIEW_PROPERTIES:
+			case LOCKTABLE:
+			case UNLOCKTABLE:
+			case CREATEROLE:
+			case DROPROLE:
+			case GRANT_PRIVILEGE:
+			case REVOKE_PRIVILEGE:
+			case SHOW_GRANT:
+			case GRANT_ROLE:
+			case REVOKE_ROLE:
+			case SHOW_ROLES:
+			case SHOW_ROLE_GRANT:
+			case SHOW_ROLE_PRINCIPALS:
+			case TRUNCATETABLE:
+			case QUERY:
+			case DESCDATABASE:
+			case ALTERVIEW_RENAME:
+			case ALTERVIEW_AS:
+			case SHOW_COMPACTIONS:
+			case SHOW_TRANSACTIONS:
+			case ABORT_TRANSACTIONS:
+			case SET:
+			case RESET:
+			case DFS:
+			case ADD:
+			case DELETE:
+			case COMPILE:
+			case START_TRANSACTION:
+			case COMMIT:
+			case ROLLBACK:
+			case SET_AUTOCOMMIT:
+			case GET_CATALOGS:
+			case GET_COLUMNS:
+			case GET_FUNCTIONS:
+			case GET_SCHEMAS:
+			case GET_TABLES:
+			case GET_TABLETYPES:
+			case GET_TYPEINFO:
+				break;
+		}
+
+		return ret;
+	}
+
+	private String buildPathForException(String path, HiveOperationType hiveOpType) {
+		String ret  	= path;
+		int endIndex 	= 0;
+		switch(hiveOpType) {
+			case DESCTABLE:
+				ret = path + "/*";
+				break;
+			case QUERY:
+				try {
+					endIndex = StringUtils.ordinalIndexOf(path, "/", 2);
+					ret = path.substring(0,endIndex) + "/*";
+				} catch( Exception e) {
+					//omit and return the path.Log error only in debug.
+					if(LOG.isDebugEnabled()) {
+						LOG.debug("RangerHiveAuthorizer.buildPathForException(): Error while creating exception message ", e);
+					}
+				}
+				break;
+		}
+		return ret;
+	}
+
     private boolean isURIAccessAllowed(String userName, FsAction action, String uri, HiveConf conf) {
         boolean ret = false;
 
@@ -1036,6 +1249,23 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
         return ret;
     }
 
+	private boolean isPathInFSScheme(String uri) {
+		// This is to find if HIVE URI operation done is for hdfs,file scheme
+		// else it may be for s3 which needs another set of authorization calls.
+		boolean ret = false;
+		String[] fsScheme = hivePlugin.getFSScheme();
+		if (fsScheme != null) {
+			for (int i = 0; i < fsScheme.length; i++) {
+				if (!uri.isEmpty() && uri.startsWith(fsScheme[i])) {
+					ret = true;
+					break;
+				}
+			}
+		}
+		return ret;
+	}
+
+
 	private void handleDfsCommand(HiveOperationType         hiveOpType,
 								  List<HivePrivilegeObject> inputHObjs,
 								  String                    user,
@@ -1136,7 +1366,12 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		if(ss != null) {
 			ret.setClientIPAddress(ss.getUserIpAddress());
 			ret.setSessionId(ss.getSessionId());
-			ret.setRequestData(ss.getConf().getQueryString());
+
+			HiveConf hiveConf = ss.getConf();
+
+			if(hiveConf != null) {
+				ret.setRequestData(hiveConf.get(HIVE_CONF_VAR_QUERY_STRING));
+			}
 		}
 
 		HiveAuthzSessionContext sessionContext = getHiveAuthzSessionContext();
@@ -1172,6 +1407,10 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			   StringUtils.equalsIgnoreCase(privName, HiveAccessType.SELECT.name()) ||
 			   StringUtils.equalsIgnoreCase(privName, HiveAccessType.UPDATE.name())) {
 				ret.getAccessTypes().add(privName.toLowerCase());
+			} else if (StringUtils.equalsIgnoreCase(privName, "Insert") ||
+							StringUtils.equalsIgnoreCase(privName, "Delete")) {
+				// Mapping Insert/Delete to Update
+				ret.getAccessTypes().add(HiveAccessType.UPDATE.name().toLowerCase());
 			} else {
 				LOG.warn("grant/revoke: unexpected privilege type '" + privName + "'. Ignored");
 			}
@@ -1224,15 +1463,23 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		return requestedResources;
 	}
 
-	private boolean blockAccessIfRowfilterColumnMaskSpecified(HiveOperationType hiveOpType, HiveAccessType accessType) {
-		boolean ret = hiveOpType == HiveOperationType.EXPORT;
+	private boolean isBlockAccessIfRowfilterColumnMaskSpecified(HiveOperationType hiveOpType, RangerHiveAccessRequest request) {
+		boolean            ret      = false;
+		RangerHiveResource resource = (RangerHiveResource)request.getResource();
+		HiveObjectType     objType  = resource.getObjectType();
 
-		if(! ret && accessType == HiveAccessType.UPDATE && hivePlugin.BlockUpdateIfRowfilterColumnMaskSpecified) {
-			ret = true;
+		if(objType == HiveObjectType.TABLE || objType == HiveObjectType.VIEW || objType == HiveObjectType.COLUMN) {
+			ret = hiveOpType == HiveOperationType.EXPORT;
+
+			if(!ret) {
+				if (request.getHiveAccessType() == HiveAccessType.UPDATE && hivePlugin.BlockUpdateIfRowfilterColumnMaskSpecified) {
+					ret = true;
+				}
+			}
 		}
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("blockAccessIfRowfilterColumnMaskSpecified(" + hiveOpType + ", " + accessType + "): " + ret);
+			LOG.debug("isBlockAccessIfRowfilterColumnMaskSpecified(" + hiveOpType + ", " + request + "): " + ret);
 		}
 
 		return ret;
@@ -1301,23 +1548,41 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 }
 
 enum HiveObjectType { NONE, DATABASE, TABLE, VIEW, PARTITION, INDEX, COLUMN, FUNCTION, URI };
-enum HiveAccessType { NONE, CREATE, ALTER, DROP, INDEX, LOCK, SELECT, UPDATE, USE, ALL, ADMIN };
+enum HiveAccessType { NONE, CREATE, ALTER, DROP, INDEX, LOCK, SELECT, UPDATE, USE, READ, WRITE, ALL, ADMIN };
 
 class RangerHivePlugin extends RangerBasePlugin {
-	public static boolean UpdateXaPoliciesOnGrantRevoke             = RangerHadoopConstants.HIVE_UPDATE_RANGER_POLICIES_ON_GRANT_REVOKE_DEFAULT_VALUE;
+	public static boolean UpdateXaPoliciesOnGrantRevoke = RangerHadoopConstants.HIVE_UPDATE_RANGER_POLICIES_ON_GRANT_REVOKE_DEFAULT_VALUE;
 	public static boolean BlockUpdateIfRowfilterColumnMaskSpecified = RangerHadoopConstants.HIVE_BLOCK_UPDATE_IF_ROWFILTER_COLUMNMASK_SPECIFIED_DEFAULT_VALUE;
+	public static String DescribeShowTableAuth = RangerHadoopConstants.HIVE_DESCRIBE_TABLE_SHOW_COLUMNS_AUTH_OPTION_PROP_DEFAULT_VALUE;
+
+	private static String RANGER_PLUGIN_HIVE_ULRAUTH_FILESYSTEM_SCHEMES = "ranger.plugin.hive.urlauth.filesystem.schemes";
+	private static String RANGER_PLUGIN_HIVE_ULRAUTH_FILESYSTEM_SCHEMES_DEFAULT = "hdfs:,file:";
+	private static String FILESYSTEM_SCHEMES_SEPARATOR_CHAR = ",";
+	private String[] fsScheme = null;
 
 	public RangerHivePlugin(String appType) {
 		super("hive", appType);
 	}
-	
+
 	@Override
 	public void init() {
 		super.init();
 
-		RangerHivePlugin.UpdateXaPoliciesOnGrantRevoke             = RangerConfiguration.getInstance().getBoolean(RangerHadoopConstants.HIVE_UPDATE_RANGER_POLICIES_ON_GRANT_REVOKE_PROP, RangerHadoopConstants.HIVE_UPDATE_RANGER_POLICIES_ON_GRANT_REVOKE_DEFAULT_VALUE);
+		RangerHivePlugin.UpdateXaPoliciesOnGrantRevoke = RangerConfiguration.getInstance().getBoolean(RangerHadoopConstants.HIVE_UPDATE_RANGER_POLICIES_ON_GRANT_REVOKE_PROP, RangerHadoopConstants.HIVE_UPDATE_RANGER_POLICIES_ON_GRANT_REVOKE_DEFAULT_VALUE);
 		RangerHivePlugin.BlockUpdateIfRowfilterColumnMaskSpecified = RangerConfiguration.getInstance().getBoolean(RangerHadoopConstants.HIVE_BLOCK_UPDATE_IF_ROWFILTER_COLUMNMASK_SPECIFIED_PROP, RangerHadoopConstants.HIVE_BLOCK_UPDATE_IF_ROWFILTER_COLUMNMASK_SPECIFIED_DEFAULT_VALUE);
+		RangerHivePlugin.DescribeShowTableAuth = RangerConfiguration.getInstance().get(RangerHadoopConstants.HIVE_DESCRIBE_TABLE_SHOW_COLUMNS_AUTH_OPTION_PROP, RangerHadoopConstants.HIVE_DESCRIBE_TABLE_SHOW_COLUMNS_AUTH_OPTION_PROP_DEFAULT_VALUE);
+
+		String fsSchemesString = RangerConfiguration.getInstance().get(RANGER_PLUGIN_HIVE_ULRAUTH_FILESYSTEM_SCHEMES, RANGER_PLUGIN_HIVE_ULRAUTH_FILESYSTEM_SCHEMES_DEFAULT);
+		fsScheme = StringUtils.split(fsSchemesString, FILESYSTEM_SCHEMES_SEPARATOR_CHAR);
+
+		if (fsScheme != null) {
+			for (int i = 0; i < fsScheme.length; i++) {
+				fsScheme[i] = fsScheme[i].trim();
+			}
+		}
+	}
+
+	public String[] getFSScheme() {
+		return fsScheme;
 	}
 }
-
-
