@@ -29,18 +29,19 @@ globalDict = {}
 
 os_name = platform.system()
 os_name = os_name.upper()
+is_unix = os_name == "LINUX" or os_name == "DARWIN"
 
 jisql_debug=True
-
-if os_name == "LINUX":
-    RANGER_KMS_HOME = os.getenv("RANGER_KMS_HOME")
-    if RANGER_KMS_HOME is None:
-        RANGER_KMS_HOME = os.getcwd()
+masked_pwd_string='********'
+if is_unix:
+	RANGER_KMS_HOME = os.getenv("RANGER_KMS_HOME")
+	if RANGER_KMS_HOME is None:
+		RANGER_KMS_HOME = os.getcwd()
 elif os_name == "WINDOWS":
-    RANGER_KMS_HOME = os.getenv("RANGER_KMS_HOME")
+	RANGER_KMS_HOME = os.getenv("RANGER_KMS_HOME")
 
 def check_output(query):
-	if os_name == "LINUX":
+	if is_unix:
 		p = subprocess.Popen(shlex.split(query), stdout=subprocess.PIPE)
 	elif os_name == "WINDOWS":
 		p = subprocess.Popen(query, stdout=subprocess.PIPE, shell=True)
@@ -61,12 +62,12 @@ def log(msg,type):
 
 def populate_global_dict():
 	global globalDict
-	if os_name == "LINUX":
+	if is_unix:
 		read_config_file = open(os.path.join(RANGER_KMS_HOME,'install.properties'))
 	elif os_name == "WINDOWS":
 		read_config_file = open(os.path.join(RANGER_KMS_HOME,'bin','install_config.properties'))
 	library_path = os.path.join(RANGER_KMS_HOME,"cred","lib","*")
-        read_config_file = open(os.path.join(RANGER_KMS_HOME,'install.properties'))
+	read_config_file = open(os.path.join(RANGER_KMS_HOME,'install.properties'))
 	for each_line in read_config_file.read().split('\n') :
 		if len(each_line) == 0 : continue
 		if re.search('=', each_line):
@@ -105,18 +106,18 @@ def password_validation(password, userType):
 			log("[I] "+userType+" user password validated","info")
 	else:
 		if userType == "DBA root":
-                        log("[I] "+userType+" user password validated","info")
-                else:
+			log("[I] "+userType+" user password validated","info")
+		else:
 			log("[E] Blank password is not allowed,please enter valid password.","error")
 			sys.exit(1)
 
 def jisql_log(query, db_root_password):
 	if jisql_debug == True:
 		if os_name == "WINDOWS":
-			query = query.replace(' -p "'+db_root_password+'"' , ' -p "********"')
+			query = query.replace(' -p "'+db_root_password+'"' , ' -p "'+masked_pwd_string+'"')
 			log("[JISQL] "+query, "info")
 		else:
-			query = query.replace(" -p '"+db_root_password+"'" , " -p '********'")
+			query = query.replace(" -p '"+db_root_password+"'" , " -p '"+masked_pwd_string+"'" )
 			log("[JISQL] "+query, "info")
 
 class BaseDB(object):
@@ -132,25 +133,38 @@ class BaseDB(object):
 
 class MysqlConf(BaseDB):
 	# Constructor
-	def __init__(self, host,SQL_CONNECTOR_JAR,JAVA_BIN):
+	def __init__(self, host,SQL_CONNECTOR_JAR,JAVA_BIN,db_ssl_enabled,db_ssl_required,db_ssl_verifyServerCertificate,javax_net_ssl_keyStore,javax_net_ssl_keyStorePassword,javax_net_ssl_trustStore,javax_net_ssl_trustStorePassword):
 		self.host = host
 		self.SQL_CONNECTOR_JAR = SQL_CONNECTOR_JAR
 		self.JAVA_BIN = JAVA_BIN
+		self.db_ssl_enabled=db_ssl_enabled.lower()
+		self.db_ssl_required=db_ssl_required.lower()
+		self.db_ssl_verifyServerCertificate=db_ssl_verifyServerCertificate.lower()
+		self.javax_net_ssl_keyStore=javax_net_ssl_keyStore
+		self.javax_net_ssl_keyStorePassword=javax_net_ssl_keyStorePassword
+		self.javax_net_ssl_trustStore=javax_net_ssl_trustStore
+		self.javax_net_ssl_trustStorePassword=javax_net_ssl_trustStorePassword
 
 	def get_jisql_cmd(self, user, password ,db_name):
 		#TODO: User array for forming command
 		path = RANGER_KMS_HOME
-		if os_name == "LINUX":
-			jisql_cmd = "%s -cp %s:%s/jisql/lib/* org.apache.util.sql.Jisql -driver mysqlconj -cstring jdbc:mysql://%s/%s -u %s -p '%s' -noheader -trim -c \;" %(self.JAVA_BIN,self.SQL_CONNECTOR_JAR,path,self.host,db_name,user,password)
+		db_ssl_param=''
+		db_ssl_cert_param=''
+		if self.db_ssl_enabled == 'true':
+			db_ssl_param="?useSSL=%s&requireSSL=%s&verifyServerCertificate=%s" %(self.db_ssl_enabled,self.db_ssl_required,self.db_ssl_verifyServerCertificate)
+			if self.db_ssl_verifyServerCertificate == 'true':
+				db_ssl_cert_param=" -Djavax.net.ssl.keyStore=%s -Djavax.net.ssl.keyStorePassword=%s -Djavax.net.ssl.trustStore=%s -Djavax.net.ssl.trustStorePassword=%s " %(self.javax_net_ssl_keyStore,self.javax_net_ssl_keyStorePassword,self.javax_net_ssl_trustStore,self.javax_net_ssl_trustStorePassword)
+		if is_unix:
+			jisql_cmd = "%s %s -cp %s:%s/jisql/lib/* org.apache.util.sql.Jisql -driver mysqlconj -cstring jdbc:mysql://%s/%s%s -u %s -p '%s' -noheader -trim -c \;" %(self.JAVA_BIN,db_ssl_cert_param,self.SQL_CONNECTOR_JAR,path,self.host,db_name,db_ssl_param,user,password)
 		elif os_name == "WINDOWS":
 			self.JAVA_BIN = self.JAVA_BIN.strip("'")
-			jisql_cmd = "%s -cp %s;%s\jisql\\lib\\* org.apache.util.sql.Jisql -driver mysqlconj -cstring jdbc:mysql://%s/%s -u %s -p \"%s\" -noheader -trim" %(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path, self.host, db_name, user, password)
+			jisql_cmd = "%s %s -cp %s;%s\jisql\\lib\\* org.apache.util.sql.Jisql -driver mysqlconj -cstring jdbc:mysql://%s/%s%s -u %s -p \"%s\" -noheader -trim" %(self.JAVA_BIN,db_ssl_cert_param,self.SQL_CONNECTOR_JAR, path, self.host, db_name,db_ssl_param, user, password)
 		return jisql_cmd
 
 	def verify_user(self, root_user, db_root_password, host, db_user, get_cmd,dryMode):
 		if dryMode == False:
 			log("[I] Verifying user " + db_user+ " for Host "+ host, "info")
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -query \"select user from mysql.user where user='%s' and host='%s';\"" %(db_user,host)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"select user from mysql.user where user='%s' and host='%s';\" -c ;" %(db_user,host)
@@ -164,7 +178,7 @@ class MysqlConf(BaseDB):
 	def check_connection(self, db_name, db_user, db_password):
 		#log("[I] Checking connection..", "info")
 		get_cmd = self.get_jisql_cmd(db_user, db_password, db_name)
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -query \"SELECT version();\""
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT version();\" -c ;"
@@ -190,7 +204,7 @@ class MysqlConf(BaseDB):
 					if db_password == "":
 						if dryMode == False:
 							log("[I] MySQL user " + db_user + " does not exists for host " + host, "info")
-							if os_name == "LINUX":
+							if is_unix:
 								query = get_cmd + " -query \"create user '%s'@'%s';\"" %(db_user, host)
 								jisql_log(query, db_root_password)
 								ret = subprocess.call(shlex.split(query))
@@ -209,13 +223,15 @@ class MysqlConf(BaseDB):
 					else:
 						if dryMode == False:
 							log("[I] MySQL user " + db_user + " does not exists for host " + host, "info")
-							if os_name == "LINUX":
+							if is_unix:
 								query = get_cmd + " -query \"create user '%s'@'%s' identified by '%s';\"" %(db_user, host, db_password)
-								jisql_log(query, db_root_password)
+								query_with_masked_pwd = get_cmd + " -query \"create user '%s'@'%s' identified by '%s';\"" %(db_user, host,masked_pwd_string )
+								jisql_log(query_with_masked_pwd, db_root_password)
 								ret = subprocess.call(shlex.split(query))
 							elif os_name == "WINDOWS":
 								query = get_cmd + " -query \"create user '%s'@'%s' identified by '%s';\" -c ;" %(db_user, host, db_password)
-								jisql_log(query, db_root_password)
+								query_with_masked_pwd = get_cmd + " -query \"create user '%s'@'%s' identified by '%s';\" -c ;" %(db_user, host, masked_pwd_string)
+								jisql_log(query_with_masked_pwd, db_root_password)
 								ret = subprocess.call(query)
 							if ret == 0:
 								if self.verify_user(root_user, db_root_password, host, db_user, get_cmd,dryMode):
@@ -234,7 +250,7 @@ class MysqlConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying database " + db_name , "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'mysql')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -query \"show databases like '%s';\"" %(db_name)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"show databases like '%s';\" -c ;" %(db_name)
@@ -251,14 +267,14 @@ class MysqlConf(BaseDB):
 				log("[I] Database "+db_name + " already exists.","info")
 		else:
 			get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'mysql')
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -query \"create database %s;\"" %(db_name)
 			elif os_name == "WINDOWS":
 				query = get_cmd + " -query \"create database %s;\" -c ;" %(db_name)
 			if dryMode == False:
 				log("[I] Database does not exist, Creating database " + db_name,"info")
 				jisql_log(query, db_root_password)
-				if os_name == "LINUX":
+				if is_unix:
 					ret = subprocess.call(shlex.split(query))
 				elif os_name == "WINDOWS":
 					ret = subprocess.call(query)
@@ -282,7 +298,7 @@ class MysqlConf(BaseDB):
 			if dryMode == False:
 				log("[I] ---------- Granting privileges TO user '"+db_user+"'@'"+host+"' on db '"+db_name+"'----------" , "info")
 				get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'mysql')
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -query \"grant all privileges on %s.* to '%s'@'%s' with grant option;\"" %(db_name,db_user, host)
 					jisql_log(query, db_root_password)
 					ret = subprocess.call(shlex.split(query))
@@ -292,7 +308,7 @@ class MysqlConf(BaseDB):
 					ret = subprocess.call(query)
 				if ret == 0:
 					log("[I] ---------- FLUSH PRIVILEGES ----------" , "info")
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -query \"FLUSH PRIVILEGES;\""
 						jisql_log(query, db_root_password)
 						ret = subprocess.call(shlex.split(query))
@@ -344,7 +360,7 @@ class OracleConf(BaseDB):
 			#jdbc:oracle:thin:@//[HOST][:PORT]/SERVICE
 			cstring="jdbc:oracle:thin:@//%s" %(self.host)
 
-		if os_name == "LINUX":
+		if is_unix:
 			jisql_cmd = "%s -cp %s:%s/jisql/lib/* org.apache.util.sql.Jisql -driver oraclethin -cstring %s -u '%s' -p '%s' -noheader -trim" %(self.JAVA_BIN, self.SQL_CONNECTOR_JAR,path, cstring, user, password)
 		elif os_name == "WINDOWS":
 			jisql_cmd = "%s -cp %s;%s\jisql\\lib\\* org.apache.util.sql.Jisql -driver oraclethin -cstring %s -u \"%s\" -p \"%s\" -noheader -trim" %(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path, cstring, user, password)
@@ -353,7 +369,7 @@ class OracleConf(BaseDB):
 	def check_connection(self, db_name, db_user, db_password):
 		log("[I] Checking connection", "info")
 		get_cmd = self.get_jisql_cmd(db_user, db_password)
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"select * from v$version;\""
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"select * from v$version;\" -c ;"
@@ -370,7 +386,7 @@ class OracleConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying user " + db_user ,"info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password)		
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"select username from all_users where upper(username)=upper('%s');\"" %(db_user)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"select username from all_users where upper(username)=upper('%s');\" -c ;" %(db_user)
@@ -390,19 +406,21 @@ class OracleConf(BaseDB):
 				if dryMode == False:
 					log("[I] User does not exists, Creating user : " + db_user, "info")
 					get_cmd = self.get_jisql_cmd(root_user, db_root_password)
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -c \; -query 'create user %s identified by \"%s\";'" %(db_user, db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -c \; -query 'create user %s identified by \"%s\";'" %(db_user, masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(shlex.split(query))
 					elif os_name == "WINDOWS":
 						query = get_cmd + " -query \"create user %s identified by \"%s\";\" -c ;" %(db_user, db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -query \"create user %s identified by \"%s\";\" -c ;" %(db_user, masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(query)
 					if ret == 0:
 						if self.verify_user(root_user, db_user, db_root_password,dryMode):
 							log("[I] User " + db_user + " created", "info")
 							log("[I] Granting permission to " + db_user, "info")
-							if os_name == "LINUX":
+							if is_unix:
 								query = get_cmd + " -c \; -query 'GRANT CREATE SESSION,CREATE PROCEDURE,CREATE TABLE,CREATE VIEW,CREATE SEQUENCE,CREATE PUBLIC SYNONYM,CREATE TRIGGER,UNLIMITED Tablespace TO %s;'" % (db_user)
 								jisql_log(query, db_root_password)
 								ret = subprocess.call(shlex.split(query))
@@ -428,7 +446,7 @@ class OracleConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying tablespace " + db_name, "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password)		
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"SELECT DISTINCT UPPER(TABLESPACE_NAME) FROM USER_TablespaceS where UPPER(Tablespace_Name)=UPPER(\'%s\');\"" %(db_name)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT DISTINCT UPPER(TABLESPACE_NAME) FROM USER_TablespaceS where UPPER(Tablespace_Name)=UPPER(\'%s\');\" -c ;" %(db_name)
@@ -445,7 +463,7 @@ class OracleConf(BaseDB):
 				log("[I] Tablespace " + db_name + " already exists.","info")
 				if self.verify_user(root_user, db_user, db_root_password,dryMode):
 					get_cmd = self.get_jisql_cmd(db_user ,db_password)
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -c \; -query 'select default_tablespace from user_users;'"
 					elif os_name == "WINDOWS":
 						query = get_cmd + " -query \"select default_tablespace from user_users;\" -c ;"
@@ -463,7 +481,7 @@ class OracleConf(BaseDB):
 			if dryMode == False:
 				log("[I] Tablespace does not exist. Creating tablespace: " + db_name,"info")
 				get_cmd = self.get_jisql_cmd(root_user, db_root_password)
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -c \; -query \"create tablespace %s datafile '%s.dat' size 10M autoextend on;\"" %(db_name, db_name)
 					jisql_log(query, db_root_password)
 					ret = subprocess.call(shlex.split(query))
@@ -491,7 +509,7 @@ class OracleConf(BaseDB):
 			log("[I] Assign default tablespace " +db_name + " to " + db_user, "info")
 			# Assign default tablespace db_name
 			get_cmd = self.get_jisql_cmd(root_user , db_root_password)
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd +" -c \; -query 'alter user %s DEFAULT Tablespace %s;'" %(db_user, db_name)
 				jisql_log(query, db_root_password)
 				ret = subprocess.call(shlex.split(query))
@@ -501,7 +519,7 @@ class OracleConf(BaseDB):
 				ret = subprocess.call(query)
 			if ret == 0:
 				log("[I] Granting permission to " + db_user, "info")
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -c \; -query 'GRANT CREATE SESSION,CREATE PROCEDURE,CREATE TABLE,CREATE VIEW,CREATE SEQUENCE,CREATE PUBLIC SYNONYM,CREATE TRIGGER,UNLIMITED Tablespace TO %s;'" % (db_user)
 					jisql_log(query, db_root_password)
 					ret = subprocess.call(shlex.split(query))
@@ -526,7 +544,7 @@ class OracleConf(BaseDB):
 	def grant_xa_db_user(self, root_user, db_name, db_user, db_password, db_root_password, invoke,dryMode):
 		if dryMode == False:
 			get_cmd = self.get_jisql_cmd(root_user ,db_root_password)
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -c \; -query 'GRANT CREATE SESSION,CREATE PROCEDURE,CREATE TABLE,CREATE VIEW,CREATE SEQUENCE,CREATE PUBLIC SYNONYM,CREATE TRIGGER,UNLIMITED Tablespace TO %s;'" % (db_user)
 				jisql_log(query, db_root_password)
 				ret = subprocess.call(shlex.split(query))
@@ -562,7 +580,7 @@ class PostgresConf(BaseDB):
 		#TODO: User array for forming command
 		path = RANGER_KMS_HOME
 		self.JAVA_BIN = self.JAVA_BIN.strip("'")
-		if os_name == "LINUX":
+		if is_unix:
 			jisql_cmd = "%s -cp %s:%s/jisql/lib/* org.apache.util.sql.Jisql -driver postgresql -cstring jdbc:postgresql://%s/%s -u %s -p '%s' -noheader -trim -c \;" %(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path,self.host, db_name, user, password)
 		elif os_name == "WINDOWS":
 			jisql_cmd = "%s -cp %s;%s\jisql\\lib\\* org.apache.util.sql.Jisql -driver postgresql -cstring jdbc:postgresql://%s/%s -u %s -p \"%s\" -noheader -trim" %(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path, self.host, db_name, user, password)
@@ -572,7 +590,7 @@ class PostgresConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying user " + db_user , "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'postgres')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -query \"SELECT rolname FROM pg_roles WHERE rolname='%s';\"" %(db_user)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT rolname FROM pg_roles WHERE rolname='%s';\" -c ;" %(db_user)
@@ -586,7 +604,7 @@ class PostgresConf(BaseDB):
 	def check_connection(self, db_name, db_user, db_password):
 		#log("[I] Checking connection", "info")
 		get_cmd = self.get_jisql_cmd(db_user, db_password, db_name)
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -query \"SELECT 1;\""
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT 1;\" -c ;"
@@ -608,13 +626,15 @@ class PostgresConf(BaseDB):
 				if dryMode == False:
 					log("[I] User does not exists, Creating user : " + db_user, "info")
 					get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'postgres')
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -query \"CREATE USER %s WITH LOGIN PASSWORD '%s';\"" %(db_user, db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -query \"CREATE USER %s WITH LOGIN PASSWORD '%s';\"" %(db_user, masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(shlex.split(query))
 					elif os_name == "WINDOWS":
 						query = get_cmd + " -query \"CREATE USER %s WITH LOGIN PASSWORD '%s';\" -c ;" %(db_user, db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -query \"CREATE USER %s WITH LOGIN PASSWORD '%s';\" -c ;" %(db_user, masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(query)
 					if ret == 0:
 						if self.verify_user(root_user, db_root_password, db_user,dryMode):
@@ -632,7 +652,7 @@ class PostgresConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying database " + db_name , "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'postgres')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -query \"SELECT datname FROM pg_database where datname='%s';\"" %(db_name)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT datname FROM pg_database where datname='%s';\" -c ;" %(db_name)
@@ -652,7 +672,7 @@ class PostgresConf(BaseDB):
 			if dryMode == False:
 				log("[I] Database does not exist, Creating database : " + db_name,"info")
 				get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'postgres')
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -query \"create database %s with OWNER %s;\"" %(db_name, db_user)
 					jisql_log(query, db_root_password)
 					ret = subprocess.call(shlex.split(query))
@@ -677,7 +697,7 @@ class PostgresConf(BaseDB):
 		if dryMode == False:
 			log("[I] Granting privileges TO user '"+db_user+"' on db '"+db_name+"'" , "info")
 			get_cmd = self.get_jisql_cmd(root_user, db_root_password, db_name)
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -query \"GRANT ALL PRIVILEGES ON DATABASE %s to %s;\"" %(db_name, db_user)
 				jisql_log(query, db_root_password)
 				ret = subprocess.call(shlex.split(query))
@@ -689,7 +709,7 @@ class PostgresConf(BaseDB):
 				log("[E] Granting all privileges on database "+db_name+" to user "+db_user+" failed..", "error")
 				sys.exit(1)
 
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -query \"GRANT ALL PRIVILEGES ON SCHEMA public TO %s;\"" %(db_user)
 				jisql_log(query, db_root_password)
 				ret = subprocess.call(shlex.split(query))
@@ -701,7 +721,7 @@ class PostgresConf(BaseDB):
 				log("[E] Granting all privileges on schema public to user "+db_user+" failed..", "error")
 				sys.exit(1)
 
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -query \"SELECT table_name FROM information_schema.tables WHERE table_schema = 'public';\""
 				jisql_log(query, db_root_password)
 				output = check_output(query)
@@ -714,7 +734,7 @@ class PostgresConf(BaseDB):
 				if re.search(' |', each_line):
 					tablename , value = each_line.strip().split(" |",1)
 					tablename = tablename.strip()
-					if os_name == "LINUX":
+					if is_unix:
 						query1 = get_cmd + " -query \"GRANT ALL PRIVILEGES ON TABLE %s TO %s;\"" %(tablename,db_user)
 						jisql_log(query1, db_root_password)
 						ret = subprocess.call(shlex.split(query1))
@@ -730,7 +750,7 @@ class PostgresConf(BaseDB):
 							sys.exit(1)
 
 
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -query \"SELECT sequence_name FROM information_schema.sequences where sequence_schema='public';\""
 				jisql_log(query, db_root_password)
 				output = check_output(query)
@@ -743,7 +763,7 @@ class PostgresConf(BaseDB):
 				if re.search(' |', each_line):
 					sequence_name , value = each_line.strip().split(" |",1)
 					sequence_name = sequence_name.strip()
-					if os_name == "LINUX":
+					if is_unix:
 						query1 = get_cmd + " -query \"GRANT ALL PRIVILEGES ON SEQUENCE %s TO %s;\"" %(sequence_name,db_user)
 						jisql_log(query1, db_root_password)
 						ret = subprocess.call(shlex.split(query1))
@@ -784,7 +804,7 @@ class SqlServerConf(BaseDB):
 		#TODO: User array for forming command
 		path = RANGER_KMS_HOME
 		self.JAVA_BIN = self.JAVA_BIN.strip("'")
-		if os_name == "LINUX":
+		if is_unix:
 			jisql_cmd = "%s -cp %s:%s/jisql/lib/* org.apache.util.sql.Jisql -user %s -p '%s' -driver mssql -cstring jdbc:sqlserver://%s\\;databaseName=%s -noheader -trim"%(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path,user, password, self.host,db_name)
 		elif os_name == "WINDOWS":
 			jisql_cmd = "%s -cp %s;%s\\jisql\\lib\\* org.apache.util.sql.Jisql -user %s -p \"%s\" -driver mssql -cstring jdbc:sqlserver://%s;databaseName=%s -noheader -trim"%(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path, user, password, self.host,db_name)
@@ -794,7 +814,7 @@ class SqlServerConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying user " + db_user , "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'master')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"select name from sys.sql_logins where name = '%s';\"" %(db_user)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"select name from sys.sql_logins where name = '%s';\" -c ;" %(db_user)
@@ -808,7 +828,7 @@ class SqlServerConf(BaseDB):
 	def check_connection(self, db_name, db_user, db_password):
 		log("[I] Checking connection", "info")
 		get_cmd = self.get_jisql_cmd(db_user, db_password, db_name)
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"SELECT 1;\""
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT 1;\" -c ;"
@@ -830,13 +850,15 @@ class SqlServerConf(BaseDB):
 				if dryMode == False:
 					get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'master')
 					log("[I] User does not exists, Creating Login user " + db_user, "info")
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -c \; -query \"CREATE LOGIN %s WITH PASSWORD = '%s';\"" %(db_user,db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -c \; -query \"CREATE LOGIN %s WITH PASSWORD = '%s';\"" %(db_user,masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(shlex.split(query))
 					elif os_name == "WINDOWS":
 						query = get_cmd + " -query \"CREATE LOGIN %s WITH PASSWORD = '%s';\" -c ;" %(db_user,db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -query \"CREATE LOGIN %s WITH PASSWORD = '%s';\" -c ;" %(db_user,masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(query)
 					if ret == 0:
 						if self.verify_user(root_user, db_root_password, db_user,dryMode):
@@ -854,7 +876,7 @@ class SqlServerConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying database " + db_name, "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'master')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"SELECT name from sys.databases where name='%s';\"" %(db_name)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT name from sys.databases where name='%s';\" -c ;" %(db_name)
@@ -873,7 +895,7 @@ class SqlServerConf(BaseDB):
 			if dryMode == False:
 				log("[I] Database does not exist. Creating database : " + db_name,"info")
 				get_cmd = self.get_jisql_cmd(root_user, db_root_password, 'master')
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -c \; -query \"create database %s;\"" %(db_name)
 					jisql_log(query, db_root_password)
 					ret = subprocess.call(shlex.split(query))
@@ -889,7 +911,6 @@ class SqlServerConf(BaseDB):
 						self.create_user(root_user, db_name ,db_user, db_password, db_root_password,dryMode)
 						log("[I] Creating database " + db_name + " succeeded", "info")
 						return True
-	#	        	               	self.import_db_file(db_name, root_user, db_user, db_password, db_root_password, file_name)
 					else:
 						log("[E] Database creation failed..","error")
 						sys.exit(1)
@@ -898,7 +919,7 @@ class SqlServerConf(BaseDB):
 
 	def create_user(self, root_user, db_name ,db_user, db_password, db_root_password,dryMode):
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, db_name)
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"USE %s SELECT name FROM sys.database_principals WHERE name = N'%s';\"" %(db_name, db_user)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"USE %s SELECT name FROM sys.database_principals WHERE name = N'%s';\" -c ;" %(db_name, db_user)
@@ -909,7 +930,7 @@ class SqlServerConf(BaseDB):
 				log("[I] User "+db_user+" exist ","info")
 		else:
 			if dryMode == False:
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -c \; -query \"USE %s CREATE USER %s for LOGIN %s;\"" %(db_name ,db_user, db_user)
 					jisql_log(query, db_root_password)
 					ret = subprocess.call(shlex.split(query))
@@ -918,7 +939,7 @@ class SqlServerConf(BaseDB):
 					jisql_log(query, db_root_password)
 					ret = subprocess.call(query)
 				if ret == 0:
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -c \; -query \"USE %s SELECT name FROM sys.database_principals WHERE name = N'%s';\"" %(db_name ,db_user)
 					elif os_name == "WINDOWS":
 						query = get_cmd + " -query \"USE %s SELECT name FROM sys.database_principals WHERE name = N'%s';\" -c ;" %(db_name ,db_user)
@@ -939,7 +960,7 @@ class SqlServerConf(BaseDB):
 		if dryMode == False:
 			log("[I] Granting permission to admin user '" + db_user + "' on db '" + db_name + "'" , "info")
 			get_cmd = self.get_jisql_cmd(root_user, db_root_password, db_name)
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -c \; -query \" EXEC sp_addrolemember N'db_owner', N'%s';\"" %(db_user)
 				jisql_log(query, db_root_password)
 				ret = subprocess.call(shlex.split(query))
@@ -971,7 +992,7 @@ class SqlAnywhereConf(BaseDB):
 		#TODO: User array for forming command
 		path = RANGER_KMS_HOME
 		self.JAVA_BIN = self.JAVA_BIN.strip("'")
-		if os_name == "LINUX":
+		if is_unix:
 			jisql_cmd = "%s -cp %s:%s/jisql/lib/* org.apache.util.sql.Jisql -user %s -p '%s' -driver sapsajdbc4 -cstring jdbc:sqlanywhere:database=%s;host=%s -noheader -trim"%(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path,user, password,db_name,self.host)
 		elif os_name == "WINDOWS":
 			jisql_cmd = "%s -cp %s;%s\\jisql\\lib\\* org.apache.util.sql.Jisql -user %s -p \"%s\" -driver sapsajdbc4 -cstring jdbc:sqlanywhere:database=%s;host=%s -noheader -trim"%(self.JAVA_BIN, self.SQL_CONNECTOR_JAR, path, user, password,db_name,self.host)
@@ -981,7 +1002,7 @@ class SqlAnywhereConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying user " + db_user , "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, '')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"select name from syslogins where name = '%s';\"" %(db_user)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"select name from syslogins where name = '%s';\" -c ;" %(db_user)
@@ -995,7 +1016,7 @@ class SqlAnywhereConf(BaseDB):
 	def check_connection(self, db_name, db_user, db_password):
 		log("[I] Checking connection", "info")
 		get_cmd = self.get_jisql_cmd(db_user, db_password, db_name)
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"SELECT 1;\""
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"SELECT 1;\" -c ;"
@@ -1016,13 +1037,15 @@ class SqlAnywhereConf(BaseDB):
 				if dryMode == False:
 					get_cmd = self.get_jisql_cmd(root_user, db_root_password, '')
 					log("[I] User does not exists, Creating Login user " + db_user, "info")
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -c \; -query \"CREATE USER %s IDENTIFIED BY '%s';\"" %(db_user,db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -c \; -query \"CREATE USER %s IDENTIFIED BY '%s';\"" %(db_user,masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(shlex.split(query))
 					elif os_name == "WINDOWS":
 						query = get_cmd + " -query \"CREATE USER %s IDENTIFIED BY '%s';\" -c ;" %(db_user,db_password)
-						jisql_log(query, db_root_password)
+						query_with_masked_pwd = get_cmd + " -c \; -query \"CREATE USER %s IDENTIFIED BY '%s';\"" %(db_user,masked_pwd_string)
+						jisql_log(query_with_masked_pwd, db_root_password)
 						ret = subprocess.call(query)
 					if ret == 0:
 						if self.verify_user(root_user, db_root_password, db_user,dryMode):
@@ -1040,7 +1063,7 @@ class SqlAnywhereConf(BaseDB):
 		if dryMode == False:
 			log("[I] Verifying database " + db_name, "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, '')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"select alias from sa_db_info() where alias='%s';\"" %(db_name)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"select alias from sa_db_info() where alias='%s';\" -c ;" %(db_name)
@@ -1058,13 +1081,15 @@ class SqlAnywhereConf(BaseDB):
 			if dryMode == False:
 				log("[I] Database does not exist. Creating database : " + db_name,"info")
 				get_cmd = self.get_jisql_cmd(root_user, db_root_password, '')
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -c \; -query \"create database '%s' dba user '%s' dba password '%s' database size 100MB;\"" %(db_name,db_user, db_password)
-					jisql_log(query, db_root_password)
+					query_with_masked_pwd = get_cmd + " -c \; -query \"create database '%s' dba user '%s' dba password '%s' database size 100MB;\"" %(db_name,db_user, masked_pwd_string)
+					jisql_log(query_with_masked_pwd, db_root_password)
 					ret = subprocess.call(shlex.split(query))
 				elif os_name == "WINDOWS":
 					query = get_cmd + " -query \"create database '%s' dba user '%s' dba password '%s' database size 100MB;\" -c ;" %(db_name,db_user, db_password)
-					jisql_log(query, db_root_password)
+					query_with_masked_pwd = get_cmd + " -query \"create database '%s' dba user '%s' dba password '%s' database size 100MB;\" -c ;" %(db_name,db_user, masked_pwd_string)
+					jisql_log(query_with_masked_pwd, db_root_password)
 					ret = subprocess.call(query)
 				if ret != 0:
 					log("[E] Database creation failed..","error")
@@ -1083,7 +1108,7 @@ class SqlAnywhereConf(BaseDB):
 
 	def create_user(self, root_user, db_name ,db_user, db_password, db_root_password,dryMode):
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, '')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"select name from syslogins where name ='%s';\"" %(db_user)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"select name from syslogins where name ='%s';\" -c ;" %(db_user)
@@ -1094,16 +1119,18 @@ class SqlAnywhereConf(BaseDB):
 				log("[I] User "+db_user+" exist ","info")
 		else:
 			if dryMode == False:
-				if os_name == "LINUX":
+				if is_unix:
 					query = get_cmd + " -c \; -query \"CREATE USER %s IDENTIFIED BY '%s';\"" %(db_user, db_password)
-					jisql_log(query, db_root_password)
+					query_with_masked_pwd = get_cmd + " -c \; -query \"CREATE USER %s IDENTIFIED BY '%s';\"" %(db_user, masked_pwd_string)
+					jisql_log(query_with_masked_pwd, db_root_password)
 					ret = subprocess.call(shlex.split(query))
 				elif os_name == "WINDOWS":
 					query = get_cmd + " -query \"CREATE USER %s IDENTIFIED BY '%s';\" -c ;" %(db_user, db_password)
-					jisql_log(query, db_root_password)
+					query_with_masked_pwd = get_cmd + " -query \"CREATE USER %s IDENTIFIED BY '%s';\" -c ;" %(db_user, masked_pwd_string)
+					jisql_log(query_with_masked_pwd, db_root_password)
 					ret = subprocess.call(query)
 				if ret == 0:
-					if os_name == "LINUX":
+					if is_unix:
 						query = get_cmd + " -c \; -query \"select name from syslogins where name ='%s';\"" %(db_user)
 					elif os_name == "WINDOWS":
 						query = get_cmd + " -query \"select name from syslogins where name ='%s';\" -c ;" %(db_user)
@@ -1124,13 +1151,15 @@ class SqlAnywhereConf(BaseDB):
 		if dryMode == False:
 			log("[I] Granting permission to user '" + db_user + "' on db '" + db_name + "'" , "info")
 			get_cmd = self.get_jisql_cmd(root_user, db_root_password, '')
-			if os_name == "LINUX":
+			if is_unix:
 				query = get_cmd + " -c \; -query \"GRANT CONNECT to %s IDENTIFIED BY '%s';\"" %(db_user, db_password)
-				jisql_log(query, db_root_password)
+				query_with_masked_pwd = get_cmd + " -c \; -query \"GRANT CONNECT to %s IDENTIFIED BY '%s';\"" %(db_user, masked_pwd_string)
+				jisql_log(query_with_masked_pwd, db_root_password)
 				ret = subprocess.call(shlex.split(query))
 			elif os_name == "WINDOWS":
 				query = get_cmd + " -query \"GRANT CONNECT to %s IDENTIFIED BY '%s';\" -c ;" %(db_user, db_password)
-				jisql_log(query, db_root_password)
+				query_with_masked_pwd = get_cmd + " -query \"GRANT CONNECT to %s IDENTIFIED BY '%s';\" -c ;" %(db_user, masked_pwd_string)
+				jisql_log(query_with_masked_pwd, db_root_password)
 				ret = subprocess.call(query)
 			if ret != 0:
 				sys.exit(1)
@@ -1141,7 +1170,7 @@ class SqlAnywhereConf(BaseDB):
 		if dryMode == False:
 			log("[I] Starting database " + db_name, "info")
 		get_cmd = self.get_jisql_cmd(root_user, db_root_password, '')
-		if os_name == "LINUX":
+		if is_unix:
 			query = get_cmd + " -c \; -query \"start database '%s' autostop off;\"" %(db_name)
 		elif os_name == "WINDOWS":
 			query = get_cmd + " -query \"start database '%s' autostop off;\" -c ;" %(db_name)
@@ -1331,9 +1360,45 @@ def main(argv):
 	x_db_version = 'x_db_version_h'
 	x_user = 'x_portal_user'
 
+	db_ssl_enabled='false'
+	db_ssl_required='false'
+	db_ssl_verifyServerCertificate='false'
+	javax_net_ssl_keyStore=''
+	javax_net_ssl_keyStorePassword=''
+	javax_net_ssl_trustStore=''
+	javax_net_ssl_trustStorePassword=''
 	if XA_DB_FLAVOR == "MYSQL":
+		if 'db_ssl_enabled' in globalDict:
+			db_ssl_enabled=globalDict['db_ssl_enabled'].lower()
+			if db_ssl_enabled == 'true':
+				if 'db_ssl_required' in globalDict:
+					db_ssl_required=globalDict['db_ssl_required'].lower()
+				if 'db_ssl_verifyServerCertificate' in globalDict:
+					db_ssl_verifyServerCertificate=globalDict['db_ssl_verifyServerCertificate'].lower()
+				if db_ssl_verifyServerCertificate == 'true':
+					if 'javax_net_ssl_keyStore' in globalDict:
+						javax_net_ssl_keyStore=globalDict['javax_net_ssl_keyStore']
+					if 'javax_net_ssl_keyStorePassword' in globalDict:
+						javax_net_ssl_keyStorePassword=globalDict['javax_net_ssl_keyStorePassword']
+					if 'javax_net_ssl_trustStore' in globalDict:
+						javax_net_ssl_trustStore=globalDict['javax_net_ssl_trustStore']
+					if 'javax_net_ssl_trustStorePassword' in globalDict:
+						javax_net_ssl_trustStorePassword=globalDict['javax_net_ssl_trustStorePassword']
+					if not os.path.exists(javax_net_ssl_keyStore):
+						log("[E] Invalid file Name! Unable to find keystore file:"+javax_net_ssl_keyStore,"error")
+						sys.exit(1)
+					if not os.path.exists(javax_net_ssl_trustStore):
+						log("[E] Invalid file Name! Unable to find truststore file:"+javax_net_ssl_trustStore,"error")
+						sys.exit(1)
+					if javax_net_ssl_keyStorePassword is None or javax_net_ssl_keyStorePassword =="":
+						log("[E] Invalid ssl keystore password!","error")
+						sys.exit(1)
+					if javax_net_ssl_trustStorePassword is None or javax_net_ssl_trustStorePassword =="":
+						log("[E] Invalid ssl truststore password!","error")
+						sys.exit(1)
+
 		MYSQL_CONNECTOR_JAR=CONNECTOR_JAR
-		xa_sqlObj = MysqlConf(xa_db_host, MYSQL_CONNECTOR_JAR, JAVA_BIN)
+		xa_sqlObj = MysqlConf(xa_db_host, MYSQL_CONNECTOR_JAR, JAVA_BIN,db_ssl_enabled,db_ssl_required,db_ssl_verifyServerCertificate,javax_net_ssl_keyStore,javax_net_ssl_keyStorePassword,javax_net_ssl_trustStore,javax_net_ssl_trustStorePassword)
 		xa_db_core_file = os.path.join(RANGER_KMS_HOME,mysql_core_file)
 
 	elif XA_DB_FLAVOR == "ORACLE":
