@@ -63,6 +63,9 @@ db_host=$(get_prop 'db_host' $PROPFILE)
 db_name=$(get_prop 'db_name' $PROPFILE)
 db_user=$(get_prop 'db_user' $PROPFILE)
 db_password=$(get_prop 'db_password' $PROPFILE)
+db_ssl_enabled=$(get_prop 'db_ssl_enabled' $PROPFILE)
+db_ssl_required=$(get_prop 'db_ssl_required' $PROPFILE)
+db_ssl_verifyServerCertificate=$(get_prop 'db_ssl_verifyServerCertificate' $PROPFILE)
 KMS_MASTER_KEY_PASSWD=$(get_prop 'KMS_MASTER_KEY_PASSWD' $PROPFILE)
 unix_user=$(get_prop 'unix_user' $PROPFILE)
 unix_group=$(get_prop 'unix_group' $PROPFILE)
@@ -88,6 +91,7 @@ sqlanywhere_core_file=$(get_prop 'sqlanywhere_core_file' $PROPFILE)
 cred_keystore_filename=$(eval echo "$(get_prop 'cred_keystore_filename' $PROPFILE)")
 KMS_BLACKLIST_DECRYPT_EEK=$(get_prop 'KMS_BLACKLIST_DECRYPT_EEK' $PROPFILE)
 RANGER_KMS_LOG_DIR=$(eval echo "$(get_prop 'RANGER_KMS_LOG_DIR' $PROPFILE)")
+RANGER_KMS_PID_DIR_PATH=$(eval echo "$(get_prop 'RANGER_KMS_PID_DIR_PATH' $PROPFILE)")
 HSM_TYPE=$(get_prop 'HSM_TYPE' $PROPFILE)
 HSM_ENABLED=$(get_prop 'HSM_ENABLED' $PROPFILE)
 HSM_PARTITION_NAME=$(get_prop 'HSM_PARTITION_NAME' $PROPFILE)
@@ -99,6 +103,16 @@ hadoop_conf=$(get_prop 'hadoop_conf' $PROPFILE)
 
 DB_HOST="${db_host}"
 
+ranger_kms_http_enabled=$(get_prop 'ranger_kms_http_enabled' $PROPFILE)
+ranger_kms_https_keystore_file=$(get_prop 'ranger_kms_https_keystore_file' $PROPFILE)
+ranger_kms_https_keystore_keyalias=$(get_prop 'ranger_kms_https_keystore_keyalias' $PROPFILE)
+ranger_kms_https_keystore_password=$(get_prop 'ranger_kms_https_keystore_password' $PROPFILE)
+
+javax_net_ssl_keyStore=$(get_prop 'javax_net_ssl_keyStore' $PROPFILE)
+javax_net_ssl_keyStorePassword=$(get_prop 'javax_net_ssl_keyStorePassword' $PROPFILE)
+javax_net_ssl_trustStore=$(get_prop 'javax_net_ssl_trustStore' $PROPFILE)
+javax_net_ssl_trustStorePassword=$(get_prop 'javax_net_ssl_trustStorePassword' $PROPFILE)
+
 check_ret_status(){
 	if [ $1 -ne 0 ]; then
 		log "[E] $2";
@@ -250,6 +264,26 @@ init_variables(){
 
    #     log "Create link of conf -> /etc/ranger/kms/conf"
    #     ln -sf ${ETC_CONF_FILE} ${CONF_FILE}	
+	db_ssl_enabled=`echo $db_ssl_enabled | tr '[:upper:]' '[:lower:]'`
+	if [ "${db_ssl_enabled}" != "true" ]
+	then
+		db_ssl_enabled="false"
+		db_ssl_required="false"
+		db_ssl_verifyServerCertificate="false"
+	fi
+	if [ "${db_ssl_enabled}" == "true" ]
+	then
+		db_ssl_required=`echo $db_ssl_required | tr '[:upper:]' '[:lower:]'`
+		db_ssl_verifyServerCertificate=`echo $db_ssl_verifyServerCertificate | tr '[:upper:]' '[:lower:]'`
+		if [ "${db_ssl_required}" != "true" ]
+		then
+			db_ssl_required="false"
+		fi
+		if [ "${db_ssl_verifyServerCertificate}" != "true" ]
+		then
+			db_ssl_verifyServerCertificate="false"
+		fi
+	fi
 }
 
 
@@ -412,6 +446,21 @@ update_properties() {
 		log "[E] $to_file does not exists" ; exit 1;
     fi
 
+	if [ "${db_ssl_enabled}" != "" ]
+	then
+		propertyName=ranger.db.ssl.enabled
+		newPropertyValue="${db_ssl_enabled}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file
+
+		propertyName=ranger.db.ssl.required
+		newPropertyValue="${db_ssl_required}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file
+
+		propertyName=ranger.db.ssl.verifyServerCertificate
+		newPropertyValue="${db_ssl_verifyServerCertificate}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file
+	fi
+
 	if [ "${DB_FLAVOR}" == "MYSQL" ]
 	then
 		propertyName=ranger.ks.jpa.jdbc.url
@@ -635,6 +684,70 @@ update_properties() {
                 updatePropertyToFilePy $propertyName $newPropertyValue $to_file         
         fi
 
+	to_file_kms_site=$PWD/ews/webapp/WEB-INF/classes/conf/ranger-kms-site.xml
+    if test -f $to_file_kms_site; then
+		log "[I] $to_file_kms_site file found"
+	else
+		log "[E] $to_file_kms_site does not exists" ; exit 1;
+    fi
+
+	propertyName=ranger.service.http.enabled
+	newPropertyValue="${ranger_kms_http_enabled}"
+	updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+	if [ "${ranger_kms_http_enabled}" == "false" ]
+	then
+		if [ "${ranger_kms_https_keystore_keyalias}" == "" ]
+		then
+			ranger_kms_https_keystore_keyalias=rangerkms
+		fi
+		if [ "${ranger_kms_https_keystore_file}" != "" ] && [ "${ranger_kms_https_keystore_password}" != "" ]
+		then
+			propertyName=ranger.service.https.attrib.ssl.enabled
+			newPropertyValue="true"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+
+			propertyName=ranger.service.https.attrib.client.auth
+			newPropertyValue="want"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+
+			propertyName=ranger.service.https.attrib.keystore.file
+			newPropertyValue="${ranger_kms_https_keystore_file}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+
+			propertyName=ranger.service.https.attrib.keystore.keyalias
+			newPropertyValue="${ranger_kms_https_keystore_keyalias}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+
+			policymgr_https_keystore_credential_alias=keyStoreCredentialAlias
+			propertyName=ranger.service.https.attrib.keystore.credential.alias
+			newPropertyValue="${policymgr_https_keystore_credential_alias}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+
+			propertyName=ranger.credential.provider.path
+			newPropertyValue="${keystore}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+
+			if [ "${keystore}" != "" ]
+			then
+				propertyName=ranger.service.https.attrib.keystore.pass
+				newPropertyValue="_"
+				updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+				$PYTHON_COMMAND_INVOKER ranger_credential_helper.py -l "cred/lib/*" -f "$keystore" -k "$policymgr_https_keystore_credential_alias" -v "$ranger_kms_https_keystore_password" -c 1
+			else
+				propertyName=ranger.service.https.attrib.keystore.pass
+				newPropertyValue="${ranger_kms_https_keystore_password}"
+				updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+			fi
+			if test -f $keystore; then
+				chown -R ${unix_user}:${unix_group} ${keystore}
+				chmod 640 ${keystore}
+			else
+				propertyName=ranger.service.https.attrib.keystore.pass
+				newPropertyValue="${ranger_kms_https_keystore_password}"
+				updatePropertyToFilePy $propertyName $newPropertyValue $to_file_kms_site
+			fi
+		fi
+	fi
 }
 
 #=====================================================================
@@ -765,6 +878,29 @@ setup_install_files(){
         echo "export RANGER_KMS_LOG_DIR=${RANGER_KMS_LOG_DIR}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-logdir.sh
     	chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-logdir.sh
 
+        if [ ! -d ${RANGER_KMS_PID_DIR_PATH} ]; then
+                log "[I] Creating KMS PID folder: ${RANGER_KMS_PID_DIR_PATH}"
+                mkdir -p ${RANGER_KMS_PID_DIR_PATH}
+        fi
+        if [ -d ${RANGER_KMS_PID_DIR_PATH} ]; then
+                chown -R ${unix_user} ${RANGER_KMS_PID_DIR_PATH}
+        fi
+        echo "export RANGER_KMS_PID_DIR_PATH=${RANGER_KMS_PID_DIR_PATH}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-piddir.sh
+        echo "export KMS_USER=${unix_user}" >> ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-piddir.sh
+        chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-piddir.sh
+
+	if [ "${db_ssl_verifyServerCertificate}" == "true" ]
+	then
+		DB_SSL_PARAM="' -Djavax.net.ssl.keyStore=${javax_net_ssl_keyStore} -Djavax.net.ssl.keyStorePassword=${javax_net_ssl_keyStorePassword} -Djavax.net.ssl.trustStore=${javax_net_ssl_trustStore} -Djavax.net.ssl.trustStorePassword=${javax_net_ssl_trustStorePassword} '"
+		echo "export DB_SSL_PARAM=${DB_SSL_PARAM}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-dbsslparam.sh
+        chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-dbsslparam.sh
+    else
+		if [ -f ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-dbsslparam.sh ]; then
+			DB_SSL_PARAM=""
+			echo "export DB_SSL_PARAM=${DB_SSL_PARAM}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-dbsslparam.sh
+			chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-kms-env-dbsslparam.sh
+		fi
+	fi
 	log "[I] Setting up installation files and directory DONE";
 
 	if [ ! -f ${INSTALL_DIR}/rpm ]; then
