@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -68,7 +68,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see kafka.security.auth.Authorizer#configure(Map<String, Object>)
 	 */
 	@Override
@@ -122,10 +122,10 @@ public class RangerKafkaAuthorizer implements Authorizer {
 			return false;
 		}
 
-		// TODO: If resource type if consumer group, then allow it by default
+		// TODO: If resource type is consumer group, then allow it by default
 		if (resource.resourceType().equals(Group$.MODULE$)) {
 			if (logger.isDebugEnabled()) {
-				logger.debug("If resource type if consumer group, then we allow it by default!  Returning true");
+				logger.debug("If resource type is consumer group, then we allow it by default!  Returning true");
 			}
 			return true;
 		}
@@ -160,6 +160,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 			validationStr += "Unsupported access type. operation=" + operation;
 		}
 		String action = accessType;
+		String clusterName = rangerPlugin.getClusterName();
 
 		RangerAccessRequestImpl rangerRequest = new RangerAccessRequestImpl();
 		rangerRequest.setUser(userName);
@@ -172,6 +173,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 		rangerRequest.setAccessType(accessType);
 		rangerRequest.setAction(action);
 		rangerRequest.setRequestData(resource.name());
+		rangerRequest.setClusterName(clusterName);
 
 		if (resource.resourceType().equals(Topic$.MODULE$)) {
 			rangerResource.setValue(KEY_TOPIC, resource.name());
@@ -213,7 +215,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see
 	 * kafka.security.auth.Authorizer#addAcls(scala.collection.immutable.Set,
 	 * kafka.security.auth.Resource)
@@ -225,7 +227,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see
 	 * kafka.security.auth.Authorizer#removeAcls(scala.collection.immutable.Set,
 	 * kafka.security.auth.Resource)
@@ -238,7 +240,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see
 	 * kafka.security.auth.Authorizer#removeAcls(kafka.security.auth.Resource)
 	 */
@@ -250,7 +252,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see kafka.security.auth.Authorizer#getAcls(kafka.security.auth.Resource)
 	 */
 	@Override
@@ -263,7 +265,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see
 	 * kafka.security.auth.Authorizer#getAcls(kafka.security.auth.KafkaPrincipal
 	 * )
@@ -278,7 +280,7 @@ public class RangerKafkaAuthorizer implements Authorizer {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see kafka.security.auth.Authorizer#getAcls()
 	 */
 	@Override
