@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -66,13 +66,15 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 	      "User:%s not allowed to do '%s'";
 
 	  public static final int RELOADER_SLEEP_MILLIS = 1000;
-	  
+	
+	  private static final Map<KMSACLsType.Type, String> ACCESS_TYPE_MAP = new HashMap<>();
+	
 	  private volatile Map<Type, AccessControlList> blacklistedAcls;
-	  
+	
 	  private long lastReload;
 
 	  private ScheduledExecutorService executorService;
-	  
+	
 	  public static final String ACCESS_TYPE_DECRYPT_EEK   	= "decrypteek";
 	  public static final String ACCESS_TYPE_GENERATE_EEK   = "generateeek";
 	  public static final String ACCESS_TYPE_GET_METADATA  	= "getmetadata";
@@ -81,7 +83,7 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 	  public static final String ACCESS_TYPE_SET_KEY_MATERIAL= "setkeymaterial";
 	  public static final String ACCESS_TYPE_ROLLOVER       = "rollover";
 	  public static final String ACCESS_TYPE_CREATE       	= "create";
-	  public static final String ACCESS_TYPE_DELETE       	= "delete";	  
+	  public static final String ACCESS_TYPE_DELETE       	= "delete";	
 
 	  private static volatile RangerKMSPlugin kmsPlugin = null;
 
@@ -99,11 +101,23 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 	   * Constant for the configuration property that indicates the keytab file path.
 	   */
 	  public static final String KEYTAB = TYPE + ".keytab";
+	
+	  static {
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.CREATE, RangerKmsAuthorizer.ACCESS_TYPE_CREATE);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.DELETE, RangerKmsAuthorizer.ACCESS_TYPE_DELETE);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.ROLLOVER, RangerKmsAuthorizer.ACCESS_TYPE_ROLLOVER);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.GET, RangerKmsAuthorizer.ACCESS_TYPE_GET);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.GET_KEYS, RangerKmsAuthorizer.ACCESS_TYPE_GET_KEYS);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.GET_METADATA, RangerKmsAuthorizer.ACCESS_TYPE_GET_METADATA);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.SET_KEY_MATERIAL, RangerKmsAuthorizer.ACCESS_TYPE_SET_KEY_MATERIAL);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.GENERATE_EEK, RangerKmsAuthorizer.ACCESS_TYPE_GENERATE_EEK);
+		  ACCESS_TYPE_MAP.put(KMSACLsType.Type.DECRYPT_EEK, RangerKmsAuthorizer.ACCESS_TYPE_DECRYPT_EEK);
+	  }
 
 	  RangerKmsAuthorizer(Configuration conf) {
 		  LOG.info("RangerKmsAuthorizer(conf)...");
 		  if (conf == null) {
-		      conf = loadACLs();		      
+		      conf = loadACLs();		
 		  }
 		  authWithKerberos(conf);
 		  setKMSACLs(conf);	
@@ -135,7 +149,7 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 	  public RangerKmsAuthorizer() {
 	    this(null);
 	  }
-	  
+	
 	  @Override
 	  public void run() {
 		  try {
@@ -147,7 +161,7 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 		          String.format("Could not reload ACLs file: '%s'", ex.toString()), ex);
 		  }
 	  }
-	  
+	
 	  private Configuration loadACLs() {
 		  LOG.debug("Loading ACLs file");
 		  lastReload = System.currentTimeMillis();
@@ -194,9 +208,10 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 		    if(!ret){
 		    	LOG.debug("Operation "+rangerAccessType+" blocked in the blacklist for user "+ugi.getUserName());
 		    }
-		    
+		    String clusterName = kmsPlugin.getClusterName();
+		
 			if(plugin != null && ret) {				
-				RangerKMSAccessRequest request = new RangerKMSAccessRequest("", rangerAccessType, ugi, clientIp);
+				RangerKMSAccessRequest request = new RangerKMSAccessRequest("", rangerAccessType, ugi, clientIp, clusterName);
 				RangerAccessResult result = plugin.isAccessAllowed(request);
 				ret = result == null ? false : result.getIsAllowed();
 			}
@@ -207,7 +222,7 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 
 			return ret;
 	  }
-	  
+	
 	  public boolean hasAccess(Type type, UserGroupInformation ugi, String keyName, String clientIp) {
 		  if(LOG.isDebugEnabled()) {
 				LOG.debug("==> RangerKmsAuthorizer.hasAccess(" + type + ", " + ugi + " , "+keyName+")");
@@ -220,9 +235,10 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 		    if(!ret){
 		    	LOG.debug("Operation "+rangerAccessType+" blocked in the blacklist for user "+ugi.getUserName());
 		    }
-		    
+		    String clusterName = kmsPlugin.getClusterName();
+		
 			if(plugin != null && ret) {				
-				RangerKMSAccessRequest request = new RangerKMSAccessRequest(keyName, rangerAccessType, ugi, clientIp);
+				RangerKMSAccessRequest request = new RangerKMSAccessRequest(keyName, rangerAccessType, ugi, clientIp, clusterName);
 				RangerAccessResult result = plugin.isAccessAllowed(request);
 				ret = result == null ? false : result.getIsAllowed();
 			}
@@ -253,9 +269,6 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 
 	  @Override
 	  public boolean hasAccessToKey(String keyName, UserGroupInformation ugi, KeyOpType opType) {
-		  if(LOG.isDebugEnabled()) {
-				LOG.debug("==> RangerKmsAuthorizer.hasAccessToKey(" + keyName + ", " + ugi +", " + opType + ")");
-			}
 			if(LOG.isDebugEnabled()) {
 				LOG.debug("<== RangerKmsAuthorizer.hasAccessToKey(" + keyName + ", " + ugi +", " + opType + ")");
 			}
@@ -307,46 +320,11 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 		}
 
 		private static String getRangerAccessType(KMSACLsType.Type accessType) {
-			String ret = null;
-		
-			switch(accessType) {
-				case CREATE:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_CREATE;
-				break;
-
-				case DELETE:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_DELETE;
-				break;
-				
-				case ROLLOVER:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_ROLLOVER;
-				break;
-				
-				case GET:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_GET;
-				break;
-				
-				case GET_KEYS:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_GET_KEYS;
-				break;
-				
-				case GET_METADATA:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_GET_METADATA;
-				break;
-				
-				case SET_KEY_MATERIAL:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_SET_KEY_MATERIAL;
-				break;
-				
-				case GENERATE_EEK:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_GENERATE_EEK;
-				break;
-				
-				case DECRYPT_EEK:
-					ret = RangerKmsAuthorizer.ACCESS_TYPE_DECRYPT_EEK;
-				break;			
+			if (ACCESS_TYPE_MAP.containsKey(accessType)) {
+				return ACCESS_TYPE_MAP.get(accessType);
 			}
-			return ret;
+			
+			return null;
 		}
 	}
 
@@ -376,7 +354,7 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 	}
 
 	class RangerKMSAccessRequest extends RangerAccessRequestImpl {
-		public RangerKMSAccessRequest(String keyName, String accessType, UserGroupInformation ugi, String clientIp) {
+		public RangerKMSAccessRequest(String keyName, String accessType, UserGroupInformation ugi, String clientIp, String clusterName) {
 			super.setResource(new RangerKMSResource(keyName));
 			super.setAccessType(accessType);
 			super.setUser(ugi.getShortUserName());
@@ -384,5 +362,6 @@ public class RangerKmsAuthorizer implements Runnable, KeyACLs {
 			super.setAccessTime(new Date());
 			super.setClientIPAddress(clientIp);			
 			super.setAction(accessType);
+			super.setClusterName(clusterName);
 		}
 	}
