@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -54,7 +54,7 @@ import com.sun.jersey.api.client.config.DefaultClientConfig;
 
 public class KMSClient {
 
-	public static final Logger LOG = Logger.getLogger(KMSClient.class);
+	private static final Logger LOG = Logger.getLogger(KMSClient.class);
 
 	private static final String EXPECTED_MIME_TYPE = "application/json";
 
@@ -193,7 +193,7 @@ public class KMSClient {
 						uri = uri.concat("?doAs="+shortName);
 						String decryptedPwd = PasswordUtils.decryptPassword(password);
 						sub = SecureClientLogin.loginUserWithPassword(username, decryptedPwd);						
-					} 
+					}
 				}
 				final WebResource webResource = client.resource(uri);
 				response = Subject.doAs(sub, new PrivilegedAction<ClientResponse>() {
@@ -305,13 +305,13 @@ public class KMSClient {
 		return lret;
 	}
 
-	public static HashMap<String, Object> testConnection(String serviceName,
+	public static Map<String, Object> testConnection(String serviceName,
 			Map<String, String> configs) {
 
 		List<String> strList = new ArrayList<String>();
 		String errMsg = errMessage;
 		boolean connectivityStatus = false;
-		HashMap<String, Object> responseData = new HashMap<String, Object>();
+		Map<String, Object> responseData = new HashMap<String, Object>();
 
 		KMSClient kmsClient = getKmsClient(serviceName, configs);
 		strList = getKmsKey(kmsClient, "", null);
