@@ -19,14 +19,6 @@
 #
 # This script will install policymanager webapplication under tomcat and also, initialize the database with ranger users/tables.
 
-PROPFILE=$PWD/install.properties
-propertyValue=''
-pidFolderName='/var/run/ranger'
-mkdir -p ${pidFolderName}
-if [ ! $? = "0" ];then
-	log "$PROPFILE file not found....!!";
-	exit 1;
-fi
 usage() {
   [ "$*" ] && echo "$0: $*"
   sed -n '/^##/,/^$/s/^## \{0,1\}//p' "$0"
@@ -50,6 +42,20 @@ get_prop(){
         fi
 }
 
+PROPFILE=$PWD/install.properties
+if [ ! -f "${PROPFILE}" ]; then
+    echo "$PROPFILE file not found....!!"
+    exit 1;
+fi
+
+LOGFILE=$(eval echo " $(get_prop 'LOGFILE' $PROPFILE)")
+pidFolderName='/var/run/ranger'
+mkdir -p ${pidFolderName}
+if [ ! $? = "0" ];then
+    log "Make $pidFolderName failure....!!";
+    exit 1;
+fi
+
 PYTHON_COMMAND_INVOKER=$(get_prop 'PYTHON_COMMAND_INVOKER' $PROPFILE)
 DB_FLAVOR=$(get_prop 'DB_FLAVOR' $PROPFILE)
 SQL_CONNECTOR_JAR=$(get_prop 'SQL_CONNECTOR_JAR' $PROPFILE)
@@ -59,6 +65,13 @@ db_host=$(get_prop 'db_host' $PROPFILE)
 db_name=$(get_prop 'db_name' $PROPFILE)
 db_user=$(get_prop 'db_user' $PROPFILE)
 db_password=$(get_prop 'db_password' $PROPFILE)
+db_ssl_enabled=$(get_prop 'db_ssl_enabled' $PROPFILE)
+db_ssl_required=$(get_prop 'db_ssl_required' $PROPFILE)
+db_ssl_verifyServerCertificate=$(get_prop 'db_ssl_verifyServerCertificate' $PROPFILE)
+javax_net_ssl_keyStore=$(get_prop 'javax_net_ssl_keyStore' $PROPFILE)
+javax_net_ssl_keyStorePassword=$(get_prop 'javax_net_ssl_keyStorePassword' $PROPFILE)
+javax_net_ssl_trustStore=$(get_prop 'javax_net_ssl_trustStore' $PROPFILE)
+javax_net_ssl_trustStorePassword=$(get_prop 'javax_net_ssl_trustStorePassword' $PROPFILE)
 audit_store=$(get_prop 'audit_store' $PROPFILE)
 audit_solr_urls=$(get_prop 'audit_solr_urls' $PROPFILE)
 audit_solr_user=$(get_prop 'audit_solr_user' $PROPFILE)
@@ -69,6 +82,9 @@ audit_db_user=''
 audit_db_password=''
 policymgr_external_url=$(get_prop 'policymgr_external_url' $PROPFILE)
 policymgr_http_enabled=$(get_prop 'policymgr_http_enabled' $PROPFILE)
+policymgr_https_keystore_file=$(get_prop 'policymgr_https_keystore_file' $PROPFILE)
+policymgr_https_keystore_keyalias=$(get_prop 'policymgr_https_keystore_keyalias' $PROPFILE)
+policymgr_https_keystore_password=$(get_prop 'policymgr_https_keystore_password' $PROPFILE)
 policymgr_supportedcomponents=$(get_prop 'policymgr_supportedcomponents' $PROPFILE)
 unix_user=$(get_prop 'unix_user' $PROPFILE)
 unix_group=$(get_prop 'unix_group' $PROPFILE)
@@ -76,6 +92,10 @@ authentication_method=$(get_prop 'authentication_method' $PROPFILE)
 remoteLoginEnabled=$(get_prop 'remoteLoginEnabled' $PROPFILE)
 authServiceHostName=$(get_prop 'authServiceHostName' $PROPFILE)
 authServicePort=$(get_prop 'authServicePort' $PROPFILE)
+ranger_unixauth_keystore=$(get_prop 'ranger_unixauth_keystore' $PROPFILE)
+ranger_unixauth_keystore_password=$(get_prop 'ranger_unixauth_keystore_password' $PROPFILE)
+ranger_unixauth_truststore=$(get_prop 'ranger_unixauth_truststore' $PROPFILE)
+ranger_unixauth_truststore_password=$(get_prop 'ranger_unixauth_truststore_password' $PROPFILE)
 xa_ldap_url=$(get_prop 'xa_ldap_url' $PROPFILE)
 xa_ldap_userDNpattern=$(get_prop 'xa_ldap_userDNpattern' $PROPFILE)
 xa_ldap_groupSearchBase=$(get_prop 'xa_ldap_groupSearchBase' $PROPFILE)
@@ -96,7 +116,6 @@ xa_ldap_ad_userSearchFilter=$(get_prop 'xa_ldap_ad_userSearchFilter' $PROPFILE)
 XAPOLICYMGR_DIR=$(eval echo "$(get_prop 'XAPOLICYMGR_DIR' $PROPFILE)")
 app_home=$(eval echo "$(get_prop 'app_home' $PROPFILE)")
 TMPFILE=$(eval echo "$(get_prop 'TMPFILE' $PROPFILE)")
-LOGFILE=$(eval echo " $(get_prop 'LOGFILE' $PROPFILE)")
 LOGFILES=$(eval echo "$(get_prop 'LOGFILES' $PROPFILE)")
 JAVA_BIN=$(get_prop 'JAVA_BIN' $PROPFILE)
 JAVA_VERSION_REQUIRED=$(get_prop 'JAVA_VERSION_REQUIRED' $PROPFILE)
@@ -116,6 +135,7 @@ sso_enabled=$(get_prop 'sso_enabled' $PROPFILE)
 sso_providerurl=$(get_prop 'sso_providerurl' $PROPFILE)
 sso_publickey=$(get_prop 'sso_publickey' $PROPFILE)
 RANGER_ADMIN_LOG_DIR=$(eval echo "$(get_prop 'RANGER_ADMIN_LOG_DIR' $PROPFILE)")
+RANGER_PID_DIR_PATH=$(eval echo "$(get_prop 'RANGER_PID_DIR_PATH' $PROPFILE)")
 
 spnego_principal=$(get_prop 'spnego_principal' $PROPFILE)
 spnego_keytab=$(get_prop 'spnego_keytab' $PROPFILE)
@@ -228,6 +248,26 @@ init_variables(){
 		audit_db_user=$(get_prop 'audit_db_user' $PROPFILE)
 		audit_db_password=$(get_prop 'audit_db_password' $PROPFILE)
 	fi
+	db_ssl_enabled=`echo $db_ssl_enabled | tr '[:upper:]' '[:lower:]'`
+	if [ "${db_ssl_enabled}" != "true" ]
+	then
+		db_ssl_enabled="false"
+		db_ssl_required="false"
+		db_ssl_verifyServerCertificate="false"
+	fi
+	if [ "${db_ssl_enabled}" == "true" ]
+	then
+		db_ssl_required=`echo $db_ssl_required | tr '[:upper:]' '[:lower:]'`
+		db_ssl_verifyServerCertificate=`echo $db_ssl_verifyServerCertificate | tr '[:upper:]' '[:lower:]'`
+		if [ "${db_ssl_required}" != "true" ]
+		then
+			db_ssl_required="false"
+		fi
+		if [ "${db_ssl_verifyServerCertificate}" != "true" ]
+		then
+			db_ssl_verifyServerCertificate="false"
+		fi
+	fi
 }
 
 check_python_command() {
@@ -432,6 +472,21 @@ update_properties() {
                updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
 	fi
 
+	if [ "${db_ssl_enabled}" != "" ]
+	then
+		propertyName=ranger.db.ssl.enabled
+		newPropertyValue="${db_ssl_enabled}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.db.ssl.required
+		newPropertyValue="${db_ssl_required}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.db.ssl.verifyServerCertificate
+		newPropertyValue="${db_ssl_verifyServerCertificate}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+	fi
+
 	if [ "${DB_FLAVOR}" == "MYSQL" ]
 	then
 		propertyName=ranger.jpa.jdbc.url
@@ -782,6 +837,183 @@ update_properties() {
                 updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
 
 	fi
+	if [ "${javax_net_ssl_keyStore}" != "" ]  && [ "${javax_net_ssl_keyStorePassword}" != "" ]
+	then
+		javax_net_ssl_keyStoreAlias=keyStoreAlias
+
+		propertyName=ranger.keystore.file
+		newPropertyValue="${javax_net_ssl_keyStore}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.keystore.alias
+		newPropertyValue="${javax_net_ssl_keyStoreAlias}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		if [ "${keystore}" != "" ]
+		then
+			propertyName=ranger.keystore.password
+			newPropertyValue="_"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+			$PYTHON_COMMAND_INVOKER ranger_credential_helper.py -l "cred/lib/*" -f "$keystore" -k "$javax_net_ssl_keyStoreAlias" -v "$javax_net_ssl_keyStorePassword" -c 1
+		else
+			propertyName=ranger.keystore.password
+			newPropertyValue="${javax_net_ssl_keyStorePassword}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+
+		if test -f $keystore; then
+			chown -R ${unix_user}:${unix_group} ${keystore}
+		else
+			propertyName=ranger.keystore.password
+			newPropertyValue="${javax_net_ssl_keyStorePassword}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+
+	fi
+	if [ "${javax_net_ssl_trustStore}" != "" ]  && [ "${javax_net_ssl_trustStorePassword}" != "" ]
+	then
+		javax_net_ssl_trustStoreAlias=trustStoreAlias
+
+		propertyName=ranger.truststore.file
+		newPropertyValue="${javax_net_ssl_trustStore}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.truststore.alias
+		newPropertyValue="${javax_net_ssl_trustStoreAlias}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		if [ "${keystore}" != "" ]
+		then
+			propertyName=ranger.truststore.password
+			newPropertyValue="_"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+			$PYTHON_COMMAND_INVOKER ranger_credential_helper.py -l "cred/lib/*" -f "$keystore" -k "$javax_net_ssl_trustStoreAlias" -v "$javax_net_ssl_trustStorePassword" -c 1
+		else
+			propertyName=ranger.truststore.password
+			newPropertyValue="${javax_net_ssl_trustStorePassword}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+		if test -f $keystore; then
+			chown -R ${unix_user}:${unix_group} ${keystore}
+		else
+			propertyName=ranger.truststore.password
+			newPropertyValue="${javax_net_ssl_trustStorePassword}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+
+	fi
+	if [ "${policymgr_http_enabled}" == "false" ]
+	then
+		if [ "${policymgr_https_keystore_keyalias}" == "" ]
+		then
+			policymgr_https_keystore_keyalias=rangeradmin
+		fi
+		if [ "${policymgr_https_keystore_file}" != "" ] && [ "${policymgr_https_keystore_password}" != "" ]
+		then
+			propertyName=ranger.service.https.attrib.ssl.enabled
+			newPropertyValue="true"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+
+			propertyName=ranger.service.https.attrib.client.auth
+			newPropertyValue="want"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+			propertyName=ranger.service.https.attrib.keystore.file
+			newPropertyValue="${policymgr_https_keystore_file}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+
+			propertyName=ranger.service.https.attrib.keystore.keyalias
+			newPropertyValue="${policymgr_https_keystore_keyalias}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+
+			policymgr_https_keystore_credential_alias=keyStoreCredentialAlias
+			propertyName=ranger.service.https.attrib.keystore.credential.alias
+			newPropertyValue="${policymgr_https_keystore_credential_alias}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+
+			if [ "${keystore}" != "" ]
+			then
+				propertyName=ranger.service.https.attrib.keystore.pass
+				newPropertyValue="_"
+				updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+				$PYTHON_COMMAND_INVOKER ranger_credential_helper.py -l "cred/lib/*" -f "$keystore" -k "$policymgr_https_keystore_credential_alias" -v "$policymgr_https_keystore_password" -c 1
+			else
+				propertyName=ranger.service.https.attrib.keystore.pass
+				newPropertyValue="${policymgr_https_keystore_password}"
+				updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+			fi
+			if test -f $keystore; then
+				chown -R ${unix_user}:${unix_group} ${keystore}
+			else
+				propertyName=ranger.service.https.attrib.keystore.pass
+				newPropertyValue="${policymgr_https_keystore_password}"
+				updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+			fi
+		fi
+	fi
+
+	if [ "${ranger_unixauth_keystore}" != "" ] && [ "${ranger_unixauth_keystore_password}" != "" ]
+	then
+		propertyName=ranger.unixauth.keystore
+		newPropertyValue="${ranger_unixauth_keystore}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		ranger_unixauth_keystore_alias=unixAuthKeyStoreAlias
+		propertyName=ranger.unixauth.keystore.credential.alias
+		newPropertyValue="${ranger_unixauth_keystore_alias}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		if [ "${keystore}" != "" ]
+		then
+			propertyName=ranger.unixauth.keystore.password
+			newPropertyValue="_"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+			$PYTHON_COMMAND_INVOKER ranger_credential_helper.py -l "cred/lib/*" -f "$keystore" -k "$ranger_unixauth_keystore_alias" -v "$ranger_unixauth_keystore_password" -c 1
+		else
+			propertyName=ranger.unixauth.keystore.password
+			newPropertyValue="${ranger_unixauth_keystore_password}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+		if test -f $keystore; then
+			chown -R ${unix_user}:${unix_group} ${keystore}
+		else
+			propertyName=ranger.unixauth.keystore.password
+			newPropertyValue="${ranger_unixauth_keystore_password}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+	fi
+
+	if [ "${ranger_unixauth_truststore}" != "" ] && [ "${ranger_unixauth_truststore_password}" != "" ]
+	then
+		propertyName=ranger.unixauth.truststore
+		newPropertyValue="${ranger_unixauth_truststore}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		ranger_unixauth_truststore_alias=unixAuthTrustStoreAlias
+		propertyName=ranger.unixauth.truststore.credential.alias
+		newPropertyValue="${ranger_unixauth_truststore_alias}"
+		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		if [ "${keystore}" != "" ]
+		then
+			propertyName=ranger.unixauth.truststore.password
+			newPropertyValue="_"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+			$PYTHON_COMMAND_INVOKER ranger_credential_helper.py -l "cred/lib/*" -f "$keystore" -k "$ranger_unixauth_truststore_alias" -v "$ranger_unixauth_truststore_password" -c 1
+		else
+			propertyName=ranger.unixauth.truststore.password
+			newPropertyValue="${ranger_unixauth_truststore_password}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+		if test -f $keystore; then
+			chown -R ${unix_user}:${unix_group} ${keystore}
+		else
+			propertyName=ranger.unixauth.truststore.password
+			newPropertyValue="${ranger_unixauth_truststore_password}"
+			updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+		fi
+	fi
+
 }
 
 do_unixauth_setup() {
@@ -1132,6 +1364,29 @@ setup_install_files(){
         echo "export RANGER_ADMIN_LOG_DIR=${RANGER_ADMIN_LOG_DIR}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-logdir.sh
         chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-logdir.sh
 
+        if [ ! -d ${RANGER_PID_DIR_PATH} ]; then
+                log "[I]Creating Ranger PID folder: ${RANGER_PID_DIR_PATH}"
+                mkdir -p ${RANGER_PID_DIR_PATH}
+        fi
+        if [ -d ${RANGER_PID_DIR_PATH} ]; then
+                chown -R ${unix_user} ${RANGER_PID_DIR_PATH}
+        fi
+        echo "export RANGER_PID_DIR_PATH=${RANGER_PID_DIR_PATH}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-piddir.sh
+        echo "export RANGER_USER=${unix_user}" >> ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-piddir.sh
+        chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-piddir.sh
+
+	if [ "${db_ssl_verifyServerCertificate}" == "true" ]
+	then
+		DB_SSL_PARAM="' -Djavax.net.ssl.keyStore=${javax_net_ssl_keyStore} -Djavax.net.ssl.keyStorePassword=${javax_net_ssl_keyStorePassword} -Djavax.net.ssl.trustStore=${javax_net_ssl_trustStore} -Djavax.net.ssl.trustStorePassword=${javax_net_ssl_trustStorePassword} '"
+		echo "export DB_SSL_PARAM=${DB_SSL_PARAM}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-dbsslparam.sh
+        chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-dbsslparam.sh
+	else
+		if [ -f ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-dbsslparam.sh ]; then
+			DB_SSL_PARAM=""
+			echo "export DB_SSL_PARAM=${DB_SSL_PARAM}" > ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-dbsslparam.sh
+			chmod a+rx ${WEBAPP_ROOT}/WEB-INF/classes/conf/ranger-admin-env-dbsslparam.sh
+		fi
+	fi
 	log "[I] Setting up installation files and directory DONE";
 
 	if [ ! -f ${INSTALL_DIR}/rpm ]; then
@@ -1166,24 +1421,29 @@ check_python_command
 run_dba_steps
 if [ "$?" == "0" ]
 then
-$PYTHON_COMMAND_INVOKER db_setup.py
-else
-	exit 1
-fi
-if [ "$?" == "0" ]
-then
-update_properties
-do_authentication_setup
+	update_properties
+	do_authentication_setup
 else
 	log "[E] DB schema setup failed! Please contact Administrator."
 	exit 1
 fi
-$PYTHON_COMMAND_INVOKER db_setup.py -javapatch
 if [ "$?" == "0" ]
 then
-echo "ln -sf ${WEBAPP_ROOT}/WEB-INF/classes/conf ${INSTALL_DIR}/conf"
-ln -sf ${WEBAPP_ROOT}/WEB-INF/classes/conf ${INSTALL_DIR}/conf
-echo "Installation of Ranger PolicyManager Web Application is completed."
+	echo "ln -sf ${WEBAPP_ROOT}/WEB-INF/classes/conf ${INSTALL_DIR}/conf"
+	ln -sf ${WEBAPP_ROOT}/WEB-INF/classes/conf ${INSTALL_DIR}/conf
 else
 	exit 1
 fi
+if [ "$?" == "0" ]
+then
+	$PYTHON_COMMAND_INVOKER db_setup.py
+	if [ "$?" == "0" ]
+	then
+		$PYTHON_COMMAND_INVOKER db_setup.py -javapatch
+	else
+		exit 1
+	fi
+else
+	exit 1
+fi
+echo "Installation of Ranger PolicyManager Web Application is completed."
