@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -23,6 +23,7 @@ import java.io.File;
 import java.io.IOException;
 import java.security.cert.X509Certificate;
 import java.util.ArrayList;
+import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -32,8 +33,10 @@ import java.util.Set;
 import javax.naming.InvalidNameException;
 import javax.naming.ldap.LdapName;
 import javax.naming.ldap.Rdn;
+import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import org.apache.commons.lang.StringUtils;
 import org.apache.log4j.Logger;
 import org.apache.ranger.common.AppConstants;
 import org.apache.ranger.common.DateUtil;
@@ -45,10 +48,15 @@ import org.apache.ranger.common.SearchCriteria;
 import org.apache.ranger.common.StringUtil;
 import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.entity.XXPermMap;
+import org.apache.ranger.entity.XXPluginInfo;
 import org.apache.ranger.entity.XXPolicyExportAudit;
 import org.apache.ranger.entity.XXPortalUser;
 import org.apache.ranger.entity.XXTrxLog;
 import org.apache.ranger.entity.XXUser;
+import org.apache.ranger.plugin.model.RangerPluginInfo;
+import org.apache.ranger.plugin.util.RangerRESTUtils;
+import org.apache.ranger.service.RangerPluginActivityLogger;
+import org.apache.ranger.service.RangerPluginInfoService;
 import org.apache.ranger.service.XAccessAuditService;
 import org.apache.ranger.service.XAuditMapService;
 import org.apache.ranger.service.XGroupService;
@@ -58,25 +66,26 @@ import org.apache.ranger.service.XTrxLogService;
 import org.apache.ranger.service.XUserService;
 import org.apache.ranger.solr.SolrAccessAuditsService;
 import org.apache.ranger.util.RestUtil;
-import org.apache.ranger.view.*;
+import org.apache.ranger.view.VXAccessAuditList;
+import org.apache.ranger.view.VXAsset;
+import org.apache.ranger.view.VXAuditMap;
+import org.apache.ranger.view.VXPermMap;
+import org.apache.ranger.view.VXPolicyExportAuditList;
+import org.apache.ranger.view.VXResource;
+import org.apache.ranger.view.VXTrxLog;
+import org.apache.ranger.view.VXTrxLogList;
+import org.apache.ranger.view.VXUser;
 import org.codehaus.jackson.JsonGenerationException;
 import org.codehaus.jackson.map.JsonMappingException;
 import org.springframework.beans.factory.annotation.Autowired;
-import org.springframework.beans.factory.annotation.Qualifier;
 import org.springframework.stereotype.Component;
-import org.springframework.transaction.PlatformTransactionManager;
-import org.springframework.transaction.TransactionDefinition;
-import org.springframework.transaction.TransactionStatus;
-import org.springframework.transaction.support.TransactionCallback;
-import org.springframework.transaction.support.TransactionTemplate;
 
 @Component
 public class AssetMgr extends AssetMgrBase {
-	
-	
+
 	@Autowired
 	XPermMapService xPermMapService;
-	
+
 	@Autowired
 	XAuditMapService xAuditMapService;
 
@@ -113,15 +122,16 @@ public class AssetMgr extends AssetMgrBase {
 	@Autowired
 	SolrAccessAuditsService solrAccessAuditsService;
 
-	@Autowired
-	@Qualifier(value = "transactionManager")
-	PlatformTransactionManager txManager;
-	
 	@Autowired
 	XPolicyService xPolicyService;
-	
-	static Logger logger = Logger.getLogger(AssetMgr.class);
 
+	@Autowired
+	RangerPluginActivityLogger activityLogger;
+
+	@Autowired
+	RangerPluginInfoService pluginInfoService;
+
+	private static final Logger logger = Logger.getLogger(AssetMgr.class);
 
 	public File getXResourceFile(Long id, String fileType) {
 		VXResource xResource = xResourceService.readResource(id);
@@ -171,8 +181,8 @@ public class AssetMgr extends AssetMgrBase {
 	}
 
 	public String getLatestRepoPolicy(VXAsset xAsset, List<VXResource> xResourceList, Long updatedTime,
-			X509Certificate[] certchain, boolean httpEnabled, String epoch,
-			String ipAddress, boolean isSecure, String count, String agentId) {
+									  X509Certificate[] certchain, boolean httpEnabled, String epoch,
+									  String ipAddress, boolean isSecure, String count, String agentId) {
 		if(xAsset==null){
 			logger.error("Requested repository not found");
 			throw restErrorUtil.createRESTException("No Data Found.",
@@ -204,7 +214,7 @@ public class AssetMgr extends AssetMgrBase {
 		if (epoch != null && !epoch.trim().isEmpty() && !epoch.equalsIgnoreCase("null")) {
 			policyExportAudit.setRequestedEpoch(Long.parseLong(epoch));
 		} else {
-			policyExportAudit.setRequestedEpoch(0l);
+			policyExportAudit.setRequestedEpoch(0L);
 		}
 
 		if (!httpEnabled) {
@@ -271,7 +281,7 @@ public class AssetMgr extends AssetMgrBase {
 		}
 
 		if (policyCount == null) {
-			policyCount = 0l;
+			policyCount = 0L;
 		}
 
 		if (commonName != null) {
@@ -295,7 +305,7 @@ public class AssetMgr extends AssetMgrBase {
 		long epochTime = epoch != null ? Long.parseLong(epoch) : 0;
 
 		if(epochTime == updatedTime) {
-			int resourceListSz = xResourceList.size() ;
+			int resourceListSz = xResourceList.size();
 			
 			if (policyCount == resourceListSz) {
 				policyExportAudit
@@ -401,8 +411,8 @@ public class AssetMgr extends AssetMgrBase {
 				HashMap<String, Object> resourceMap = new HashMap<String, Object>();
 
 				resourceMap.put("id", xResource.getId());
-				resourceMap.put("topology_name", xResource.getTopologies()) ;
-				resourceMap.put("service_name", xResource.getServices()) ;
+				resourceMap.put("topology_name", xResource.getTopologies());
+				resourceMap.put("service_name", xResource.getServices());
 				resourceMap.put("policyStatus", RangerCommonEnums
 						.getLabelFor_ActiveStatus(xResource
 								.getResourceStatus()));
@@ -429,7 +439,7 @@ public class AssetMgr extends AssetMgrBase {
                         HashMap<String, Object> resourceMap = new HashMap<String, Object>();
 
                         resourceMap.put("id", xResource.getId());
-                        resourceMap.put("topology_name", xResource.getTopologies()) ;
+                        resourceMap.put("topology_name", xResource.getTopologies());
                         resourceMap.put("policyStatus", RangerCommonEnums
                                         .getLabelFor_ActiveStatus(xResource
                                                         .getResourceStatus()));
@@ -631,26 +641,259 @@ public class AssetMgr extends AssetMgrBase {
 
 	public XXPolicyExportAudit createPolicyAudit(
 			final XXPolicyExportAudit xXPolicyExportAudit) {
-		TransactionTemplate txTemplate = new TransactionTemplate(txManager);
-		txTemplate
-				.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRED);
-		XXPolicyExportAudit policyExportAudit = (XXPolicyExportAudit) txTemplate
-				.execute(new TransactionCallback<Object>() {
-					public Object doInTransaction(TransactionStatus status) {
-						if (xXPolicyExportAudit.getHttpRetCode() == HttpServletResponse.SC_NOT_MODIFIED) {
-							boolean logNotModified = PropertiesUtil.getBooleanProperty("ranger.log.SC_NOT_MODIFIED", false);
-							if (!logNotModified) {
-								logger.debug("Not logging HttpServletResponse."
-										+ "SC_NOT_MODIFIED, to enable, update "
-										+ ": ranger.log.SC_NOT_MODIFIED");
-								return null;
-							}
-						}
-						return rangerDaoManager.getXXPolicyExportAudit().create(
-								xXPolicyExportAudit);
+
+		XXPolicyExportAudit ret = null;
+		if (xXPolicyExportAudit.getHttpRetCode() == HttpServletResponse.SC_NOT_MODIFIED) {
+			boolean logNotModified = PropertiesUtil.getBooleanProperty("ranger.log.SC_NOT_MODIFIED", false);
+			if (!logNotModified) {
+				logger.debug("Not logging HttpServletResponse."
+						+ "SC_NOT_MODIFIED, to enable, update "
+						+ ": ranger.log.SC_NOT_MODIFIED");
+			} else {
+				// Create PolicyExportAudit record after transaction is completed. If it is created in-line here
+				// then the TransactionManager will roll-back the changes because the HTTP return code is
+				// HttpServletResponse.SC_NOT_MODIFIED
+				Runnable commitWork = new Runnable() {
+					@Override
+					public void run() {
+						rangerDaoManager.getXXPolicyExportAudit().create(xXPolicyExportAudit);
+
 					}
-				});
-		return policyExportAudit;
+				};
+				activityLogger.commitAfterTransactionComplete(commitWork);
+			}
+		} else {
+			ret = rangerDaoManager.getXXPolicyExportAudit().create(xXPolicyExportAudit);
+		}
+
+		return ret;
+	}
+
+	public void createPluginInfo(String serviceName, String pluginId, HttpServletRequest request, int entityType, Long downloadedVersion, long lastKnownVersion, long lastActivationTime, int httpCode) {
+		RangerRESTUtils restUtils = new RangerRESTUtils();
+
+		final String ipAddress = getRemoteAddress(request);
+		final String appType = restUtils.getAppIdFromPluginId(pluginId);
+
+		String tmpHostName = null;
+		if (StringUtils.isNotBlank(pluginId)) {
+			tmpHostName = restUtils.getHostnameFromPluginId(pluginId, serviceName);
+		}
+		if (StringUtils.isBlank(tmpHostName) && request != null) {
+			tmpHostName = request.getRemoteHost();
+		}
+
+		final String hostName = (StringUtils.isBlank(tmpHostName)) ? ipAddress : tmpHostName;
+
+		RangerPluginInfo pluginSvcVersionInfo = new RangerPluginInfo();
+
+		pluginSvcVersionInfo.setServiceName(serviceName);
+		pluginSvcVersionInfo.setAppType(appType);
+		pluginSvcVersionInfo.setHostName(hostName);
+		pluginSvcVersionInfo.setIpAddress(ipAddress);
+
+		if (entityType == RangerPluginInfo.ENTITY_TYPE_POLICIES) {
+			pluginSvcVersionInfo.setPolicyActiveVersion(lastKnownVersion);
+			pluginSvcVersionInfo.setPolicyActivationTime(lastActivationTime);
+			pluginSvcVersionInfo.setPolicyDownloadedVersion(downloadedVersion);
+			pluginSvcVersionInfo.setPolicyDownloadTime(new Date().getTime());
+		} else {
+			pluginSvcVersionInfo.setTagActiveVersion(lastKnownVersion);
+			pluginSvcVersionInfo.setTagActivationTime(lastActivationTime);
+			pluginSvcVersionInfo.setTagDownloadedVersion(downloadedVersion);
+			pluginSvcVersionInfo.setTagDownloadTime(new Date().getTime());
+		}
+
+		createOrUpdatePluginInfo(pluginSvcVersionInfo, entityType == RangerPluginInfo.ENTITY_TYPE_POLICIES, httpCode);
+	}
+
+	private void createOrUpdatePluginInfo(final RangerPluginInfo pluginInfo, final boolean isPolicyDownloadRequest, final int httpCode) {
+		if (logger.isDebugEnabled()) {
+			logger.debug("==> createOrUpdatePluginInfo(pluginInfo=" + pluginInfo + ", isPolicyDownloadRequest=" + isPolicyDownloadRequest + ", httpCode=" + httpCode + ")");
+		}
+
+		final boolean isTagVersionResetNeeded;
+
+		if (httpCode == HttpServletResponse.SC_NOT_MODIFIED) {
+			// Create or update PluginInfo record after transaction is completed. If it is created in-line here
+			// then the TransactionManager will roll-back the changes because the HTTP return code is
+			// HttpServletResponse.SC_NOT_MODIFIED
+
+			if (isPolicyDownloadRequest) {
+				isTagVersionResetNeeded = rangerDaoManager.getXXService().findAssociatedTagService(pluginInfo.getServiceName()) == null;
+			} else {
+				isTagVersionResetNeeded = false;
+			}
+
+			Runnable commitWork = new Runnable() {
+				@Override
+				public void run() {
+					doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, isTagVersionResetNeeded);
+				}
+			};
+			activityLogger.commitAfterTransactionComplete(commitWork);
+		} else if (httpCode == HttpServletResponse.SC_NOT_FOUND) {
+			Runnable commitWork;
+			if ((isPolicyDownloadRequest && (pluginInfo.getPolicyActiveVersion() == null || pluginInfo.getPolicyActiveVersion() == -1))
+				|| (!isPolicyDownloadRequest && (pluginInfo.getTagActiveVersion() == null || pluginInfo.getTagActiveVersion() == -1))) {
+				commitWork = new Runnable() {
+					@Override
+					public void run() {
+						doDeleteXXPluginInfo(pluginInfo);
+					}
+				};
+			} else {
+				commitWork = new Runnable() {
+					@Override
+					public void run() {
+						doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, false);
+					}
+				};
+			}
+			activityLogger.commitAfterTransactionComplete(commitWork);
+
+		} else {
+			isTagVersionResetNeeded = false;
+			doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, isTagVersionResetNeeded);
+		}
+		if (logger.isDebugEnabled()) {
+			logger.debug("<== createOrUpdatePluginInfo(pluginInfo=" + pluginInfo + ", isPolicyDownloadRequest=" + isPolicyDownloadRequest + ", httpCode=" + httpCode + ")");
+		}
+
+	}
+
+	private XXPluginInfo doCreateOrUpdateXXPluginInfo(RangerPluginInfo pluginInfo, final boolean isPolicyDownloadRequest, final boolean isTagVersionResetNeeded) {
+		XXPluginInfo ret = null;
+
+		if (StringUtils.isNotBlank(pluginInfo.getServiceName())) {
+
+			XXPluginInfo xObj = rangerDaoManager.getXXPluginInfo().find(pluginInfo.getServiceName(),
+					pluginInfo.getHostName(), pluginInfo.getAppType());
+
+			if (xObj == null) {
+				// ranger-admin is restarted, plugin contains latest versions and no earlier record for this plug-in client
+				if (isPolicyDownloadRequest) {
+					if (pluginInfo.getPolicyDownloadedVersion() != null && pluginInfo.getPolicyDownloadedVersion().equals(pluginInfo.getPolicyActiveVersion())) {
+						// This is our best guess of when policies may have been downloaded
+						pluginInfo.setPolicyDownloadTime(pluginInfo.getPolicyActivationTime());
+					}
+				} else if (pluginInfo.getTagDownloadedVersion() != null && pluginInfo.getTagDownloadedVersion().equals(pluginInfo.getTagActiveVersion())) {
+					// This is our best guess of when tags may have been downloaded
+					pluginInfo.setTagDownloadTime(pluginInfo.getTagActivationTime());
+				}
+
+				xObj = pluginInfoService.populateDBObject(pluginInfo);
+
+				if (logger.isDebugEnabled()) {
+					logger.debug("Creating RangerPluginInfo record for service-version");
+				}
+				ret = rangerDaoManager.getXXPluginInfo().create(xObj);
+			} else {
+				boolean needsUpdating = false;
+
+				RangerPluginInfo dbObj = pluginInfoService.populateViewObject(xObj);
+				if (!dbObj.getIpAddress().equals(pluginInfo.getIpAddress())) {
+					dbObj.setIpAddress(pluginInfo.getIpAddress());
+					needsUpdating = true;
+				}
+				if (isPolicyDownloadRequest) {
+					if (dbObj.getPolicyDownloadedVersion() == null || !dbObj.getPolicyDownloadedVersion().equals(pluginInfo.getPolicyDownloadedVersion())) {
+						dbObj.setPolicyDownloadedVersion(pluginInfo.getPolicyDownloadedVersion());
+						dbObj.setPolicyDownloadTime(pluginInfo.getPolicyDownloadTime());
+						needsUpdating = true;
+					}
+					Long lastKnownPolicyVersion = pluginInfo.getPolicyActiveVersion();
+					Long lastPolicyActivationTime = pluginInfo.getPolicyActivationTime();
+
+					if (lastKnownPolicyVersion != null && lastKnownPolicyVersion == -1) {
+						// First download request after plug-in's policy-refresher starts
+						dbObj.setPolicyDownloadTime(pluginInfo.getPolicyDownloadTime());
+						needsUpdating = true;
+					}
+					if (lastKnownPolicyVersion != null && lastKnownPolicyVersion > 0 && (dbObj.getPolicyActiveVersion() == null || !dbObj.getPolicyActiveVersion().equals(lastKnownPolicyVersion))) {
+						dbObj.setPolicyActiveVersion(lastKnownPolicyVersion);
+						needsUpdating = true;
+					}
+					if (lastPolicyActivationTime != null && lastPolicyActivationTime > 0 && (dbObj.getPolicyActivationTime() == null || !dbObj.getPolicyActivationTime().equals(lastPolicyActivationTime))) {
+						dbObj.setPolicyActivationTime(lastPolicyActivationTime);
+						needsUpdating = true;
+					}
+				} else {
+					if (dbObj.getTagDownloadedVersion() == null || !dbObj.getTagDownloadedVersion().equals(pluginInfo.getTagDownloadedVersion())) {
+						// First download for tags after tag-service is associated with resource-service
+						dbObj.setTagDownloadedVersion(pluginInfo.getTagDownloadedVersion());
+						dbObj.setTagDownloadTime(pluginInfo.getTagDownloadTime());
+						needsUpdating = true;
+					}
+
+					Long lastKnownTagVersion = pluginInfo.getTagActiveVersion();
+					Long lastTagActivationTime = pluginInfo.getTagActivationTime();
+
+					if (lastKnownTagVersion != null && lastKnownTagVersion == -1) {
+						// First download request after plug-in's tag-refresher restarts
+						dbObj.setTagDownloadTime(pluginInfo.getTagDownloadTime());
+						needsUpdating = true;
+					}
+					if (lastKnownTagVersion != null && lastKnownTagVersion > 0 && (dbObj.getTagActiveVersion() == null || !dbObj.getTagActiveVersion().equals(lastKnownTagVersion))) {
+						dbObj.setTagActiveVersion(lastKnownTagVersion);
+						needsUpdating = true;
+					}
+
+					if (lastTagActivationTime != null && lastTagActivationTime > 0 && (dbObj.getTagActivationTime() == null || !dbObj.getTagActivationTime().equals(lastTagActivationTime))) {
+						dbObj.setTagActivationTime(lastTagActivationTime);
+						needsUpdating = true;
+					}
+				}
+
+				if (isTagVersionResetNeeded) {
+					dbObj.setTagDownloadedVersion(null);
+					dbObj.setTagDownloadTime(null);
+					dbObj.setTagActiveVersion(null);
+					dbObj.setTagActivationTime(null);
+					needsUpdating = true;
+				}
+
+				if (needsUpdating) {
+					if (logger.isDebugEnabled()) {
+						logger.debug("Updating XXPluginInfo record for service-version");
+					}
+					xObj = pluginInfoService.populateDBObject(dbObj);
+
+					ret = rangerDaoManager.getXXPluginInfo().update(xObj);
+				}
+			}
+		} else {
+			logger.error("Invalid parameters: pluginInfo=" + pluginInfo + ")");
+		}
+
+		return ret;
+	}
+
+	private void doDeleteXXPluginInfo(RangerPluginInfo pluginInfo) {
+		XXPluginInfo xObj = rangerDaoManager.getXXPluginInfo().find(pluginInfo.getServiceName(),
+				pluginInfo.getHostName(), pluginInfo.getAppType());
+		if (xObj != null) {
+			rangerDaoManager.getXXPluginInfo().remove(xObj.getId());
+		}
+	}
+
+	private String getRemoteAddress(final HttpServletRequest request) {
+		String ret = null;
+
+		if (request != null) {
+			String xForwardedAddress = request.getHeader("X-Forwarded-For");
+			if (StringUtils.isNotBlank(xForwardedAddress)) {
+				String[] forwardedAddresses = xForwardedAddress.split(",");
+				if (forwardedAddresses.length > 0) {
+					// Use first one. Hope it is the IP of the originating client
+					ret = forwardedAddresses[0].trim();
+				}
+			}
+			if (ret == null) {
+				ret = request.getRemoteAddr();
+			}
+		}
+		return ret;
 	}
 
 	public VXTrxLogList getReportLogs(SearchCriteria searchCriteria) {
@@ -665,17 +908,17 @@ public class AssetMgr extends AssetMgrBase {
 		if (searchCriteria.getParamList() != null
 				&& searchCriteria.getParamList().size() > 0) {
 			int clientTimeOffsetInMinute = RestUtil.getClientTimeOffset();
-			java.util.Date temp = null;
+			Date temp = null;
 			DateUtil dateUtil = new DateUtil();
 			if (searchCriteria.getParamList().containsKey("startDate")) {
-				temp = (java.util.Date) searchCriteria.getParamList().get(
+				temp = (Date) searchCriteria.getParamList().get(
 						"startDate");
 				temp = dateUtil.getDateFromGivenDate(temp, 0, 0, 0, 0);
 				temp = dateUtil.addTimeOffset(temp, clientTimeOffsetInMinute);
 				searchCriteria.getParamList().put("startDate", temp);
 			}
 			if (searchCriteria.getParamList().containsKey("endDate")) {
-				temp = (java.util.Date) searchCriteria.getParamList().get(
+				temp = (Date) searchCriteria.getParamList().get(
 						"endDate");
 				temp = dateUtil.getDateFromGivenDate(temp, 0, 23, 59, 59);
 				temp = dateUtil.addTimeOffset(temp, clientTimeOffsetInMinute);
@@ -699,7 +942,7 @@ public class AssetMgr extends AssetMgrBase {
 		Long count=xTrxLogService
 				.searchXTrxLogsCount(searchCriteria);
 		vXTrxLogList.setTotalCount(count);
-		 
+		
 		List<VXTrxLog> newList = validateXXTrxLogList(vXTrxLogList.getVXTrxLogs());
 		vXTrxLogList.setVXTrxLogs(newList);
 		return vXTrxLogList;
@@ -713,17 +956,17 @@ public class AssetMgr extends AssetMgrBase {
         if (searchCriteria.getParamList() != null
                 && searchCriteria.getParamList().size() > 0) {
             int clientTimeOffsetInMinute = RestUtil.getClientTimeOffset();
-            java.util.Date temp = null;
+            Date temp = null;
             DateUtil dateUtil = new DateUtil();
             if (searchCriteria.getParamList().containsKey("startDate")) {
-                temp = (java.util.Date) searchCriteria.getParamList().get(
+                temp = (Date) searchCriteria.getParamList().get(
                         "startDate");
                 temp = dateUtil.getDateFromGivenDate(temp, 0, 0, 0, 0);
                 temp = dateUtil.addTimeOffset(temp, clientTimeOffsetInMinute);
                 searchCriteria.getParamList().put("startDate", temp);
             }
             if (searchCriteria.getParamList().containsKey("endDate")) {
-                temp = (java.util.Date) searchCriteria.getParamList().get(
+                temp = (Date) searchCriteria.getParamList().get(
                         "endDate");
                 temp = dateUtil.getDateFromGivenDate(temp, 0, 23, 59, 59);
                 temp = dateUtil.addTimeOffset(temp, clientTimeOffsetInMinute);
@@ -811,7 +1054,7 @@ public class AssetMgr extends AssetMgrBase {
 	}
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see
 	 * org.apache.ranger.biz.AssetMgrBase#searchXPolicyExportAudits(org.apache.ranger.
 	 * common.SearchCriteria)
@@ -828,17 +1071,17 @@ public class AssetMgr extends AssetMgrBase {
                 && searchCriteria.getParamList().size() > 0) {
 
             int clientTimeOffsetInMinute = RestUtil.getClientTimeOffset();
-            java.util.Date temp = null;
+            Date temp = null;
             DateUtil dateUtil = new DateUtil();
             if (searchCriteria.getParamList().containsKey("startDate")) {
-                temp = (java.util.Date) searchCriteria.getParamList().get(
+                temp = (Date) searchCriteria.getParamList().get(
                         "startDate");
                 temp = dateUtil.getDateFromGivenDate(temp, 0, 0, 0, 0);
                 temp = dateUtil.addTimeOffset(temp, clientTimeOffsetInMinute);
                 searchCriteria.getParamList().put("startDate", temp);
             }
             if (searchCriteria.getParamList().containsKey("endDate")) {
-                temp = (java.util.Date) searchCriteria.getParamList().get(
+                temp = (Date) searchCriteria.getParamList().get(
                         "endDate");
                 temp = dateUtil.getDateFromGivenDate(temp, 0, 23, 59, 59);
                 temp = dateUtil.addTimeOffset(temp, clientTimeOffsetInMinute);
