@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -83,7 +83,7 @@ public class ServiceMgr {
 		
 		RangerService service = svcDBStore.getServiceByName(serviceName);
 		
-		String authType = PropertiesUtil.getProperty(AUTHENTICATION_TYPE); 
+		String authType = PropertiesUtil.getProperty(AUTHENTICATION_TYPE);
 		String lookupPrincipal = SecureClientLogin.getPrincipal(PropertiesUtil.getProperty(LOOKUP_PRINCIPAL), PropertiesUtil.getProperty(HOST_NAME));
 		String lookupKeytab = PropertiesUtil.getProperty(LOOKUP_KEYTAB);
 		String nameRules = PropertiesUtil.getProperty(NAME_RULES);
@@ -136,7 +136,7 @@ public class ServiceMgr {
 	public VXResponse validateConfig(RangerService service, ServiceStore svcStore) throws Exception {
 		VXResponse        ret = new VXResponse();
 		
-		String authType = PropertiesUtil.getProperty(AUTHENTICATION_TYPE); 
+		String authType = PropertiesUtil.getProperty(AUTHENTICATION_TYPE);
 		String lookupPrincipal = SecureClientLogin.getPrincipal(PropertiesUtil.getProperty(LOOKUP_PRINCIPAL), PropertiesUtil.getProperty(HOST_NAME));
 		String lookupKeytab = PropertiesUtil.getProperty(LOOKUP_KEYTAB);
 		String nameRules = PropertiesUtil.getProperty(NAME_RULES);
@@ -174,7 +174,7 @@ public class ServiceMgr {
 				// Timeout value use during validate config is 10 times that used during lookup
 				long time = getTimeoutValueForValidateConfigInMilliSeconds(svc);
 				ValidateCallable callable = new ValidateCallable(svc);
-				HashMap<String, Object> responseData = timedExecutor.timedTask(callable, time, TimeUnit.MILLISECONDS);
+				Map<String, Object> responseData = timedExecutor.timedTask(callable, time, TimeUnit.MILLISECONDS);
 
 				ret = generateResponseForTestConn(responseData, "");
 			} catch (Exception e) {
@@ -373,7 +373,7 @@ public class ServiceMgr {
 	}
 
 	private VXResponse generateResponseForTestConn(
-			HashMap<String, Object> responseData, String msg) {
+			Map<String, Object> responseData, String msg) {
 		VXResponse vXResponse = new VXResponse();
 
 		Long objId = null;
@@ -544,7 +544,7 @@ public class ServiceMgr {
 		}
 	}
 
-	static class ValidateCallable extends TimedCallable<HashMap<String, Object>> {
+	static class ValidateCallable extends TimedCallable<Map<String, Object>> {
 
 		public ValidateCallable(RangerBaseService svc) {
 			super(svc);
@@ -556,7 +556,7 @@ public class ServiceMgr {
 		}
 
 		@Override
-		public HashMap<String, Object> actualCall() throws Exception {
+		public Map<String, Object> actualCall() throws Exception {
 			return svc.validateConfig();
 		}
 	}
