@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -26,7 +26,7 @@ import java.util.List;
 
 import javax.persistence.Query;
 import javax.servlet.http.HttpServletResponse;
-
+import org.apache.commons.lang.StringUtils;
 import org.apache.log4j.Logger;
 import org.apache.ranger.common.AppConstants;
 import org.apache.ranger.common.ContextUtil;
@@ -47,6 +47,7 @@ import org.apache.ranger.entity.XXGroupPermission;
 import org.apache.ranger.entity.XXPortalUser;
 import org.apache.ranger.entity.XXPortalUserRole;
 import org.apache.ranger.entity.XXTrxLog;
+import org.apache.ranger.entity.XXUser;
 import org.apache.ranger.entity.XXUserPermission;
 import org.apache.ranger.service.XGroupPermissionService;
 import org.apache.ranger.service.XPortalUserService;
@@ -70,7 +71,7 @@ import org.springframework.security.authentication.encoding.ShaPasswordEncoder;
 @Component
 public class UserMgr {
 
-	static final Logger logger = Logger.getLogger(UserMgr.class);
+	private static final Logger logger = Logger.getLogger(UserMgr.class);
 	private static final Md5PasswordEncoder md5Encoder = new Md5PasswordEncoder();
 	private static final ShaPasswordEncoder sha256Encoder = new ShaPasswordEncoder(256);
 	@Autowired
@@ -317,7 +318,14 @@ public class UserMgr {
 		if (rolesList == null || rolesList.size() == 0) {
 			return false;
 		}
-
+		List<String> stringRolesList = new ArrayList<String>();
+		for (String userRole : rolesList) {
+			if(!VALID_ROLE_LIST.contains(userRole.toUpperCase())){
+				throw restErrorUtil.createRESTException("Invalid user role, please provide valid user role.",MessageEnums.INVALID_INPUT_DATA);
+			}
+			stringRolesList.add(userRole);
+		}
+		xUserMgr.checkAccessRoles(stringRolesList);
 		// Let's first delete old roles
 		List<XXPortalUserRole> gjUserRoles = daoManager.getXXPortalUserRole()
 				.findByUserId(userId);
@@ -374,108 +382,108 @@ public class UserMgr {
 	 * @return
 	 */
 	public VXResponse changePassword(VXPasswordChange pwdChange) {
-        VXResponse ret = new VXResponse();
+		VXResponse ret = new VXResponse();
 
-        // First let's get the XXPortalUser for the current logged in user
-        String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
-        XXPortalUser gjUserCurrent = daoManager.getXXPortalUser().findByLoginId(currentUserLoginId);
-        checkAccessForUpdate(gjUserCurrent);
+		// First let's get the XXPortalUser for the current logged in user
+		String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
+		XXPortalUser gjUserCurrent = daoManager.getXXPortalUser().findByLoginId(currentUserLoginId);
+		checkAccessForUpdate(gjUserCurrent);
 
-        // Get the user of whom we want to change the password
-        XXPortalUser gjUser = daoManager.getXXPortalUser().findByLoginId(pwdChange.getLoginId());
-        if (gjUser == null) {
-            logger.warn("SECURITY:changePassword(). User not found. LoginId="+ pwdChange.getLoginId());
-            throw restErrorUtil.createRESTException("serverMsg.userMgrInvalidUser",MessageEnums.DATA_NOT_FOUND, null, null,pwdChange.getLoginId());
-        }
+		// Get the user of whom we want to change the password
+		XXPortalUser gjUser = daoManager.getXXPortalUser().findByLoginId(pwdChange.getLoginId());
+		if (gjUser == null) {
+			logger.warn("SECURITY:changePassword(). User not found. LoginId="+ pwdChange.getLoginId());
+			throw restErrorUtil.createRESTException("serverMsg.userMgrInvalidUser",MessageEnums.DATA_NOT_FOUND, null, null,pwdChange.getLoginId());
+		}
 
-        //check current password and provided old password is same or not
-        String encryptedOldPwd = encrypt(pwdChange.getLoginId(),pwdChange.getOldPassword());
-        if (!stringUtil.equals(encryptedOldPwd, gjUser.getPassword())) {
-            logger.info("changePassword(). Invalid old password. LoginId="+ pwdChange.getLoginId());
-            throw restErrorUtil.createRESTException("serverMsg.userMgrOldPassword",MessageEnums.INVALID_INPUT_DATA, null, null,pwdChange.getLoginId());
-        }
+		//check current password and provided old password is same or not
+		String encryptedOldPwd = encrypt(pwdChange.getLoginId(),pwdChange.getOldPassword());
+		if (!stringUtil.equals(encryptedOldPwd, gjUser.getPassword())) {
+			logger.info("changePassword(). Invalid old password. LoginId="+ pwdChange.getLoginId());
+			throw restErrorUtil.createRESTException("serverMsg.userMgrOldPassword",MessageEnums.INVALID_INPUT_DATA, null, null,pwdChange.getLoginId());
+		}
 
-        //validate new password
-        if (!stringUtil.validatePassword(pwdChange.getUpdPassword(),new String[] { gjUser.getFirstName(),gjUser.getLastName(), gjUser.getLoginId()})) {
-            logger.warn("SECURITY:changePassword(). Invalid new password. LoginId="+ pwdChange.getLoginId());
-            throw restErrorUtil.createRESTException("serverMsg.userMgrNewPassword",MessageEnums.INVALID_PASSWORD, null, null,pwdChange.getLoginId());
-        }
+		//validate new password
+		if (!stringUtil.validatePassword(pwdChange.getUpdPassword(),new String[] { gjUser.getFirstName(),gjUser.getLastName(), gjUser.getLoginId()})) {
+			logger.warn("SECURITY:changePassword(). Invalid new password. LoginId="+ pwdChange.getLoginId());
+			throw restErrorUtil.createRESTException("serverMsg.userMgrNewPassword",MessageEnums.INVALID_PASSWORD, null, null,pwdChange.getLoginId());
+		}
 
-        String encryptedNewPwd = encrypt(pwdChange.getLoginId(),pwdChange.getUpdPassword());
-        String currentPassword = gjUser.getPassword();
-        if (!encryptedNewPwd.equals(currentPassword)) {
-            List<XXTrxLog> trxLogList = new ArrayList<XXTrxLog>();
-            XXTrxLog xTrxLog = new XXTrxLog();
-            xTrxLog.setAttributeName("Password");
-            xTrxLog.setPreviousValue(currentPassword);
-            xTrxLog.setNewValue(encryptedNewPwd);
-            xTrxLog.setAction("password change");
-            xTrxLog.setObjectClassType(AppConstants.CLASS_TYPE_PASSWORD_CHANGE);
-            xTrxLog.setObjectId(pwdChange.getId());
-            xTrxLog.setObjectName(pwdChange.getLoginId());
-            trxLogList.add(xTrxLog);
-            msBizUtil.createTrxLog(trxLogList);
-            gjUser.setPassword(encryptedNewPwd);
-            gjUser = daoManager.getXXPortalUser().update(gjUser);
-            ret.setMsgDesc("Password successfully updated");
-            ret.setStatusCode(VXResponse.STATUS_SUCCESS);
-        } else {
-            ret.setMsgDesc("Password update failed");
-            ret.setStatusCode(VXResponse.STATUS_ERROR);
-            throw restErrorUtil.createRESTException("serverMsg.userMgrNewPassword",MessageEnums.INVALID_INPUT_DATA, gjUser.getId(),"password", gjUser.toString());
-        }
-        return ret;
-    }
+		String encryptedNewPwd = encrypt(pwdChange.getLoginId(),pwdChange.getUpdPassword());
+		String currentPassword = gjUser.getPassword();
+		if (!encryptedNewPwd.equals(currentPassword)) {
+			List<XXTrxLog> trxLogList = new ArrayList<XXTrxLog>();
+			XXTrxLog xTrxLog = new XXTrxLog();
+			xTrxLog.setAttributeName("Password");
+			xTrxLog.setPreviousValue(currentPassword);
+			xTrxLog.setNewValue(encryptedNewPwd);
+			xTrxLog.setAction("password change");
+			xTrxLog.setObjectClassType(AppConstants.CLASS_TYPE_PASSWORD_CHANGE);
+			xTrxLog.setObjectId(pwdChange.getId());
+			xTrxLog.setObjectName(pwdChange.getLoginId());
+			trxLogList.add(xTrxLog);
+			msBizUtil.createTrxLog(trxLogList);
+			gjUser.setPassword(encryptedNewPwd);
+			gjUser = daoManager.getXXPortalUser().update(gjUser);
+			ret.setMsgDesc("Password successfully updated");
+			ret.setStatusCode(VXResponse.STATUS_SUCCESS);
+		} else {
+			ret.setMsgDesc("Password update failed");
+			ret.setStatusCode(VXResponse.STATUS_ERROR);
+			throw restErrorUtil.createRESTException("serverMsg.userMgrNewPassword",MessageEnums.INVALID_INPUT_DATA, gjUser.getId(),"password", gjUser.toString());
+		}
+		return ret;
+	}
 
 	/**
 	 * @param gjUser
 	 * @param changeEmail
 	 * @return
 	 */
-    public VXPortalUser changeEmailAddress(XXPortalUser gjUser,
-            VXPasswordChange changeEmail) {
-        checkAccessForUpdate(gjUser);
-        if (stringUtil.isEmpty(changeEmail.getEmailAddress())) {
-            throw restErrorUtil.createRESTException(
-                    "serverMsg.userMgrInvalidEmail",
-                    MessageEnums.INVALID_INPUT_DATA, changeEmail.getId(),
-                    "emailAddress", changeEmail.toString());
-        }
+	public VXPortalUser changeEmailAddress(XXPortalUser gjUser,
+			VXPasswordChange changeEmail) {
+		checkAccessForUpdate(gjUser);
+		if (StringUtils.isEmpty(changeEmail.getEmailAddress())) {
+			throw restErrorUtil.createRESTException(
+					"serverMsg.userMgrInvalidEmail",
+					MessageEnums.INVALID_INPUT_DATA, changeEmail.getId(),
+					"emailAddress", changeEmail.toString());
+		}
 
-        String encryptedOldPwd = encrypt(gjUser.getLoginId(),
-                changeEmail.getOldPassword());
+		String encryptedOldPwd = encrypt(gjUser.getLoginId(),
+				changeEmail.getOldPassword());
 
-        if (!stringUtil.validateEmail(changeEmail.getEmailAddress())) {
-            logger.info("Invalid email address." + changeEmail);
-            throw restErrorUtil.createRESTException(
-                    "serverMsg.userMgrInvalidEmail",
-                    MessageEnums.INVALID_INPUT_DATA, changeEmail.getId(),
-                    "emailAddress", changeEmail.toString());
+		if (!stringUtil.validateEmail(changeEmail.getEmailAddress())) {
+			logger.info("Invalid email address." + changeEmail);
+			throw restErrorUtil.createRESTException(
+					"serverMsg.userMgrInvalidEmail",
+					MessageEnums.INVALID_INPUT_DATA, changeEmail.getId(),
+					"emailAddress", changeEmail.toString());
 
-        }
+		}
 
-        if (!stringUtil.equals(encryptedOldPwd, gjUser.getPassword())) {
-            logger.info("changeEmailAddress(). Invalid  password. changeEmail="
-                    + changeEmail);
+		if (!stringUtil.equals(encryptedOldPwd, gjUser.getPassword())) {
+			logger.info("changeEmailAddress(). Invalid  password. changeEmail="
+					+ changeEmail);
 
-            throw restErrorUtil.createRESTException(
-                    "serverMsg.userMgrWrongPassword",
-                    MessageEnums.OPER_NO_PERMISSION, null, null, ""
-                            + changeEmail);
-        }
+			throw restErrorUtil.createRESTException(
+					"serverMsg.userMgrWrongPassword",
+					MessageEnums.OPER_NO_PERMISSION, null, null, ""
+							+ changeEmail);
+		}
 
-        // Normalize email. Make it lower case
-        gjUser.setEmailAddress(stringUtil.normalizeEmail(changeEmail
-                .getEmailAddress()));
+		// Normalize email. Make it lower case
+		gjUser.setEmailAddress(stringUtil.normalizeEmail(changeEmail
+				.getEmailAddress()));
 
-        String saltEncodedpasswd = encrypt(gjUser.getLoginId(),
-                changeEmail.getOldPassword());
+		String saltEncodedpasswd = encrypt(gjUser.getLoginId(),
+				changeEmail.getOldPassword());
 
-        gjUser.setPassword(saltEncodedpasswd);
+		gjUser.setPassword(saltEncodedpasswd);
 
-        daoManager.getXXPortalUser().update(gjUser);
-        return mapXXPortalUserVXPortalUser(gjUser);
-    }
+		daoManager.getXXPortalUser().update(gjUser);
+		return mapXXPortalUserVXPortalUser(gjUser);
+	}
 
 	/**
 	 * @param userId
@@ -662,7 +670,7 @@ public class UserMgr {
 	 * Translates XXPortalUser to VUserProfile. This method should be called in
 	 * the same transaction in which the XXPortalUser was retrieved from the
 	 * database
-	 * 
+	 *
 	 * @param user
 	 * @return
 	 */
@@ -984,6 +992,9 @@ public class UserMgr {
 			}
 		}
 		XXPortalUserRole userRoleObj = new XXPortalUserRole();
+                if(!VALID_ROLE_LIST.contains(userRole.toUpperCase())){
+                        throw restErrorUtil.createRESTException("Invalid user role, please provide valid user role.",MessageEnums.INVALID_INPUT_DATA);
+                }
 		userRoleObj.setUserRole(userRole.toUpperCase());
 		userRoleObj.setUserId(userId);
 		userRoleObj.setStatus(RangerConstants.STATUS_ENABLED);
@@ -1003,7 +1014,7 @@ public class UserMgr {
 		XXPortalUser gjUser = daoManager.getXXPortalUser().getById(userId);
 		if (gjUser == null) {
 			throw restErrorUtil
-					.create403RESTException("serverMsg.userMgrWrongUser"
+					.create403RESTException("serverMsg.userMgrWrongUser: "
 							+ userId);
 		}
 
@@ -1067,7 +1078,7 @@ public class UserMgr {
 				+ (sess != null ? sess.getXXPortalUser().getId()
 						: "Not Logged In") + ", accessing user="
 				+ gjUser.getId());
-		throw restErrorUtil.createRESTException(vXResponse);
+		throw restErrorUtil.generateRESTException(vXResponse);
 
 	}
 
@@ -1205,7 +1216,7 @@ public class UserMgr {
 		return xXPortalUser;
 	}
 	@Transactional(readOnly = false, propagation = Propagation.REQUIRED)
-	public XXPortalUser updatePasswordInSHA256(String userName,String userPassword) {
+        public XXPortalUser updatePasswordInSHA256(String userName,String userPassword,boolean logAudits) {
 		if (userName == null || userPassword == null
 				|| userName.trim().isEmpty() || userPassword.trim().isEmpty()){
 				return null;
@@ -1216,20 +1227,38 @@ public class UserMgr {
 		if (xXPortalUser == null) {
 			return null;
 		}
-
+                String dbOldPwd =xXPortalUser.getPassword();
 		String encryptedNewPwd = encrypt(xXPortalUser.getLoginId(),userPassword);
 		xXPortalUser.setPassword(encryptedNewPwd);
 		xXPortalUser = daoManager.getXXPortalUser().update(xXPortalUser);
+                if(xXPortalUser!=null && logAudits){
+                        String dbNewPwd=xXPortalUser.getPassword();
+                        if (!dbOldPwd.equals(dbNewPwd)) {
+                                List<XXTrxLog> trxLogList = new ArrayList<XXTrxLog>();
+                                XXTrxLog xTrxLog = new XXTrxLog();
+                                xTrxLog.setAttributeName("Password");
+                                xTrxLog.setPreviousValue(dbOldPwd);
+                                xTrxLog.setNewValue(dbNewPwd);
+                                xTrxLog.setAction("password change");
+                                xTrxLog.setObjectClassType(AppConstants.CLASS_TYPE_PASSWORD_CHANGE);
+                                xTrxLog.setObjectId(xXPortalUser.getId());
+                                xTrxLog.setObjectName(xXPortalUser.getLoginId());
+                                xTrxLog.setAddedByUserId(xXPortalUser.getId());
+                                xTrxLog.setUpdatedByUserId(xXPortalUser.getId());
+                                trxLogList.add(xTrxLog);
+                                msBizUtil.createTrxLog(trxLogList);
+                        }
+                }
 
 		return xXPortalUser;
 	}
-	
+
 	public void checkAdminAccess() {
 		UserSessionBase sess = ContextUtil.getCurrentUserSession();
 		if (sess != null && sess.isUserAdmin()) {
 			return;
 		}
-		throw restErrorUtil.create403RESTException("Operation not allowed." + " loggedInUser=" + (sess != null ? sess.getXXPortalUser().getId() : "Not Logged In"));
+		throw restErrorUtil.create403RESTException("Operation not allowed." + " loggedInUser=" + (sess != null ? sess.getXXPortalUser().getId() : ". Not Logged In."));
 	}
 
 	public Collection<String> getRolesByLoginId(String loginId) {
@@ -1258,4 +1287,40 @@ public class UserMgr {
 		}
 		return roleList;
 	}
+
+        @Transactional(readOnly = false, propagation = Propagation.REQUIRED)
+        public XXPortalUser updateOldUserName(String userLoginId,String newUserName, String currentPassword) {
+                if (userLoginId == null || newUserName == null
+                                || userLoginId.trim().isEmpty() || newUserName.trim().isEmpty()){
+                        return null;
+                }
+
+                XXPortalUser xXPortalUser = this.findByLoginId(userLoginId);
+        XXUser xXUser = daoManager.getXXUser().findByUserName(userLoginId);
+                if (xXPortalUser == null || xXUser == null) {
+                        return null;
+                }
+                xXUser.setName(newUserName);
+                daoManager.getXXUser().update(xXUser);
+
+                xXPortalUser.setLoginId(newUserName);
+                // The old password needs to be encrypted by the new user name
+                String updatedPwd = encrypt(newUserName,currentPassword);
+                xXPortalUser.setPassword(updatedPwd);
+                xXPortalUser = daoManager.getXXPortalUser().update(xXPortalUser);
+                List<XXTrxLog> trxLogList = new ArrayList<XXTrxLog>();
+                XXTrxLog xTrxLog = new XXTrxLog();
+                xTrxLog.setAttributeName("User Name");
+                xTrxLog.setPreviousValue(userLoginId);
+                xTrxLog.setNewValue(newUserName);
+                xTrxLog.setAction("update");
+                xTrxLog.setObjectClassType(AppConstants.CLASS_TYPE_USER_PROFILE);
+                xTrxLog.setObjectId(xXPortalUser.getId());
+                xTrxLog.setObjectName(xXPortalUser.getLoginId());
+                xTrxLog.setAddedByUserId(xXPortalUser.getId());
+                xTrxLog.setUpdatedByUserId(xXPortalUser.getId());
+                trxLogList.add(xTrxLog);
+                msBizUtil.createTrxLog(trxLogList);
+                return xXPortalUser;
+        }
 }
