@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -88,6 +88,7 @@ import org.apache.ranger.view.VXGroup;
 import org.apache.ranger.view.VXGroupGroup;
 import org.apache.ranger.view.VXGroupList;
 import org.apache.ranger.view.VXGroupUser;
+import org.apache.ranger.view.VXGroupUserInfo;
 import org.apache.ranger.view.VXGroupUserList;
 import org.apache.ranger.view.VXLong;
 import org.apache.ranger.view.VXPermMap;
@@ -541,6 +542,75 @@ public class XUserMgr extends XUserMgrBase {
 
 		return vxUGInfo;
 	}
+	
+	@Transactional(readOnly = false, propagation = Propagation.REQUIRED)
+	public VXGroupUserInfo createXGroupUserFromMap(
+			VXGroupUserInfo vXGroupUserInfo) {
+		checkAdminAccess();
+		VXGroupUserInfo vxGUInfo = new VXGroupUserInfo();
+
+		VXGroup vXGroup = vXGroupUserInfo.getXgroupInfo();
+		// Add the group user mappings for a given group to x_group_user table
+		/*XXGroup xGroup = daoManager.getXXGroup().findByGroupName(vXGroup.getName());
+		if (xGroup == null) {
+			return vxGUInfo;
+		}*/
+
+		List<VXUser> vxu = new ArrayList<VXUser>();
+
+		for (VXUser vXUser : vXGroupUserInfo.getXuserInfo()) {
+			XXUser xUser = daoManager.getXXUser().findByUserName(vXUser.getName());
+			if (xUser != null) {
+				// Add or update group user mapping only if the user already exists in x_user table.
+				vXGroup = xGroupService.createXGroupWithOutLogin(vXGroup);
+				vxGUInfo.setXgroupInfo(vXGroup);
+				vxu.add(vXUser);
+				VXGroupUser vXGroupUser = new VXGroupUser();
+				vXGroupUser.setUserId(xUser.getId());
+				vXGroupUser.setName(vXGroup.getName());
+				vXGroupUser = xGroupUserService
+						.createXGroupUserWithOutLogin(vXGroupUser);
+			}
+		}
+
+		vxGUInfo.setXuserInfo(vxu);
+
+		return vxGUInfo;
+	}
+	
+	public VXGroupUserInfo getXGroupUserFromMap(
+			String groupName) {
+		checkAdminAccess();
+		VXGroupUserInfo vxGUInfo = new VXGroupUserInfo();
+
+		XXGroup xGroup = daoManager.getXXGroup().findByGroupName(groupName);
+		if (xGroup == null) {
+			return vxGUInfo;
+		}
+
+		VXGroup xgroupInfo = xGroupService.populateViewBean(xGroup);
+		vxGUInfo.setXgroupInfo(xgroupInfo);
+
+		SearchCriteria searchCriteria = new SearchCriteria();
+		searchCriteria.addParam("xGroupId", xGroup.getId());
+
+		VXGroupUserList vxGroupUserList = searchXGroupUsers(searchCriteria);
+		List<VXUser> vxu = new ArrayList<VXUser>();
+		logger.debug("removing all the group user mapping for : " + xGroup.getName());
+		for (VXGroupUser groupUser : vxGroupUserList.getList()) {
+			XXUser xUser = daoManager.getXXUser().getById(groupUser.getUserId());
+			if (xUser != null) {
+				VXUser vxUser = new VXUser();
+				vxUser.setName(xUser.getName());
+				vxu.add(vxUser);
+			}
+			
+		}
+		vxGUInfo.setXuserInfo(vxu);
+
+		return vxGUInfo;
+	}
+
 
 	public VXUser createXUserWithOutLogin(VXUser vXUser) {
 		checkAdminAccess();
@@ -597,7 +667,7 @@ public class XUserMgr extends XUserMgrBase {
 
 	/**
 	 * // public void createXGroupAndXUser(String groupName, String userName) {
-	 * 
+	 *
 	 * // Long groupId; // Long userId; // XXGroup xxGroup = //
 	 * appDaoManager.getXXGroup().findByGroupName(groupName); // VXGroup
 	 * vxGroup; // if (xxGroup == null) { // vxGroup = new VXGroup(); //
@@ -616,7 +686,7 @@ public class XUserMgr extends XUserMgrBase {
 	 * vxGroupUser.setUserId(userId); // vxGroupUser.setName(groupName); //
 	 * vxGroupUser.setPriAcctId(1l); // vxGroupUser.setPriGrpId(1l); //
 	 * vxGroupUser = xGroupUserService.createResource(vxGroupUser);
-	 * 
+	 *
 	 * // }
 	 */
 
@@ -1393,36 +1463,204 @@ public class XUserMgr extends XUserMgrBase {
 
 	@Override
 	public VXUserList searchXUsers(SearchCriteria searchCriteria) {
-        VXUserList vXUserList = new VXUserList();
-        vXUserList=xUserService.searchXUsers(searchCriteria);
-        if(vXUserList!=null && !hasAccessToModule(RangerConstants.MODULE_USER_GROUPS)){
-	        List<VXUser> vXUsers = new ArrayList<VXUser>();
-	        if(vXUserList!=null && vXUserList.getListSize()>0){
-	            for(VXUser vXUser:vXUserList.getList()){
-                    vXUser=getMaskedVXUser(vXUser);
-                    vXUsers.add(vXUser);
-	            }
-	            vXUserList.setVXUsers(vXUsers);
-	        }
-        }
-        return vXUserList;
+		VXUserList vXUserList = new VXUserList();
+		VXUser vXUserExactMatch = null;
+		try{
+			VXUserList vXUserListSort = new VXUserList();
+			if(searchCriteria.getParamList() != null && searchCriteria.getParamList().get("name") != null){
+				searchCriteria.setSortBy("name");
+				vXUserListSort = xUserService.searchXUsers(searchCriteria);
+				vXUserExactMatch = getXUserByUserName((String)searchCriteria.getParamList().get("name"));
+			}
+			int vXUserExactMatchwithSearchCriteria = 0;
+			if(vXUserExactMatch != null){
+				vXUserListSort = xUserService.searchXUsers(searchCriteria);
+				HashMap<String, Object> searchCriteriaParamList = searchCriteria.getParamList();
+				vXUserExactMatchwithSearchCriteria = 1;
+				for(Map.Entry<String, Object> entry:searchCriteriaParamList.entrySet()){
+					String caseKey=entry.getKey();
+					switch (caseKey.toLowerCase()) {
+						case "isvisible":
+							Integer isVisible = vXUserExactMatch.getIsVisible();
+							if(isVisible != null && !isVisible.equals(entry.getValue())){
+								vXUserExactMatchwithSearchCriteria = -1;
+							}
+							break;
+						case "status":
+							Integer status = vXUserExactMatch.getStatus();
+							if(status != null && !status.equals(entry.getValue())){
+								vXUserExactMatchwithSearchCriteria = -1;
+							}
+							break;
+						case "usersource":
+							Integer userSource = vXUserExactMatch.getUserSource();
+							if(userSource != null && !userSource.equals(entry.getValue())){
+								vXUserExactMatchwithSearchCriteria = -1;
+							}
+							break;
+						case "emailaddress":
+							String email = vXUserExactMatch.getEmailAddress();
+							if(email != null && !email.equals(entry.getValue())){
+								vXUserExactMatchwithSearchCriteria = -1;
+							}
+							break;
+						case "userrole":
+							if(vXUserExactMatch.getUserRoleList() != null && !vXUserExactMatch.getUserRoleList().contains(entry.getValue())){
+								vXUserExactMatchwithSearchCriteria = -1;
+							}
+							break;
+						case "userrolelist":
+							@SuppressWarnings("unchecked")
+							Collection<String> userrolelist = (Collection<String>) entry.getValue();
+							if(!CollectionUtils.isEmpty(userrolelist)){
+								for(String role:userrolelist){
+									if(vXUserExactMatch.getUserRoleList() != null && vXUserExactMatch.getUserRoleList().contains(role)){
+										vXUserExactMatchwithSearchCriteria = 1;
+										break;
+									}
+									else{
+										vXUserExactMatchwithSearchCriteria = -1;
+									}
+								}
+							}
+							break;
+						default:
+							logger.warn("XUserMgr.searchXUsers: unexpected searchCriteriaParam:" + caseKey);
+							break;
+					}
+					if(vXUserExactMatchwithSearchCriteria == -1){
+						break;
+					}
+				}
+			}
+			if(vXUserExactMatchwithSearchCriteria == 1){
+				VXGroupList groups = getXUserGroups(vXUserExactMatch.getId());
+				if(groups.getListSize() > 0){
+					Collection<String> groupNameList = new ArrayList<String>();
+					Collection<Long> groupIdList = new ArrayList<Long>();
+					for(VXGroup group:groups.getList()){
+						groupIdList.add(group.getId());
+						groupNameList.add(group.getName());
+					}
+					vXUserExactMatch.setGroupIdList(groupIdList);
+					vXUserExactMatch.setGroupNameList(groupNameList);
+				}
+				List<VXUser> vXUsers = new ArrayList<VXUser>();
+				if(searchCriteria.getStartIndex() == 0){
+					vXUsers.add(0,vXUserExactMatch);
+				}
+				for(VXUser vxUser:vXUserListSort.getVXUsers()){
+					if(vXUserExactMatch.getId()!=null && vxUser!=null){
+						if(!vXUserExactMatch.getId().equals(vxUser.getId())){
+							vXUsers.add(vxUser);
+						}
+					}
+				}
+				vXUserList.setVXUsers(vXUsers);
+				vXUserList.setStartIndex(searchCriteria.getStartIndex());
+				vXUserList.setResultSize(vXUserList.getVXUsers().size());
+				vXUserList.setTotalCount(vXUserListSort.getTotalCount());
+				vXUserList.setPageSize(searchCriteria.getMaxRows());
+				vXUserList.setSortBy(searchCriteria.getSortBy());
+				vXUserList.setSortType(searchCriteria.getSortType());
+			}
+		} catch (Exception e){
+			logger.error("Error getting the exact match of user =>"+e);
+		}
+		if(vXUserList.getVXUsers().isEmpty()) {
+			searchCriteria.setSortBy("id");
+			vXUserList = xUserService.searchXUsers(searchCriteria);
+		}
+		if(vXUserList!=null && !hasAccessToModule(RangerConstants.MODULE_USER_GROUPS)){
+			List<VXUser> vXUsers = new ArrayList<VXUser>();
+			if(vXUserList!=null && vXUserList.getListSize()>0){
+				for(VXUser vXUser:vXUserList.getList()){
+					vXUser=getMaskedVXUser(vXUser);
+					vXUsers.add(vXUser);
+				}
+				vXUserList.setVXUsers(vXUsers);
+			}
+		}
+		return vXUserList;
 	}
 
 	@Override
 	public VXGroupList searchXGroups(SearchCriteria searchCriteria) {
-        VXGroupList vXGroupList=null;
-        vXGroupList=xGroupService.searchXGroups(searchCriteria);
-        if(vXGroupList!=null && !hasAccessToModule(RangerConstants.MODULE_USER_GROUPS)){
-            if(vXGroupList!=null && vXGroupList.getListSize()>0){
-                List<VXGroup> listMasked=new ArrayList<VXGroup>();
-                for(VXGroup vXGroup:vXGroupList.getList()){
-                    vXGroup=getMaskedVXGroup(vXGroup);
-                    listMasked.add(vXGroup);
-                }
-                vXGroupList.setVXGroups(listMasked);
-            }
-        }
-        return vXGroupList;
+		VXGroupList vXGroupList= new VXGroupList();
+		VXGroup vXGroupExactMatch = null;
+		try{
+			VXGroupList vXGroupListSort= new VXGroupList();
+			if(searchCriteria.getParamList() != null && searchCriteria.getParamList().get("name") != null){
+				searchCriteria.setSortBy("name");
+				vXGroupListSort = xGroupService.searchXGroups(searchCriteria);
+				vXGroupExactMatch = getGroupByGroupName((String)searchCriteria.getParamList().get("name"));
+			}
+			int vXGroupExactMatchwithSearchCriteria = 0;
+			if(vXGroupExactMatch != null){
+				HashMap<String, Object> searchCriteriaParamList = searchCriteria.getParamList();
+				vXGroupExactMatchwithSearchCriteria = 1;
+				for (Map.Entry<String, Object> entry: searchCriteriaParamList.entrySet()){
+					String caseKey=entry.getKey();
+					switch (caseKey.toLowerCase()) {
+						case "isvisible":
+							Integer isVisible = vXGroupExactMatch.getIsVisible();
+							if(isVisible != null && !isVisible.equals(entry.getValue())){
+								vXGroupExactMatchwithSearchCriteria = -1;
+							}
+							break;
+						case "groupsource":
+							Integer groupsource = vXGroupExactMatch.getGroupSource();
+							if(groupsource != null && !groupsource.equals(entry.getValue())){
+								vXGroupExactMatchwithSearchCriteria = -1;
+							}
+							break;
+						default:
+							logger.warn("XUserMgr.searchXGroups: unexpected searchCriteriaParam:" + caseKey);
+							break;
+					}
+					if(vXGroupExactMatchwithSearchCriteria == -1){
+						break;
+					}
+				}
+			}
+			if(vXGroupExactMatchwithSearchCriteria == 1){
+				List<VXGroup> vXGroups = new ArrayList<VXGroup>();
+				if(searchCriteria.getStartIndex() == 0){
+					vXGroups.add(0,vXGroupExactMatch);
+				}
+				for(VXGroup vXGroup:vXGroupListSort.getList()){
+					if(vXGroupExactMatch.getId() != null && vXGroup != null){
+						if(!vXGroupExactMatch.getId().equals(vXGroup.getId())){
+							vXGroups.add(vXGroup);
+						}
+					}
+				}
+				vXGroupList.setVXGroups(vXGroups);
+				vXGroupList.setStartIndex(searchCriteria.getStartIndex());
+				vXGroupList.setResultSize(vXGroupList.getList().size());
+				vXGroupList.setTotalCount(vXGroupListSort.getTotalCount());
+				vXGroupList.setPageSize(searchCriteria.getMaxRows());
+				vXGroupList.setSortBy(searchCriteria.getSortBy());
+				vXGroupList.setSortType(searchCriteria.getSortType());
+			}
+		} catch (Exception e){
+			logger.error("Error getting the exact match of group =>"+e);
+		}
+		if(vXGroupList.getList().isEmpty()) {
+			searchCriteria.setSortBy("id");
+			vXGroupList=xGroupService.searchXGroups(searchCriteria);
+		}
+		if(vXGroupList!=null && !hasAccessToModule(RangerConstants.MODULE_USER_GROUPS)){
+			if(vXGroupList!=null && vXGroupList.getListSize()>0){
+				List<VXGroup> listMasked=new ArrayList<VXGroup>();
+				for(VXGroup vXGroup:vXGroupList.getList()){
+					vXGroup=getMaskedVXGroup(vXGroup);
+					listMasked.add(vXGroup);
+				}
+				vXGroupList.setVXGroups(listMasked);
+			}
+		}
+		return vXGroupList;
 	}
 
 	public Collection<String> getMaskedCollection(Collection<String> listunMasked){
@@ -1866,7 +2104,7 @@ public class XUserMgr extends XUserMgrBase {
 		if(xXPortalUser==null){
 			vXPortalUser=new VXPortalUser();
 			vXPortalUser.setLoginId(userName);
-			vXPortalUser.setEmailAddress(guidUtil.genGUID());
+			vXPortalUser.setEmailAddress(vXUser.getEmailAddress());
 			vXPortalUser.setFirstName(vXUser.getFirstName());
 			vXPortalUser.setLastName(vXUser.getLastName());
 			vXPortalUser.setPassword(vXUser.getPassword());
