@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -67,6 +67,11 @@ public class RangerSearchUtil extends SearchUtil {
 		ret.setParam(SearchFilter.RESOURCE_SIGNATURE, request.getParameter(SearchFilter.RESOURCE_SIGNATURE));
 		ret.setParam(SearchFilter.POLICY_TYPE, request.getParameter(SearchFilter.POLICY_TYPE));
 
+		ret.setParam(SearchFilter.PLUGIN_HOST_NAME, request.getParameter(SearchFilter.PLUGIN_HOST_NAME));
+		ret.setParam(SearchFilter.PLUGIN_APP_TYPE, request.getParameter(SearchFilter.PLUGIN_APP_TYPE));
+		ret.setParam(SearchFilter.PLUGIN_ENTITY_TYPE, request.getParameter(SearchFilter.PLUGIN_ENTITY_TYPE));
+		ret.setParam(SearchFilter.PLUGIN_IP_ADDRESS, request.getParameter(SearchFilter.PLUGIN_IP_ADDRESS));
+
 		for (Map.Entry<String, String[]> e : request.getParameterMap().entrySet()) {
 			String name = e.getKey();
 			String[] values = e.getValue();
@@ -76,7 +81,8 @@ public class RangerSearchUtil extends SearchUtil {
 				ret.setParam(name, values[0]);
 			}
 		}
-		
+		ret.setParam(SearchFilter.RESOURCE_MATCH_SCOPE, request.getParameter(SearchFilter.RESOURCE_MATCH_SCOPE));
+
 		extractCommonCriteriasForFilter(request, ret, sortFields);
 
 		return ret;
@@ -95,11 +101,11 @@ public class RangerSearchUtil extends SearchUtil {
 
 		ret.setParam(SearchFilter.SERVICE_NAME, request.getParameter("name"));
 		ret.setParam(SearchFilter.IS_ENABLED, request.getParameter("status"));
-		String serviceType = request.getParameter("type") ;
+		String serviceType = request.getParameter("type");
 		if (serviceType != null) {
-			serviceType = serviceType.toLowerCase() ;
+			serviceType = serviceType.toLowerCase();
 		}
-		ret.setParam(SearchFilter.SERVICE_TYPE,serviceType) ;
+		ret.setParam(SearchFilter.SERVICE_TYPE,serviceType);
 		extractCommonCriteriasForFilter(request, ret, sortFields);
 
 		return ret;
@@ -117,10 +123,10 @@ public class RangerSearchUtil extends SearchUtil {
 			ret.setParams(new HashMap<String, String>());
 		}
 
-		String repositoryType = request.getParameter("repositoryType") ;
+		String repositoryType = request.getParameter("repositoryType");
 
 		if (repositoryType != null) {
-			repositoryType = repositoryType.toLowerCase() ;
+			repositoryType = repositoryType.toLowerCase();
 		}
 
 		String repositoryId = request.getParameter("repositoryId");
@@ -128,7 +134,7 @@ public class RangerSearchUtil extends SearchUtil {
 			repositoryId = request.getParameter("assetId");
 		}
 
-		ret.setParam(SearchFilter.SERVICE_TYPE, repositoryType) ;
+		ret.setParam(SearchFilter.SERVICE_TYPE, repositoryType);
 		ret.setParam(SearchFilter.SERVICE_NAME, request.getParameter("repositoryName"));
 		ret.setParam(SearchFilter.SERVICE_ID, repositoryId);
 		ret.setParam(SearchFilter.POLICY_NAME, request.getParameter("policyName"));
@@ -234,7 +240,7 @@ public class RangerSearchUtil extends SearchUtil {
 		for (SearchField searchField : searchFields) {
 			int startWhereLen = whereClause.length();
 
-			if (searchField.getFieldName() == null && searchField.getCustomCondition() == null) { 
+			if (searchField.getFieldName() == null && searchField.getCustomCondition() == null) {
 				continue;
 			}
 
@@ -284,8 +290,8 @@ public class RangerSearchUtil extends SearchUtil {
 					}
 				}
 			} else if (searchField.getDataType() == SearchField.DATA_TYPE.DATE) {
-				Date fieldValue = restErrorUtil.parseDate(searchCriteria.getParam(searchField.getClientFieldName()), 
-						"Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA, 
+				Date fieldValue = restErrorUtil.parseDate(searchCriteria.getParam(searchField.getClientFieldName()),
+						"Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA,
 						null, searchField.getClientFieldName(), null);
 				if (fieldValue != null) {
 					if (searchField.getCustomCondition() == null) {
@@ -353,8 +359,8 @@ public class RangerSearchUtil extends SearchUtil {
 					query.setParameter(searchField.getClientFieldName(), boolFieldValue);
 				}
 			} else if (searchField.getDataType() == SearchField.DATA_TYPE.DATE) {
-				Date fieldValue = restErrorUtil.parseDate(searchCriteria.getParam(searchField.getClientFieldName()), 
-						"Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA, 
+				Date fieldValue = restErrorUtil.parseDate(searchCriteria.getParam(searchField.getClientFieldName()),
+						"Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA,
 						null, searchField.getClientFieldName(), null);
 				if (fieldValue != null) {
 					query.setParameter(searchField.getClientFieldName(), fieldValue);
