@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -41,7 +41,7 @@ import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.db.RangerDaoManagerBase;
 
 public abstract class BaseDao<T> {
-	static final Logger logger = Logger.getLogger(BaseDao.class);
+	private static final Logger logger = Logger.getLogger(BaseDao.class);
 
 	protected RangerDaoManager daoManager;
 
@@ -250,4 +250,27 @@ public abstract class BaseDao<T> {
 		}
 	}
 
+	public String getDBVersion(){
+		String dbVersion="Not Available";
+		String query ="SELECT 1";
+		try{
+			if(RangerBizUtil.getDBFlavor() == AppConstants.DB_FLAVOR_MYSQL) {
+				query="SELECT version()";
+				dbVersion=(String) getEntityManager().createNativeQuery(query).getSingleResult();
+			}else if(RangerBizUtil.getDBFlavor() == AppConstants.DB_FLAVOR_ORACLE){
+				query="SELECT * from v$version where rownum<2";
+				dbVersion=(String) getEntityManager().createNativeQuery(query).getSingleResult();
+			}else if(RangerBizUtil.getDBFlavor() == AppConstants.DB_FLAVOR_POSTGRES){
+				query="SELECT version()";
+				dbVersion=(String) getEntityManager().createNativeQuery(query).getSingleResult();
+			}else if(RangerBizUtil.getDBFlavor() == AppConstants.DB_FLAVOR_SQLSERVER){
+				query="SELECT @@version";
+				dbVersion=(String) getEntityManager().createNativeQuery(query).getSingleResult();
+			}else if(RangerBizUtil.getDBFlavor() == AppConstants.DB_FLAVOR_SQLANYWHERE){
+				query="SELECT @@version";
+				dbVersion=(String) getEntityManager().createNativeQuery(query).getSingleResult();
+			}
+		}catch(Exception ex){}
+		return dbVersion;
+	}
 }
