@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -20,7 +20,7 @@
  package org.apache.ranger.db;
 
 /**
- * 
+ *
  */
 
 import javax.persistence.EntityManager;
@@ -33,7 +33,7 @@ import org.springframework.beans.factory.annotation.Autowired;
 
 
 public abstract class RangerDaoManagerBase {
-	final static Logger logger = Logger.getLogger(RangerDaoManagerBase.class);
+	private static final Logger logger = Logger.getLogger(RangerDaoManagerBase.class);
 
 	@Autowired
 	protected RESTErrorUtil restErrorUtil;
@@ -363,6 +363,9 @@ public abstract class RangerDaoManagerBase {
 		if (className.equals("XXServiceVersionInfo")) {
 			return getXXServiceVersionInfo();
 		}
+		if (className.equals("XXPluginInfo")) {
+			return getXXPluginInfo();
+		}
 		logger.error("No DaoManager found for className=" + className, new Throwable());
 		return null;
 	}
@@ -583,5 +586,9 @@ public abstract class RangerDaoManagerBase {
 	public XXServiceVersionInfoDao getXXServiceVersionInfo() {
 		return new XXServiceVersionInfoDao(this);
 	}
+
+	public XXPluginInfoDao getXXPluginInfo() {
+		return new XXPluginInfoDao(this);
+	}
 }
 
