@@ -58,7 +58,7 @@ import org.springframework.util.CollectionUtils;
 
 @Component
 public class DbToSolrMigrationUtil extends BaseLoader {
-	private static Logger logger = Logger.getLogger(DbToSolrMigrationUtil.class);
+	private static final Logger logger = Logger.getLogger(DbToSolrMigrationUtil.class);
 	private final static String CHECK_FILE_NAME = "migration_check_file.txt";
 	private final static Charset ENCODING = StandardCharsets.UTF_8;
 
@@ -417,7 +417,7 @@ public class DbToSolrMigrationUtil extends BaseLoader {
 								+ zkHosts + ", collection="
 								+ collectionName, e);
 				throw e;
-			} 
+			}
 		} else {
 			if (solrURL == null || solrURL.isEmpty()
 					|| solrURL.equalsIgnoreCase("none")) {
@@ -458,7 +458,7 @@ public class DbToSolrMigrationUtil extends BaseLoader {
 			 // Acutal solrclient JAAS configs are read from the ranger-admin-site.xml in ranger admin config folder and set by InMemoryJAASConfiguration
 			 // Refer InMemoryJAASConfiguration doc for JAAS Configuration
 			 if ( System.getProperty(PROP_JAVA_SECURITY_AUTH_LOGIN_CONFIG) == null ) {
-				 System.setProperty(PROP_JAVA_SECURITY_AUTH_LOGIN_CONFIG, "/dev/null") ;
+				 System.setProperty(PROP_JAVA_SECURITY_AUTH_LOGIN_CONFIG, "/dev/null");
 			 }
 			 logger.info("Loading SolrClient JAAS config from Ranger audit config if present...");
 			 InMemoryJAASConfiguration.init(props);
