@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -62,7 +62,6 @@ import org.apache.ranger.plugin.util.SearchFilter;
 import org.apache.ranger.plugin.util.ServicePolicies;
 import org.apache.ranger.security.context.RangerAPIList;
 import org.apache.ranger.service.XAccessAuditService;
-import org.apache.ranger.service.XAgentService;
 import org.apache.ranger.service.XAssetService;
 import org.apache.ranger.service.XCredentialStoreService;
 import org.apache.ranger.service.XPolicyExportAuditService;
@@ -94,7 +93,7 @@ import org.springframework.transaction.annotation.Transactional;
 @RangerAnnotationJSMgrName("AssetMgr")
 @Transactional(propagation = Propagation.REQUIRES_NEW)
 public class AssetREST {
-	static Logger logger = Logger.getLogger(AssetREST.class);
+	private static final Logger logger = Logger.getLogger(AssetREST.class);
 
 	@Autowired
 	RangerSearchUtil searchUtil;
@@ -114,9 +113,6 @@ public class AssetREST {
 	@Autowired
 	XCredentialStoreService xCredentialStoreService;
 
-	@Autowired
-	XAgentService xAgentService;
-
 	@Autowired
 	RESTErrorUtil restErrorUtil;
 	
@@ -524,13 +520,13 @@ public class AssetREST {
 		
 		String            epoch       = request.getParameter("epoch");
 		X509Certificate[] certchain   = (X509Certificate[]) request.getAttribute("javax.servlet.request.X509Certificate");
-		String            ipAddress   = request.getHeader("X-FORWARDED-FOR");  
+		String            ipAddress   = request.getHeader("X-FORWARDED-FOR");
 		boolean           isSecure    = request.isSecure();
 		String            policyCount = request.getParameter("policyCount");
 		String            agentId     = request.getParameter("agentId");
 		Long              lastKnowPolicyVersion = Long.valueOf(-1);
 
-		if (ipAddress == null) {  
+		if (ipAddress == null) {
 			ipAddress = request.getRemoteAddr();
 		}
 
@@ -539,7 +535,7 @@ public class AssetREST {
 		ServicePolicies servicePolicies = null;
 
 		try {
-			servicePolicies = serviceREST.getServicePoliciesIfUpdated(repository, lastKnowPolicyVersion, agentId, request);
+			servicePolicies = serviceREST.getServicePoliciesIfUpdated(repository, lastKnowPolicyVersion, 0L, agentId, "",request);
 		} catch(Exception excp) {
 			logger.error("failed to retrieve policies for repository " + repository, excp);
 		}
@@ -571,21 +567,23 @@ public class AssetREST {
 
 		SearchCriteria searchCriteria = searchUtil.extractCommonCriterias(
 				request, xPolicyExportAudits.sortFields);
-		searchUtil.extractString(request, searchCriteria, "agentId", 
-				"The XA agent id pulling the policies.", 
+		searchUtil.extractString(request, searchCriteria, "agentId",
+				"The XA agent id pulling the policies.",
 				StringUtil.VALIDATION_TEXT);
-		searchUtil.extractString(request, searchCriteria, "clientIP", 
+		searchUtil.extractString(request, searchCriteria, "clientIP",
 				"The XA agent ip pulling the policies.",
 				StringUtil.VALIDATION_TEXT);		
-		searchUtil.extractString(request, searchCriteria, "repositoryName", 
+		searchUtil.extractString(request, searchCriteria, "repositoryName",
 				"Repository name for which export was done.",
 				StringUtil.VALIDATION_TEXT);
-		searchUtil.extractInt(request, searchCriteria, "httpRetCode", 
+		searchUtil.extractInt(request, searchCriteria, "httpRetCode",
 				"HTTP response code for exported policy.");
-		searchUtil.extractDate(request, searchCriteria, "startDate", 
-				"Start date for search", null);
-		searchUtil.extractDate(request, searchCriteria, "endDate", 
-				"End date for search", null);
+		searchUtil.extractDate(request, searchCriteria, "startDate",
+                                "Start Date", null);
+		searchUtil.extractDate(request, searchCriteria, "endDate",
+                                "End Date", null);
+		searchUtil.extractString(request, searchCriteria, "cluster",
+				"Cluster Name", StringUtil.VALIDATION_TEXT);
 		return assetMgr.searchXPolicyExportAudits(searchCriteria);
 	}
 
@@ -597,14 +595,14 @@ public class AssetREST {
 
 		SearchCriteria searchCriteria = searchUtil.extractCommonCriterias(
 				request, xTrxLogService.sortFields);
-		searchUtil.extractInt(request, searchCriteria, "objectClassType", "Class type for report.");
-		searchUtil.extractString(request, searchCriteria, "attributeName", 
+                searchUtil.extractInt(request, searchCriteria, "objectClassType", "audit type.");
+		searchUtil.extractString(request, searchCriteria, "attributeName",
 				"Attribute Name", StringUtil.VALIDATION_TEXT);
-		searchUtil.extractString(request, searchCriteria, "action", 
+		searchUtil.extractString(request, searchCriteria, "action",
 				"CRUD Action Type", StringUtil.VALIDATION_TEXT);
-		searchUtil.extractString(request, searchCriteria, "sessionId", 
+		searchUtil.extractString(request, searchCriteria, "sessionId",
 				"Session Id", StringUtil.VALIDATION_TEXT);
-		searchUtil.extractString(request, searchCriteria, "owner", 
+		searchUtil.extractString(request, searchCriteria, "owner",
 				"Owner", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractDate(request, searchCriteria, "startDate", "Trasaction date since", "MM/dd/yyyy");
 		searchUtil.extractDate(request, searchCriteria, "endDate", "Trasaction date till", "MM/dd/yyyy");
@@ -615,7 +613,7 @@ public class AssetREST {
 	@Path("/report/{transactionId}")
 	@Produces({ "application/xml", "application/json" })
 	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.GET_TRANSACTION_REPORT + "\")")
-	public VXTrxLogList getTransactionReport(@Context HttpServletRequest request, 
+	public VXTrxLogList getTransactionReport(@Context HttpServletRequest request,
 			@PathParam("transactionId") String transactionId){
 		return assetMgr.getTransactionReport(transactionId);
 	}
@@ -649,20 +647,21 @@ public class AssetREST {
 				"Resource Type", StringUtil.VALIDATION_TEXT);
 
 		searchUtil.extractInt(request, searchCriteria, "auditType", "Audit Type");
-		searchUtil.extractInt(request, searchCriteria, "accessResult", "Audit Type");
+                searchUtil.extractInt(request, searchCriteria, "accessResult", "Result");
 		searchUtil.extractInt(request, searchCriteria, "assetId", "Audit Type");
 		searchUtil.extractLong(request, searchCriteria, "policyId", "Audit Type");
-		searchUtil.extractInt(request, searchCriteria, "repoType", "Audit Type");
+                searchUtil.extractInt(request, searchCriteria, "repoType", "Service Type");
 		
 		searchUtil.extractDate(request, searchCriteria, "startDate",
-				"startDate", "MM/dd/yyyy");
-		searchUtil.extractDate(request, searchCriteria, "endDate", "endDate",
+                                "Start Date", "MM/dd/yyyy");
+                searchUtil.extractDate(request, searchCriteria, "endDate", "End Date",
 				"MM/dd/yyyy");
 
 		searchUtil.extractString(request, searchCriteria, "tags", "tags", null);
+		searchUtil.extractString(request, searchCriteria, "cluster", "Cluster Name", StringUtil.VALIDATION_TEXT);
 		
 		boolean isKeyAdmin = msBizUtil.isKeyAdmin();
-		XXServiceDef xxServiceDef = daoManager.getXXServiceDef().findByName(EmbeddedServiceDefsUtil.EMBEDDED_SERVICEDEF_KMS_NAME); 
+		XXServiceDef xxServiceDef = daoManager.getXXServiceDef().findByName(EmbeddedServiceDefsUtil.EMBEDDED_SERVICEDEF_KMS_NAME);
 		if(isKeyAdmin && xxServiceDef != null){
 			searchCriteria.getParamList().put("repoType", xxServiceDef.getId());
 		}
