@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -32,7 +32,6 @@ import javax.ws.rs.Produces;
 import javax.ws.rs.core.Context;
 
 import org.apache.commons.lang.StringUtils;
-import org.apache.log4j.Logger;
 import org.apache.ranger.biz.RangerBizUtil;
 import org.apache.ranger.biz.SessionMgr;
 import org.apache.ranger.biz.XUserMgr;
@@ -67,6 +66,7 @@ import org.apache.ranger.view.VXGroupList;
 import org.apache.ranger.view.VXGroupPermission;
 import org.apache.ranger.view.VXGroupPermissionList;
 import org.apache.ranger.view.VXGroupUser;
+import org.apache.ranger.view.VXGroupUserInfo;
 import org.apache.ranger.view.VXGroupUserList;
 import org.apache.ranger.view.VXLong;
 import org.apache.ranger.view.VXModuleDef;
@@ -94,7 +94,6 @@ import org.springframework.transaction.annotation.Transactional;
 @RangerAnnotationJSMgrName("XUserMgr")
 @Transactional(propagation = Propagation.REQUIRES_NEW)
 public class XUserREST {
-	static Logger logger = Logger.getLogger(XUserREST.class);
 
 	@Autowired
 	SearchUtil searchUtil;
@@ -172,6 +171,14 @@ public class XUserREST {
 		return xUserMgr.createXGroupWithoutLogin(vXGroup);
 	}
 
+	@POST
+	@Path("/groups/groupinfo")
+	@Produces({ "application/xml", "application/json" })
+	@PreAuthorize("hasRole('ROLE_SYS_ADMIN')")
+	public VXGroupUserInfo createXGroupUserFromMap(VXGroupUserInfo vXGroupUserInfo) {
+		return  xUserMgr.createXGroupUserFromMap(vXGroupUserInfo);
+	}
+	
 	@POST
 	@Path("/secure/groups")
 	@Produces({ "application/xml", "application/json" })
@@ -218,7 +225,7 @@ public class XUserREST {
 
 	/**
 	 * Implements the traditional search functionalities for XGroups
-	 * 
+	 *
 	 * @param request
 	 * @return
 	 */
@@ -232,6 +239,7 @@ public class XUserREST {
 		searchUtil.extractString(request, searchCriteria, "name", "group name", null);
 		searchUtil.extractInt(request, searchCriteria, "isVisible", "Group Visibility");
 		searchUtil.extractString(request, searchCriteria, "groupSource", "group source", null);
+//		searchUtil.extractInt(request, searchCriteria, "groupSource", "group source");
 		return xUserMgr.searchXGroups(searchCriteria);
 	}
 
@@ -277,7 +285,7 @@ public class XUserREST {
 	@PreAuthorize("hasRole('ROLE_SYS_ADMIN')")
 	public VXUserGroupInfo createXUserGroupFromMap(VXUserGroupInfo vXUserGroupInfo) {
 		return  xUserMgr.createXUserGroupFromMap(vXUserGroupInfo);
-	} 
+	}
 	
 	@POST
 	@Path("/secure/users")
@@ -329,7 +337,7 @@ public class XUserREST {
 
 	/**
 	 * Implements the traditional search functionalities for XUsers
-	 * 
+	 *
 	 * @param request
 	 * @return
 	 */
@@ -400,7 +408,7 @@ public class XUserREST {
 
 	/**
 	 * Implements the traditional search functionalities for XGroupUsers
-	 * 
+	 *
 	 * @param request
 	 * @return
 	 */
@@ -413,6 +421,21 @@ public class XUserREST {
 				request, xGroupUserService.sortFields);
 		return xUserMgr.searchXGroupUsers(searchCriteria);
 	}
+	
+	/**
+	 * Implements the traditional search functionalities for XGroupUsers by Group name
+	 *
+	 * @param request
+	 * @return
+	 */
+	@GET
+	@Path("/groupusers/groupName/{groupName}")
+	@Produces({ "application/xml", "application/json" })
+	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.GET_X_GROUP_USERS_BY_GROUP_NAME + "\")")
+	public VXGroupUserInfo getXGroupUsersByGroupName(@Context HttpServletRequest request,
+			@PathParam("groupName") String groupName) {
+		return xUserMgr.getXGroupUserFromMap(groupName);
+	}
 
 	@GET
 	@Path("/groupusers/count")
@@ -460,7 +483,7 @@ public class XUserREST {
 
 	/**
 	 * Implements the traditional search functionalities for XGroupGroups
-	 * 
+	 *
 	 * @param request
 	 * @return
 	 */
@@ -545,7 +568,7 @@ public class XUserREST {
 
 	/**
 	 * Implements the traditional search functionalities for XPermMaps
-	 * 
+	 *
 	 * @param request
 	 * @return
 	 */
@@ -629,7 +652,7 @@ public class XUserREST {
 
 	/**
 	 * Implements the traditional search functionalities for XAuditMaps
-	 * 
+	 *
 	 * @param request
 	 * @return
 	 */
@@ -715,7 +738,7 @@ public class XUserREST {
 	@Path("/{userId}/groups")
 	@Produces({ "application/xml", "application/json" })
 	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.GET_X_USER_GROUPS + "\")")
-	public VXGroupList getXUserGroups(@Context HttpServletRequest request, 
+	public VXGroupList getXUserGroups(@Context HttpServletRequest request,
 			@PathParam("userId") Long id){
 		return xUserMgr.getXUserGroups(id);
 	}
@@ -724,7 +747,7 @@ public class XUserREST {
 	@Path("/{groupId}/users")
 	@Produces({ "application/xml", "application/json" })
 	@PreAuthorize("@rangerPreAuthSecurityHandler.isAPIAccessible(\"" + RangerAPIList.GET_X_GROUP_USERS + "\")")
-	public VXUserList getXGroupUsers(@Context HttpServletRequest request, 
+	public VXUserList getXGroupUsers(@Context HttpServletRequest request,
 			@PathParam("groupId") Long id){
 		return xUserMgr.getXGroupUsers(id);
 	}
@@ -739,15 +762,15 @@ public class XUserREST {
 		searchUtil.extractLong(request, searchCriteria, "id", "Auth Session Id");
 		searchUtil.extractLong(request, searchCriteria, "userId", "User Id");
 		searchUtil.extractInt(request, searchCriteria, "authStatus", "Auth Status");
-		searchUtil.extractInt(request, searchCriteria, "authType", "Auth Type");
+                searchUtil.extractInt(request, searchCriteria, "authType", "Login Type");
 		searchUtil.extractInt(request, searchCriteria, "deviceType", "Device Type");
 		searchUtil.extractString(request, searchCriteria, "firstName", "User First Name", StringUtil.VALIDATION_NAME);
 		searchUtil.extractString(request, searchCriteria, "lastName", "User Last Name", StringUtil.VALIDATION_NAME);
 		searchUtil.extractString(request, searchCriteria, "requestUserAgent", "User Agent", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "requestIP", "Request IP Address", StringUtil.VALIDATION_IP_ADDRESS);
 		searchUtil.extractString(request, searchCriteria, "loginId", "Login ID", StringUtil.VALIDATION_TEXT);
-		searchUtil.extractDate(request, searchCriteria, "startDate", "Start date for search", null);
-		searchUtil.extractDate(request, searchCriteria, "endDate", "End date for search", null);						
+                searchUtil.extractDate(request, searchCriteria, "startDate", "Start Date", null);
+                searchUtil.extractDate(request, searchCriteria, "endDate", "End Date", null);
 		return sessionMgr.searchAuthSessions(searchCriteria);
 	}
 	
