@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -95,11 +95,19 @@ public class RangerPreAuthSecurityHandler {
 
 	public boolean isAPISpnegoAccessible(){
 		UserSessionBase userSession = ContextUtil.getCurrentUserSession();
-		if (userSession != null && userSession.isSpnegoEnabled()) {
+		if (userSession != null && (userSession.isSpnegoEnabled() || userSession.isUserAdmin())) {
 			return true;
 		}else if(userSession != null && (userSession.isUserAdmin() || userSession.isKeyAdmin())){
 			return true;
 		}
 		throw restErrorUtil.createRESTException(HttpServletResponse.SC_FORBIDDEN, "User is not allowed to access the API", true);
 	}
+	
+	public boolean isAdminOrKeyAdminRole(){
+		UserSessionBase userSession = ContextUtil.getCurrentUserSession();
+		if (userSession != null && (userSession.isKeyAdmin() || userSession.isUserAdmin())) {
+			return true;
+		}
+		throw restErrorUtil.createRESTException(HttpServletResponse.SC_UNAUTHORIZED, "User is not allowed to access the API", true);
+	}
 }
