@@ -31,6 +31,7 @@ import javax.security.auth.login.Configuration;
 
 import org.apache.log4j.Logger;
 import org.apache.ranger.authentication.unix.jaas.RoleUserAuthorityGranter;
+import org.apache.ranger.authorization.utils.StringUtil;
 import org.apache.ranger.common.PropertiesUtil;
 import org.springframework.ldap.core.support.LdapContextSource;
 import org.springframework.security.authentication.AuthenticationProvider;
@@ -71,7 +72,7 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 
 	@Autowired
 	UserMgr userMgr;
-	private static Logger logger = Logger.getLogger(RangerAuthenticationProvider.class);
+	private static final Logger logger = Logger.getLogger(RangerAuthenticationProvider.class);
 	private String rangerAuthenticationMethod;
 
 	private LdapAuthenticator authenticator;
@@ -85,37 +86,37 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 	@Override
 	public Authentication authenticate(Authentication authentication)
 			throws AuthenticationException {
-		if(isSsoEnabled()){
-			if (authentication != null){
+		if (isSsoEnabled()) {
+			if (authentication != null) {
 				authentication = getSSOAuthentication(authentication);
-				if(authentication!=null && authentication.isAuthenticated()){
+				if (authentication != null && authentication.isAuthenticated()) {
 					return authentication;
 				}
 			}
-		}else{
-		String sha256PasswordUpdateDisable=PropertiesUtil.getProperty("ranger.sha256Password.update.disable", "false");
-		if(rangerAuthenticationMethod==null){
+		} else {
+		String sha256PasswordUpdateDisable = PropertiesUtil.getProperty("ranger.sha256Password.update.disable", "false");
+		if (rangerAuthenticationMethod==null) {
 			rangerAuthenticationMethod="NONE";
 		}
-		if (authentication != null && rangerAuthenticationMethod!=null) {
+		if (authentication != null && rangerAuthenticationMethod != null) {
 			if (rangerAuthenticationMethod.equalsIgnoreCase("LDAP")) {
-				authentication=getLdapAuthentication(authentication);
-				if(authentication!=null && authentication.isAuthenticated()){
+				authentication = getLdapAuthentication(authentication);
+				if (authentication!=null && authentication.isAuthenticated()) {
 					return authentication;
-				}else{
+				} else {
 					authentication=getLdapBindAuthentication(authentication);
-					if(authentication!=null && authentication.isAuthenticated()){
+					if (authentication != null && authentication.isAuthenticated()) {
 						return authentication;
 					}
 				}
 			}
 			if (rangerAuthenticationMethod.equalsIgnoreCase("ACTIVE_DIRECTORY")) {
-				authentication=getADBindAuthentication(authentication);
-				if(authentication!=null && authentication.isAuthenticated()){
+				authentication = getADBindAuthentication(authentication);
+				if (authentication != null && authentication.isAuthenticated()) {
 					return authentication;
-				}else{
-					authentication=getADAuthentication(authentication);
-					if(authentication!=null && authentication.isAuthenticated()){
+				} else {
+					authentication = getADAuthentication(authentication);
+					if (authentication != null && authentication.isAuthenticated()) {
 						return authentication;
 					}
 				}
@@ -123,49 +124,41 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 			if (rangerAuthenticationMethod.equalsIgnoreCase("UNIX")) {
                 boolean isPAMAuthEnabled = PropertiesUtil.getBooleanProperty("ranger.pam.authentication.enabled", false);
                 authentication= (isPAMAuthEnabled ? getPamAuthentication(authentication) : getUnixAuthentication(authentication));
-				authentication= getUnixAuthentication(authentication);
-				if(authentication!=null && authentication.isAuthenticated()){
+				if (authentication != null && authentication.isAuthenticated()) {
 					return authentication;
 				}
 			}
 			if (rangerAuthenticationMethod.equalsIgnoreCase("PAM")) {
 				authentication = getPamAuthentication(authentication);
-				if(authentication!=null && authentication.isAuthenticated()) {
+				if (authentication != null && authentication.isAuthenticated()) {
 					return authentication;
 				}
 			}
 			String encoder="SHA256";
-			try{
-				authentication=getJDBCAuthentication(authentication,encoder);
-			}catch (BadCredentialsException e) {
-			}catch (AuthenticationServiceException e) {
-			}catch (AuthenticationException e) {
-			}catch (Exception e) {
+			try {
+				authentication = getJDBCAuthentication(authentication,encoder);
+			} catch (Exception e) {
+				logger.debug("JDBC Authentication failure: ", e);
 			}
-			if(authentication!=null && authentication.isAuthenticated()){
+			if (authentication !=null && authentication.isAuthenticated()) {
 				return authentication;
 			}
-			if(authentication!=null && !authentication.isAuthenticated()){
+			if (authentication != null && !authentication.isAuthenticated()) {
+				logger.info("Authentication with SHA-256 failed. Now trying with MD5.");
 				encoder="MD5";
 				String userName = authentication.getName();
 				String userPassword = null;
 				if (authentication.getCredentials() != null) {
 					userPassword = authentication.getCredentials().toString();
 				}
-				try{
-					authentication=getJDBCAuthentication(authentication,encoder);
-				}catch (BadCredentialsException e) {
-					throw e;
-				}catch (AuthenticationServiceException e) {
-					throw e;
-				}catch (AuthenticationException e) {
-					throw e;
-				}catch (Exception e) {
+				try {
+					authentication = getJDBCAuthentication(authentication,encoder);
+				} catch (Exception e) {
 					throw e;
 				}
-				if(authentication!=null && authentication.isAuthenticated()){
-					if("false".equalsIgnoreCase(sha256PasswordUpdateDisable)){
-						userMgr.updatePasswordInSHA256(userName,userPassword);
+				if (authentication != null && authentication.isAuthenticated()) {
+					if ("false".equalsIgnoreCase(sha256PasswordUpdateDisable)) {
+                                                userMgr.updatePasswordInSHA256(userName,userPassword,false);
 					}
 					return authentication;
 				}else{
@@ -210,19 +203,6 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 			ldapContextSource.setCacheEnvironmentProperties(false);
 			ldapContextSource.setAnonymousReadOnly(true);
 
-			// Creating LDAP authorities populator using Ldap context source and
-			// Ldap group search base.
-			// populating LDAP authorities populator with group search
-			// base,group role attribute, group search filter.
-			DefaultLdapAuthoritiesPopulator defaultLdapAuthoritiesPopulator = new DefaultLdapAuthoritiesPopulator(
-					ldapContextSource, rangerLdapGroupSearchBase);
-			defaultLdapAuthoritiesPopulator
-					.setGroupRoleAttribute(rangerLdapGroupRoleAttribute);
-			defaultLdapAuthoritiesPopulator
-					.setGroupSearchFilter(rangerLdapGroupSearchFilter);
-			defaultLdapAuthoritiesPopulator
-					.setIgnorePartialResultException(true);
-
 			// Creating BindAuthenticator using Ldap Context Source.
 			BindAuthenticator bindAuthenticator = new BindAuthenticator(
 					ldapContextSource);
@@ -230,10 +210,25 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 			String[] userDnPatterns = rangerLdapUserDNPattern.split(";");
 			bindAuthenticator.setUserDnPatterns(userDnPatterns);
 
-			// Creating Ldap authentication provider using BindAuthenticator and
-			// Ldap authentication populator
-			LdapAuthenticationProvider ldapAuthenticationProvider = new LdapAuthenticationProvider(
-					bindAuthenticator, defaultLdapAuthoritiesPopulator);
+			LdapAuthenticationProvider ldapAuthenticationProvider = null;
+
+			if (!StringUtil.isEmpty(rangerLdapGroupSearchBase) && !StringUtil.isEmpty(rangerLdapGroupSearchFilter)) {
+				// Creating LDAP authorities populator using Ldap context source and
+				// Ldap group search base.
+				// populating LDAP authorities populator with group search
+				// base,group role attribute, group search filter.
+				DefaultLdapAuthoritiesPopulator defaultLdapAuthoritiesPopulator = new DefaultLdapAuthoritiesPopulator(
+						ldapContextSource, rangerLdapGroupSearchBase);
+				defaultLdapAuthoritiesPopulator.setGroupRoleAttribute(rangerLdapGroupRoleAttribute);
+				defaultLdapAuthoritiesPopulator.setGroupSearchFilter(rangerLdapGroupSearchFilter);
+				defaultLdapAuthoritiesPopulator.setIgnorePartialResultException(true);
+
+				// Creating Ldap authentication provider using BindAuthenticator and Ldap authentication populator
+				ldapAuthenticationProvider = new LdapAuthenticationProvider(
+						bindAuthenticator, defaultLdapAuthoritiesPopulator);
+			} else {
+				ldapAuthenticationProvider = new LdapAuthenticationProvider(bindAuthenticator);
+			}
 
 			// getting user authenticated
 			if (userName != null && userPassword != null
@@ -270,11 +265,14 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 					"ranger.ldap.ad.domain", "");
 			String rangerLdapDefaultRole = PropertiesUtil.getProperty(
 					"ranger.ldap.default.role", "ROLE_USER");
+			String rangerLdapUserSearchFilter = PropertiesUtil.getProperty(
+                                       "ranger.ldap.ad.user.searchfilter", "(sAMAccountName={0})");
 
 			ActiveDirectoryLdapAuthenticationProvider adAuthenticationProvider = new ActiveDirectoryLdapAuthenticationProvider(
 					rangerADDomain, rangerADURL);
 			adAuthenticationProvider.setConvertSubErrorCodesToExceptions(true);
 			adAuthenticationProvider.setUseAuthenticationRequestCredentials(true);
+			adAuthenticationProvider.setSearchFilter(rangerLdapUserSearchFilter);
 
 			// Grab the user-name and password out of the authentication object.
 			String userName = authentication.getName();
@@ -458,7 +456,7 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 			ldapContextSource.afterPropertiesSet();
 
 			//String searchFilter="(sAMAccountName={0})";
-			if(rangerLdapUserSearchFilter==null||rangerLdapUserSearchFilter.trim().isEmpty()){
+			if (rangerLdapUserSearchFilter==null || rangerLdapUserSearchFilter.trim().isEmpty()) {
 				rangerLdapUserSearchFilter="(sAMAccountName={0})";
 			}
 			FilterBasedLdapUserSearch userSearch=new FilterBasedLdapUserSearch(rangerLdapADBase, rangerLdapUserSearchFilter,ldapContextSource);
@@ -522,7 +520,7 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 			defaultLdapAuthoritiesPopulator.setIgnorePartialResultException(true);
 
 			//String searchFilter="(uid={0})";
-			if(rangerLdapUserSearchFilter==null||rangerLdapUserSearchFilter.trim().isEmpty()){
+			if (rangerLdapUserSearchFilter==null||rangerLdapUserSearchFilter.trim().isEmpty()) {
 				rangerLdapUserSearchFilter="(uid={0})";
 			}
 			FilterBasedLdapUserSearch userSearch=new FilterBasedLdapUserSearch(rangerLdapBase, rangerLdapUserSearchFilter,ldapContextSource);
@@ -562,16 +560,16 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 
 			DaoAuthenticationProvider authenticator = new DaoAuthenticationProvider();
 			authenticator.setUserDetailsService(userDetailsService);
-			if(encoder!=null && "SHA256".equalsIgnoreCase(encoder)){
-				authenticator.setPasswordEncoder( new ShaPasswordEncoder(256));
-			}else if(encoder!=null && "MD5".equalsIgnoreCase(encoder)){
-				authenticator.setPasswordEncoder( new Md5PasswordEncoder());
+			if (encoder != null && "SHA256".equalsIgnoreCase(encoder)) {
+				authenticator.setPasswordEncoder(new ShaPasswordEncoder(256));
+			} else if(encoder != null && "MD5".equalsIgnoreCase(encoder)) {
+				authenticator.setPasswordEncoder(new Md5PasswordEncoder());
 			}
 
 			authenticator.setSaltSource(saltSource);
 			String userName ="";
 			String userPassword = "";
-			if(authentication!=null){
+			if (authentication!=null) {
 				userName = authentication.getName();
 				if (authentication.getCredentials() != null) {
 					userPassword = authentication.getCredentials().toString();
@@ -586,8 +584,8 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 				final Authentication finalAuthentication = new UsernamePasswordAuthenticationToken(principal, userPassword, grantedAuths);
 				authentication= authenticator.authenticate(finalAuthentication);
 				return authentication;
-			}else{
-				if(authentication!=null&&!authentication.isAuthenticated()){
+			} else {
+				if (authentication !=null && !authentication.isAuthenticated()) {
 					throw new BadCredentialsException("Bad credentials");
 				}
 			}
@@ -606,15 +604,15 @@ public class RangerAuthenticationProvider implements AuthenticationProvider {
 	private List<GrantedAuthority> getAuthorities(String username) {
 		Collection<String> roleList=userMgr.getRolesByLoginId(username);
 		final List<GrantedAuthority> grantedAuths = new ArrayList<>();
-		for(String role:roleList){
+		for (String role : roleList) {
 			grantedAuths.add(new SimpleGrantedAuthority(role));
 		}
 		return grantedAuths;
 	}
- 
+
 	public Authentication getAuthenticationWithGrantedAuthority(Authentication authentication){
-		UsernamePasswordAuthenticationToken result=null;
-		if(authentication!=null && authentication.isAuthenticated()){
+		UsernamePasswordAuthenticationToken result = null;
+		if (authentication != null && authentication.isAuthenticated()) {
 			final List<GrantedAuthority> grantedAuths=getAuthorities(authentication.getName().toString());
 			final UserDetails userDetails = new User(authentication.getName().toString(), authentication.getCredentials().toString(),grantedAuths);
 			result = new UsernamePasswordAuthenticationToken(userDetails,authentication.getCredentials(),grantedAuths);
