@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -41,18 +41,18 @@ import org.springframework.security.web.authentication.SavedRequestAwareAuthenti
 import org.springframework.security.web.authentication.WebAuthenticationDetails;
 
 /**
- * 
+ *
  *
  */
 public class RangerAuthSuccessHandler extends
 SavedRequestAwareAuthenticationSuccessHandler {
-    static Logger logger = Logger.getLogger(RangerAuthSuccessHandler.class);
+    private static final Logger logger = Logger.getLogger(RangerAuthSuccessHandler.class);
 
     String ajaxLoginSuccessPage = null;
-    
+
     @Autowired
     SessionMgr sessionMgr;
-    
+
     @Autowired
     JSONUtil jsonUtil;
 
