@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -22,16 +22,12 @@ package org.apache.ranger.security.web.filter;
 import java.io.IOException;
 import java.util.HashSet;
 import java.util.Set;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-
 import javax.servlet.Filter;
 import javax.servlet.FilterChain;
 import javax.servlet.FilterConfig;
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
@@ -42,22 +38,22 @@ public class RangerCSRFPreventionFilter implements Filter {
 	
 	private static final Logger LOG = Logger.getLogger(RangerCSRFPreventionFilter.class);
 		
-	public static final boolean isCSRF_ENABLED = PropertiesUtil.getBooleanProperty("ranger.rest-csrf.enabled", true);
 	public static final String BROWSER_USER_AGENT_PARAM = "ranger.rest-csrf.browser-useragents-regex";
-	public static final String BROWSER_USER_AGENTS_DEFAULT = "^Mozilla.*,^Opera.*,^Chrome.*";
+	public static final String BROWSER_USER_AGENTS_DEFAULT = "Mozilla,Opera,Chrome";
 	public static final String CUSTOM_METHODS_TO_IGNORE_PARAM = "ranger.rest-csrf.methods-to-ignore";
 	public static final String METHODS_TO_IGNORE_DEFAULT = "GET,OPTIONS,HEAD,TRACE";
 	public static final String CUSTOM_HEADER_PARAM = "ranger.rest-csrf.custom-header";
 	public static final String HEADER_DEFAULT = "X-XSRF-HEADER";
 	public static final String HEADER_USER_AGENT = "User-Agent";
+	private static final boolean IS_CSRF_ENABLED = PropertiesUtil.getBooleanProperty("ranger.rest-csrf.enabled", true);
 
 	private String  headerName = HEADER_DEFAULT;
 	private Set<String> methodsToIgnore = null;
-	private Set<Pattern> browserUserAgents;
+	private String[] browserUserAgents;
 	
 	public RangerCSRFPreventionFilter() {
 		try {
-			if (isCSRF_ENABLED){
+			if (IS_CSRF_ENABLED){
 				init(null);
 			}
 		} catch (Exception e) {
@@ -70,7 +66,7 @@ public class RangerCSRFPreventionFilter implements Filter {
 	    if (customHeader != null) {
 	      headerName = customHeader;
 	    }
-	    
+	
 	    String customMethodsToIgnore = PropertiesUtil.getProperty(CUSTOM_METHODS_TO_IGNORE_PARAM, METHODS_TO_IGNORE_DEFAULT);
         if (customMethodsToIgnore != null) {
           parseMethodsToIgnore(customMethodsToIgnore);
@@ -94,28 +90,22 @@ public class RangerCSRFPreventionFilter implements Filter {
 	}
 	
 	void parseBrowserUserAgents(String userAgents) {
-		String[] agentsArray = userAgents.split(",");
-		browserUserAgents = new HashSet<Pattern>();
-		for (String patternString : agentsArray) {
-			browserUserAgents.add(Pattern.compile(patternString));
-		}
+		browserUserAgents = userAgents.split(",");
 	}
 	
 	protected boolean isBrowser(String userAgent) {
-		if (userAgent == null) {
-			return false;
-		}
-		if (browserUserAgents != null){
-			for (Pattern pattern : browserUserAgents) {
-				Matcher matcher = pattern.matcher(userAgent);
-				if (matcher.matches()) {
-					return true;
+		boolean isWeb = false;
+		if (browserUserAgents != null && browserUserAgents.length > 0 && userAgent != null) {
+			for (String ua : browserUserAgents) {
+				if (userAgent.toLowerCase().startsWith(ua.toLowerCase())) {
+					isWeb = true;
+					break;
 				}
 			}
 		}
-		return false;
+		return isWeb;
 	}
-	  
+	
 	public interface HttpInteraction {
 		/**
 		 * Returns the value of a header.
@@ -157,12 +147,12 @@ public class RangerCSRFPreventionFilter implements Filter {
 		 */
 		void sendError(int code, String message) throws IOException;
 	}	
-	  
+	
 	public void handleHttpInteraction(HttpInteraction httpInteraction)
 			throws IOException, ServletException {
-		if (!isBrowser(httpInteraction.getHeader(HEADER_USER_AGENT))
-				|| methodsToIgnore.contains(httpInteraction.getMethod())
-				|| httpInteraction.getHeader(headerName) != null) {
+		if (httpInteraction.getHeader(headerName) != null
+				|| !isBrowser(httpInteraction.getHeader(HEADER_USER_AGENT))
+				|| methodsToIgnore.contains(httpInteraction.getMethod())) {
 			httpInteraction.proceed();
 		}else {
 			httpInteraction.sendError(HttpServletResponse.SC_BAD_REQUEST,"Missing Required Header for CSRF Vulnerability Protection");
@@ -170,7 +160,7 @@ public class RangerCSRFPreventionFilter implements Filter {
 	}
 	
 	public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
-		if (isCSRF_ENABLED){
+		if (IS_CSRF_ENABLED) {
 			final HttpServletRequest httpRequest = (HttpServletRequest)request;
 		    final HttpServletResponse httpResponse = (HttpServletResponse)response;
 		    handleHttpInteraction(new ServletFilterHttpInteraction(httpRequest, httpResponse, chain));
