@@ -51,7 +51,7 @@ import java.util.regex.Pattern;
 @InterfaceStability.Unstable
 public class RangerKrbFilter implements Filter {
 
-  private static Logger LOG = LoggerFactory.getLogger(RangerKrbFilter.class);
+    private static final Logger LOG = LoggerFactory.getLogger(RangerKrbFilter.class);
 
   /**
    * Constant for the property that specifies the configuration prefix.
@@ -106,8 +106,8 @@ public class RangerKrbFilter implements Filter {
       "signer.secret.provider.object";
 
   private static final String BROWSER_USER_AGENT_PARAM = "ranger.krb.browser-useragents-regex";	
-  
-  private Set<Pattern> browserUserAgents;
+
+  private String[] browserUserAgents;
 
   private Properties config;
   private Signer signer;
@@ -135,9 +135,9 @@ public class RangerKrbFilter implements Filter {
     String authHandlerClassName;
     if (authHandlerName == null) {
       throw new ServletException("Authentication type must be specified: " +
-          PseudoAuthenticationHandler.TYPE + "|" + 
+          PseudoAuthenticationHandler.TYPE + "|" +
           KerberosAuthenticationHandler.TYPE + "|<class>");
-    }    
+    }
     if(StringUtils.equalsIgnoreCase(authHandlerName, PseudoAuthenticationHandler.TYPE)){
       authHandlerClassName = PseudoAuthenticationHandler.class.getName();
     }else if(StringUtils.equalsIgnoreCase(authHandlerName, KerberosAuthenticationHandler.TYPE)){
@@ -589,28 +589,22 @@ public class RangerKrbFilter implements Filter {
     sb.append("; HttpOnly");
     resp.addHeader("Set-Cookie", sb.toString());
   }
-  
-  void parseBrowserUserAgents(String userAgents) {
-		String[] agentsArray = userAgents.split(",");
-		browserUserAgents = new HashSet<Pattern>();
-		for (String patternString : agentsArray) {
-			browserUserAgents.add(Pattern.compile(patternString));
-		}
+
+	void parseBrowserUserAgents(String userAgents) {
+		browserUserAgents = userAgents.split(",");
 	}
-	
+
 	protected boolean isBrowser(String userAgent) {
-		if (userAgent == null) {
-			return false;
-		}
-		if (browserUserAgents != null){
-			for (Pattern pattern : browserUserAgents) {
-				Matcher matcher = pattern.matcher(userAgent);
-				if (matcher.matches()) {
-					return true;
+		boolean isWeb = false;
+		if (browserUserAgents != null && browserUserAgents.length > 0 && userAgent != null) {
+			for (String ua : browserUserAgents) {
+				if (userAgent.toLowerCase().startsWith(ua.toLowerCase())) {
+					isWeb = true;
+					break;
 				}
 			}
 		}
-		return false;
+		return isWeb;
 	}
 }
 
