@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -67,7 +67,7 @@ import org.springframework.beans.factory.annotation.Autowired;
 
 public abstract class AbstractBaseResourceService<T extends XXDBBase, V extends VXDataObject> {
 
-	public static final Logger logger = Logger
+	protected static final Logger logger = Logger
 			.getLogger(AbstractBaseResourceService.class);
 
 	public static final int OPERATION_CREATE_CONTEXT = 1;
