@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -100,11 +100,12 @@ public class XTrxLogService extends XTrxLogServiceBase<XXTrxLog, VXTrxLog> {
 		Predicate intPredicate = null;		
 		Predicate datePredicate =null;
 		Map<String, Object> paramList = searchCriteria.getParamList();	
-		for(String key : paramList.keySet()){
+		for(Map.Entry<String, Object> entry: paramList.entrySet()){
 			for(SearchField searchField : searchFields){				
 				fieldName = searchField.getFieldName();
-				clientFieldName = searchField.getClientFieldName();				
-				paramValue = paramList.get(key);
+				clientFieldName = searchField.getClientFieldName();	
+				String key=entry.getKey();
+				paramValue = entry.getValue();
 				isListValue = false;				
 				if (paramValue != null && paramValue instanceof Collection) {
 					isListValue = true;
@@ -126,7 +127,7 @@ public class XTrxLogService extends XTrxLogServiceBase<XXTrxLog, VXTrxLog> {
 							predicate = criteriaBuilder.and(predicate, stringPredicate);
 							
 						}	
-					} else if (searchField.getDataType() == SearchField.DATA_TYPE.INT_LIST || 
+					} else if (searchField.getDataType() == SearchField.DATA_TYPE.INT_LIST ||
 							isListValue && searchField.getDataType() == SearchField.DATA_TYPE.INTEGER) {
 						// build where clause for integer lists or integers datatypes
 						intValueList = null;
@@ -164,7 +165,7 @@ public class XTrxLogService extends XTrxLogServiceBase<XXTrxLog, VXTrxLog> {
 									datePredicate = criteriaBuilder.equal(rootEntityType.get(attr), fieldValue);
 								}
 								predicate = criteriaBuilder.and(predicate, datePredicate);
-							} 
+							}
 						}
 						
 					}
@@ -225,11 +226,12 @@ public class XTrxLogService extends XTrxLogServiceBase<XXTrxLog, VXTrxLog> {
 		Predicate stringPredicate =null;		
 		Predicate intPredicate = null;		
 		Predicate datePredicate =null;		
-		for(String key : paramList.keySet()){
+		for(Map.Entry<String, Object> entry : paramList.entrySet()){
+			String key=entry.getKey();
 			for(SearchField searchField : searchFields){				
 				fieldName = searchField.getFieldName();
 				clientFieldName = searchField.getClientFieldName();				
-				paramValue = paramList.get(key);
+				paramValue = entry.getValue();
 				isListValue = false;				
 				if (paramValue != null && paramValue instanceof Collection) {
 					isListValue = true;
@@ -251,7 +253,7 @@ public class XTrxLogService extends XTrxLogServiceBase<XXTrxLog, VXTrxLog> {
 							predicate = criteriaBuilder.and(predicate, stringPredicate);
 							
 						}	
-					} else if (searchField.getDataType() == SearchField.DATA_TYPE.INT_LIST || 
+					} else if (searchField.getDataType() == SearchField.DATA_TYPE.INT_LIST ||
 							isListValue && searchField.getDataType() == SearchField.DATA_TYPE.INTEGER) {
 						// build where clause for integer lists or integers datatypes
 						intValueList = null;
@@ -289,7 +291,7 @@ public class XTrxLogService extends XTrxLogServiceBase<XXTrxLog, VXTrxLog> {
 									datePredicate = criteriaBuilder.equal(rootEntityType.get(attr), fieldValue);
 								}
 								predicate = criteriaBuilder.and(predicate, datePredicate);
-							} 
+							}
 						}
 						
 					}
@@ -308,82 +310,6 @@ public class XTrxLogService extends XTrxLogServiceBase<XXTrxLog, VXTrxLog> {
 		return count;
 	}
 	
-	@SuppressWarnings({ "rawtypes", "unchecked" })
-	private Predicate buildWhereClause(Predicate predicate, Map<String, Object> paramList, EntityType<XXTrxLog> trxLogEntity, 
-			CriteriaBuilder criteriaBuilder, Root<XXTrxLog> root){
-		
-		for(String key : paramList.keySet()) {
-			for(SearchField searchField : searchFields){
-				
-				String fieldName = searchField.getFieldName();
-				String clientFieldName = searchField.getClientFieldName();
-				
-				Object paramValue = paramList.get(key);
-				boolean isListValue = false;
-				
-				if (paramValue != null && paramValue instanceof Collection) {
-					isListValue = true;
-				}
-				
-				if(fieldName != null){
-					fieldName = fieldName.contains(".") ? fieldName.substring(fieldName.indexOf(".") + 1) : fieldName;
-				}
-				
-				if(key.equalsIgnoreCase(clientFieldName)){
-					// build where clause depending upon given parameters
-					if(searchField.getDataType() == SearchField.DATA_TYPE.STRING) {
-						// build where clause for String datatypes
-						SingularAttribute attr = trxLogEntity.getSingularAttribute(fieldName);
-						if(attr != null){
-							Predicate stringPredicate = criteriaBuilder.equal(root.get(attr), paramValue);
-							predicate = criteriaBuilder.and(predicate, stringPredicate);
-						}	
-					} else if (searchField.getDataType() == SearchField.DATA_TYPE.INT_LIST || 
-							isListValue && searchField.getDataType() == SearchField.DATA_TYPE.INTEGER) {
-						// build where clause for integer lists or integers datatypes
-						Collection<Number> intValueList = null;
-						if (paramValue != null && (paramValue instanceof Integer || paramValue instanceof Long)) {
-							intValueList = new ArrayList<Number>();
-							intValueList.add((Number) paramValue);
-						} else {
-							intValueList = (Collection<Number>) paramValue;
-						}
-						for(Number value : intValueList){
-							SingularAttribute attr = trxLogEntity.getSingularAttribute(fieldName);
-							if(attr != null){
-								Predicate intPredicate = criteriaBuilder.equal(root.get(attr), value);
-								predicate = criteriaBuilder.and(predicate, intPredicate);
-							}							
-						}
-					} else if (searchField.getDataType() == SearchField.DATA_TYPE.DATE){
-						// build where clause for date datatypes
-						Date fieldValue = (Date) paramList.get(searchField
-								.getClientFieldName());
-						SingularAttribute attr = trxLogEntity.getSingularAttribute(fieldName);
-						if (fieldValue != null) {
-							if (searchField.getCustomCondition() == null) {
-								Predicate datePredicate = criteriaBuilder.equal(root.get(attr), fieldValue);
-								if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.LESS_THAN)) {
-									datePredicate = criteriaBuilder.lessThan(root.get(attr), fieldValue);
-								} else if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.LESS_EQUAL_THAN)) {
-									datePredicate = criteriaBuilder.lessThanOrEqualTo(root.get(attr), fieldValue);
-								} else if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.GREATER_THAN)) {
-									datePredicate = criteriaBuilder.greaterThan(root.get(attr), fieldValue);
-								} else if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.GREATER_EQUAL_THAN)) {
-									datePredicate = criteriaBuilder.greaterThanOrEqualTo(root.get(attr), fieldValue);
-								} else {
-									datePredicate = criteriaBuilder.equal(root.get(attr), fieldValue);
-								}
-								predicate = criteriaBuilder.and(predicate, datePredicate);
-							} 
-						}
-					}
-				}
-			}
-		}
-		return predicate;
-	}
-
 	private VXTrxLog mapCustomViewToViewObj(VXXTrxLog vXXTrxLog){
 		VXTrxLog vXTrxLog = new VXTrxLog();
 		vXTrxLog.setId(vXXTrxLog.getId());
