@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -20,7 +20,7 @@
  package org.apache.ranger.util;
 
 /**
- * 
+ *
  */
 
 import java.util.ArrayList;
@@ -36,7 +36,7 @@ import org.springframework.stereotype.Component;
 @Component
 public class RangerEnumUtil {
 
-    static final Logger logger = Logger.getLogger(RangerEnumUtil.class);
+    private static final Logger logger = Logger.getLogger(RangerEnumUtil.class);
     public final static String ENUM_CommonEnums_ActiveStatus = "CommonEnums.ActiveStatus";
     public final static String ENUM_CommonEnums_ActivationStatus = "CommonEnums.ActivationStatus";
     public final static String ENUM_CommonEnums_BooleanValue = "CommonEnums.BooleanValue";
