@@ -233,9 +233,16 @@ define(function(require) {
 				componentPermissions			: 'Component Permissions',
 				selectDataMaskTypes				: 'Select Data Mask Types',
 				accessTypes						: 'Access Types',
-                                rowLevelFilter					: 'Row Level Filter',
-                                selectAndAddUser                : 'Select and Add User',
-                                selectAndAddGroup               : 'Select and Add Group',
+				rowLevelFilter					: 'Row Level Filter',
+				selectMaskingOption             : 'Select Masking Option',
+				versionTime                     : 'Version / Time',
+				serviceType                     : 'Service Type',
+                hostName						: 'Host Name',
+                selectAndAddUser                : 'Select and Add User',
+                selectAndAddGroup               : 'Select and Add Group',
+                download                        : 'Download',
+                lastUpdate                      : 'Last Update',
+		clusterName                     : 'Cluster Name'
 			},
 			btn : {
 				add							: 'Add',
@@ -295,7 +302,7 @@ define(function(require) {
 				searchForYourUser 			:"Search for your users...",
 				searchForYourGroup 			:"Search for your groups...",
 				access						: 'Access',
-				policyCondition				: 'Policy Condtions',
+				policyCondition				: 'Policy Conditions',
 				permissions					: 'Permissions',
 				kms							: 'KMS',
 				keyCreate					: 'Key Create',
@@ -303,9 +310,27 @@ define(function(require) {
 				searchForKeys				:"Search for your keys...",
 				encryption					: 'Encryption',
 				settings					: 'Settings',
-				
-				
-			},
+                serviceNameMsg              :'Name of service.',
+                serviceTypeMsg              :'Select type of service.',
+                startDate                   :'Set start date.',
+                userMsg                     :'Name of User.',
+                tagsMsg                     :'Tag Name.',
+                endDate                     :'Set end date.',
+                groupNameMsg                :'Name of Group.',
+                collection                  :'Solr collection.',
+                database                    :'Hive database.',
+                entity                      :'Atlas all-entity.',
+                operation                   :'Atlas all-operation.',
+                path                        :'Name of policy resource.',
+                queue                       :'Yarn queue.',
+                taxonomy                    :'Atlas all-taxonomy.',
+                term                        :'Policy for all-term.',
+                topic                       :'Kafka topic.',
+                type                        :'Policy for all type.',
+                udf                         :'Hive udf.',
+                pluginStatus                :'Plugin Status',
+		clusterName                 :'Name of ambari cluster'
+                        },
 			msg : {
 				deletePolicyValidationMsg : 'Policy does not have any settings for the specific resource. Policy will be deleted. Press [Ok] to continue. Press [Cancel] to edit the policy.',
 				areYouSureWantToDelete	  : 'Are you sure want to delete ?',
@@ -339,14 +364,38 @@ define(function(require) {
 				userUpdatedSucc           :     'User updated successfully',
 				grpUpdatedSucc            : 'Group updated successfully',
 				grpCreatedSucc            : 'Group created successfully',
-				errorLoadingAuditLogs	  : 'Unable to connect to Audit store !!',
-                                enterCustomMask			  : 'Please enter custom masked value or expression !!',
-                                pleaseSelectUser          : 'Please select user.',
-                                pleaseSelectGroup         : 'Please select group.',
-                                addSelectedUserGroup      : 'Please add selected user/group to permissions else user/group will not be added.'
-				
-				
-				
+                                errorLoadingAuditLogs	  : 'Error loading audit logs!!',
+                enterCustomMask			  : 'Please enter custom masked value or expression !!',
+                policyNameMsg           :'Enter name of policy.',
+                policyTypeMsg           :'Select Type of policy eg. access, masking, row level filter policies.'    ,
+                componentMsg            :'Select Hadoop Component eg. HDFS, Hive etc.',
+                searchBy                :'Search by user name or group name.',
+                resourceMsg             :'Enter name of resource for eg. path, table/column name etc.',
+                accessEnforcer          :'Search by access enforcer name.',
+                accessTypeMsg           :'Search by access Type like READ_EXECUTE, WRITE_EXECUTE.',
+                clientIP                :'Search by IP address from where resource was accessed.',
+                resourceName            :'Resource name.',
+                resourceTypeMsg         :'Search by resource type based on component. eg. path in HDFS, database    ,table in Hive.',
+                resultMsg               :'Search by access result i.e Allowed/Denied logs.',
+                statusMsg               :'Status of Policy Enable/Disable.',
+                columnfamily            :'Hbase column-family',
+                searchForPluginStatus   : "Search for Plugin Status....",
+                pleaseSelectUser        : 'Please select user.',
+                pleaseSelectGroup       : 'Please select group.',
+                addSelectedUserGroup	: 'Please add selected user/group to permissions else user/group will not be added.',
+                maskingPolicyInfoMsg   	: 'Please ensure that users/groups listed in this policy have access to the column via an <b>Access Policy</b>. This policy does not implicitly grant access to the column.',
+                rowFilterPolicyInfoMsg 	: 'Please ensure that users/groups listed in this policy have access to the table via an <b>Access Policy</b>. This policy does not implicitly grant access to the table.',
+                udfPolicyViolation      : '<b> Warning !!</b>  : UDF create is a privileged operation. Please make sure you grant them to only trusted users.',
+                noServiceToExport       :'No service found to export policies.',
+                noServiceToImport       :'No service found to import policies.',
+                noPolicytoExport        :'No policies found to export!',
+                importingFiles          :'Importing policies from file is started...',
+                noDeleteUserRow           :'Please select user first to delete.',
+                noDeleteGroupRow        :'Please select Group first to delete.',
+                plsSelectUserToSetVisibility :' Please select user to set visibility or selected user is already visible/hidden.',
+                plsSelectGroupToSetVisibility:' Please select group to set visibility or selected group is already visible/hidden.',
+                activationTimeDelayMsg       :'Policy activation time delayed by more than 1hr from last update time.',
+ 
 			},
 			plcHldr : {
 				search 						:'Search',
@@ -361,27 +410,31 @@ define(function(require) {
 				
 			},	
 			validationMessages : {
-				required 					: "* This field is required",
+				required 			   : "* This field is required",
 				onlyLetterNumberUnderscore :'* Only Alpha Numeric and underscore characters are allowed',
 				alphaNumericUnderscoreDotComma :'* Only Alpha Numeric,underscore,comma,hypen,dot and space characters are allowed',
-				oldPasswordError :'Your password does not match. Please try again with proper password',
+				oldPasswordError       :'Your password does not match. Please try again with proper password',
 				oldPasswordRepeatError :'You can not use old password.',
-				newPasswordError :'Invalid Password.Minimum 8 characters with min one alphabet and one numeric.',
-				emailIdError				: 'Please enter valid email address.',
-				enterValidName				: 'Please enter valid name.',
-				passwordError	            :'Invalid Password.Minimum 8 characters with min one alphabet and one numeric.'
+				newPasswordError       :'Invalid Password. Minimum 8 characters with min one alphabet and one numeric.',
+				emailIdError           : 'Please enter valid email address.',
+				enterValidName         : 'Please enter valid name.',
+				passwordError          :'Password should be minimum 8 characters with min one alphabet and one numeric.',
+				userNameValidationMsg  :'1. User name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ,._\-+/@= and space. <br>3. Name length should be greater than one.',
+				groupNameValidationMsg :'1. Group name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ,._\-+/@= and space. <br>3. Name length should be greater than one.',
+                firstNameValidationMsg :'1. First name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ._-@ and space. <br>3. Name length should be greater than one.',
+                lastNameValidationMsg  :'1. Last name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ._-@ and space. <br>3. Name length should be greater than one.',
 			},
 			serverMsg : {
 				
 				// UserMgr
-				userMgrPassword : 'The password you\'ve provided is incorrect. Please try again with correct password',
-				userMgrInvalidUser : 'Invalid user provided',
-				userMgrNewPassword : 'Invalid new password',
-				userMgrOldPassword : ' You can not use old password.',
-				userMgrEmailChange : 'Email address cannot be changed. Please send a request to change using feedback',
-				userMgrInvalidEmail : 'Invalid email address',
-				userMgrWrongPassword : 'Password doesnot match. Please try again with proper password',
-				userMgrWrongUser : 'User access denied. User not found.',
+				userMgrPassword        : 'The password you\'ve provided is incorrect. Please try again with correct password',
+				userMgrInvalidUser     : 'Invalid user provided',
+				userMgrNewPassword     : 'Invalid new password',
+				userMgrOldPassword     : ' You can not use old password.',
+				userMgrEmailChange     : 'Email address cannot be changed. Please send a request to change using feedback',
+				userMgrInvalidEmail    : 'Invalid email address',
+				userMgrWrongPassword   : 'Password doesnot match. Please try again with proper password',
+				userMgrWrongUser       : 'User access denied. User not found.',
 				fsDefaultNameValidationError:"Please provide  fs.default.name in  format 'hdfs://hostname:portNumber' .",
 				fsDefaultNameEmptyError:'Please provide  fs.default.name.',
 				userAlreadyExistsError : 'User already exists',
