@@ -173,6 +173,21 @@ define(function(require) {
 		});
 		return nvPairs;
 	};
+   //	Search Info it give popover box
+   XAUtils.searchInfoPopover = function(myArray, $infoEle, placement){
+            var msg = "<span> Wildcard searches ( for example using * or ? ) are not currently supported.</span>";
+		myArray.map(function(m){
+                   msg += '<div><span><b>'+m.text+' : </b></span><span>'+m.info+'</span></div>'
+                });
+        $infoEle.popover({
+           content: msg,
+           html: true,
+           trigger: 'hover',
+           placement: placement,
+           container: 'body'
+        });
+   };
+
 
 	/**
 	 * Notify Info the given title / text
@@ -214,7 +229,7 @@ define(function(require) {
 	XAUtils.notifyError = function(type, text, options) {
 		var html = '<div style="width: 245px;"><div style="min-height: 16px;"><div><span class="icon-warning-sign"></span>\
 			</div><h4 style="margin-top: -19px;margin-left: 15px;">Error</h4><div>'
-				+ text + '</div></div></div>';
+                                + _.escape(text) + '</div></div></div>';
 		if (_.isUndefined(options)) {
 			options = {
 				message : {
@@ -362,6 +377,20 @@ define(function(require) {
 		}
 	};
 
+	/*
+	 * icon Info
+	 */
+	XAUtils.errorsInfoPopover = function(filed, msg) {
+		filed.popover({
+			content : '<span class="popoverTextMsg" >'+msg+'</span>',
+			html    : true,
+			trigger : 'hover',
+			placement : 'right',
+			container : 'body'
+
+		 })
+	};
+	
 	/**
 	 * Bootbox wrapper for alert
 	 * 
@@ -375,7 +404,13 @@ define(function(require) {
 			bootbox.alert(params.msg, params.callback);
 		}
 	};
-
+     
+	//Alert box with time set 
+	XAUtils.alertBoxWithTimeSet = function(msg) {
+		var alert = bootbox.alert(msg);
+    	return(setTimeout(function(){alert.modal('hide'); }, 4000));
+	}
+	
 	/**
 	 * Bootbox wrapper for confirm
 	 * 
@@ -383,6 +418,7 @@ define(function(require) {
 	 *            params - The params
 	 */
 	XAUtils.confirmPopup = function(params) {
+		bootbox.hideAll();
 		bootbox.confirm(params.msg, function(result) {
 			if (result) {
 				params.callback();
@@ -535,7 +571,7 @@ define(function(require) {
                                         if(i == objArr.length - 1){
                                                 eleStr += '</div>';
                                         }
-                                        lastShowMoreCnt = ( listShownCnt*j ) + 4;
+                                        lastShowMoreCnt = ( listShownCnt*j) + 4;
                                         j++;
                                 }else if(i === lastShowMoreCnt - 1 || i == objArr.length - 1){
                                         eleStr = span + '</div>';
@@ -547,10 +583,10 @@ define(function(require) {
 			} else if (i == 3 && objArr.length > 4) {
 				showMoreLess = true;
 				return '<span class="label label-info float-left-margin-2" policy-' + userOrGroups
-						+ '-id="' + model.id + '">' + name + '</span>';
+                                                + '-id="' + model.id + '">' +  _.escape(name) + '</span>';
 			} else {
 				return '<span class="label label-info float-left-margin-2" policy-' + userOrGroups
-						+ '-id="' + model.id + '">' + name + '</span>';
+                                                + '-id="' + model.id + '">' +  _.escape(name) + '</span>';
 			}
 		});
 		if (showMoreLess) {
@@ -741,7 +777,10 @@ define(function(require) {
 				reset : true,
 				cache : false,
 				error : function(coll, response, options) {
-					that.notifyError('Error', localization.tt('msg.errorLoadingAuditLogs'));
+                                        if(response && response.responseJSON && response.responseJSON.msgDesc){
+                                                that.notifyError('Error', response.responseJSON.msgDesc);  				                                                     }else{
+                                                that.notifyError('Error', localization.tt('msg.errorLoadingAuditLogs'));
+					}
 				}
 			// data : params,
 			});
@@ -757,6 +796,11 @@ define(function(require) {
 				search(searchCollection, serverAttrName, searchOpt, collection);
 			},
 			clearSearch : function(callback) {
+                                //Remove search history when click on clear search
+                                if(!_.isUndefined(pluginAttr.type)){
+                                        var App = require('App');
+                                        App.vsHistory[pluginAttr.type] = [];
+                                }
 				_.each(serverAttrName, function(attr) {
 					delete collection.queryParams[attr.label];
 				});
@@ -786,10 +830,6 @@ define(function(require) {
 				if (!_.isUndefined(removedFacetSeverName)) {
 					delete collection.queryParams[removedFacetSeverName.label];
 					collection.state.currentPage = collection.state.firstPage;
-					collection.fetch({
-						reset : true,
-						cache : false
-					});
 				}
 				// TODO Added for Demo to remove datapicker popups
 				if (!_.isUndefined(visualSearch.searchBox.$el))
@@ -812,12 +852,15 @@ define(function(require) {
 	};
 
 	XAUtils.displayDatepicker = function($el, facet, $date, callback) {
-		var input = $el
-				.find('.search_facet.is_editing input.search_facet_input');
+                var input = $el.find('.search_facet.is_editing input.search_facet_input');
+                //disabling user enter value in date
+                input.keypress(function(event) {
+                        event.preventDefault();
+                });
 		$el.parents('body').find('.datepicker').hide();
 		input.datepicker({
 			autoclose : true,
-			dateFormat : 'yy-mm-dd'
+                        dateFormat : 'yy-mm-dd',
 		}).on('changeDate', function(ev) {
 			callback(ev.date);
 			input.datepicker("hide");
@@ -1236,5 +1279,55 @@ define(function(require) {
 		}
 		return enableDenyAndExceptionsInPolicies;
 	};
+	XAUtils.isEmptyObjectResourceVal = function (obj) {
+		return !_.isUndefined(obj['resources']) && !_.isEmpty(obj['resources'])
+		 		&& !_.isNull(obj['resources']) ? false : true;
+	};
+    XAUtils.removeEmptySearchValue = function(arr) {
+            return  _.reject(arr,function(m){
+                    return (m.get('value')=="");
+            });
+    };
+        XAUtils.showAuditLogTags = function(rawValue, model) {
+                var showMoreLess = false, id = model.id, tagLabels = '';
+                var tagNames = _.pluck(rawValue, 'type');
+                if (!_.isUndefined(rawValue)) {
+                        var tagArr = _.map(rawValue, function(tag, i) {
+                                if(tag.attributes && !_.isEmpty(tag.attributes)){
+                                        tagLabels = '<a href="javascript:void(0)" data-name="tags" data-id="'+model.id+''+i+'" class="tagsColumn">'+tag.type+'</a>';
+                                }else{
+                                        tagLabels = tag.type;
+                                }
+                                tagLabels += (i+1 < rawValue.length) ? '&nbsp;,&nbsp;' : '';
+                                if (i >= 4){
+                                        return '<span class="float-left-margin-1" audit-log-id="'
+                                        + id + '" style="display:none;">' + tagLabels
+                                        + '</span>';
+                                }
+                                else{
+                                        if (i == 3 && rawValue.length > 4) {
+                                                showMoreLess = true;
+                                                return '<span class="float-left-margin-1" audit-log-id="'
+                                                                + id + '">' + tagLabels + '</span>';
+                                        } else{
+                                                return '<span class="float-left-margin-1" audit-log-id="'
+                                                + id + '">' + tagLabels + '</span>';
+                                        }
+                                }
+                        });
+                        if (showMoreLess) {
+                                tagArr.push('<span class="float-left-margin-1"><a href="javascript:void(0);" data-id="showMore" class="" audit-log-id="'
+                                                                + id
+                                                                + '"><code style=""> + More..</code></a></span><span class="float-left-margin-1"><a href="javascript:void(0);" data-id="showLess" class="" audit-log-id="'
+                                                                + id
+                                                                + '" style="display:none;"><code> - Less..</code></a></span>');
+                        }
+                        tagArr.unshift('<div data-id="tagDiv" class="popovertag">');
+                        tagArr.push('</div>');
+                        return tagArr.length ? tagArr.join(' ') : '--';
+                } else{
+                        return '--';
+                }
+        };
 	return XAUtils;
-});
+});
\ No newline at end of file
