@@ -77,7 +77,7 @@ define(function(require) {
 		},
 
 		initialize : function(options) {
-			_.extend(this, _.pick(options, 'groupList','accessTypes','policyConditions','userList','rangerServiceDefModel','rangerPolicyType'));
+                        _.extend(this, _.pick(options,'accessTypes','policyConditions','rangerServiceDefModel','rangerPolicyType'));
 			this.setupPermissionsAndConditions();
 			
 		},
@@ -86,8 +86,8 @@ define(function(require) {
 			//To setup permissions for edit mode 
 			this.setupFormForEditMode();
 			//create select2 dropdown for groups and users  
-			this.createDropDown(this.ui.selectGroups, this.groupList, true);
-			this.createDropDown(this.ui.selectUsers, this.userList, false);
+                        this.createDropDown(this.ui.selectGroups, true);
+                        this.createDropDown(this.ui.selectUsers, false);
 			//groups or users select2 dropdown change vent 
 			
 			this.dropDownChange(this.ui.selectGroups);
@@ -182,43 +182,24 @@ define(function(require) {
 				}
 			});
 		},
-		createDropDown :function($select, list, typeGroup){
-			var that = this,
+                createDropDown :function($select, typeGroup){
+                        var that = this, tags = [],
 			placeholder = (typeGroup) ? 'Select Group' : 'Select User',
-			searchUrl   = (typeGroup) ? "service/xusers/groups" : "service/xusers/users",
-			getUrl 		= (typeGroup) ? "service/xusers/groups/groupName/" : "service/xusers/users/userName/";
+                        searchUrl   = (typeGroup) ? "service/xusers/groups" : "service/xusers/users";
 			if(this.model.has('editMode') && !_.isEmpty($select.val())){
-				var temp = $select.val().split(",");
+                                var temp = this.model.attributes[ (typeGroup) ? 'groupName': 'userName'];
 				_.each(temp , function(name){
-					if(_.isEmpty(list.where({ 'name' : name}))){
-						var model = typeGroup ? new VXGroup() : new VXUser();
-						model.urlRoot = getUrl + name;
-						model.fetch({async:false}).done(function(){
-							list.add(model);
-						});
-					}
+                                        tags.push( { 'id' : _.escape( name ), 'text' : _.escape( name ) } );
 				});
 			}
-			var tags = list.map(function(m){
-//				return { id : m.id+"" , text : _.escape(m.get('name'))};
-				return { id : m.id+"" , text : m.get('name')};
-			});
-			
 			$select.select2({
 				closeOnSelect : true,
 				placeholder : placeholder,
-			//	maximumSelectionSize : 1,
 				width :'220px',
 				tokenSeparators: [",", " "],
-				tags : tags, 
+                                tags : true,
 				initSelection : function (element, callback) {
-					var data = [], names = (typeGroup) ? that.model.get('groupName') : that.model.get('userName');
-					_.each(names, function (name) {
-//						name = _.escape(name);
-						var obj = _.findWhere(tags, {text: name });
-						data.push({ id : obj.id, text : name })
-					});
-					callback(data);
+                                        callback(tags);
 				},
 				ajax: { 
 					url: searchUrl,
@@ -232,9 +213,9 @@ define(function(require) {
 						selectedVals = that.getSelectedValues($select, typeGroup);
 						if(data.resultSize != "0"){
 							if(typeGroup){
-								results = data.vXGroups.map(function(m, i){	return {id : m.id+"", text: _.escape(m.name) };	});
+                                                                results = data.vXGroups.map(function(m, i){	return {id : _.escape(m.name), text: _.escape(m.name) };	});
 							} else {
-								results = data.vXUsers.map(function(m, i){	return {id : m.id+"", text: _.escape(m.name) };	});
+                                                                results = data.vXUsers.map(function(m, i){	return {id : _.escape(m.name), text: _.escape(m.name) };	});
 							}
 							if(!_.isEmpty(selectedVals)){
 								results = XAUtil.filterResultByText(results, selectedVals);
@@ -269,7 +250,7 @@ define(function(require) {
 				source: this.perms,
 				value : this.permsIds,
 				display: function(values,srcData) {
-					if(_.isNull(values) || _.isEmpty(values)){
+					if(_.isNull(values) || _.isEmpty(values) || (_.contains(values,"-1")  &&  values.length == 1)){
 						$(this).empty();
 						that.model.unset('accesses');
 						that.ui.addPermissionsSpan.find('i').attr('class', 'icon-plus');
@@ -278,6 +259,7 @@ define(function(require) {
 					}
 					if(_.contains(values,"-1")){
 						values = _.without(values,"-1")
+
 					}
 //			    	that.checkDirtyFieldForGroup(values);
 					
@@ -475,7 +457,6 @@ define(function(require) {
                                                                 return '<span class="'+label+' white-space-normal" >'+name+' : '+ _.escape(val) + '</span>';
 							});
 							var cond = _.map(value, function(val, name) {
-                                                                val = _.escape(val);
                                                                 return {'type' : name, 'values' : !_.isArray(val) ?  val.split(',') : val};
 							});
 							
@@ -598,7 +579,7 @@ define(function(require) {
 			this.maskTypes =  _.map(maskingTypes, function(m){return {text:m.label, value : m.name };});
 			//create x-editable for permissions
 			this.ui.maskingType.editable({
-			    emptytext : 'Select Masking Type',
+			    emptytext : localization.tt('lbl.selectMaskingOption'),
 				source: this.maskTypes,
 				value : this.maskTypeIds,
 				display: function(value,srcData) {
@@ -627,18 +608,16 @@ define(function(require) {
 			}).on('click', function(e) {
 				e.stopPropagation();
 				e.preventDefault();
-//				that.clickOnMaskingType(that);
 			});
 			that.ui.addMaskingTypeSpan.click(function(e) {
 				e.stopPropagation();
 				that.$('a[data-js="maskingType"]').editable('toggle');
-//				that.clickOnMaskingType(that);
 			});
 			this.$el.find('input[data-id="maskTypeCustom"]').on('change', function(e){
 				if(!_.isUndefined(that.model.get('dataMaskInfo'))){
 					that.model.get('dataMaskInfo').valueExpr = e.currentTarget.value;
 				}
-			});
+			}).trigger('change');
 		},
 		renderRowLevelFilter :function(){
 			var that = this;
@@ -696,8 +675,6 @@ define(function(require) {
 			this.setAccessTypeByPolicyType();
 			return {
 				'collection' 	: this.collection,
-				'groupList' 	: this.groupList,
-				'userList' 	: this.userList,
 				'accessTypes'	: this.accessTypes,
 				'policyConditions' : this.rangerServiceDefModel.get('policyConditions'),
 				'rangerServiceDefModel' : this.rangerServiceDefModel,
@@ -708,8 +685,7 @@ define(function(require) {
 			'click [data-action="addGroup"]' : 'addNew'
 		},
 		initialize : function(options) {
-			_.extend(this, _.pick(options, 'groupList','accessTypes','rangerServiceDefModel','userList', 'headerTitle','rangerPolicyType'));
-			this.listenTo(this.groupList, 'sync', this.render, this);
+                        _.extend(this, _.pick(options, 'accessTypes','rangerServiceDefModel', 'headerTitle','rangerPolicyType'));
 			if(this.collection.length == 0)
 				this.collection.add(new Backbone.Model());
 		},
@@ -731,7 +707,7 @@ define(function(require) {
 					permList.unshift(localization.tt('lbl.rowLevelFilter'));
 					permList.unshift(localization.tt('lbl.accessTypes'));
 				}else if(XAUtil.isMaskingPolicy(this.rangerPolicyType)){
-					permList.unshift(localization.tt('lbl.selectDataMaskTypes'));
+					permList.unshift(localization.tt('lbl.selectMaskingOption'));
 					permList.unshift(localization.tt('lbl.accessTypes'));
 				}else{
 					permList.unshift(localization.tt('lbl.permissions'));
