@@ -43,8 +43,16 @@ define(function(require){
 		
     	template : RangerPolicycreateTmpl,
     	templateHelpers : function(){
+		var infoMsg = '', displayClass = 'hide';
+		if(XAUtil.isMaskingPolicy(this.model.get('policyType'))){
+			infoMsg = localization.tt('msg.maskingPolicyInfoMsg'), displayClass = 'show';
+		}else if(XAUtil.isRowFilterPolicy(this.model.get('policyType'))){
+			infoMsg = localization.tt('msg.rowFilterPolicyInfoMsg'), displayClass = 'show';
+		}
     		return {
-    			editPolicy : this.editPolicy
+			editPolicy : this.editPolicy,
+			infoMsg : infoMsg,
+			displayClass : displayClass
     		};
     	},
     	breadCrumbs :function(){
@@ -108,27 +116,6 @@ define(function(require){
 				cache : false,
 				async : false
 			});
-//			if(this.rangerServiceDefModel.get('name') == "hive"){
-//				this.rangerServiceDefModel.set("dataMaskDef",{ "accessTypes": [ { "name": "select" } ], 
-//					"resources": [ 
-//					               { "lookupSupported" :true, "name": "database", "matcherOptions": { "wildCard": "false" }, "uiHint":"{ \"singleValue\":true }" }, 
-//					               { "name": "table", "matcherOptions": { "wildCard": "false" }, "uiHint":"{ \"singleValue\":true }" }, 
-//					               { "name": "column", "matcherOptions": { "wildCard": "false" }, "uiHint":"{ \"singleValue\":true }" }
-//					               ],
-//					 "maskTypes": [ { "itemId": 1, "name": "MASK", "label": "Mask", "description": "Replace lowercase with 'x', uppercase with 'X', digits with '0'", "dataMaskOptions": { } }, { "itemId": 2, "name": "SHUFFLE", "label": "Shuffle", "description": "Shuffle the value of the column", "dataMaskOptions": { } }, { "itemId": 3, "name": "MASK_x_SHOW_LAST_4", "label": "Partial mask: show last 4", "description": "Show last 4 characters; replace rest with 'x'", "dataMaskOptions": { } }, { "itemId": 4, "name": "MASK_x_SHOW_FIRST_4", "label": "Partial mask: show first 4", "description": "Show first 4 characters; replace rest with 'x'", "dataMaskOptions": { } }, { "itemId": 10, "name": "NULL", "label": "NULL", "description": "Replace with NULL", "dataMaskOptions": { } } ] });
-//				
-//				this.rangerServiceDefModel.set("rowFilterDef", 
-//						{ 
-//							"accessTypes":[
-//							               {"name":"select","label":"Select"}
-//							               ],
-//							"resources":[
-//							             {"name":"database","matcherOptions":{"wildCard":false}},
-//							             {"name":"table","matcherOptions":{"wildCard":false}}
-//							             ]
-//					    });
-//			}
-			
 		},
 
 		/** all events binding here */
