@@ -276,16 +276,6 @@
             	return options.fn(this);
 			return options.inverse(this);
 	});
-	Handlebars.registerHelper('isSchoolAdmin', function(context, options) {
-            if(SessionMgr.isSchoolAdmin() || SessionMgr.isSystemAdmin())
-            	return options.fn(this);
-			return options.inverse(this);
-	});
-	Handlebars.registerHelper('isTeacher', function(context, options) {
-            if(SessionMgr.isTeacher())
-            	return options.fn(this);
-			return options.inverse(this);
-	});
 	Handlebars.registerHelper('getAvatar', function(options,size) {
 		var path;
 			if(_.has(options,'profileImageGId')){
@@ -363,7 +353,7 @@
 	    return new Handlebars.SafeString(ret);
 	});
 	Handlebars.registerHelper('highlightNewForAttr', function(newValue, oldValue, hightlightValue) {
-		var html='';
+                var html='', newValue = _.escape( newValue ), oldValue = _.escape( oldValue );
 		if(hightlightValue == 'new'){
 			if(_.isNull(oldValue) || oldValue == '--' || oldValue == "" || _.isUndefined(oldValue)){
 				html = '<span class="add-text">'+newValue+'</span>';
@@ -380,7 +370,7 @@
 	    return html;
 	});
 	Handlebars.registerHelper('highlightNewForObj', function(prop, newValue, oldValue, hightlightValue) {
-		var html='';
+                var html='', newValue = _.escape( newValue ), oldValue = _.escape( oldValue );
 		if(hightlightValue == 'new'){
 			if(_.isNull(oldValue[prop]) || oldValue[prop] == ""){
 				html = '<span class="add-text">'+newValue+'</span>';
