@@ -133,14 +133,14 @@ public class TestUserMgr {
 	}
 
 	public void setupUser() {
-        RangerSecurityContext context = new RangerSecurityContext();
-        context.setUserSession(new UserSessionBase());
-        RangerContextHolder.setSecurityContext(context);
-        UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
-        XXPortalUser user = new XXPortalUser();
-        user.setId(userProfile().getId());
-        user.setLoginId(userProfile().getLoginId());
-        currentUserSession.setXXPortalUser(user);
+		RangerSecurityContext context = new RangerSecurityContext();
+		context.setUserSession(new UserSessionBase());
+		RangerContextHolder.setSecurityContext(context);
+		UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
+		XXPortalUser user = new XXPortalUser();
+		user.setId(userProfile().getId());
+		user.setLoginId(userProfile().getLoginId());
+		currentUserSession.setXXPortalUser(user);
 	}
 
 	private VXPortalUser userProfile() {
@@ -303,64 +303,66 @@ public class TestUserMgr {
 				new String[] { Mockito.anyString() });
 	}
 
+	@Test
 	public void test14ChangePasswordAsKeyAdmin() {
-        setupKeyAdmin();
-        XXPortalUserDao userDao = Mockito.mock(XXPortalUserDao.class);
-        VXPortalUser userProfile = userProfile();
+		setupKeyAdmin();
+		XXPortalUserDao userDao = Mockito.mock(XXPortalUserDao.class);
+		VXPortalUser userProfile = userProfile();
 
-        VXPasswordChange pwdChange = new VXPasswordChange();
-        pwdChange.setId(userProfile.getId());
-        pwdChange.setLoginId(userProfile.getLoginId());
-        pwdChange.setOldPassword(userProfile.getPassword());
-        pwdChange.setEmailAddress(userProfile.getEmailAddress());
-        pwdChange.setUpdPassword(userProfile.getPassword());
+		VXPasswordChange pwdChange = new VXPasswordChange();
+		pwdChange.setId(userProfile.getId());
+		pwdChange.setLoginId(userProfile.getLoginId());
+		pwdChange.setOldPassword(userProfile.getPassword());
+		pwdChange.setEmailAddress(userProfile.getEmailAddress());
+		pwdChange.setUpdPassword(userProfile.getPassword());
 
-        XXPortalUser userKeyAdmin = new XXPortalUser();
-        userKeyAdmin.setId(userProfile.getId());
-        userKeyAdmin.setLoginId(userProfile.getLoginId());
-        Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
-        Mockito.when(userDao.findByLoginId(Mockito.anyString())).thenReturn(userKeyAdmin);
-        Mockito.when(stringUtil.equals(Mockito.anyString(), Mockito.anyString())).thenReturn(true);
-        Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
-        Mockito.when(userDao.getById(Mockito.anyLong())).thenReturn(userKeyAdmin);
-        Mockito.when(stringUtil.validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() })).thenReturn(true);
+		XXPortalUser userKeyAdmin = new XXPortalUser();
+		userKeyAdmin.setId(userProfile.getId());
+		userKeyAdmin.setLoginId(userProfile.getLoginId());
+		Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
+		Mockito.when(userDao.findByLoginId(Mockito.anyString())).thenReturn(userKeyAdmin);
+		Mockito.when(stringUtil.equals(Mockito.anyString(), Mockito.anyString())).thenReturn(true);
+		Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
+		Mockito.when(userDao.getById(Mockito.anyLong())).thenReturn(userKeyAdmin);
+		Mockito.when(stringUtil.validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() })).thenReturn(true);
 
-        VXResponse dbVXResponse = userMgr.changePassword(pwdChange);
-        Assert.assertNotNull(dbVXResponse);
-        Assert.assertEquals(userProfile.getStatus(),dbVXResponse.getStatusCode());
+		VXResponse dbVXResponse = userMgr.changePassword(pwdChange);
+		Assert.assertNotNull(dbVXResponse);
+		Assert.assertEquals(userProfile.getStatus(),dbVXResponse.getStatusCode());
 
-        Mockito.verify(stringUtil).equals(Mockito.anyString(),Mockito.anyString());
-        Mockito.verify(stringUtil).validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() });
+		Mockito.verify(stringUtil).equals(Mockito.anyString(),Mockito.anyString());
+		Mockito.verify(stringUtil).validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() });
 	}
 
+	@Test
 	public void test15ChangePasswordAsUser() {
-        setupUser();
-        XXPortalUserDao userDao = Mockito.mock(XXPortalUserDao.class);
-        VXPortalUser userProfile = userProfile();
+		setupUser();
+		XXPortalUserDao userDao = Mockito.mock(XXPortalUserDao.class);
+		VXPortalUser userProfile = userProfile();
 
-        VXPasswordChange pwdChange = new VXPasswordChange();
-        pwdChange.setId(userProfile.getId());
-        pwdChange.setLoginId(userProfile.getLoginId());
-        pwdChange.setOldPassword(userProfile.getPassword());
-        pwdChange.setEmailAddress(userProfile.getEmailAddress());
-        pwdChange.setUpdPassword(userProfile.getPassword());
+		VXPasswordChange pwdChange = new VXPasswordChange();
+		pwdChange.setId(userProfile.getId());
+		pwdChange.setLoginId(userProfile.getLoginId());
+		pwdChange.setOldPassword(userProfile.getPassword());
+		pwdChange.setEmailAddress(userProfile.getEmailAddress());
+		pwdChange.setUpdPassword(userProfile.getPassword());
 
-        XXPortalUser user = new XXPortalUser();
-        user.setId(userProfile.getId());
-        user.setLoginId(userProfile.getLoginId());
-        Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
-        Mockito.when(userDao.findByLoginId(Mockito.anyString())).thenReturn(user);
-        Mockito.when(stringUtil.equals(Mockito.anyString(), Mockito.anyString())).thenReturn(true);
-        Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
-        Mockito.when(userDao.getById(Mockito.anyLong())).thenReturn(user);
-        Mockito.when(stringUtil.validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() })).thenReturn(true);
+		XXPortalUser user = new XXPortalUser();
+		user.setId(userProfile.getId());
+		user.setLoginId(userProfile.getLoginId());
+		Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
+		Mockito.when(userDao.findByLoginId(Mockito.anyString())).thenReturn(user);
+		Mockito.when(stringUtil.equals(Mockito.anyString(), Mockito.anyString())).thenReturn(true);
+		Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
+		Mockito.when(userDao.getById(Mockito.anyLong())).thenReturn(user);
+		Mockito.when(stringUtil.validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() })).thenReturn(true);
 
-        VXResponse dbVXResponse = userMgr.changePassword(pwdChange);
-        Assert.assertNotNull(dbVXResponse);
-        Assert.assertEquals(userProfile.getStatus(),dbVXResponse.getStatusCode());
+		VXResponse dbVXResponse = userMgr.changePassword(pwdChange);
+		Assert.assertNotNull(dbVXResponse);
+		Assert.assertEquals(userProfile.getStatus(),dbVXResponse.getStatusCode());
 
-        Mockito.verify(stringUtil).equals(Mockito.anyString(),Mockito.anyString());
-        Mockito.verify(stringUtil).validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() });
+		Mockito.verify(stringUtil).equals(Mockito.anyString(),Mockito.anyString());
+		Mockito.verify(stringUtil).validatePassword(Mockito.anyString(),new String[] { Mockito.anyString() });
 	}
 
 	@Test
@@ -1299,7 +1301,7 @@ public class TestUserMgr {
 		Mockito.when(daoManager.getXXPortalUser()).thenReturn(userDao);
 		Mockito.when(userDao.update(user)).thenReturn(user);
 		XXPortalUser dbXXPortalUser = userMgr.updatePasswordInSHA256(userName,
-				userPassword);
+                                userPassword,false);
 		Assert.assertNotNull(dbXXPortalUser);
 	 }
 
