@@ -25,11 +25,11 @@ import java.util.Map;
 import java.util.Set;
 
 import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 import javax.ws.rs.WebApplicationException;
 
 import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.admin.client.datatype.RESTResponse;
+import org.apache.ranger.biz.AssetMgr;
 import org.apache.ranger.biz.RangerBizUtil;
 import org.apache.ranger.biz.ServiceDBStore;
 import org.apache.ranger.biz.ServiceMgr;
@@ -175,7 +175,10 @@ public class TestServiceREST {
 
 	@Mock
 	StringUtils stringUtils;
-	
+
+	@Mock
+	AssetMgr assetMgr;
+
 	@Rule
 	public ExpectedException thrown = ExpectedException.none();
 
@@ -962,9 +965,12 @@ public class TestServiceREST {
 		String serviceName = "HDFS_1";
 		Long lastKnownVersion = 1L;
 		String pluginId = "1";
+
+		Mockito.doNothing().when(assetMgr).createPluginInfo(serviceName, pluginId, null, 1, 1L, lastKnownVersion, 1, 0);
+
 		ServicePolicies dbServicePolicies = serviceREST
-				.getServicePoliciesIfUpdated(serviceName, lastKnownVersion,
-						pluginId, request);
+				.getServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L,
+						pluginId, "", request);
 		Assert.assertNull(dbServicePolicies);
 	}
 
@@ -999,7 +1005,7 @@ public class TestServiceREST {
 	public void test30getPolicyFromEventTime() throws Exception {
 		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
 
-		String strdt = new Date().toString(); 
+		String strdt = new Date().toString();
 		String userName="Admin";
 		Set<String> userGroupsList = new HashSet<String>();
 		userGroupsList.add("group1");
