@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -51,11 +51,11 @@ import com.sun.jersey.api.client.WebResource;
 
 public class StormClient {
 	
-	public static final Logger LOG = Logger.getLogger(StormClient.class) ;
+	private static final Logger LOG = Logger.getLogger(StormClient.class);
 
 	private static final String EXPECTED_MIME_TYPE = "application/json";
 	
-	private static final String TOPOLOGY_LIST_API_ENDPOINT = "/api/v1/topology/summary" ;
+	private static final String TOPOLOGY_LIST_API_ENDPOINT = "/api/v1/topology/summary";
 	
 	private static final String errMessage =  " You can still save the repository and start creating "
 											  + "policies, but you would not be able to use autocomplete for "
@@ -71,7 +71,7 @@ public class StormClient {
 	public StormClient(String aStormUIUrl, String aUserName, String aPassword, String lookupPrincipal, String lookupKeytab, String nameRules) {
 		
 		this.stormUIUrl = aStormUIUrl;
-		this.userName = aUserName ;
+		this.userName = aUserName;
 		this.password = aPassword;
 		this.lookupPrincipal = lookupPrincipal;
 		this.lookupKeytab = lookupKeytab;
@@ -84,108 +84,143 @@ public class StormClient {
 	}
 
 	public List<String> getTopologyList(final String topologyNameMatching, final List<String> stormTopologyList) {
-		
-		LOG.debug("Getting Storm topology list for topologyNameMatching : " +
-				topologyNameMatching);
+
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("Getting Storm topology list for topologyNameMatching : " + topologyNameMatching);
+		}
 		final String errMsg = errMessage;
-		
-		List<String> ret = new ArrayList<String>();
-		
+
 		PrivilegedAction<ArrayList<String>> topologyListGetter = new PrivilegedAction<ArrayList<String>>() {
 			@Override
 			public ArrayList<String> run() {
-				
+				if (stormUIUrl == null || stormUIUrl.trim().isEmpty()) {
+					return null;
+				}
+
+				String[] stormUIUrls = stormUIUrl.trim().split("[,;]");
+				if (stormUIUrls == null || stormUIUrls.length == 0) {
+					return null;
+				}
+
+				Client client = Client.create();
+				ClientResponse response = null;
+				for (String currentUrl : stormUIUrls) {
+					if (currentUrl == null || currentUrl.trim().isEmpty()) {
+						continue;
+					}
+
+					String url = currentUrl.trim() + TOPOLOGY_LIST_API_ENDPOINT;
+					try {
+						response = getTopologyResponse(url, client);
+
+						if (response != null) {
+							if (response.getStatus() == 200) {
+								break;
+							} else {
+								response.close();
+							}
+						}
+					} catch (Throwable t) {
+						String msgDesc = "Exception while getting topology list." + " URL : " + url;
+						LOG.error(msgDesc, t);
+					}
+				}
+
 				ArrayList<String> lret = new ArrayList<String>();
-				
-				String url = stormUIUrl + TOPOLOGY_LIST_API_ENDPOINT ;
-				
-				Client client = null ;
-				ClientResponse response = null ;
-				
 				try {
-					client = Client.create() ;
-					
-					WebResource webResource = client.resource(url);
-					
-					response = webResource.accept(EXPECTED_MIME_TYPE)
-						    .get(ClientResponse.class);
-					
-					LOG.debug("getTopologyList():calling " + url);
-					
 					if (response != null) {
-						LOG.debug("getTopologyList():response.getStatus()= " + response.getStatus());	
+						if (LOG.isDebugEnabled()) {
+							LOG.debug("getTopologyList():response.getStatus()= " + response.getStatus());
+						}
 						if (response.getStatus() == 200) {
 							String jsonString = response.getEntity(String.class);
 							Gson gson = new GsonBuilder().setPrettyPrinting().create();
 							TopologyListResponse topologyListResponse = gson.fromJson(jsonString, TopologyListResponse.class);
 							if (topologyListResponse != null) {
 								if (topologyListResponse.getTopologyList() != null) {
-									for(Topology topology : topologyListResponse.getTopologyList()) {
-										String topologyName = topology.getName() ;
-										if ( stormTopologyList != null && stormTopologyList.contains(topologyName)) {
-								        	continue;
-								        }
-										LOG.debug("getTopologyList():Found topology " + topologyName);
-										LOG.debug("getTopologyList():topology Name=[" + topology.getName() + "], topologyNameMatching=[" + topologyNameMatching + "], existingStormTopologyList=[" + stormTopologyList + "]");
+									for (Topology topology : topologyListResponse.getTopologyList()) {
+										String topologyName = topology.getName();
+										if (stormTopologyList != null && stormTopologyList.contains(topologyName)) {
+											continue;
+										}
+										if (LOG.isDebugEnabled()) {
+											LOG.debug("getTopologyList():Found topology " + topologyName);
+											LOG.debug("getTopologyList():topology Name=[" + topology.getName()
+													+ "], topologyNameMatching=[" + topologyNameMatching
+													+ "], existingStormTopologyList=[" + stormTopologyList + "]");
+										}
 										if (topologyName != null) {
 											if (topologyNameMatching == null || topologyNameMatching.isEmpty() || FilenameUtils.wildcardMatch(topology.getName(), topologyNameMatching + "*")) {
-												LOG.debug("getTopologyList():Adding topology " + topologyName);
-												lret.add(topologyName) ;
+												if (LOG.isDebugEnabled()) {
+													LOG.debug("getTopologyList():Adding topology " + topologyName);
+												}
+												lret.add(topologyName);
 											}
 										}
 									}
 								}
 							}
-						} else{
-							LOG.info("getTopologyList():response.getStatus()= " + response.getStatus() + " for URL " + url + ", so returning null list");	
-							String jsonString = response.getEntity(String.class);
-							LOG.info(jsonString);
-							lret = null;
 						}
 					} else {
-						String msgDesc = "Unable to get a valid response for "
-								+ "expected mime type : [" + EXPECTED_MIME_TYPE
-								+ "] URL : " + url + " - got null response.";
+						String msgDesc = "Unable to get a valid response for " + "expected mime type : ["
+								+ EXPECTED_MIME_TYPE + "] URL : " + stormUIUrl + " - got null response.";
 						LOG.error(msgDesc);
 						HadoopException hdpException = new HadoopException(msgDesc);
-						hdpException.generateResponseDataMap(false, msgDesc,
-								msgDesc + errMsg, null, null);
+						hdpException.generateResponseDataMap(false, msgDesc, msgDesc + errMsg, null, null);
 						throw hdpException;
 					}
 				} catch (HadoopException he) {
 					throw he;
 				} catch (Throwable t) {
-					String msgDesc = "Exception while getting Storm TopologyList."
-							+ " URL : " + url;
-					HadoopException hdpException = new HadoopException(msgDesc,
-							t);
+					String msgDesc = "Exception while getting Storm TopologyList." + " URL : " + stormUIUrl;
+					HadoopException hdpException = new HadoopException(msgDesc, t);
 					LOG.error(msgDesc, t);
 
-					hdpException.generateResponseDataMap(false,
-							BaseClient.getMessage(t), msgDesc + errMsg, null,
-							null);
+					hdpException.generateResponseDataMap(false, BaseClient.getMessage(t), msgDesc + errMsg, null, null);
 					throw hdpException;
-					
 				} finally {
 					if (response != null) {
 						response.close();
 					}
-					
+
 					if (client != null) {
-						client.destroy(); 
+						client.destroy();
 					}
-				
 				}
-				return lret ;
+				return lret;
 			}
-		} ;
-		
+
+			private ClientResponse getTopologyResponse(String url, Client client) {
+				if (LOG.isDebugEnabled()) {
+					LOG.debug("getTopologyResponse():calling " + url);
+				}
+
+				WebResource webResource = client.resource(url);
+
+				ClientResponse response = webResource.accept(EXPECTED_MIME_TYPE).get(ClientResponse.class);
+
+				if (response != null) {
+					if (LOG.isDebugEnabled()) {
+						LOG.debug("getTopologyResponse():response.getStatus()= " + response.getStatus());
+					}
+					if (response.getStatus() != 200) {
+						LOG.info("getTopologyResponse():response.getStatus()= " + response.getStatus() + " for URL "
+								+ url + ", failed to get topology list");
+						String jsonString = response.getEntity(String.class);
+						LOG.info(jsonString);
+					}
+				}
+				return response;
+			}
+		};
+
+		List<String> ret = null;
 		try {
-			ret = executeUnderKerberos(this.userName, this.password, this.lookupPrincipal, this.lookupKeytab, this.nameRules, topologyListGetter) ;
+			ret = executeUnderKerberos(this.userName, this.password, this.lookupPrincipal, this.lookupKeytab, this.nameRules, topologyListGetter);
 		} catch (IOException e) {
-			LOG.error("Unable to get Topology list from [" + stormUIUrl + "]", e) ;
+			LOG.error("Unable to get Topology list from [" + stormUIUrl + "]", e);
 		}
-		
+
 		return ret;
 	}
 	
@@ -197,7 +232,7 @@ public class StormClient {
 				javax.security.auth.login.Configuration {
 
 			private String userName;
-			private String password ;
+			private String password;
 
 			MySecureClientLoginConfiguration(String aUserName,
 					String password) {
@@ -241,7 +276,7 @@ public class StormClient {
 							null);
 					throw hdpException;
 				}
-                
+
 				LOG.debug("getAppConfigurationEntry():" + kerberosOptions.get("principal"));
 				
                 return new AppConfigurationEntry[] { KERBEROS_PWD_SAVER, KEYTAB_KERBEROS_LOGIN };
@@ -313,12 +348,12 @@ public class StormClient {
 		return ret;
 	}
 
-	public static HashMap<String, Object> connectionTest(String serviceName,
+	public static Map<String, Object> connectionTest(String serviceName,
 			Map<String, String> configs) {
 
 		String errMsg = errMessage;
 		boolean connectivityStatus = false;
-		HashMap<String, Object> responseData = new HashMap<String, Object>();
+		Map<String, Object> responseData = new HashMap<String, Object>();
 
 		StormClient stormClient = getStormClient(serviceName,
 				configs);
