@@ -23,6 +23,7 @@ import org.apache.atlas.AtlasException;
 import org.apache.atlas.notification.entity.EntityNotification;
 import org.apache.atlas.typesystem.IReferenceableInstance;
 import org.apache.atlas.typesystem.IStruct;
+import org.apache.atlas.typesystem.persistence.Id;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
@@ -84,12 +85,17 @@ public class AtlasNotificationMapper {
 				IReferenceableInstance entity = entityNotification.getEntity();
 
 				if (entity != null && AtlasResourceMapperUtil.isEntityTypeHandled(entity.getTypeName())) {
-					AtlasEntityWithTraits entityWithTraits = new AtlasEntityWithTraits(entityNotification.getEntity(), entityNotification.getAllTraits());
+					AtlasEntityWithTraits entityWithTraits = new AtlasEntityWithTraits(entity, entityNotification.getAllTraits());
 					if (entityNotification.getOperationType() == EntityNotification.OperationType.ENTITY_DELETE) {
-						// Special case for ENTITY_DELETE notifications
 						ret = buildServiceTagsForEntityDeleteNotification(entityWithTraits);
 					} else {
-						ret = buildServiceTags(entityWithTraits, null);
+						if (entity.getId().getState() == Id.EntityState.ACTIVE) {
+							ret = buildServiceTags(entityWithTraits, null);
+						} else {
+							if (LOG.isDebugEnabled()) {
+								LOG.debug("Ignoring entityNotification for entity that is not ACTIVE: " + entityWithTraits);
+							}
+						}
 					}
 				} else {
 					logUnhandledEntityNotification(entityNotification);
@@ -102,7 +108,7 @@ public class AtlasNotificationMapper {
 		return ret;
 	}
 
-	public static Map<String, ServiceTags> processEntitiesWithTraits(List<AtlasEntityWithTraits> atlasEntities) {
+	public static Map<String, ServiceTags> processAtlasEntities(List<AtlasEntityWithTraits> atlasEntities) {
 		Map<String, ServiceTags> ret = null;
 
 		try {
@@ -173,7 +179,14 @@ public class AtlasNotificationMapper {
 		Map<String, ServiceTags> ret = new HashMap<String, ServiceTags>();
 
 		for (AtlasEntityWithTraits element : entitiesWithTraits) {
-			buildServiceTags(element, ret);
+			IReferenceableInstance entity = element.getEntity();
+			if (entity != null && entity.getId().getState() == Id.EntityState.ACTIVE) {
+				buildServiceTags(element, ret);
+			} else {
+				if (LOG.isDebugEnabled()) {
+					LOG.debug("Ignoring entity because its State is not ACTIVE: " + element);
+				}
+			}
 		}
 
 		// Remove duplicate tag definitions
@@ -232,32 +245,40 @@ public class AtlasNotificationMapper {
 		RangerServiceResource  serviceResource = AtlasResourceMapperUtil.getRangerServiceResource(entity);
 
 		if (serviceResource != null) {
-			List<RangerTag>    tags    = getTags(entityWithTraits);
-			List<RangerTagDef> tagDefs = getTagDefs(entityWithTraits);
 
-			String serviceName = serviceResource.getServiceName();
+			List<RangerTag>     tags        = getTags(entityWithTraits);
+			List<RangerTagDef>  tagDefs     = getTagDefs(entityWithTraits);
+			String              serviceName = serviceResource.getServiceName();
 
 			ret = createOrGetServiceTags(serviceTagsMap, serviceName);
 
-			serviceResource.setId((long)ret.getServiceResources().size());
-			ret.getServiceResources().add(serviceResource);
+			if (serviceTagsMap == null || CollectionUtils.isNotEmpty(tags)) {
 
-			List<Long> tagIds = new ArrayList<Long>();
+				serviceResource.setId((long) ret.getServiceResources().size());
+				ret.getServiceResources().add(serviceResource);
 
-			if(CollectionUtils.isNotEmpty(tags)) {
-				for(RangerTag tag : tags) {
-					tag.setId((long)ret.getTags().size());
-					ret.getTags().put(tag.getId(), tag);
+				List<Long> tagIds = new ArrayList<Long>();
 
-					tagIds.add(tag.getId());
+				if (CollectionUtils.isNotEmpty(tags)) {
+					for (RangerTag tag : tags) {
+						tag.setId((long) ret.getTags().size());
+						ret.getTags().put(tag.getId(), tag);
+
+						tagIds.add(tag.getId());
+					}
 				}
-			}
-			ret.getResourceToTagIds().put(serviceResource.getId(), tagIds);
+				ret.getResourceToTagIds().put(serviceResource.getId(), tagIds);
 
-			if(CollectionUtils.isNotEmpty(tagDefs)) {
-				for(RangerTagDef tagDef : tagDefs) {
-					tagDef.setId((long)ret.getTagDefinitions().size());
-					ret.getTagDefinitions().put(tagDef.getId(), tagDef);
+				if (CollectionUtils.isNotEmpty(tagDefs)) {
+					for (RangerTagDef tagDef : tagDefs) {
+						tagDef.setId((long) ret.getTagDefinitions().size());
+						ret.getTagDefinitions().put(tagDef.getId(), tagDef);
+					}
+				}
+			} else {
+				if (LOG.isDebugEnabled()) {
+					LOG.debug("Entity " + entityWithTraits + " does not have any tags associated with it when full-sync is being done.");
+					LOG.debug("Will not add this entity to serviceTags, so that this entity, if exists,  will be removed from ranger");
 				}
 			}
 		} else {
