@@ -75,7 +75,7 @@ public class AtlasResourceMapperUtil {
 	}
 
 	static public boolean initializeAtlasResourceMappers(Properties properties) {
-		final String MAPPER_NAME_DELIMIER = ",";
+		final String MAPPER_NAME_DELIMITER = ",";
 
 		String customMapperNames = TagSyncConfig.getCustomAtlasResourceMappers(properties);
 
@@ -84,20 +84,21 @@ public class AtlasResourceMapperUtil {
 		}
 		boolean ret = true;
 
-		String allResourceMappers = "org.apache.ranger.tagsync.source.atlas.AtlasHiveResourceMapper";
+		List<String> mapperNames = new ArrayList<String>();
+		mapperNames.add("org.apache.ranger.tagsync.source.atlas.AtlasHiveResourceMapper");
+		mapperNames.add("org.apache.ranger.tagsync.source.atlas.AtlasHdfsResourceMapper");
+		mapperNames.add("org.apache.ranger.tagsync.source.atlas.AtlasHbaseResourceMapper");
+		mapperNames.add("org.apache.ranger.tagsync.source.atlas.AtlasKafkaResourceMapper");
 
 		if (StringUtils.isNotBlank(customMapperNames)) {
-			allResourceMappers = allResourceMappers + MAPPER_NAME_DELIMIER + customMapperNames;
+			for (String customMapperName : customMapperNames.split(MAPPER_NAME_DELIMITER)) {
+				mapperNames.add(customMapperName.trim());
+			}
 		}
 
-		String[] mapperNamesArray = allResourceMappers.split(MAPPER_NAME_DELIMIER);
-
-		List<String> mapperNames = Arrays.asList(mapperNamesArray);
-
 		for (String mapperName : mapperNames) {
-			mapperName = mapperName.trim();
 			try {
-				Class clazz = Class.forName(mapperName);
+				Class<?> clazz = Class.forName(mapperName);
 				AtlasResourceMapper resourceMapper = (AtlasResourceMapper) clazz.newInstance();
 
 				resourceMapper.initialize(properties);
@@ -113,7 +114,7 @@ public class AtlasResourceMapperUtil {
 		}
 
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("<== initializeAtlasResourceMappers.initializeAtlasResourceMappers(" + allResourceMappers + "): " + ret);
+			LOG.debug("<== initializeAtlasResourceMappers.initializeAtlasResourceMappers(" + mapperNames + "): " + ret);
 		}
 		return ret;
 	}
