@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -194,16 +194,16 @@ public class AtlasRESTTagSource extends AbstractTagSource implements Runnable {
 
 	public void synchUp() {
 
-		List<AtlasEntityWithTraits> atlasEntitiesWithTraits = atlasRESTUtil.getEntitiesWithTraits();
+		List<AtlasEntityWithTraits> atlasEntities = atlasRESTUtil.getAtlasEntities();
 
-		if (CollectionUtils.isNotEmpty(atlasEntitiesWithTraits)) {
+		if (CollectionUtils.isNotEmpty(atlasEntities)) {
 			if (LOG.isDebugEnabled()) {
-				for (AtlasEntityWithTraits element : atlasEntitiesWithTraits) {
+				for (AtlasEntityWithTraits element : atlasEntities) {
 					LOG.debug(element);
 				}
 			}
 
-			Map<String, ServiceTags> serviceTagsMap = AtlasNotificationMapper.processEntitiesWithTraits(atlasEntitiesWithTraits);
+			Map<String, ServiceTags> serviceTagsMap = AtlasNotificationMapper.processAtlasEntities(atlasEntities);
 
 			if (MapUtils.isNotEmpty(serviceTagsMap)) {
 				for (Map.Entry<String, ServiceTags> entry : serviceTagsMap.entrySet()) {
