@@ -19,6 +19,7 @@ import StringIO
 import xml.etree.ElementTree as ET
 import ConfigParser
 import os,errno,sys,getopt
+import sys
 from os import listdir
 from os.path import isfile, join, dirname, basename
 from urlparse import urlparse
@@ -35,7 +36,6 @@ if (not 'JAVA_HOME' in os.environ):
 debugLevel = 1
 generateXML = 0
 installPropDirName = '.'
-pidFolderName = '/var/run/ranger'
 #logFolderName = '/var/log/ranger'
 initdDirName = '/etc/init.d'
 
@@ -61,13 +61,11 @@ installTemplateDirName = join(installPropDirName,'templates')
 confDistDirName = join(installPropDirName, confDistBaseDirName)
 #ugsyncLogFolderName = join(logFolderName, 'usersync')
 nativeAuthFolderName = join(installPropDirName, 'native')
+localConfFolderName = join(installPropDirName, confBaseDirName)
+
 nativeAuthProgramName = join(nativeAuthFolderName, 'credValidator.uexe')
 pamAuthProgramName = join(nativeAuthFolderName, 'pamCredValidator.uexe')
-usersyncBaseDirFullName = join(rangerBaseDirName, usersyncBaseDirName)
-confFolderName = join(usersyncBaseDirFullName, confBaseDirName)
-localConfFolderName = join(installPropDirName, confBaseDirName)
-certFolderName = join(confFolderName, certBaseDirName)
-defaultKSFileName = join(certFolderName, defaultCertFileName)
+
 defaultKSPassword = 'UnIx529p'
 defaultDNAME = 'cn=unixauthservice,ou=authenticator,o=mycompany,c=US'
 
@@ -85,11 +83,10 @@ SYNC_SOURCE_LDAP = 'ldap'
 SYNC_SOURCE_LIST = [ SYNC_SOURCE_UNIX, SYNC_SOURCE_LDAP ]
 SYNC_LDAP_BIND_PASSWORD_KEY  = 'ranger.usersync.ldap.ldapbindpassword'
 credUpdateClassName =  'org.apache.ranger.credentialapi.buildks'
-#credUpdateClassName =  'com.hortonworks.credentialapi.buildks'
 ENV_LOGDIR_FILE = 'ranger-usersync-env-logdir.sh'
 hadoopConfFileName = 'core-site.xml'
 ENV_HADOOP_CONF_FILE = "ranger-usersync-env-hadoopconfdir.sh"
-
+ENV_PID_FILE = 'ranger-usersync-env-piddir.sh'
 
 RANGER_USERSYNC_HOME = os.getenv("RANGER_USERSYNC_HOME")
 if RANGER_USERSYNC_HOME is None:
@@ -99,9 +96,13 @@ def populate_global_dict():
     global globalDict
     read_config_file = open(os.path.join(RANGER_USERSYNC_HOME,'install.properties'))
     for each_line in read_config_file.read().split('\n') :
-        if len(each_line) == 0 : continue
+        each_line = each_line.strip()
+        if len(each_line) == 0:
+            continue
+        elif each_line[0] == "#":
+            continue
         if re.search('=', each_line):
-            key , value = each_line.strip().split("=",1)
+            key , value = each_line.split("=",1)
             key = key.strip()
             if 'PASSWORD' in key:
                 jceks_file_path = os.path.join(RANGER_USERSYNC_HOME, 'jceks','ranger_db.jceks')
@@ -109,6 +110,25 @@ def populate_global_dict():
             value = value.strip()
             globalDict[key] = value
 
+def initvariable():
+	global usersyncBaseDirFullName
+	global confFolderName
+	global certFolderName
+	global defaultKSFileName
+	global rangerBaseDirName
+	try:
+		ranger_base_dir = globalDict['ranger_base_dir']
+		if (len(ranger_base_dir.strip())>1):
+			rangerBaseDirName = ranger_base_dir
+	except:
+		info = sys.exc_info()
+		print info[0], ":",info[1]
+
+	usersyncBaseDirFullName = join(rangerBaseDirName, usersyncBaseDirName)
+	confFolderName = join(usersyncBaseDirFullName, confBaseDirName)
+	certFolderName = join(confFolderName, certBaseDirName)
+	defaultKSFileName = join(certFolderName, defaultCertFileName)
+
 def archiveFile(originalFileName):
     archiveDir = dirname(originalFileName)
     archiveFileName = "." + basename(originalFileName) + "." + (strftime("%d%m%Y%H%M%S", localtime()))
@@ -225,6 +245,7 @@ def convertInstallPropsToXML(props):
 			#	if (key.startswith("ranger.usersync.ldap") or key.startswith("ranger.usersync.group") or key.startswith("ranger.usersync.paged")):
 			#		del ret[key]
 		elif (syncSource == SYNC_SOURCE_LDAP):
+			ret['ranger.usersync.ldap.deltasync'] = "true"
 			ldapPass=ret[SYNC_LDAP_BIND_PASSWORD_KEY]
 			password_validation(ldapPass, SYNC_LDAP_BIND_PASSWORD_KEY)
 			ret['ranger.usersync.source.impl.class'] = 'org.apache.ranger.ldapusersync.process.LdapUserGroupBuilder'
@@ -294,12 +315,12 @@ def initializeInitD(ownerName):
 					if isfile(scriptName) or os.path.islink(scriptName):
 						os.remove(scriptName)
 					os.symlink(initdFn,scriptName)
-			userSyncScriptName = "ranger-usersync-services.sh"
-			localScriptName = os.path.abspath(join(installPropDirName,userSyncScriptName))
-			ubinScriptName = join("/usr/bin",initdProgramName)
-			if isfile(ubinScriptName) or os.path.islink(ubinScriptName):
-				os.remove(ubinScriptName)
-			os.symlink(localScriptName,ubinScriptName)
+		userSyncScriptName = "ranger-usersync-services.sh"
+		localScriptName = os.path.abspath(join(installPropDirName,userSyncScriptName))
+		ubinScriptName = join("/usr/bin",initdProgramName)
+		if isfile(ubinScriptName) or os.path.islink(ubinScriptName):
+			os.remove(ubinScriptName)
+		os.symlink(localScriptName,ubinScriptName)
 
 
 def createJavaKeystoreForSSL(fn,passwd):
@@ -321,14 +342,20 @@ def write_env_files(exp_var_name, log_path, file_name):
 def main():
 
 	populate_global_dict()
+	initvariable()
 	logFolderName = globalDict['logdir']
 	hadoop_conf = globalDict['hadoop_conf']
+        pid_dir_path = globalDict['USERSYNC_PID_DIR_PATH']
+        unix_user = globalDict['unix_user']
+
+        if pid_dir_path == "":
+                pid_dir_path = "/var/run/ranger"
 
 	if logFolderName.lower() == "$pwd" or logFolderName == "" :
                 logFolderName = os.path.join(os.getcwd(),"logs")
 	ugsyncLogFolderName = logFolderName
 
-	dirList = [ rangerBaseDirName, usersyncBaseDirName, confFolderName, certFolderName ]
+	dirList = [ rangerBaseDirName, usersyncBaseDirFullName, confFolderName, certFolderName ]
 	for dir in dirList:
 		if (not os.path.isdir(dir)):
 			os.makedirs(dir,0750)
@@ -395,12 +422,12 @@ def main():
 	else:
 		os.makedirs(logFolderName,logFolderPermMode)
 
-	if (not os.path.isdir(pidFolderName)):
-		os.makedirs(pidFolderName,logFolderPermMode)
-
 	if (not os.path.isdir(ugsyncLogFolderName)):
 		os.makedirs(ugsyncLogFolderName,logFolderPermMode)
 
+        if (not os.path.isdir(pid_dir_path)):
+                os.makedirs(pid_dir_path,logFolderPermMode)
+
 	if (unixUserProp in mergeProps):
 		ownerName = mergeProps[unixUserProp]
 	else:
@@ -425,7 +452,6 @@ def main():
 
 	os.chown(logFolderName,ownerId,groupId)
 	os.chown(ugsyncLogFolderName,ownerId,groupId)
-	os.chown(pidFolderName,ownerId,groupId)
 	os.chown(rangerBaseDirName,ownerId,groupId)
 	os.chown(usersyncBaseDirFullName,ownerId,groupId)
 
@@ -469,7 +495,7 @@ def main():
 
 	writeXMLUsingProperties(fn, mergeProps, outfn)
 
-	fixPermList = [ ".", usersyncBaseDirName, confFolderName, certFolderName ]
+	fixPermList = [ ".", usersyncBaseDirFullName, confFolderName, certFolderName ]
 
 	for dir in fixPermList:
 		for root, dirs, files in os.walk(dir):
@@ -498,10 +524,17 @@ def main():
 
         write_env_files("logdir", logFolderName, ENV_LOGDIR_FILE);
         write_env_files("RANGER_USERSYNC_HADOOP_CONF_DIR", hadoop_conf, ENV_HADOOP_CONF_FILE);
+        write_env_files("USERSYNC_PID_DIR_PATH", pid_dir_path, ENV_PID_FILE);
         os.chown(os.path.join(confBaseDirName, ENV_LOGDIR_FILE),ownerId,groupId)
         os.chmod(os.path.join(confBaseDirName, ENV_LOGDIR_FILE),0755)
         os.chown(os.path.join(confBaseDirName, ENV_HADOOP_CONF_FILE),ownerId,groupId)
         os.chmod(os.path.join(confBaseDirName, ENV_HADOOP_CONF_FILE),0755)
+        os.chown(os.path.join(confBaseDirName, ENV_PID_FILE),ownerId,groupId)
+        os.chmod(os.path.join(confBaseDirName, ENV_PID_FILE),0755)
+
+        f = open(os.path.join(confBaseDirName, ENV_PID_FILE), "a+")
+        f.write("\nexport {0}={1}".format("UNIX_USERSYNC_USER",unix_user))
+        f.close()
 
         hadoop_conf_full_path = os.path.join(hadoop_conf, hadoopConfFileName)
 	usersync_conf_full_path = os.path.join(usersyncBaseDirFullName,confBaseDirName,hadoopConfFileName)
@@ -516,7 +549,7 @@ def main():
                 if os.path.islink(usersync_conf_full_path):
                         os.remove(usersync_conf_full_path)
 
-	if isfile(hadoop_conf_full_path):
+	if isfile(hadoop_conf_full_path) and not isfile(usersync_conf_full_path):
         	os.symlink(hadoop_conf_full_path, usersync_conf_full_path)
 
 main()
