@@ -14,9 +14,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-if [ "${JAVA_HOME}" != "" ]
+if [ "${JAVA_HOME}" == "" ]
 then
+	echo "JAVA_HOME environment property not defined, aborting installation."
+	exit 1
+elif [ ! -d "${JAVA_HOME}" ]
+then
+	echo "JAVA_HOME environment property was set incorrectly, aborting installation."
+	exit 1
+else
 	export JAVA_HOME
 	PATH="${JAVA_HOME}/bin:${PATH}"
 	export PATH
